
/*
	GoToSocial
	Copyright (C) 2021-2023 GoToSocial Authors admin@gotosocial.org

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU Affero General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU Affero General Public License for more details.

	You should have received a copy of the GNU Affero General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

header a {
	margin: 2rem;
	gap: 2rem;
}

header a img {
		height: 6rem;
	}

header a h1 {
		font-size: 2rem;
	}

main section {
		background: var(--bg-accent);
		box-shadow: var(--boxshadow);
		border: var(--boxshadow-border);
		border-radius: var(--br);
		padding: 2rem;
		margin-bottom: 2rem;
	}
