
:root {
	--br: 0.4rem;
	--br-inner: 0.2rem;
	--fa-fw: 1.28571429em;
}

/*
	GoToSocial
	Copyright (C) 2021-2023 GoToSocial Authors admin@gotosocial.org

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU Affero General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU Affero General Public License for more details.

	You should have received a copy of the GNU Affero General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/*! modern-normalize v1.1.0 | MIT License | https://github.com/sindresorhus/modern-normalize */

/*
Document
========
*/

/**
Use a better box model (opinionated).
*/

*,
::before,
::after {
	box-sizing: border-box;
}

/**
Use a more readable tab size (opinionated).
*/

html {
	-o-tab-size: 4;
	   tab-size: 4;
}

/**
1. Correct the line height in all browsers.
2. Prevent adjustments of font size after orientation changes in iOS.
*/

html {
	line-height: 1.15; /* 1 */
	-webkit-text-size-adjust: 100%; /* 2 */
}

/*
Sections
========
*/

/**
Remove the margin in all browsers.
*/

body {
	margin: 0;
}

/**
Improve consistency of default fonts in all browsers. (https://github.com/sindresorhus/modern-normalize/issues/3)
*/

body {
	font-family:
		system-ui,
		-apple-system, /* Firefox supports this but not yet `system-ui` */
		'Segoe UI',
		Roboto,
		Helvetica,
		Arial,
		sans-serif,
		'Apple Color Emoji',
		'Segoe UI Emoji';
}

/*
Grouping content
================
*/

/**
1. Add the correct height in Firefox.
2. Correct the inheritance of border color in Firefox. (https://bugzilla.mozilla.org/show_bug.cgi?id=190655)
*/

hr {
	height: 0; /* 1 */
	color: inherit; /* 2 */
}

/*
Text-level semantics
====================
*/

/**
Add the correct text decoration in Chrome, Edge, and Safari.
*/

abbr[title] {
	-webkit-text-decoration: underline dotted;
	        text-decoration: underline dotted;
}

/**
Add the correct font weight in Edge and Safari.
*/

b,
strong {
	font-weight: bolder;
}

/**
1. Improve consistency of default fonts in all browsers. (https://github.com/sindresorhus/modern-normalize/issues/3)
2. Correct the odd 'em' font sizing in all browsers.
*/

code,
kbd,
samp,
pre {
	font-family:
		ui-monospace,
		SFMono-Regular,
		Consolas,
		'Liberation Mono',
		Menlo,
		monospace; /* 1 */
	font-size: 1em; /* 2 */
}

/**
Add the correct font size in all browsers.
*/

small {
	font-size: 80%;
}

/**
Prevent 'sub' and 'sup' elements from affecting the line height in all browsers.
*/

sub,
sup {
	font-size: 75%;
	line-height: 0;
	position: relative;
	vertical-align: baseline;
}

sub {
	bottom: -0.25em;
}

sup {
	top: -0.5em;
}

/*
Tabular data
============
*/

/**
1. Remove text indentation from table contents in Chrome and Safari. (https://bugs.chromium.org/p/chromium/issues/detail?id=999088, https://bugs.webkit.org/show_bug.cgi?id=201297)
2. Correct table border color inheritance in all Chrome and Safari. (https://bugs.chromium.org/p/chromium/issues/detail?id=935729, https://bugs.webkit.org/show_bug.cgi?id=195016)
*/

table {
	text-indent: 0; /* 1 */
	border-color: inherit; /* 2 */
}

/*
Forms
=====
*/

/**
1. Change the font styles in all browsers.
2. Remove the margin in Firefox and Safari.
*/

button,
input,
optgroup,
select,
textarea {
	font-family: inherit; /* 1 */
	font-size: 100%; /* 1 */
	line-height: 1.15; /* 1 */
	margin: 0; /* 2 */
}

/**
Remove the inheritance of text transform in Edge and Firefox.
1. Remove the inheritance of text transform in Firefox.
*/

button,
select { /* 1 */
	text-transform: none;
}

/**
Correct the inability to style clickable types in iOS and Safari.
*/

button,
[type='button'],
[type='reset'],
[type='submit'] {
	-webkit-appearance: button;
}

/**
Remove the inner border and padding in Firefox.
*/

::-moz-focus-inner {
	border-style: none;
	padding: 0;
}

/**
Restore the focus styles unset by the previous rule.
*/

:-moz-focusring {
	outline: 1px dotted ButtonText;
}

/**
Remove the additional ':invalid' styles in Firefox.
See: https://github.com/mozilla/gecko-dev/blob/2f9eacd9d3d995c937b4251a5557d95d494c9be1/layout/style/res/forms.css#L728-L737
*/

:-moz-ui-invalid {
	box-shadow: none;
}

/**
Remove the padding so developers are not caught out when they zero out 'fieldset' elements in all browsers.
*/

legend {
	padding: 0;
}

/**
Add the correct vertical alignment in Chrome and Firefox.
*/

progress {
	vertical-align: baseline;
}

/**
Correct the cursor style of increment and decrement buttons in Safari.
*/

::-webkit-inner-spin-button,
::-webkit-outer-spin-button {
	height: auto;
}

/**
1. Correct the odd appearance in Chrome and Safari.
2. Correct the outline style in Safari.
*/

[type='search'] {
	-webkit-appearance: textfield; /* 1 */
	outline-offset: -2px; /* 2 */
}

/**
Remove the inner padding in Chrome and Safari on macOS.
*/

::-webkit-search-decoration {
	-webkit-appearance: none;
}

/**
1. Correct the inability to style clickable types in iOS and Safari.
2. Change font properties to 'inherit' in Safari.
*/

::-webkit-file-upload-button {
	-webkit-appearance: button; /* 1 */
	font: inherit; /* 2 */
}

/*
Interactive
===========
*/

/*
Add the correct display in Chrome and Safari.
*/

summary {
	display: list-item;
}

/* noto-sans-regular - latin */

@font-face {
  font-family: "Noto Sans";
  font-weight: 400;
  font-display: swap;
  font-style: normal;
  src: url('../fonts/noto-sans-v27-latin-regular.woff2') format('woff2'),
       url('../fonts/noto-sans-v27-latin-regular.woff') format('woff');
}

/* noto-sans-700 - latin */

@font-face {
  font-family: "Noto Sans";
  font-weight: 700;
  font-display: swap;
  font-style: normal;
  src: url('../fonts/noto-sans-v27-latin-700.woff2') format('woff2'),
       url('../fonts/noto-sans-v27-latin-700.woff') format('woff');
}

/* standard border radius for nice squircles */

/* border radius for items that are framed/bordered
   inside something with $br, eg avatar, header img */

/* Fork-Awesome 'fa-fw' fixed icon width 
   keep in sync with https://github.com/ForkAwesome/Fork-Awesome/blob/a99579ae3e735ee70e51ed62dfcee3172b5b2db7/css/fork-awesome.css#L50
*/

html, body {
	padding: 0;
	margin: 0;
	background: var(--bg);
	color: var(--fg);
	font-family: "Noto Sans", sans-serif;
	scrollbar-color: var(--orange1) var(--gray3);
}

body {
	line-height: 1.5em;
	position: relative;
}

.hidden {
	display: none;
}

.page {
	display: grid;
	min-height: 100vh;

	grid-template-columns: 1fr minmax(auto, 50rem) 1fr;
	grid-template-columns: 1fr min(92%, 50rem) 1fr;
	grid-template-rows: auto 1fr auto;
}

h1 {
	margin: 0;
	line-height: 2.4rem;
}

a {
	color: var(--link-fg);
}

header, footer {
	grid-column: 1 / span 3;
}

.content {
	grid-column: 2;
	align-self: start;
}

header {
	display: flex;
	justify-content: center;
}

header a {
	display: flex;
	flex-wrap: wrap;
	margin: 1.5rem;
	gap: 1rem;
	justify-content: center;
}

header a img {
		align-self: center;
		height: 3rem;
	}

header a h1 {
		flex-grow: 1;
		align-self: center;
		text-align: center;

		font-size: 1.5rem;
		word-wrap: anywhere;
		color: var(--fg);
	}

.excerpt-top {
	margin-bottom: 2rem;
	font-style: italic;
	font-weight: normal;
	text-align: center;
	font-size: 1.2rem;
}

.excerpt-top .count {
		font-weight: bold;
		color: var(--fg-accent);
	}

main p:first-child {
		margin-top: 0;
	}

main p:last-child {
		margin-bottom: 0;
	}

.button, button {
	border-radius: 0.2rem;
	color: var(--button-fg);
	background: var(--button-bg);
	box-shadow: var(--boxshadow);
	border: var(--button-border);
	text-decoration: none;
	font-size: 1.2rem;
	font-weight: bold;
	padding: 0.5rem;
	border: none;
	cursor: pointer;
	text-align: center;
	font-family: 'Noto Sans', sans-serif;
}

.button.danger, button.danger {
		color: var(--button-danger-fg);
		background: var(--button-danger-bg);
	}

.button.danger:hover, button.danger:hover {
			background: var(--button-danger-hover-bg);
		}

.button:disabled, button:disabled {
		color: var(--white2);
		background: var(--gray2);
		cursor: auto;
	}

.button:disabled:hover, button:disabled:hover {
			background: var(--gray3);
		}

.button:hover, button:hover {
		background: var(--button-hover-bg);
	}

.nounderline {
	text-decoration: none;
}

.accent {
	color: var(--acc1);
}

.logo {
	justify-self: center;
}

.logo img {
		height: 30vh;
	}

section.apps {
	align-self: start;
}

section.apps .applist {
		display: grid;
		grid-template-columns: 1fr 1fr;
		grid-gap: 0.5rem;
		align-content: start;
	}

section.apps .applist .entry {
			display: grid;
			grid-template-columns: 25% 1fr;
			gap: 1.5rem;
			padding: 0.5rem;
			background: var(--bg-accent);
			border-radius: 0.5rem;
		}

section.apps .applist .entry .logo {
				align-self: center;
				width: 100%;
				-o-object-fit: contain;
				   object-fit: contain;
				flex: 1 1 auto;
			}

section.apps .applist .entry .logo.redraw {
				fill: var(--fg);
				stroke: var(--fg);
			}

section.apps .applist .entry a {
				font-weight: bold;
			}

section.apps .applist .entry div {
				padding: 0;
			}

section.apps .applist .entry div h3 {
					margin-top: 0;
				}

section.login form {
		display: flex;
		flex-direction: column;
		gap: 1rem;


		padding-bottom: 1rem;
		padding-top: 1rem;
	}

section.login form label, section.login form input {
			padding-left: 0.2rem;
		}

section.login form .labelinput {
			display: flex;
			flex-direction: column;
			gap: 0.4rem;
		}

section.login form .btn {
			margin-top: 1rem;
		}

section.error {
	word-break: break-word;
	margin-bottom: 0.5rem;
}

section.error pre {
		border: 1px solid #ff000080;
		padding: 0.5rem;
		border-radius: 0.5em;
		background-color: #ff000010;
		font-size: 1.3em;
		white-space: pre-wrap;
	}

section.oob-token code {
		background: var(--gray1);
		padding: 0.5rem;
		margin: 0;
		border-radius: 0.3rem;
	}

.error-text {
	color: var(--error1);
	background: var(--error2);
	border-radius: 0.1rem;
	font-weight: bold;
}

input, select, textarea, .input {
	box-sizing: border-box;
	border: 0.15rem solid var(--input-border);
	border-radius: 0.1rem;
	color: var(--fg);
	background: var(--input-bg);
	width: 100%;
	font-family: 'Noto Sans', sans-serif;
	font-size: 1rem;
	padding: 0.3rem;
}

input:focus, input:active, select:focus, select:active, textarea:focus, textarea:active, .input:focus, .input:active {
		border-color: var(--input-focus-border);
	}

input:invalid, .invalid input, select:invalid, .invalid select, textarea:invalid, .invalid textarea, .input:invalid, .invalid .input {
		border-color: var(--input-error-border);
	}

input:disabled, select:disabled, textarea:disabled, .input:disabled {
		background: transparent;
	}

::placeholder {
	opacity: 1;
	color: var(--fg-reduced)
}

hr {
	color: transparent;
	width: 100%;
	border-bottom: 0.02rem solid var(--border-accent);
}

footer {
	align-self: end;
	padding: 2rem 0 1rem 0;

	display: flex;
	flex-wrap: wrap;
	justify-content: center;
}

footer div {
		text-align: center;
		padding: 1rem;
		flex-grow: 1;
	}

footer a {
		font-weight: bold;
	}

@media screen and (max-width: 600px) {
	header {
		text-align: center;
	}

	footer {
		grid-template-columns: 1fr;
	}

		footer div {
			text-align: initial;
			width: 100%;
		}

	section.apps .applist {
		grid-template-columns: 1fr;
	}
}

.emoji {
	width: 1.45em;
	height: 1.45em;
	margin: -0.2em 0.02em 0;
	-o-object-fit: contain;
	   object-fit: contain;
	vertical-align: middle;
}

.monospace {
	font-family: monospace;
}

.callout {
	margin: 1.5rem 0;
	border: .05rem solid var(--border-accent);
	border-radius: .2rem;
	padding: 0 .6rem .6rem;
}

.callout .callout-title {
		margin: 0 -.6rem;
		padding: .6rem;
		font-weight: bold;
		background-color: var(--border-accent);
		color: var(--gray1);
	}

label {
	cursor: pointer;
}

@media (prefers-reduced-motion) {
	.fa-spin {
		animation: none;
	}
}

.text-cutoff {
	text-overflow: ellipsis;
	overflow: hidden;
	white-space: nowrap;
}

.list {
	display: flex;
	flex-direction: column;
}

.list .header, .list .entry {
		padding: 0.5rem;
	}

.list .header {
		border: 0.1rem solid transparent !important; /* for alignment with .entry border padding */
		background: var(--gray1) !important;
		display: flex;
		font-weight: bold;
	}

.list .entries {
		display: flex;
		flex-direction: column;
	}

.list .entries.scrolling {
			height: 20rem;
			max-height: 20rem;
			overflow: auto;
		}

.list input[type=checkbox] {
		margin-left: 0.5rem;
	}

.list .entry {
		display: flex;
		flex-wrap: wrap;
		background: var(--list-entry-bg);
		border: 0.1rem solid transparent;
	}

.list .entry:nth-child(even) {
			background: var(--list-entry-alternate-bg);
		}

.list .entry:hover {
			background: var(--list-entry-hover-bg);
		}

.list .entry:active, .list .entry:focus, .list .entry:hover, .list .entry:target {
			border-color: var(--fg-accent);
		}

.domain-blocklist {
	box-shadow: var(--boxshadow);
}

.domain-blocklist .entry {
		display: grid;
		grid-template-columns: max(30%, 10rem) 1fr;
		gap: 0.5rem;
		align-items: start;
		border: var(--boxshadow-border);
		border-top-color: transparent;
	}

.domain-blocklist .entry > div {
			display: flex;
			align-items: center
		}

.domain-blocklist .entry .domain a {
			font-weight: bold;
			text-decoration: none;
			display: inline-block; /* so it wraps properly */
		}

.domain-blocklist .entry .public_comment p {
			margin: 0;
		}

.domain-blocklist .header .domain {
		color: var(--fg);
	}

.about {
	display: flex;
	flex-direction: column;
	gap: 1rem;

}

.about h2 {
		margin: 0.5rem 0;
	}

.about ul {
		margin-bottom: 0;
	}

.account-card {
	display: inline-grid;
	grid-template-columns: auto 1fr;
	grid-template-rows: auto auto;
	text-decoration: none;
	gap: 0.5rem 1rem;
	border-radius: var(--br);
	padding: 0.5rem;
	min-width: 40%;
	margin-bottom: 0.3rem;

	background: var(--list-entry-bg);
}

.account-card:hover {
		background: var(--list-entry-alternate-bg);
	}

.account-card h3 {
		align-self: end;
		margin: 0;
		color: var(--fg);
	}

.account-card img.avatar {
		border-radius: 0.5rem;
		width: 5rem;
		height: 5rem;
		-o-object-fit: cover;
		   object-fit: cover;
		grid-row: 1 / span 2;
	}

.instance-rules {
	list-style-position: inside;
	margin: 0;
	padding: 0;
}

.instance-rules a.rule {
		display: grid;
		grid-template-columns: 1fr auto;
		align-items: center;
		color: var(--fg);
		text-decoration: none;
		background: var(--toot-bg);
		padding: 1rem;
		margin: 0.5rem 0;
		border-radius: var(--br);
		line-height: 2rem;
		position: relative;
	}

.instance-rules a.rule:hover {
			color: var(--fg-accent);
		}

.instance-rules a.rule:hover .edit-icon {
				display: inline;
			}

.instance-rules a.rule .edit-icon {
			display: none;
			font-size: 1rem;
			line-height: 1.5rem;
		}

.instance-rules a.rule li {
			font-size: 1.75rem;
			padding: 0;
			margin: 0;
		}

.instance-rules a.rule li h2 {
				margin: 0;
				margin-top: 0 !important;
				display: inline-block;
				font-size: 1.5rem;
			}

.instance-rules a.rule span {
			color: var(--fg-reduced);
		}

@media screen and (max-width: 30rem) {
	.domain-blocklist .entry {
		grid-template-columns: 1fr;
		gap: 0;
	}
}
