(function(){function r(e,n,t){function o(i,f){if(!n[i]){if(!e[i]){var c="function"==typeof require&&require;if(!f&&c)return c(i,!0);if(u)return u(i,!0);var a=new Error("Cannot find module '"+i+"'");throw a.code="MODULE_NOT_FOUND",a}var p=n[i]={exports:{}};e[i][0].call(p.exports,function(r){var n=e[i][1][r];return o(n||r)},p,p.exports,r,e,n,t)}return n[i].exports}for(var u="function"==typeof require&&require,i=0;i<t.length;i++)o(t[i]);return o}return r})()({2:[function(require,module,exports){
function _extends(){return module.exports=_extends=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var o=arguments[t];for(var r in o)Object.prototype.hasOwnProperty.call(o,r)&&(e[r]=o[r])}return e},module.exports.__esModule=!0,module.exports.default=module.exports,_extends.apply(this,arguments)}module.exports=_extends,module.exports.__esModule=!0,module.exports.default=module.exports;

},{}],3:[function(require,module,exports){
function _interopRequireDefault(e){return e&&e.__esModule?e:{default:e}}module.exports=_interopRequireDefault,module.exports.__esModule=!0,module.exports.default=module.exports;

},{}],5:[function(require,module,exports){
function _objectWithoutPropertiesLoose(e,o){if(null==e)return{};var t,r,u={},s=Object.keys(e);for(r=0;r<s.length;r++)t=s[r],o.indexOf(t)>=0||(u[t]=e[t]);return u}module.exports=_objectWithoutPropertiesLoose,module.exports.__esModule=!0,module.exports.default=module.exports;

},{}],8:[function(require,module,exports){
function _typeof(o){return module.exports=_typeof="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(o){return typeof o}:function(o){return o&&"function"==typeof Symbol&&o.constructor===Symbol&&o!==Symbol.prototype?"symbol":typeof o},module.exports.__esModule=!0,module.exports.default=module.exports,_typeof(o)}module.exports=_typeof,module.exports.__esModule=!0,module.exports.default=module.exports;

},{}],9:[function(require,module,exports){
!function(t,e){"object"==typeof exports&&"undefined"!=typeof module?e(exports):"function"==typeof define&&define.amd?define(["exports"],e):e((t="undefined"!=typeof globalThis?globalThis:t||self).FloatingUICore={})}(this,(function(t){"use strict";const e=["top","right","bottom","left"],n=["start","end"],i=e.reduce(((t,e)=>t.concat(e,e+"-"+n[0],e+"-"+n[1])),[]),o=Math.min,r=Math.max,a={left:"right",right:"left",bottom:"top",top:"bottom"},l={start:"end",end:"start"};function s(t,e,n){return r(t,o(e,n))}function f(t,e){return"function"==typeof t?t(e):t}function c(t){return t.split("-")[0]}function u(t){return t.split("-")[1]}function m(t){return"x"===t?"y":"x"}function d(t){return"y"===t?"height":"width"}function g(t){return["top","bottom"].includes(c(t))?"y":"x"}function p(t){return m(g(t))}function h(t,e,n){void 0===n&&(n=!1);const i=u(t),o=p(t),r=d(o);let a="x"===o?i===(n?"end":"start")?"right":"left":"start"===i?"bottom":"top";return e.reference[r]>e.floating[r]&&(a=x(a)),[a,x(a)]}function y(t){return t.replace(/start|end/g,(t=>l[t]))}function x(t){return t.replace(/left|right|bottom|top/g,(t=>a[t]))}function w(t){return"number"!=typeof t?function(t){return{top:0,right:0,bottom:0,left:0,...t}}(t):{top:t,right:t,bottom:t,left:t}}function v(t){return{...t,top:t.y,left:t.x,right:t.x+t.width,bottom:t.y+t.height}}function b(t,e,n){let{reference:i,floating:o}=t;const r=g(e),a=p(e),l=d(a),s=c(e),f="y"===r,m=i.x+i.width/2-o.width/2,h=i.y+i.height/2-o.height/2,y=i[l]/2-o[l]/2;let x;switch(s){case"top":x={x:m,y:i.y-o.height};break;case"bottom":x={x:m,y:i.y+i.height};break;case"right":x={x:i.x+i.width,y:h};break;case"left":x={x:i.x-o.width,y:h};break;default:x={x:i.x,y:i.y}}switch(u(e)){case"start":x[a]-=y*(n&&f?-1:1);break;case"end":x[a]+=y*(n&&f?-1:1)}return x}async function A(t,e){var n;void 0===e&&(e={});const{x:i,y:o,platform:r,rects:a,elements:l,strategy:s}=t,{boundary:c="clippingAncestors",rootBoundary:u="viewport",elementContext:m="floating",altBoundary:d=!1,padding:g=0}=f(e,t),p=w(g),h=l[d?"floating"===m?"reference":"floating":m],y=v(await r.getClippingRect({element:null==(n=await(null==r.isElement?void 0:r.isElement(h)))||n?h:h.contextElement||await(null==r.getDocumentElement?void 0:r.getDocumentElement(l.floating)),boundary:c,rootBoundary:u,strategy:s})),x="floating"===m?{...a.floating,x:i,y:o}:a.reference,b=await(null==r.getOffsetParent?void 0:r.getOffsetParent(l.floating)),A=await(null==r.isElement?void 0:r.isElement(b))&&await(null==r.getScale?void 0:r.getScale(b))||{x:1,y:1},R=v(r.convertOffsetParentRelativeRectToViewportRelativeRect?await r.convertOffsetParentRelativeRectToViewportRelativeRect({rect:x,offsetParent:b,strategy:s}):x);return{top:(y.top-R.top+p.top)/A.y,bottom:(R.bottom-y.bottom+p.bottom)/A.y,left:(y.left-R.left+p.left)/A.x,right:(R.right-y.right+p.right)/A.x}}function R(t,e){return{top:t.top-e.height,right:t.right-e.width,bottom:t.bottom-e.height,left:t.left-e.width}}function P(t){return e.some((e=>t[e]>=0))}function T(t){const e=o(...t.map((t=>t.left))),n=o(...t.map((t=>t.top)));return{x:e,y:n,width:r(...t.map((t=>t.right)))-e,height:r(...t.map((t=>t.bottom)))-n}}t.arrow=t=>({name:"arrow",options:t,async fn(e){const{x:n,y:i,placement:r,rects:a,platform:l,elements:c,middlewareData:m}=e,{element:g,padding:h=0}=f(t,e)||{};if(null==g)return{};const y=w(h),x={x:n,y:i},v=p(r),b=d(v),A=await l.getDimensions(g),R="y"===v,P=R?"top":"left",T=R?"bottom":"right",D=R?"clientHeight":"clientWidth",E=a.reference[b]+a.reference[v]-x[v]-a.floating[b],O=x[v]-a.reference[v],L=await(null==l.getOffsetParent?void 0:l.getOffsetParent(g));let k=L?L[D]:0;k&&await(null==l.isElement?void 0:l.isElement(L))||(k=c.floating[D]||a.floating[b]);const C=E/2-O/2,B=k/2-A[b]/2-1,H=o(y[P],B),S=o(y[T],B),F=H,j=k-A[b]-S,z=k/2-A[b]/2+C,M=s(F,z,j),V=!m.arrow&&null!=u(r)&&z!=M&&a.reference[b]/2-(z<F?H:S)-A[b]/2<0,W=V?z<F?z-F:z-j:0;return{[v]:x[v]+W,data:{[v]:M,centerOffset:z-M-W,...V&&{alignmentOffset:W}},reset:V}}}),t.autoPlacement=function(t){return void 0===t&&(t={}),{name:"autoPlacement",options:t,async fn(e){var n,o,r;const{rects:a,middlewareData:l,placement:s,platform:m,elements:d}=e,{crossAxis:g=!1,alignment:p,allowedPlacements:x=i,autoAlignment:w=!0,...v}=f(t,e),b=void 0!==p||x===i?function(t,e,n){return(t?[...n.filter((e=>u(e)===t)),...n.filter((e=>u(e)!==t))]:n.filter((t=>c(t)===t))).filter((n=>!t||u(n)===t||!!e&&y(n)!==n))}(p||null,w,x):x,R=await A(e,v),P=(null==(n=l.autoPlacement)?void 0:n.index)||0,T=b[P];if(null==T)return{};const D=h(T,a,await(null==m.isRTL?void 0:m.isRTL(d.floating)));if(s!==T)return{reset:{placement:b[0]}};const E=[R[c(T)],R[D[0]],R[D[1]]],O=[...(null==(o=l.autoPlacement)?void 0:o.overflows)||[],{placement:T,overflows:E}],L=b[P+1];if(L)return{data:{index:P+1,overflows:O},reset:{placement:L}};const k=O.map((t=>{const e=u(t.placement);return[t.placement,e&&g?t.overflows.slice(0,2).reduce(((t,e)=>t+e),0):t.overflows[0],t.overflows]})).sort(((t,e)=>t[1]-e[1])),C=(null==(r=k.filter((t=>t[2].slice(0,u(t[0])?2:3).every((t=>t<=0))))[0])?void 0:r[0])||k[0][0];return C!==s?{data:{index:P+1,overflows:O},reset:{placement:C}}:{}}}},t.computePosition=async(t,e,n)=>{const{placement:i="bottom",strategy:o="absolute",middleware:r=[],platform:a}=n,l=r.filter(Boolean),s=await(null==a.isRTL?void 0:a.isRTL(e));let f=await a.getElementRects({reference:t,floating:e,strategy:o}),{x:c,y:u}=b(f,i,s),m=i,d={},g=0;for(let n=0;n<l.length;n++){const{name:r,fn:p}=l[n],{x:h,y:y,data:x,reset:w}=await p({x:c,y:u,initialPlacement:i,placement:m,strategy:o,middlewareData:d,rects:f,platform:a,elements:{reference:t,floating:e}});c=null!=h?h:c,u=null!=y?y:u,d={...d,[r]:{...d[r],...x}},w&&g<=50&&(g++,"object"==typeof w&&(w.placement&&(m=w.placement),w.rects&&(f=!0===w.rects?await a.getElementRects({reference:t,floating:e,strategy:o}):w.rects),({x:c,y:u}=b(f,m,s))),n=-1)}return{x:c,y:u,placement:m,strategy:o,middlewareData:d}},t.detectOverflow=A,t.flip=function(t){return void 0===t&&(t={}),{name:"flip",options:t,async fn(e){var n,i;const{placement:o,middlewareData:r,rects:a,initialPlacement:l,platform:s,elements:m}=e,{mainAxis:d=!0,crossAxis:g=!0,fallbackPlacements:p,fallbackStrategy:w="bestFit",fallbackAxisSideDirection:v="none",flipAlignment:b=!0,...R}=f(t,e);if(null!=(n=r.arrow)&&n.alignmentOffset)return{};const P=c(o),T=c(l)===l,D=await(null==s.isRTL?void 0:s.isRTL(m.floating)),E=p||(T||!b?[x(l)]:function(t){const e=x(t);return[y(t),e,y(e)]}(l));p||"none"===v||E.push(...function(t,e,n,i){const o=u(t);let r=function(t,e,n){const i=["left","right"],o=["right","left"],r=["top","bottom"],a=["bottom","top"];switch(t){case"top":case"bottom":return n?e?o:i:e?i:o;case"left":case"right":return e?r:a;default:return[]}}(c(t),"start"===n,i);return o&&(r=r.map((t=>t+"-"+o)),e&&(r=r.concat(r.map(y)))),r}(l,b,v,D));const O=[l,...E],L=await A(e,R),k=[];let C=(null==(i=r.flip)?void 0:i.overflows)||[];if(d&&k.push(L[P]),g){const t=h(o,a,D);k.push(L[t[0]],L[t[1]])}if(C=[...C,{placement:o,overflows:k}],!k.every((t=>t<=0))){var B,H;const t=((null==(B=r.flip)?void 0:B.index)||0)+1,e=O[t];if(e)return{data:{index:t,overflows:C},reset:{placement:e}};let n=null==(H=C.filter((t=>t.overflows[0]<=0)).sort(((t,e)=>t.overflows[1]-e.overflows[1]))[0])?void 0:H.placement;if(!n)switch(w){case"bestFit":{var S;const t=null==(S=C.map((t=>[t.placement,t.overflows.filter((t=>t>0)).reduce(((t,e)=>t+e),0)])).sort(((t,e)=>t[1]-e[1]))[0])?void 0:S[0];t&&(n=t);break}case"initialPlacement":n=l}if(o!==n)return{reset:{placement:n}}}return{}}}},t.hide=function(t){return void 0===t&&(t={}),{name:"hide",options:t,async fn(e){const{rects:n}=e,{strategy:i="referenceHidden",...o}=f(t,e);switch(i){case"referenceHidden":{const t=R(await A(e,{...o,elementContext:"reference"}),n.reference);return{data:{referenceHiddenOffsets:t,referenceHidden:P(t)}}}case"escaped":{const t=R(await A(e,{...o,altBoundary:!0}),n.floating);return{data:{escapedOffsets:t,escaped:P(t)}}}default:return{}}}}},t.inline=function(t){return void 0===t&&(t={}),{name:"inline",options:t,async fn(e){const{placement:n,elements:i,rects:a,platform:l,strategy:s}=e,{padding:u=2,x:m,y:d}=f(t,e),p=Array.from(await(null==l.getClientRects?void 0:l.getClientRects(i.reference))||[]),h=function(t){const e=t.slice().sort(((t,e)=>t.y-e.y)),n=[];let i=null;for(let t=0;t<e.length;t++){const o=e[t];!i||o.y-i.y>i.height/2?n.push([o]):n[n.length-1].push(o),i=o}return n.map((t=>v(T(t))))}(p),y=v(T(p)),x=w(u);const b=await l.getElementRects({reference:{getBoundingClientRect:function(){if(2===h.length&&h[0].left>h[1].right&&null!=m&&null!=d)return h.find((t=>m>t.left-x.left&&m<t.right+x.right&&d>t.top-x.top&&d<t.bottom+x.bottom))||y;if(h.length>=2){if("y"===g(n)){const t=h[0],e=h[h.length-1],i="top"===c(n),o=t.top,r=e.bottom,a=i?t.left:e.left,l=i?t.right:e.right;return{top:o,bottom:r,left:a,right:l,width:l-a,height:r-o,x:a,y:o}}const t="left"===c(n),e=r(...h.map((t=>t.right))),i=o(...h.map((t=>t.left))),a=h.filter((n=>t?n.left===i:n.right===e)),l=a[0].top,s=a[a.length-1].bottom;return{top:l,bottom:s,left:i,right:e,width:e-i,height:s-l,x:i,y:l}}return y}},floating:i.floating,strategy:s});return a.reference.x!==b.reference.x||a.reference.y!==b.reference.y||a.reference.width!==b.reference.width||a.reference.height!==b.reference.height?{reset:{rects:b}}:{}}}},t.limitShift=function(t){return void 0===t&&(t={}),{options:t,fn(e){const{x:n,y:i,placement:o,rects:r,middlewareData:a}=e,{offset:l=0,mainAxis:s=!0,crossAxis:u=!0}=f(t,e),d={x:n,y:i},p=g(o),h=m(p);let y=d[h],x=d[p];const w=f(l,e),v="number"==typeof w?{mainAxis:w,crossAxis:0}:{mainAxis:0,crossAxis:0,...w};if(s){const t="y"===h?"height":"width",e=r.reference[h]-r.floating[t]+v.mainAxis,n=r.reference[h]+r.reference[t]-v.mainAxis;y<e?y=e:y>n&&(y=n)}if(u){var b,A;const t="y"===h?"width":"height",e=["top","left"].includes(c(o)),n=r.reference[p]-r.floating[t]+(e&&(null==(b=a.offset)?void 0:b[p])||0)+(e?0:v.crossAxis),i=r.reference[p]+r.reference[t]+(e?0:(null==(A=a.offset)?void 0:A[p])||0)-(e?v.crossAxis:0);x<n?x=n:x>i&&(x=i)}return{[h]:y,[p]:x}}}},t.offset=function(t){return void 0===t&&(t=0),{name:"offset",options:t,async fn(e){const{x:n,y:i}=e,o=await async function(t,e){const{placement:n,platform:i,elements:o}=t,r=await(null==i.isRTL?void 0:i.isRTL(o.floating)),a=c(n),l=u(n),s="y"===g(n),m=["left","top"].includes(a)?-1:1,d=r&&s?-1:1,p=f(e,t);let{mainAxis:h,crossAxis:y,alignmentAxis:x}="number"==typeof p?{mainAxis:p,crossAxis:0,alignmentAxis:null}:{mainAxis:0,crossAxis:0,alignmentAxis:null,...p};return l&&"number"==typeof x&&(y="end"===l?-1*x:x),s?{x:y*d,y:h*m}:{x:h*m,y:y*d}}(e,t);return{x:n+o.x,y:i+o.y,data:o}}}},t.rectToClientRect=v,t.shift=function(t){return void 0===t&&(t={}),{name:"shift",options:t,async fn(e){const{x:n,y:i,placement:o}=e,{mainAxis:r=!0,crossAxis:a=!1,limiter:l={fn:t=>{let{x:e,y:n}=t;return{x:e,y:n}}},...u}=f(t,e),d={x:n,y:i},p=await A(e,u),h=g(c(o)),y=m(h);let x=d[y],w=d[h];if(r){const t="y"===y?"bottom":"right";x=s(x+p["y"===y?"top":"left"],x,x-p[t])}if(a){const t="y"===h?"bottom":"right";w=s(w+p["y"===h?"top":"left"],w,w-p[t])}const v=l.fn({...e,[y]:x,[h]:w});return{...v,data:{x:v.x-n,y:v.y-i}}}}},t.size=function(t){return void 0===t&&(t={}),{name:"size",options:t,async fn(e){const{placement:n,rects:i,platform:a,elements:l}=e,{apply:s=(()=>{}),...m}=f(t,e),d=await A(e,m),p=c(n),h=u(n),y="y"===g(n),{width:x,height:w}=i.floating;let v,b;"top"===p||"bottom"===p?(v=p,b=h===(await(null==a.isRTL?void 0:a.isRTL(l.floating))?"start":"end")?"left":"right"):(b=p,v="end"===h?"top":"bottom");const R=w-d[v],P=x-d[b],T=!e.middlewareData.shift;let D=R,E=P;if(y){const t=x-d.left-d.right;E=h||T?o(P,t):t}else{const t=w-d.top-d.bottom;D=h||T?o(R,t):t}if(T&&!h){const t=r(d.left,0),e=r(d.right,0),n=r(d.top,0),i=r(d.bottom,0);y?E=x-2*(0!==t||0!==e?t+e:r(d.left,d.right)):D=w-2*(0!==n||0!==i?n+i:r(d.top,d.bottom))}await s({...e,availableWidth:E,availableHeight:D});const O=await a.getDimensions(l.floating);return x!==O.width||w!==O.height?{reset:{rects:!0}}:{}}}}}));

},{}],21:[function(require,module,exports){
"use strict";function setRef(e,t){"function"==typeof e?e(t):e&&(e.current=t)}exports.setRef=setRef;

},{}],24:[function(require,module,exports){
"use strict";function toArray(r){return Array.isArray(r)?r:void 0!==r?[r]:[]}function addItemToArray(r,e,t){return void 0===t&&(t=-1),t in r?[...r.slice(0,t),e,...r.slice(t)]:[...r,e]}function flatten2DArray(r){const e=[];for(const t of r)e.push(...t);return e}function reverseArray(r){return r.slice().reverse()}exports.addItemToArray=addItemToArray,exports.flatten2DArray=flatten2DArray,exports.reverseArray=reverseArray,exports.toArray=toArray;

},{}],25:[function(require,module,exports){
"use strict";const canUseDOM=checkIsBrowser();function checkIsBrowser(){return"undefined"!=typeof window&&!!window.document?.createElement}function getDocument(e){return e?e.ownerDocument||e:document}function getWindow(e){return getDocument(e).defaultView||window}function getActiveElement(e,t){void 0===t&&(t=!1);const{activeElement:n}=getDocument(e);if(!n?.nodeName)return null;if(isFrame(n)&&n.contentDocument)return getActiveElement(n.contentDocument.body,t);if(t){const e=n.getAttribute("aria-activedescendant");if(e){const t=getDocument(n).getElementById(e);if(t)return t}}return n}function contains(e,t){return e===t||e.contains(t)}function isFrame(e){return"IFRAME"===e.tagName}function isButton(e){const t=e.tagName.toLowerCase();return"button"===t||!("input"!==t||!e.type)&&-1!==buttonInputTypes.indexOf(e.type)}const buttonInputTypes=["button","color","file","image","reset","submit"];function matches(e,t){return"matches"in e?e.matches(t):"msMatchesSelector"in e?e.msMatchesSelector(t):e.webkitMatchesSelector(t)}function isVisible(e){const t=e;return t.offsetWidth>0||t.offsetHeight>0||e.getClientRects().length>0}function closest(e,t){if("closest"in e)return e.closest(t);do{if(matches(e,t))return e;e=e.parentElement||e.parentNode}while(null!==e&&1===e.nodeType);return null}function isTextField(e){try{const t=e instanceof HTMLInputElement&&null!==e.selectionStart,n="TEXTAREA"===e.tagName;return t||n||!1}catch(e){return!1}}function getPopupRole(e,t){const n=e?.getAttribute("role");return n&&-1!==["dialog","menu","listbox","tree","grid"].indexOf(n)?n:t}function getPopupItemRole(e,t){const n=getPopupRole(e);if(!n)return t;return{menu:"menuitem",listbox:"option",tree:"treeitem",grid:"gridcell"}[n]??t}function getTextboxSelection(e){let t=0,n=0;if(isTextField(e))t=e.selectionStart||0,n=e.selectionEnd||0;else if(e.isContentEditable){const o=getDocument(e).getSelection();if(o?.rangeCount&&o.anchorNode&&contains(e,o.anchorNode)&&o.focusNode&&contains(e,o.focusNode)){const i=o.getRangeAt(0),r=i.cloneRange();r.selectNodeContents(e),r.setEnd(i.startContainer,i.startOffset),t=r.toString().length,r.setEnd(i.endContainer,i.endOffset),n=r.toString().length}}return{start:t,end:n}}function scrollIntoViewIfNeeded(e,t){isPartiallyHidden(e)&&"scrollIntoView"in e&&e.scrollIntoView(t)}function getScrollingElement(e){if(!e)return null;if(e.clientHeight&&e.scrollHeight>e.clientHeight){const{overflowY:t}=getComputedStyle(e);if("visible"!==t&&"hidden"!==t)return e}return getScrollingElement(e.parentElement)||document.scrollingElement||document.body}function isPartiallyHidden(e){const t=e.getBoundingClientRect(),n=getScrollingElement(e);if(!n)return!1;const o=n.getBoundingClientRect(),i="HTML"===n.tagName,r=i?o.top+n.scrollTop:o.top,s=i?n.clientHeight:o.bottom,c=i?o.left+n.scrollLeft:o.left,l=i?n.clientWidth:o.right,u=t.top<r,g=t.left<c,a=t.bottom>s,d=t.right>l;return u||g||a||d}exports.canUseDOM=canUseDOM,exports.closest=closest,exports.contains=contains,exports.getActiveElement=getActiveElement,exports.getDocument=getDocument,exports.getPopupItemRole=getPopupItemRole,exports.getPopupRole=getPopupRole,exports.getScrollingElement=getScrollingElement,exports.getTextboxSelection=getTextboxSelection,exports.getWindow=getWindow,exports.isButton=isButton,exports.isFrame=isFrame,exports.isPartiallyHidden=isPartiallyHidden,exports.isTextField=isTextField,exports.isVisible=isVisible,exports.matches=matches,exports.scrollIntoViewIfNeeded=scrollIntoViewIfNeeded;

},{}],28:[function(require,module,exports){
"use strict";function noop(){}function shallowEqual(t,e){if(t===e)return!0;if(!t)return!1;if(!e)return!1;if("object"!=typeof t)return!1;if("object"!=typeof e)return!1;const r=Object.keys(t),n=Object.keys(e),{length:o}=r;if(n.length!==o)return!1;for(const n of r)if(t[n]!==e[n])return!1;return!0}function applyState(t,e){if(isUpdater(t)){return t(isLazyValue(e)?e():e)}return t}function isUpdater(t){return"function"==typeof t}function isLazyValue(t){return"function"==typeof t}function isObject(t){return"object"==typeof t&&null!=t}function isEmpty(t){return Array.isArray(t)?!t.length:isObject(t)?!Object.keys(t).length:null==t||""===t}function isPromise(t){return Boolean(t&&"then"in t&&"function"==typeof t.then)}function isInteger(t){return"number"==typeof t?Math.floor(t)===t:String(Math.floor(Number(t)))===t}function hasOwnProperty(t,e){return Object.prototype.hasOwnProperty.call(t,e)}function chain(){for(var t=arguments.length,e=new Array(t),r=0;r<t;r++)e[r]=arguments[r];return function(){for(const t of e)"function"==typeof t&&t(...arguments)}}function cx(){for(var t=arguments.length,e=new Array(t),r=0;r<t;r++)e[r]=arguments[r];return e.filter(Boolean).join(" ")||void 0}function normalizeString(t){return t.normalize("NFD").replace(/[\u0300-\u036f]/g,"")}function queueMicrotask(t){if(window.queueMicrotask)return window.queueMicrotask(t);Promise.resolve().then(t)}exports.applyState=applyState,exports.chain=chain,exports.cx=cx,exports.hasOwnProperty=hasOwnProperty,exports.isEmpty=isEmpty,exports.isInteger=isInteger,exports.isObject=isObject,exports.isPromise=isPromise,exports.noop=noop,exports.normalizeString=normalizeString,exports.queueMicrotask=queueMicrotask,exports.shallowEqual=shallowEqual;

},{}],82:[function(require,module,exports){
"use strict";module.exports=function(r){return null==r?[]:Array.isArray(r)?r:[r]};

},{}],83:[function(require,module,exports){
"use strict";class SubRange{constructor(h,t){this.low=h,this.high=t,this.length=1+t-h}overlaps(h){return!(this.high<h.low||this.low>h.high)}touches(h){return!(this.high+1<h.low||this.low-1>h.high)}add(h){return new SubRange(Math.min(this.low,h.low),Math.max(this.high,h.high))}subtract(h){return h.low<=this.low&&h.high>=this.high?[]:h.low>this.low&&h.high<this.high?[new SubRange(this.low,h.low-1),new SubRange(h.high+1,this.high)]:h.low<=this.low?[new SubRange(h.high+1,this.high)]:[new SubRange(this.low,h.low-1)]}toString(){return this.low==this.high?this.low.toString():this.low+"-"+this.high}}class DRange{constructor(h,t){this.ranges=[],this.length=0,null!=h&&this.add(h,t)}_update_length(){this.length=this.ranges.reduce(((h,t)=>h+t.length),0)}add(h,t){var s=h=>{for(var t=0;t<this.ranges.length&&!h.touches(this.ranges[t]);)t++;for(var s=this.ranges.slice(0,t);t<this.ranges.length&&h.touches(this.ranges[t]);)h=h.add(this.ranges[t]),t++;s.push(h),this.ranges=s.concat(this.ranges.slice(t)),this._update_length()};return h instanceof DRange?h.ranges.forEach(s):(null==t&&(t=h),s(new SubRange(h,t))),this}subtract(h,t){var s=h=>{for(var t=0;t<this.ranges.length&&!h.overlaps(this.ranges[t]);)t++;for(var s=this.ranges.slice(0,t);t<this.ranges.length&&h.overlaps(this.ranges[t]);)s=s.concat(this.ranges[t].subtract(h)),t++;this.ranges=s.concat(this.ranges.slice(t)),this._update_length()};return h instanceof DRange?h.ranges.forEach(s):(null==t&&(t=h),s(new SubRange(h,t))),this}intersect(h,t){var s=[],e=h=>{for(var t=0;t<this.ranges.length&&!h.overlaps(this.ranges[t]);)t++;for(;t<this.ranges.length&&h.overlaps(this.ranges[t]);){var e=Math.max(this.ranges[t].low,h.low),n=Math.min(this.ranges[t].high,h.high);s.push(new SubRange(e,n)),t++}};return h instanceof DRange?h.ranges.forEach(e):(null==t&&(t=h),e(new SubRange(h,t))),this.ranges=s,this._update_length(),this}index(h){for(var t=0;t<this.ranges.length&&this.ranges[t].length<=h;)h-=this.ranges[t].length,t++;return this.ranges[t].low+h}toString(){return"[ "+this.ranges.join(", ")+" ]"}clone(){return new DRange(this)}numbers(){return this.ranges.reduce(((h,t)=>{for(var s=t.low;s<=t.high;)h.push(s),s++;return h}),[])}subranges(){return this.ranges.map((h=>({low:h.low,high:h.high,length:1+h.high-h.low})))}}module.exports=DRange;

},{}],84:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.default=void 0;const getByDot=(e,t)=>{if(["undefined","number","string"].includes(typeof e)||[null].includes(e))throw new Error("You have to provide a valid first parameter.");return t?-1===t.indexOf(".")?e[t]:t.split(".").reduce(((e,t)=>void 0!==e?"object"==typeof e?e[t]:void 0:"undefined"),e):e};var _default=getByDot;exports.default=_default;

},{}],87:[function(require,module,exports){
"use strict";var _ref;Object.defineProperty(exports,"__esModule",{value:!0});var hasSymbol="undefined"!=typeof Symbol&&"symbol"==typeof Symbol("x"),hasMap="undefined"!=typeof Map,hasSet="undefined"!=typeof Set,hasProxies="undefined"!=typeof Proxy&&void 0!==Proxy.revocable&&"undefined"!=typeof Reflect,NOTHING=hasSymbol?Symbol.for("immer-nothing"):((_ref={})["immer-nothing"]=!0,_ref),DRAFTABLE=hasSymbol?Symbol.for("immer-draftable"):"__$immer_draftable",DRAFT_STATE=hasSymbol?Symbol.for("immer-state"):"__$immer_state",iteratorSymbol="undefined"!=typeof Symbol&&Symbol.iterator||"@@iterator",errors={0:"Illegal state",1:"Immer drafts cannot have computed properties",2:"This object has been frozen and should not be mutated",3:function(e){return"Cannot use a proxy that has been revoked. Did you pass an object from inside an immer function to an async process? "+e},4:"An immer producer returned a new value *and* modified its draft. Either return a new value *or* modify the draft.",5:"Immer forbids circular references",6:"The first or second argument to `produce` must be a function",7:"The third argument to `produce` must be a function or undefined",8:"First argument to `createDraft` must be a plain object, an array, or an immerable object",9:"First argument to `finishDraft` must be a draft returned by `createDraft`",10:"The given draft is already finalized",11:"Object.defineProperty() cannot be used on an Immer draft",12:"Object.setPrototypeOf() cannot be used on an Immer draft",13:"Immer only supports deleting array indices",14:"Immer only supports setting array indices and the 'length' property",15:function(e){return"Cannot apply patch, path doesn't resolve: "+e},16:'Sets cannot have "replace" patches.',17:function(e){return"Unsupported patch operation: "+e},18:function(e){return"The plugin for '"+e+"' has not been loaded into Immer. To enable the plugin, import and call `enable"+e+"()` when initializing your application."},20:"Cannot use proxies if Proxy, Proxy.revocable or Reflect are not available",21:function(e){return"produce can only be called on things that are draftable: plain objects, arrays, Map, Set or classes that are marked with '[immerable]: true'. Got '"+e+"'"},22:function(e){return"'current' expects a draft, got: "+e},23:function(e){return"'original' expects a draft, got: "+e},24:"Patching reserved attributes like __proto__, prototype and constructor is not allowed"};function die(e){for(var t=arguments.length,r=new Array(t>1?t-1:0),n=1;n<t;n++)r[n-1]=arguments[n];var a=errors[e],o=a?"function"==typeof a?a.apply(null,r):a:"unknown error nr: "+e;throw new Error("[Immer] "+o)}function isDraft(e){return!!e&&!!e[DRAFT_STATE]}function isDraftable(e){var t;return!!e&&(isPlainObject(e)||Array.isArray(e)||!!e[DRAFTABLE]||!!(null===(t=e.constructor)||void 0===t?void 0:t[DRAFTABLE])||isMap(e)||isSet(e))}var objectCtorString=Object.prototype.constructor.toString();function isPlainObject(e){if(!e||"object"!=typeof e)return!1;var t=Object.getPrototypeOf(e);if(null===t)return!0;var r=Object.hasOwnProperty.call(t,"constructor")&&t.constructor;return r===Object||"function"==typeof r&&Function.toString.call(r)===objectCtorString}function original(e){return isDraft(e)||die(23,e),e[DRAFT_STATE].base_}var ownKeys="undefined"!=typeof Reflect&&Reflect.ownKeys?Reflect.ownKeys:void 0!==Object.getOwnPropertySymbols?function(e){return Object.getOwnPropertyNames(e).concat(Object.getOwnPropertySymbols(e))}:Object.getOwnPropertyNames,getOwnPropertyDescriptors=Object.getOwnPropertyDescriptors||function(e){var t={};return ownKeys(e).forEach((function(r){t[r]=Object.getOwnPropertyDescriptor(e,r)})),t};function each(e,t,r){void 0===r&&(r=!1),0===getArchtype(e)?(r?Object.keys:ownKeys)(e).forEach((function(n){r&&"symbol"==typeof n||t(n,e[n],e)})):e.forEach((function(r,n){return t(n,r,e)}))}function getArchtype(e){var t=e[DRAFT_STATE];return t?t.type_>3?t.type_-4:t.type_:Array.isArray(e)?1:isMap(e)?2:isSet(e)?3:0}function has(e,t){return 2===getArchtype(e)?e.has(t):Object.prototype.hasOwnProperty.call(e,t)}function get(e,t){return 2===getArchtype(e)?e.get(t):e[t]}function set(e,t,r){var n=getArchtype(e);2===n?e.set(t,r):3===n?e.add(r):e[t]=r}function is(e,t){return e===t?0!==e||1/e==1/t:e!=e&&t!=t}function isMap(e){return hasMap&&e instanceof Map}function isSet(e){return hasSet&&e instanceof Set}function latest(e){return e.copy_||e.base_}function shallowCopy(e){if(Array.isArray(e))return Array.prototype.slice.call(e);var t=getOwnPropertyDescriptors(e);delete t[DRAFT_STATE];for(var r=ownKeys(t),n=0;n<r.length;n++){var a=r[n],o=t[a];!1===o.writable&&(o.writable=!0,o.configurable=!0),(o.get||o.set)&&(t[a]={configurable:!0,writable:!0,enumerable:o.enumerable,value:e[a]})}return Object.create(Object.getPrototypeOf(e),t)}function freeze(e,t){return void 0===t&&(t=!1),isFrozen(e)||isDraft(e)||!isDraftable(e)||(getArchtype(e)>1&&(e.set=e.add=e.clear=e.delete=dontMutateFrozenCollections),Object.freeze(e),t&&each(e,(function(e,t){return freeze(t,!0)}),!0)),e}function dontMutateFrozenCollections(){die(2)}function isFrozen(e){return null==e||"object"!=typeof e||Object.isFrozen(e)}var currentScope,plugins={};function getPlugin(e){var t=plugins[e];return t||die(18,e),t}function loadPlugin(e,t){plugins[e]||(plugins[e]=t)}function getCurrentScope(){return currentScope||die(0),currentScope}function createScope(e,t){return{drafts_:[],parent_:e,immer_:t,canAutoFreeze_:!0,unfinalizedDrafts_:0}}function usePatchesInScope(e,t){t&&(getPlugin("Patches"),e.patches_=[],e.inversePatches_=[],e.patchListener_=t)}function revokeScope(e){leaveScope(e),e.drafts_.forEach(revokeDraft),e.drafts_=null}function leaveScope(e){e===currentScope&&(currentScope=e.parent_)}function enterScope(e){return currentScope=createScope(currentScope,e)}function revokeDraft(e){var t=e[DRAFT_STATE];0===t.type_||1===t.type_?t.revoke_():t.revoked_=!0}function processResult(e,t){t.unfinalizedDrafts_=t.drafts_.length;var r=t.drafts_[0],n=void 0!==e&&e!==r;return t.immer_.useProxies_||getPlugin("ES5").willFinalizeES5_(t,e,n),n?(r[DRAFT_STATE].modified_&&(revokeScope(t),die(4)),isDraftable(e)&&(e=finalize(t,e),t.parent_||maybeFreeze(t,e)),t.patches_&&getPlugin("Patches").generateReplacementPatches_(r[DRAFT_STATE].base_,e,t.patches_,t.inversePatches_)):e=finalize(t,r,[]),revokeScope(t),t.patches_&&t.patchListener_(t.patches_,t.inversePatches_),e!==NOTHING?e:void 0}function finalize(e,t,r){if(isFrozen(t))return t;var n=t[DRAFT_STATE];if(!n)return each(t,(function(a,o){return finalizeProperty(e,n,t,a,o,r)}),!0),t;if(n.scope_!==e)return t;if(!n.modified_)return maybeFreeze(e,n.base_,!0),n.base_;if(!n.finalized_){n.finalized_=!0,n.scope_.unfinalizedDrafts_--;var a=4===n.type_||5===n.type_?n.copy_=shallowCopy(n.draft_):n.copy_,o=a,i=!1;3===n.type_&&(o=new Set(a),a.clear(),i=!0),each(o,(function(t,o){return finalizeProperty(e,n,a,t,o,r,i)})),maybeFreeze(e,a,!1),r&&e.patches_&&getPlugin("Patches").generatePatches_(n,r,e.patches_,e.inversePatches_)}return n.copy_}function finalizeProperty(e,t,r,n,a,o,i){if(a===r&&die(5),isDraft(a)){var s=finalize(e,a,o&&t&&3!==t.type_&&!has(t.assigned_,n)?o.concat(n):void 0);if(set(r,n,s),!isDraft(s))return;e.canAutoFreeze_=!1}else i&&r.add(a);if(isDraftable(a)&&!isFrozen(a)){if(!e.immer_.autoFreeze_&&e.unfinalizedDrafts_<1)return;finalize(e,a),t&&t.scope_.parent_||maybeFreeze(e,a)}}function maybeFreeze(e,t,r){void 0===r&&(r=!1),!e.parent_&&e.immer_.autoFreeze_&&e.canAutoFreeze_&&freeze(t,r)}function createProxyProxy(e,t){var r=Array.isArray(e),n={type_:r?1:0,scope_:t?t.scope_:getCurrentScope(),modified_:!1,finalized_:!1,assigned_:{},parent_:t,base_:e,draft_:null,copy_:null,revoke_:null,isManual_:!1},a=n,o=objectTraps;r&&(a=[n],o=arrayTraps);var i=Proxy.revocable(a,o),s=i.revoke,c=i.proxy;return n.draft_=c,n.revoke_=s,c}var objectTraps={get:function(e,t){if(t===DRAFT_STATE)return e;var r=latest(e);if(!has(r,t))return readPropFromProto(e,r,t);var n=r[t];return e.finalized_||!isDraftable(n)?n:n===peek(e.base_,t)?(prepareCopy(e),e.copy_[t]=createProxy(e.scope_.immer_,n,e)):n},has:function(e,t){return t in latest(e)},ownKeys:function(e){return Reflect.ownKeys(latest(e))},set:function(e,t,r){var n=getDescriptorFromProto(latest(e),t);if(null==n?void 0:n.set)return n.set.call(e.draft_,r),!0;if(!e.modified_){var a=peek(latest(e),t),o=null==a?void 0:a[DRAFT_STATE];if(o&&o.base_===r)return e.copy_[t]=r,e.assigned_[t]=!1,!0;if(is(r,a)&&(void 0!==r||has(e.base_,t)))return!0;prepareCopy(e),markChanged(e)}return e.copy_[t]===r&&(void 0!==r||t in e.copy_)||Number.isNaN(r)&&Number.isNaN(e.copy_[t])||(e.copy_[t]=r,e.assigned_[t]=!0),!0},deleteProperty:function(e,t){return void 0!==peek(e.base_,t)||t in e.base_?(e.assigned_[t]=!1,prepareCopy(e),markChanged(e)):delete e.assigned_[t],e.copy_&&delete e.copy_[t],!0},getOwnPropertyDescriptor:function(e,t){var r=latest(e),n=Reflect.getOwnPropertyDescriptor(r,t);return n?{writable:!0,configurable:1!==e.type_||"length"!==t,enumerable:n.enumerable,value:r[t]}:n},defineProperty:function(){die(11)},getPrototypeOf:function(e){return Object.getPrototypeOf(e.base_)},setPrototypeOf:function(){die(12)}},arrayTraps={};function peek(e,t){var r=e[DRAFT_STATE];return(r?latest(r):e)[t]}function readPropFromProto(e,t,r){var n,a=getDescriptorFromProto(t,r);return a?"value"in a?a.value:null===(n=a.get)||void 0===n?void 0:n.call(e.draft_):void 0}function getDescriptorFromProto(e,t){if(t in e)for(var r=Object.getPrototypeOf(e);r;){var n=Object.getOwnPropertyDescriptor(r,t);if(n)return n;r=Object.getPrototypeOf(r)}}function markChanged(e){e.modified_||(e.modified_=!0,e.parent_&&markChanged(e.parent_))}function prepareCopy(e){e.copy_||(e.copy_=shallowCopy(e.base_))}each(objectTraps,(function(e,t){arrayTraps[e]=function(){return arguments[0]=arguments[0][0],t.apply(this,arguments)}})),arrayTraps.deleteProperty=function(e,t){return isNaN(parseInt(t))&&die(13),arrayTraps.set.call(this,e,t,void 0)},arrayTraps.set=function(e,t,r){return"length"!==t&&isNaN(parseInt(t))&&die(14),objectTraps.set.call(this,e[0],t,r,e[0])};var Immer=function(){function e(e){var t=this;this.useProxies_=hasProxies,this.autoFreeze_=!0,this.produce=function(e,r,n){if("function"==typeof e&&"function"!=typeof r){var a=r;r=e;var o=t;return function(e){var t=this;void 0===e&&(e=a);for(var n=arguments.length,i=new Array(n>1?n-1:0),s=1;s<n;s++)i[s-1]=arguments[s];return o.produce(e,(function(e){var n;return(n=r).call.apply(n,[t,e].concat(i))}))}}var i;if("function"!=typeof r&&die(6),void 0!==n&&"function"!=typeof n&&die(7),isDraftable(e)){var s=enterScope(t),c=createProxy(t,e,void 0),u=!0;try{i=r(c),u=!1}finally{u?revokeScope(s):leaveScope(s)}return"undefined"!=typeof Promise&&i instanceof Promise?i.then((function(e){return usePatchesInScope(s,n),processResult(e,s)}),(function(e){throw revokeScope(s),e})):(usePatchesInScope(s,n),processResult(i,s))}if(!e||"object"!=typeof e){if(void 0===(i=r(e))&&(i=e),i===NOTHING&&(i=void 0),t.autoFreeze_&&freeze(i,!0),n){var f=[],p=[];getPlugin("Patches").generateReplacementPatches_(e,i,f,p),n(f,p)}return i}die(21,e)},this.produceWithPatches=function(e,r){if("function"==typeof e)return function(r){for(var n=arguments.length,a=new Array(n>1?n-1:0),o=1;o<n;o++)a[o-1]=arguments[o];return t.produceWithPatches(r,(function(t){return e.apply(void 0,[t].concat(a))}))};var n,a,o=t.produce(e,r,(function(e,t){n=e,a=t}));return"undefined"!=typeof Promise&&o instanceof Promise?o.then((function(e){return[e,n,a]})):[o,n,a]},"boolean"==typeof(null==e?void 0:e.useProxies)&&this.setUseProxies(e.useProxies),"boolean"==typeof(null==e?void 0:e.autoFreeze)&&this.setAutoFreeze(e.autoFreeze)}var t=e.prototype;return t.createDraft=function(e){isDraftable(e)||die(8),isDraft(e)&&(e=current(e));var t=enterScope(this),r=createProxy(this,e,void 0);return r[DRAFT_STATE].isManual_=!0,leaveScope(t),r},t.finishDraft=function(e,t){var r=e&&e[DRAFT_STATE];r&&r.isManual_||die(9),r.finalized_&&die(10);var n=r.scope_;return usePatchesInScope(n,t),processResult(void 0,n)},t.setAutoFreeze=function(e){this.autoFreeze_=e},t.setUseProxies=function(e){e&&!hasProxies&&die(20),this.useProxies_=e},t.applyPatches=function(e,t){var r;for(r=t.length-1;r>=0;r--){var n=t[r];if(0===n.path.length&&"replace"===n.op){e=n.value;break}}r>-1&&(t=t.slice(r+1));var a=getPlugin("Patches").applyPatches_;return isDraft(e)?a(e,t):this.produce(e,(function(e){return a(e,t)}))},e}();function createProxy(e,t,r){var n=isMap(t)?getPlugin("MapSet").proxyMap_(t,r):isSet(t)?getPlugin("MapSet").proxySet_(t,r):e.useProxies_?createProxyProxy(t,r):getPlugin("ES5").createES5Proxy_(t,r);return(r?r.scope_:getCurrentScope()).drafts_.push(n),n}function current(e){return isDraft(e)||die(22,e),currentImpl(e)}function currentImpl(e){if(!isDraftable(e))return e;var t,r=e[DRAFT_STATE],n=getArchtype(e);if(r){if(!r.modified_&&(r.type_<4||!getPlugin("ES5").hasChanges_(r)))return r.base_;r.finalized_=!0,t=copyHelper(e,n),r.finalized_=!1}else t=copyHelper(e,n);return each(t,(function(e,n){r&&get(r.base_,e)===n||set(t,e,currentImpl(n))})),3===n?new Set(t):t}function copyHelper(e,t){switch(t){case 2:return new Map(e);case 3:return Array.from(e)}return shallowCopy(e)}function enableES5(){var e={};function t(t,r){var n=e[t];return n?n.enumerable=r:e[t]=n={configurable:!0,enumerable:r,get:function(){var e=this[DRAFT_STATE];return i(e),objectTraps.get(e,t)},set:function(e){var r=this[DRAFT_STATE];i(r),objectTraps.set(r,t,e)}},n}function r(e){for(var t=e.length-1;t>=0;t--){var r=e[t][DRAFT_STATE];if(!r.modified_)switch(r.type_){case 5:o(r)&&markChanged(r);break;case 4:a(r)&&markChanged(r)}}}function n(e){if(e&&"object"==typeof e){var t=e[DRAFT_STATE];if(t){var r=t.base_,a=t.draft_,i=t.assigned_,s=t.type_;if(4===s)each(a,(function(e){e!==DRAFT_STATE&&(void 0!==r[e]||has(r,e)?i[e]||n(a[e]):(i[e]=!0,markChanged(t)))})),each(r,(function(e){void 0!==a[e]||has(a,e)||(i[e]=!1,markChanged(t))}));else if(5===s){if(o(t)&&(markChanged(t),i.length=!0),a.length<r.length)for(var c=a.length;c<r.length;c++)i[c]=!1;else for(var u=r.length;u<a.length;u++)i[u]=!0;for(var f=Math.min(a.length,r.length),p=0;p<f;p++)a.hasOwnProperty(p)||(i[p]=!0),void 0===i[p]&&n(a[p])}}}}function a(e){for(var t=e.base_,r=e.draft_,n=ownKeys(r),a=n.length-1;a>=0;a--){var o=n[a];if(o!==DRAFT_STATE){var i=t[o];if(void 0===i&&!has(t,o))return!0;var s=r[o],c=s&&s[DRAFT_STATE];if(c?c.base_!==i:!is(s,i))return!0}}var u=!!t[DRAFT_STATE];return n.length!==ownKeys(t).length+(u?0:1)}function o(e){var t=e.draft_;if(t.length!==e.base_.length)return!0;var r=Object.getOwnPropertyDescriptor(t,t.length-1);if(r&&!r.get)return!0;for(var n=0;n<t.length;n++)if(!t.hasOwnProperty(n))return!0;return!1}function i(e){e.revoked_&&die(3,JSON.stringify(latest(e)))}loadPlugin("ES5",{createES5Proxy_:function(e,r){var n=Array.isArray(e),a=function(e,r){if(e){for(var n=new Array(r.length),a=0;a<r.length;a++)Object.defineProperty(n,""+a,t(a,!0));return n}var o=getOwnPropertyDescriptors(r);delete o[DRAFT_STATE];for(var i=ownKeys(o),s=0;s<i.length;s++){var c=i[s];o[c]=t(c,e||!!o[c].enumerable)}return Object.create(Object.getPrototypeOf(r),o)}(n,e),o={type_:n?5:4,scope_:r?r.scope_:getCurrentScope(),modified_:!1,finalized_:!1,assigned_:{},parent_:r,base_:e,draft_:a,copy_:null,revoked_:!1,isManual_:!1};return Object.defineProperty(a,DRAFT_STATE,{value:o,writable:!0}),a},willFinalizeES5_:function(e,t,a){a?isDraft(t)&&t[DRAFT_STATE].scope_===e&&r(e.drafts_):(e.patches_&&n(e.drafts_[0]),r(e.drafts_))},hasChanges_:function(e){return 4===e.type_?a(e):o(e)}})}function enablePatches(){var e="replace",t="add",r="remove";function n(e){if(!isDraftable(e))return e;if(Array.isArray(e))return e.map(n);if(isMap(e))return new Map(Array.from(e.entries()).map((function(e){return[e[0],n(e[1])]})));if(isSet(e))return new Set(Array.from(e).map(n));var t=Object.create(Object.getPrototypeOf(e));for(var r in e)t[r]=n(e[r]);return has(e,DRAFTABLE)&&(t[DRAFTABLE]=e[DRAFTABLE]),t}function a(e){return isDraft(e)?n(e):e}loadPlugin("Patches",{applyPatches_:function(a,o){return o.forEach((function(o){for(var i=o.path,s=o.op,c=a,u=0;u<i.length-1;u++){var f=getArchtype(c),p=i[u];"string"!=typeof p&&"number"!=typeof p&&(p=""+p),0!==f&&1!==f||"__proto__"!==p&&"constructor"!==p||die(24),"function"==typeof c&&"prototype"===p&&die(24),"object"!=typeof(c=get(c,p))&&die(15,i.join("/"))}var l=getArchtype(c),_=n(o.value),h=i[i.length-1];switch(s){case e:switch(l){case 2:return c.set(h,_);case 3:die(16);default:return c[h]=_}case t:switch(l){case 1:return"-"===h?c.push(_):c.splice(h,0,_);case 2:return c.set(h,_);case 3:return c.add(_);default:return c[h]=_}case r:switch(l){case 1:return c.splice(h,1);case 2:return c.delete(h);case 3:return c.delete(o.value);default:return delete c[h]}default:die(17,s)}})),a},generatePatches_:function(n,o,i,s){switch(n.type_){case 0:case 4:case 2:return function(n,o,i,s){var c=n.base_,u=n.copy_;each(n.assigned_,(function(n,f){var p=get(c,n),l=get(u,n),_=f?has(c,n)?e:t:r;if(p!==l||_!==e){var h=o.concat(n);i.push(_===r?{op:_,path:h}:{op:_,path:h,value:l}),s.push(_===t?{op:r,path:h}:_===r?{op:t,path:h,value:a(p)}:{op:e,path:h,value:a(p)})}}))}(n,o,i,s);case 5:case 1:return function(r,n,o,i){var s=r.base_,c=r.assigned_,u=r.copy_;if(u.length<s.length){var f=[u,s];s=f[0],u=f[1];var p=[i,o];o=p[0],i=p[1]}for(var l=0;l<s.length;l++)if(c[l]&&u[l]!==s[l]){var _=n.concat([l]);o.push({op:e,path:_,value:a(u[l])}),i.push({op:e,path:_,value:a(s[l])})}for(var h=s.length;h<u.length;h++){var d=n.concat([h]);o.push({op:t,path:d,value:a(u[h])})}s.length<u.length&&i.push({op:e,path:n.concat(["length"]),value:s.length})}(n,o,i,s);case 3:return function(e,n,a,o){var i=e.base_,s=e.copy_,c=0;i.forEach((function(e){if(!s.has(e)){var i=n.concat([c]);a.push({op:r,path:i,value:e}),o.unshift({op:t,path:i,value:e})}c++})),c=0,s.forEach((function(e){if(!i.has(e)){var s=n.concat([c]);a.push({op:t,path:s,value:e}),o.unshift({op:r,path:s,value:e})}c++}))}(n,o,i,s)}},generateReplacementPatches_:function(t,r,n,a){n.push({op:e,path:[],value:r===NOTHING?void 0:r}),a.push({op:e,path:[],value:t})}})}function enableMapSet(){var e=function(t,r){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var r in t)t.hasOwnProperty(r)&&(e[r]=t[r])},e(t,r)};function t(t,r){function n(){this.constructor=t}e(t,r),t.prototype=(n.prototype=r.prototype,new n)}var r=function(e){function r(e,t){return this[DRAFT_STATE]={type_:2,parent_:t,scope_:t?t.scope_:getCurrentScope(),modified_:!1,finalized_:!1,copy_:void 0,assigned_:void 0,base_:e,draft_:this,isManual_:!1,revoked_:!1},this}t(r,Map);var a=r.prototype;return Object.defineProperty(a,"size",{get:function(){return latest(this[DRAFT_STATE]).size}}),a.has=function(e){return latest(this[DRAFT_STATE]).has(e)},a.set=function(e,t){var r=this[DRAFT_STATE];return i(r),latest(r).has(e)&&latest(r).get(e)===t||(n(r),markChanged(r),r.assigned_.set(e,!0),r.copy_.set(e,t),r.assigned_.set(e,!0)),this},a.delete=function(e){if(!this.has(e))return!1;var t=this[DRAFT_STATE];return i(t),n(t),markChanged(t),t.base_.has(e)?t.assigned_.set(e,!1):t.assigned_.delete(e),t.copy_.delete(e),!0},a.clear=function(){var e=this[DRAFT_STATE];i(e),latest(e).size&&(n(e),markChanged(e),e.assigned_=new Map,each(e.base_,(function(t){e.assigned_.set(t,!1)})),e.copy_.clear())},a.forEach=function(e,t){var r=this;latest(this[DRAFT_STATE]).forEach((function(n,a,o){e.call(t,r.get(a),a,r)}))},a.get=function(e){var t=this[DRAFT_STATE];i(t);var r=latest(t).get(e);if(t.finalized_||!isDraftable(r))return r;if(r!==t.base_.get(e))return r;var a=createProxy(t.scope_.immer_,r,t);return n(t),t.copy_.set(e,a),a},a.keys=function(){return latest(this[DRAFT_STATE]).keys()},a.values=function(){var e,t=this,r=this.keys();return(e={})[iteratorSymbol]=function(){return t.values()},e.next=function(){var e=r.next();return e.done?e:{done:!1,value:t.get(e.value)}},e},a.entries=function(){var e,t=this,r=this.keys();return(e={})[iteratorSymbol]=function(){return t.entries()},e.next=function(){var e=r.next();if(e.done)return e;var n=t.get(e.value);return{done:!1,value:[e.value,n]}},e},a[iteratorSymbol]=function(){return this.entries()},r}();function n(e){e.copy_||(e.assigned_=new Map,e.copy_=new Map(e.base_))}var a=function(e){function r(e,t){return this[DRAFT_STATE]={type_:3,parent_:t,scope_:t?t.scope_:getCurrentScope(),modified_:!1,finalized_:!1,copy_:void 0,base_:e,draft_:this,drafts_:new Map,revoked_:!1,isManual_:!1},this}t(r,Set);var n=r.prototype;return Object.defineProperty(n,"size",{get:function(){return latest(this[DRAFT_STATE]).size}}),n.has=function(e){var t=this[DRAFT_STATE];return i(t),t.copy_?!!t.copy_.has(e)||!(!t.drafts_.has(e)||!t.copy_.has(t.drafts_.get(e))):t.base_.has(e)},n.add=function(e){var t=this[DRAFT_STATE];return i(t),this.has(e)||(o(t),markChanged(t),t.copy_.add(e)),this},n.delete=function(e){if(!this.has(e))return!1;var t=this[DRAFT_STATE];return i(t),o(t),markChanged(t),t.copy_.delete(e)||!!t.drafts_.has(e)&&t.copy_.delete(t.drafts_.get(e))},n.clear=function(){var e=this[DRAFT_STATE];i(e),latest(e).size&&(o(e),markChanged(e),e.copy_.clear())},n.values=function(){var e=this[DRAFT_STATE];return i(e),o(e),e.copy_.values()},n.entries=function(){var e=this[DRAFT_STATE];return i(e),o(e),e.copy_.entries()},n.keys=function(){return this.values()},n[iteratorSymbol]=function(){return this.values()},n.forEach=function(e,t){for(var r=this.values(),n=r.next();!n.done;)e.call(t,n.value,n.value,this),n=r.next()},r}();function o(e){e.copy_||(e.copy_=new Set,e.base_.forEach((function(t){if(isDraftable(t)){var r=createProxy(e.scope_.immer_,t,e);e.drafts_.set(t,r),e.copy_.add(r)}else e.copy_.add(t)})))}function i(e){e.revoked_&&die(3,JSON.stringify(latest(e)))}loadPlugin("MapSet",{proxyMap_:function(e,t){return new r(e,t)},proxySet_:function(e,t){return new a(e,t)}})}function enableAllPlugins(){enableES5(),enableMapSet(),enablePatches()}var immer=new Immer,produce=immer.produce,produceWithPatches=immer.produceWithPatches.bind(immer),setAutoFreeze=immer.setAutoFreeze.bind(immer),setUseProxies=immer.setUseProxies.bind(immer),applyPatches=immer.applyPatches.bind(immer),createDraft=immer.createDraft.bind(immer),finishDraft=immer.finishDraft.bind(immer);function castDraft(e){return e}function castImmutable(e){return e}exports.Immer=Immer,exports.applyPatches=applyPatches,exports.castDraft=castDraft,exports.castImmutable=castImmutable,exports.createDraft=createDraft,exports.current=current,exports.default=produce,exports.enableAllPlugins=enableAllPlugins,exports.enableES5=enableES5,exports.enableMapSet=enableMapSet,exports.enablePatches=enablePatches,exports.finishDraft=finishDraft,exports.freeze=freeze,exports.immerable=DRAFTABLE,exports.isDraft=isDraft,exports.isDraftable=isDraftable,exports.nothing=NOTHING,exports.original=original,exports.produce=produce,exports.produceWithPatches=produceWithPatches,exports.setAutoFreeze=setAutoFreeze,exports.setUseProxies=setUseProxies;

},{}],88:[function(require,module,exports){
function n(t){for(var e=arguments.length,r=Array(e>1?e-1:0),n=1;n<e;n++)r[n-1]=arguments[n];throw Error("[Immer] minified error nr: "+t+(r.length?" "+r.map((function(t){return"'"+t+"'"})).join(","):"")+". Find the full error at: https://bit.ly/3cXEKWf")}function r(t){return!!t&&!!t[H]}function t(t){var e;return!!t&&(function(t){if(!t||"object"!=typeof t)return!1;var e=Object.getPrototypeOf(t);if(null===e)return!0;var r=Object.hasOwnProperty.call(e,"constructor")&&e.constructor;return r===Object||"function"==typeof r&&Function.toString.call(r)===Q}(t)||Array.isArray(t)||!!t[G]||!!(null===(e=t.constructor)||void 0===e?void 0:e[G])||c(t)||v(t))}function e(t,e,r){void 0===r&&(r=!1),0===i(t)?(r?Object.keys:T)(t).forEach((function(n){r&&"symbol"==typeof n||e(n,t[n],t)})):t.forEach((function(r,n){return e(n,r,t)}))}function i(t){var e=t[H];return e?e.t>3?e.t-4:e.t:Array.isArray(t)?1:c(t)?2:v(t)?3:0}function u(t,e){return 2===i(t)?t.has(e):Object.prototype.hasOwnProperty.call(t,e)}function o(t,e){return 2===i(t)?t.get(e):t[e]}function f(t,e,r){var n=i(t);2===n?t.set(e,r):3===n?t.add(r):t[e]=r}function a(t,e){return t===e?0!==t||1/t==1/e:t!=t&&e!=e}function c(t){return W&&t instanceof Map}function v(t){return X&&t instanceof Set}function s(t){return t.i||t.u}function p(t){if(Array.isArray(t))return Array.prototype.slice.call(t);var e=U(t);delete e[H];for(var r=T(e),n=0;n<r.length;n++){var o=r[n],i=e[o];!1===i.writable&&(i.writable=!0,i.configurable=!0),(i.get||i.set)&&(e[o]={configurable:!0,writable:!0,enumerable:i.enumerable,value:t[o]})}return Object.create(Object.getPrototypeOf(t),e)}function l(n,o){return void 0===o&&(o=!1),h(n)||r(n)||!t(n)||(i(n)>1&&(n.set=n.add=n.clear=n.delete=d),Object.freeze(n),o&&e(n,(function(t,e){return l(e,!0)}),!0)),n}function d(){n(2)}function h(t){return null==t||"object"!=typeof t||Object.isFrozen(t)}function y(t){var e=V[t];return e||n(18,t),e}function _(t,e){V[t]||(V[t]=e)}function b(){return I}function m(t,e){e&&(y("Patches"),t.o=[],t.v=[],t.s=e)}function j(t){O(t),t.p.forEach(w),t.p=null}function O(t){t===I&&(I=t.l)}function x(t){return I={p:[],l:I,h:t,_:!0,m:0}}function w(t){var e=t[H];0===e.t||1===e.t?e.j():e.O=!0}function S(e,r){r.m=r.p.length;var o=r.p[0],i=void 0!==e&&e!==o;return r.h.S||y("ES5").P(r,e,i),i?(o[H].g&&(j(r),n(4)),t(e)&&(e=P(r,e),r.l||M(r,e)),r.o&&y("Patches").M(o[H].u,e,r.o,r.v)):e=P(r,o,[]),j(r),r.o&&r.s(r.o,r.v),e!==B?e:void 0}function P(t,r,n){if(h(r))return r;var o=r[H];if(!o)return e(r,(function(e,i){return g(t,o,r,e,i,n)}),!0),r;if(o.A!==t)return r;if(!o.g)return M(t,o.u,!0),o.u;if(!o.R){o.R=!0,o.A.m--;var i=4===o.t||5===o.t?o.i=p(o.k):o.i,u=i,a=!1;3===o.t&&(u=new Set(i),i.clear(),a=!0),e(u,(function(e,r){return g(t,o,i,e,r,n,a)})),M(t,i,!1),n&&t.o&&y("Patches").F(o,n,t.o,t.v)}return o.i}function g(e,n,o,i,a,c,s){if(r(a)){var l=P(e,a,c&&n&&3!==n.t&&!u(n.N,i)?c.concat(i):void 0);if(f(o,i,l),!r(l))return;e._=!1}else s&&o.add(a);if(t(a)&&!h(a)){if(!e.h.D&&e.m<1)return;P(e,a),n&&n.A.l||M(e,a)}}function M(t,e,r){void 0===r&&(r=!1),!t.l&&t.h.D&&t._&&l(e,r)}function A(t,e){var r=t[H];return(r?s(r):t)[e]}function z(t,e){if(e in t)for(var r=Object.getPrototypeOf(t);r;){var n=Object.getOwnPropertyDescriptor(r,e);if(n)return n;r=Object.getPrototypeOf(r)}}function E(t){t.g||(t.g=!0,t.l&&E(t.l))}function R(t){t.i||(t.i=p(t.u))}function k(t,e,r){var n=c(e)?y("MapSet").K(e,r):v(e)?y("MapSet").$(e,r):t.S?function(t,e){var r=Array.isArray(t),n={t:r?1:0,A:e?e.A:b(),g:!1,R:!1,N:{},l:e,u:t,k:null,i:null,j:null,C:!1},o=n,i=Y;r&&(o=[n],i=Z);var u=Proxy.revocable(o,i),a=u.revoke,c=u.proxy;return n.k=c,n.j=a,c}(e,r):y("ES5").I(e,r);return(r?r.A:b()).p.push(n),n}function F(u){return r(u)||n(22,u),function r(n){if(!t(n))return n;var u,a=n[H],c=i(n);if(a){if(!a.g&&(a.t<4||!y("ES5").J(a)))return a.u;a.R=!0,u=N(n,c),a.R=!1}else u=N(n,c);return e(u,(function(t,e){a&&o(a.u,t)===e||f(u,t,r(e))})),3===c?new Set(u):u}(u)}function N(t,e){switch(e){case 2:return new Map(t);case 3:return Array.from(t)}return p(t)}function D(){function t(t,e){var r=c[t];return r?r.enumerable=e:c[t]=r={configurable:!0,enumerable:e,get:function(){return Y.get(this[H],t)},set:function(e){Y.set(this[H],t,e)}},r}function n(t){for(var e=t.length-1;e>=0;e--){var r=t[e][H];if(!r.g)switch(r.t){case 5:i(r)&&E(r);break;case 4:o(r)&&E(r)}}}function o(t){for(var e=t.u,r=t.k,n=T(r),o=n.length-1;o>=0;o--){var i=n[o];if(i!==H){var c=e[i];if(void 0===c&&!u(e,i))return!0;var f=r[i],s=f&&f[H];if(s?s.u!==c:!a(f,c))return!0}}var l=!!e[H];return n.length!==T(e).length+(l?0:1)}function i(t){var e=t.k;if(e.length!==t.u.length)return!0;var r=Object.getOwnPropertyDescriptor(e,e.length-1);if(r&&!r.get)return!0;for(var n=0;n<e.length;n++)if(!e.hasOwnProperty(n))return!0;return!1}var c={};_("ES5",{I:function(e,r){var n=Array.isArray(e),o=function(e,r){if(e){for(var n=Array(r.length),o=0;o<r.length;o++)Object.defineProperty(n,""+o,t(o,!0));return n}var i=U(r);delete i[H];for(var u=T(i),a=0;a<u.length;a++){var c=u[a];i[c]=t(c,e||!!i[c].enumerable)}return Object.create(Object.getPrototypeOf(r),i)}(n,e),i={t:n?5:4,A:r?r.A:b(),g:!1,R:!1,N:{},l:r,u:e,k:o,i:null,O:!1,C:!1};return Object.defineProperty(o,H,{value:i,writable:!0}),o},P:function(t,o,a){a?r(o)&&o[H].A===t&&n(t.p):(t.o&&function t(r){if(r&&"object"==typeof r){var n=r[H];if(n){var o=n.u,a=n.k,c=n.N,f=n.t;if(4===f)e(a,(function(e){e!==H&&(void 0!==o[e]||u(o,e)?c[e]||t(a[e]):(c[e]=!0,E(n)))})),e(o,(function(t){void 0!==a[t]||u(a,t)||(c[t]=!1,E(n))}));else if(5===f){if(i(n)&&(E(n),c.length=!0),a.length<o.length)for(var s=a.length;s<o.length;s++)c[s]=!1;else for(var l=o.length;l<a.length;l++)c[l]=!0;for(var p=Math.min(a.length,o.length),h=0;h<p;h++)a.hasOwnProperty(h)||(c[h]=!0),void 0===c[h]&&t(a[h])}}}}(t.p[0]),n(t.p))},J:function(t){return 4===t.t?o(t):i(t)}})}function K(){function a(e){if(!t(e))return e;if(Array.isArray(e))return e.map(a);if(c(e))return new Map(Array.from(e.entries()).map((function(t){return[t[0],a(t[1])]})));if(v(e))return new Set(Array.from(e).map(a));var r=Object.create(Object.getPrototypeOf(e));for(var n in e)r[n]=a(e[n]);return u(e,G)&&(r[G]=e[G]),r}function f(t){return r(t)?a(t):t}var s="add";_("Patches",{W:function(t,e){return e.forEach((function(e){for(var r=e.path,u=e.op,c=t,f=0;f<r.length-1;f++){var l=i(c),p=r[f];"string"!=typeof p&&"number"!=typeof p&&(p=""+p),0!==l&&1!==l||"__proto__"!==p&&"constructor"!==p||n(24),"function"==typeof c&&"prototype"===p&&n(24),"object"!=typeof(c=o(c,p))&&n(15,r.join("/"))}var h=i(c),v=a(e.value),y=r[r.length-1];switch(u){case"replace":switch(h){case 2:return c.set(y,v);case 3:n(16);default:return c[y]=v}case s:switch(h){case 1:return"-"===y?c.push(v):c.splice(y,0,v);case 2:return c.set(y,v);case 3:return c.add(v);default:return c[y]=v}case"remove":switch(h){case 1:return c.splice(y,1);case 2:return c.delete(y);case 3:return c.delete(e.value);default:return delete c[y]}default:n(17,u)}})),t},F:function(t,r,n,i){switch(t.t){case 0:case 4:case 2:return function(t,r,n,i){var a=t.u,c=t.i;e(t.N,(function(t,e){var l=o(a,t),p=o(c,t),h=e?u(a,t)?"replace":s:"remove";if(l!==p||"replace"!==h){var v=r.concat(t);n.push("remove"===h?{op:h,path:v}:{op:h,path:v,value:p}),i.push(h===s?{op:"remove",path:v}:"remove"===h?{op:s,path:v,value:f(l)}:{op:"replace",path:v,value:f(l)})}}))}(t,r,n,i);case 5:case 1:return function(t,e,r,n){var o=t.u,i=t.N,u=t.i;if(u.length<o.length){var a=[u,o];o=a[0],u=a[1];var c=[n,r];r=c[0],n=c[1]}for(var l=0;l<o.length;l++)if(i[l]&&u[l]!==o[l]){var p=e.concat([l]);r.push({op:"replace",path:p,value:f(u[l])}),n.push({op:"replace",path:p,value:f(o[l])})}for(var h=o.length;h<u.length;h++){var v=e.concat([h]);r.push({op:s,path:v,value:f(u[h])})}o.length<u.length&&n.push({op:"replace",path:e.concat(["length"]),value:o.length})}(t,r,n,i);case 3:return function(t,e,r,n){var o=t.u,i=t.i,u=0;o.forEach((function(t){if(!i.has(t)){var o=e.concat([u]);r.push({op:"remove",path:o,value:t}),n.unshift({op:s,path:o,value:t})}u++})),u=0,i.forEach((function(t){if(!o.has(t)){var i=e.concat([u]);r.push({op:s,path:i,value:t}),n.unshift({op:"remove",path:i,value:t})}u++}))}(t,r,n,i)}},M:function(t,e,r,n){r.push({op:"replace",path:[],value:e===B?void 0:e}),n.push({op:"replace",path:[],value:t})}})}function $(){function r(t,e){function r(){this.constructor=t}a(t,e),t.prototype=(r.prototype=e.prototype,new r)}function o(t){t.i||(t.N=new Map,t.i=new Map(t.u))}function i(e){e.i||(e.i=new Set,e.u.forEach((function(r){if(t(r)){var n=k(e.A.h,r,e);e.p.set(r,n),e.i.add(n)}else e.i.add(r)})))}function u(t){t.O&&n(3,JSON.stringify(s(t)))}var a=function(t,e){return(a=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(t,e){t.__proto__=e}||function(t,e){for(var r in e)e.hasOwnProperty(r)&&(t[r]=e[r])})(t,e)},c=function(){function n(t,e){return this[H]={t:2,l:e,A:e?e.A:b(),g:!1,R:!1,i:void 0,N:void 0,u:t,k:this,C:!1,O:!1},this}r(n,Map);var i=n.prototype;return Object.defineProperty(i,"size",{get:function(){return s(this[H]).size}}),i.has=function(t){return s(this[H]).has(t)},i.set=function(t,e){var r=this[H];return u(r),s(r).has(t)&&s(r).get(t)===e||(o(r),E(r),r.N.set(t,!0),r.i.set(t,e),r.N.set(t,!0)),this},i.delete=function(t){if(!this.has(t))return!1;var e=this[H];return u(e),o(e),E(e),e.u.has(t)?e.N.set(t,!1):e.N.delete(t),e.i.delete(t),!0},i.clear=function(){var t=this[H];u(t),s(t).size&&(o(t),E(t),t.N=new Map,e(t.u,(function(e){t.N.set(e,!1)})),t.i.clear())},i.forEach=function(t,e){var r=this;s(this[H]).forEach((function(n,o){t.call(e,r.get(o),o,r)}))},i.get=function(e){var r=this[H];u(r);var n=s(r).get(e);if(r.R||!t(n))return n;if(n!==r.u.get(e))return n;var i=k(r.A.h,n,r);return o(r),r.i.set(e,i),i},i.keys=function(){return s(this[H]).keys()},i.values=function(){var t,e=this,r=this.keys();return(t={})[L]=function(){return e.values()},t.next=function(){var t=r.next();return t.done?t:{done:!1,value:e.get(t.value)}},t},i.entries=function(){var t,e=this,r=this.keys();return(t={})[L]=function(){return e.entries()},t.next=function(){var t=r.next();if(t.done)return t;var n=e.get(t.value);return{done:!1,value:[t.value,n]}},t},i[L]=function(){return this.entries()},n}(),f=function(){function t(t,e){return this[H]={t:3,l:e,A:e?e.A:b(),g:!1,R:!1,i:void 0,u:t,k:this,p:new Map,O:!1,C:!1},this}r(t,Set);var e=t.prototype;return Object.defineProperty(e,"size",{get:function(){return s(this[H]).size}}),e.has=function(t){var e=this[H];return u(e),e.i?!!e.i.has(t)||!(!e.p.has(t)||!e.i.has(e.p.get(t))):e.u.has(t)},e.add=function(t){var e=this[H];return u(e),this.has(t)||(i(e),E(e),e.i.add(t)),this},e.delete=function(t){if(!this.has(t))return!1;var e=this[H];return u(e),i(e),E(e),e.i.delete(t)||!!e.p.has(t)&&e.i.delete(e.p.get(t))},e.clear=function(){var t=this[H];u(t),s(t).size&&(i(t),E(t),t.i.clear())},e.values=function(){var t=this[H];return u(t),i(t),t.i.values()},e.entries=function(){var t=this[H];return u(t),i(t),t.i.entries()},e.keys=function(){return this.values()},e[L]=function(){return this.values()},e.forEach=function(t,e){for(var r=this.values(),n=r.next();!n.done;)t.call(e,n.value,n.value,this),n=r.next()},t}();_("MapSet",{K:function(t,e){return new c(t,e)},$:function(t,e){return new f(t,e)}})}var C;Object.defineProperty(exports,"__esModule",{value:!0});var I,J="undefined"!=typeof Symbol&&"symbol"==typeof Symbol("x"),W="undefined"!=typeof Map,X="undefined"!=typeof Set,q="undefined"!=typeof Proxy&&void 0!==Proxy.revocable&&"undefined"!=typeof Reflect,B=J?Symbol.for("immer-nothing"):((C={})["immer-nothing"]=!0,C),G=J?Symbol.for("immer-draftable"):"__$immer_draftable",H=J?Symbol.for("immer-state"):"__$immer_state",L="undefined"!=typeof Symbol&&Symbol.iterator||"@@iterator",Q=""+Object.prototype.constructor,T="undefined"!=typeof Reflect&&Reflect.ownKeys?Reflect.ownKeys:void 0!==Object.getOwnPropertySymbols?function(t){return Object.getOwnPropertyNames(t).concat(Object.getOwnPropertySymbols(t))}:Object.getOwnPropertyNames,U=Object.getOwnPropertyDescriptors||function(t){var e={};return T(t).forEach((function(r){e[r]=Object.getOwnPropertyDescriptor(t,r)})),e},V={},Y={get:function(e,r){if(r===H)return e;var n=s(e);if(!u(n,r))return function(t,e,r){var n,o=z(e,r);return o?"value"in o?o.value:null===(n=o.get)||void 0===n?void 0:n.call(t.k):void 0}(e,n,r);var o=n[r];return e.R||!t(o)?o:o===A(e.u,r)?(R(e),e.i[r]=k(e.A.h,o,e)):o},has:function(t,e){return e in s(t)},ownKeys:function(t){return Reflect.ownKeys(s(t))},set:function(t,e,r){var n=z(s(t),e);if(null==n?void 0:n.set)return n.set.call(t.k,r),!0;if(!t.g){var o=A(s(t),e),i=null==o?void 0:o[H];if(i&&i.u===r)return t.i[e]=r,t.N[e]=!1,!0;if(a(r,o)&&(void 0!==r||u(t.u,e)))return!0;R(t),E(t)}return t.i[e]===r&&(void 0!==r||e in t.i)||Number.isNaN(r)&&Number.isNaN(t.i[e])||(t.i[e]=r,t.N[e]=!0),!0},deleteProperty:function(t,e){return void 0!==A(t.u,e)||e in t.u?(t.N[e]=!1,R(t),E(t)):delete t.N[e],t.i&&delete t.i[e],!0},getOwnPropertyDescriptor:function(t,e){var r=s(t),n=Reflect.getOwnPropertyDescriptor(r,e);return n?{writable:!0,configurable:1!==t.t||"length"!==e,enumerable:n.enumerable,value:r[e]}:n},defineProperty:function(){n(11)},getPrototypeOf:function(t){return Object.getPrototypeOf(t.u)},setPrototypeOf:function(){n(12)}},Z={};e(Y,(function(t,e){Z[t]=function(){return arguments[0]=arguments[0][0],e.apply(this,arguments)}})),Z.deleteProperty=function(t,e){return Z.set.call(this,t,e,void 0)},Z.set=function(t,e,r){return Y.set.call(this,t[0],e,r,t[0])};var nn=function(){function e(e){var r=this;this.S=q,this.D=!0,this.produce=function(e,o,i){if("function"==typeof e&&"function"!=typeof o){var u=o;o=e;var a=r;return function(t){var e=this;void 0===t&&(t=u);for(var r=arguments.length,n=Array(r>1?r-1:0),i=1;i<r;i++)n[i-1]=arguments[i];return a.produce(t,(function(t){var r;return(r=o).call.apply(r,[e,t].concat(n))}))}}var c;if("function"!=typeof o&&n(6),void 0!==i&&"function"!=typeof i&&n(7),t(e)){var f=x(r),s=k(r,e,void 0),p=!0;try{c=o(s),p=!1}finally{p?j(f):O(f)}return"undefined"!=typeof Promise&&c instanceof Promise?c.then((function(t){return m(f,i),S(t,f)}),(function(t){throw j(f),t})):(m(f,i),S(c,f))}if(!e||"object"!=typeof e){if(void 0===(c=o(e))&&(c=e),c===B&&(c=void 0),r.D&&l(c,!0),i){var h=[],v=[];y("Patches").M(e,c,h,v),i(h,v)}return c}n(21,e)},this.produceWithPatches=function(t,e){if("function"==typeof t)return function(e){for(var n=arguments.length,o=Array(n>1?n-1:0),i=1;i<n;i++)o[i-1]=arguments[i];return r.produceWithPatches(e,(function(e){return t.apply(void 0,[e].concat(o))}))};var n,o,i=r.produce(t,e,(function(t,e){n=t,o=e}));return"undefined"!=typeof Promise&&i instanceof Promise?i.then((function(t){return[t,n,o]})):[i,n,o]},"boolean"==typeof(null==e?void 0:e.useProxies)&&this.setUseProxies(e.useProxies),"boolean"==typeof(null==e?void 0:e.autoFreeze)&&this.setAutoFreeze(e.autoFreeze)}var o=e.prototype;return o.createDraft=function(e){t(e)||n(8),r(e)&&(e=F(e));var o=x(this),i=k(this,e,void 0);return i[H].C=!0,O(o),i},o.finishDraft=function(t,e){var r=(t&&t[H]).A;return m(r,e),S(void 0,r)},o.setAutoFreeze=function(t){this.D=t},o.setUseProxies=function(t){t&&!q&&n(20),this.S=t},o.applyPatches=function(t,e){var n;for(n=e.length-1;n>=0;n--){var o=e[n];if(0===o.path.length&&"replace"===o.op){t=o.value;break}}n>-1&&(e=e.slice(n+1));var i=y("Patches").W;return r(t)?i(t,e):this.produce(t,(function(t){return i(t,e)}))},e}(),rn=new nn,tn=rn.produce,en=rn.produceWithPatches.bind(rn),un=rn.setAutoFreeze.bind(rn),on=rn.setUseProxies.bind(rn),fn=rn.applyPatches.bind(rn),an=rn.createDraft.bind(rn),cn=rn.finishDraft.bind(rn);exports.Immer=nn,exports.applyPatches=fn,exports.castDraft=function(t){return t},exports.castImmutable=function(t){return t},exports.createDraft=an,exports.current=F,exports.default=tn,exports.enableAllPlugins=function(){D(),$(),K()},exports.enableES5=D,exports.enableMapSet=$,exports.enablePatches=K,exports.finishDraft=cn,exports.freeze=l,exports.immerable=G,exports.isDraft=r,exports.isDraftable=t,exports.nothing=B,exports.original=function(t){return r(t)||n(23,t),t[H].u},exports.produce=tn,exports.produceWithPatches=en,exports.setAutoFreeze=un,exports.setUseProxies=on;

},{}],90:[function(require,module,exports){
var containers=[],styleElements=[],usage="insert-css: You need to provide a CSS string. Usage: insertCss(cssString[, options]).";function insertCss(e,t){if(t=t||{},void 0===e)throw new Error(usage);var s,n=!0===t.prepend?"prepend":"append",r=void 0!==t.container?t.container:document.querySelector("head"),o=containers.indexOf(r);return-1===o&&(o=containers.push(r)-1,styleElements[o]={}),void 0!==styleElements[o]&&void 0!==styleElements[o][n]?s=styleElements[o][n]:(s=styleElements[o][n]=createStyleElement(),"prepend"===n?r.insertBefore(s,r.childNodes[0]):r.appendChild(s)),65279===e.charCodeAt(0)&&(e=e.substr(1,e.length)),s.styleSheet?s.styleSheet.cssText+=e:s.textContent+=e,s}function createStyleElement(){var e=document.createElement("style");return e.setAttribute("type","text/css"),e}module.exports=insertCss,module.exports.insertCss=insertCss;

},{}],91:[function(require,module,exports){
module.exports={
  "ad": true,
  "ae": true,
  "af": true,
  "ag": true,
  "ai": true,
  "al": true,
  "am": true,
  "ao": true,
  "aq": true,
  "ar": true,
  "as": true,
  "at": true,
  "au": true,
  "aw": true,
  "ax": true,
  "az": true,
  "ba": true,
  "bb": true,
  "bd": true,
  "be": true,
  "bf": true,
  "bg": true,
  "bh": true,
  "bi": true,
  "bj": true,
  "bl": true,
  "bm": true,
  "bn": true,
  "bo": true,
  "bq": true,
  "br": true,
  "bs": true,
  "bt": true,
  "bv": true,
  "bw": true,
  "by": true,
  "bz": true,
  "ca": true,
  "cc": true,
  "cd": true,
  "cf": true,
  "cg": true,
  "ch": true,
  "ci": true,
  "ck": true,
  "cl": true,
  "cm": true,
  "cn": true,
  "co": true,
  "cr": true,
  "cu": true,
  "cv": true,
  "cw": true,
  "cx": true,
  "cy": true,
  "cz": true,
  "de": true,
  "dj": true,
  "dk": true,
  "dm": true,
  "do": true,
  "dz": true,
  "ec": true,
  "ee": true,
  "eg": true,
  "er": true,
  "es": true,
  "et": true,
  "fi": true,
  "fj": true,
  "fk": true,
  "fm": true,
  "fo": true,
  "fr": true,
  "ga": true,
  "gb (.uk)": true,
  "gd": true,
  "ge": true,
  "gf": true,
  "gg": true,
  "gh": true,
  "gi": true,
  "gl": true,
  "gm": true,
  "gn": true,
  "gp": true,
  "gq": true,
  "gr": true,
  "gs": true,
  "gt": true,
  "gu": true,
  "gw": true,
  "gy": true,
  "hk": true,
  "hm": true,
  "hn": true,
  "hr": true,
  "ht": true,
  "hu": true,
  "id": true,
  "ie": true,
  "il": true,
  "im": true,
  "in": true,
  "io": true,
  "iq": true,
  "ir": true,
  "is": true,
  "it": true,
  "je": true,
  "jm": true,
  "jo": true,
  "jp": true,
  "ke": true,
  "kg": true,
  "kh": true,
  "ki": true,
  "km": true,
  "kn": true,
  "kp": true,
  "kr": true,
  "kw": true,
  "ky": true,
  "kz": true,
  "la": true,
  "lb": true,
  "lc": true,
  "li": true,
  "lk": true,
  "lr": true,
  "ls": true,
  "lt": true,
  "lu": true,
  "lv": true,
  "ly": true,
  "ma": true,
  "mc": true,
  "md": true,
  "me": true,
  "mf": true,
  "mg": true,
  "mh": true,
  "mk": true,
  "ml": true,
  "mm": true,
  "mn": true,
  "mo": true,
  "mp": true,
  "mq": true,
  "mr": true,
  "ms": true,
  "mt": true,
  "mu": true,
  "mv": true,
  "mw": true,
  "mx": true,
  "my": true,
  "mz": true,
  "na": true,
  "nc": true,
  "ne": true,
  "nf": true,
  "ng": true,
  "ni": true,
  "nl": true,
  "no": true,
  "np": true,
  "nr": true,
  "nu": true,
  "nz": true,
  "om": true,
  "pa": true,
  "pe": true,
  "pf": true,
  "pg": true,
  "ph": true,
  "pk": true,
  "pl": true,
  "pm": true,
  "pn": true,
  "pr": true,
  "ps": true,
  "pt": true,
  "pw": true,
  "py": true,
  "qa": true,
  "re": true,
  "ro": true,
  "rs": true,
  "ru": true,
  "rw": true,
  "sa": true,
  "sb": true,
  "sc": true,
  "sd": true,
  "se": true,
  "sg": true,
  "sh": true,
  "si": true,
  "sj": true,
  "sk": true,
  "sl": true,
  "sm": true,
  "sn": true,
  "so": true,
  "sr": true,
  "ss": true,
  "st": true,
  "sv": true,
  "sx": true,
  "sy": true,
  "sz": true,
  "tc": true,
  "td": true,
  "tf": true,
  "tg": true,
  "th": true,
  "tj": true,
  "tk": true,
  "tl": true,
  "tm": true,
  "tn": true,
  "to": true,
  "tr": true,
  "tt": true,
  "tv": true,
  "tw": true,
  "tz": true,
  "ua": true,
  "ug": true,
  "us": true,
  "uy": true,
  "uz": true,
  "va": true,
  "vc": true,
  "ve": true,
  "vg": true,
  "vi": true,
  "vn": true,
  "vu": true,
  "wf": true,
  "ws": true,
  "ye": true,
  "yt": true,
  "za": true,
  "zm": true,
  "zw": true
}

},{}],92:[function(require,module,exports){
module.exports={
  "com.ac": true,
  "net.ac": true,
  "gov.ac": true,
  "org.ac": true,
  "mil.ac": true,
  "co.ae": true,
  "net.ae": true,
  "gov.ae": true,
  "ac.ae": true,
  "sch.ae": true,
  "org.ae": true,
  "mil.ae": true,
  "pro.ae": true,
  "name.ae": true,
  "com.af": true,
  "edu.af": true,
  "gov.af": true,
  "net.af": true,
  "org.af": true,
  "com.al": true,
  "edu.al": true,
  "gov.al": true,
  "mil.al": true,
  "net.al": true,
  "org.al": true,
  "ed.ao": true,
  "gv.ao": true,
  "og.ao": true,
  "co.ao": true,
  "pb.ao": true,
  "it.ao": true,
  "com.ar": true,
  "edu.ar": true,
  "gob.ar": true,
  "gov.ar": true,
  "int.ar": true,
  "mil.ar": true,
  "net.ar": true,
  "org.ar": true,
  "tur.ar": true,
  "gv.at": true,
  "ac.at": true,
  "co.at": true,
  "or.at": true,
  "com.au": true,
  "net.au": true,
  "org.au": true,
  "edu.au": true,
  "gov.au": true,
  "csiro.au": true,
  "asn.au": true,
  "id.au": true,
  "vic.au": true,
  "sa.au": true,
  "wa.au": true,
  "nt.au": true,
  "tas.au": true,
  "qld.au": true,
  "act.au": true,
  "conf.au": true,
  "oz.au": true,
  "org.ba": true,
  "net.ba": true,
  "edu.ba": true,
  "gov.ba": true,
  "mil.ba": true,
  "unsa.ba": true,
  "untz.ba": true,
  "unmo.ba": true,
  "unbi.ba": true,
  "unze.ba": true,
  "co.ba": true,
  "com.ba": true,
  "rs.ba": true,
  "co.bb": true,
  "com.bb": true,
  "net.bb": true,
  "org.bb": true,
  "gov.bb": true,
  "edu.bb": true,
  "info.bb": true,
  "store.bb": true,
  "tv.bb": true,
  "biz.bb": true,
  "com.bh": true,
  "info.bh": true,
  "cc.bh": true,
  "edu.bh": true,
  "biz.bh": true,
  "net.bh": true,
  "org.bh": true,
  "gov.bh": true,
  "com.bn": true,
  "edu.bn": true,
  "gov.bn": true,
  "net.bn": true,
  "org.bn": true,
  "com.bo": true,
  "net.bo": true,
  "org.bo": true,
  "tv.bo": true,
  "mil.bo": true,
  "int.bo": true,
  "gob.bo": true,
  "gov.bo": true,
  "edu.bo": true,
  "adm.br": true,
  "adv.br": true,
  "agr.br": true,
  "am.br": true,
  "arq.br": true,
  "art.br": true,
  "ato.br": true,
  "b.br": true,
  "bio.br": true,
  "blog.br": true,
  "bmd.br": true,
  "cim.br": true,
  "cng.br": true,
  "cnt.br": true,
  "com.br": true,
  "coop.br": true,
  "ecn.br": true,
  "edu.br": true,
  "eng.br": true,
  "esp.br": true,
  "etc.br": true,
  "eti.br": true,
  "far.br": true,
  "flog.br": true,
  "fm.br": true,
  "fnd.br": true,
  "fot.br": true,
  "fst.br": true,
  "g12.br": true,
  "ggf.br": true,
  "gov.br": true,
  "imb.br": true,
  "ind.br": true,
  "inf.br": true,
  "jor.br": true,
  "jus.br": true,
  "lel.br": true,
  "mat.br": true,
  "med.br": true,
  "mil.br": true,
  "mus.br": true,
  "net.br": true,
  "nom.br": true,
  "not.br": true,
  "ntr.br": true,
  "odo.br": true,
  "org.br": true,
  "ppg.br": true,
  "pro.br": true,
  "psc.br": true,
  "psi.br": true,
  "qsl.br": true,
  "rec.br": true,
  "slg.br": true,
  "srv.br": true,
  "tmp.br": true,
  "trd.br": true,
  "tur.br": true,
  "tv.br": true,
  "vet.br": true,
  "vlog.br": true,
  "wiki.br": true,
  "zlg.br": true,
  "com.bs": true,
  "net.bs": true,
  "org.bs": true,
  "edu.bs": true,
  "gov.bs": true,
  "om.bz": true,
  "du.bz": true,
  "ov.bz": true,
  "et.bz": true,
  "rg.bz": true,
  "ab.ca": true,
  "bc.ca": true,
  "mb.ca": true,
  "nb.ca": true,
  "nf.ca": true,
  "nl.ca": true,
  "ns.ca": true,
  "nt.ca": true,
  "nu.ca": true,
  "on.ca": true,
  "pe.ca": true,
  "qc.ca": true,
  "sk.ca": true,
  "yk.ca": true,
  "co.ck": true,
  "org.ck": true,
  "edu.ck": true,
  "gov.ck": true,
  "net.ck": true,
  "gen.ck": true,
  "biz.ck": true,
  "info.ck": true,
  "ac.cn": true,
  "com.cn": true,
  "edu.cn": true,
  "gov.cn": true,
  "mil.cn": true,
  "net.cn": true,
  "org.cn": true,
  "ah.cn": true,
  "bj.cn": true,
  "cq.cn": true,
  "fj.cn": true,
  "gd.cn": true,
  "gs.cn": true,
  "gz.cn": true,
  "gx.cn": true,
  "ha.cn": true,
  "hb.cn": true,
  "he.cn": true,
  "hi.cn": true,
  "hl.cn": true,
  "hn.cn": true,
  "jl.cn": true,
  "js.cn": true,
  "jx.cn": true,
  "ln.cn": true,
  "nm.cn": true,
  "nx.cn": true,
  "qh.cn": true,
  "sc.cn": true,
  "sd.cn": true,
  "sh.cn": true,
  "sn.cn": true,
  "sx.cn": true,
  "tj.cn": true,
  "tw.cn": true,
  "xj.cn": true,
  "xz.cn": true,
  "yn.cn": true,
  "zj.cn": true,
  "com.co": true,
  "org.co": true,
  "edu.co": true,
  "gov.co": true,
  "net.co": true,
  "mil.co": true,
  "nom.co": true,
  "ac.cr": true,
  "co.cr": true,
  "ed.cr": true,
  "fi.cr": true,
  "go.cr": true,
  "or.cr": true,
  "sa.cr": true,
  "cr": true,
  "ac.cy": true,
  "net.cy": true,
  "gov.cy": true,
  "org.cy": true,
  "pro.cy": true,
  "name.cy": true,
  "ekloges.cy": true,
  "tm.cy": true,
  "ltd.cy": true,
  "biz.cy": true,
  "press.cy": true,
  "parliament.cy": true,
  "com.cy": true,
  "edu.do": true,
  "gob.do": true,
  "gov.do": true,
  "com.do": true,
  "sld.do": true,
  "org.do": true,
  "net.do": true,
  "web.do": true,
  "mil.do": true,
  "art.do": true,
  "com.dz": true,
  "org.dz": true,
  "net.dz": true,
  "gov.dz": true,
  "edu.dz": true,
  "asso.dz": true,
  "pol.dz": true,
  "art.dz": true,
  "com.ec": true,
  "info.ec": true,
  "net.ec": true,
  "fin.ec": true,
  "med.ec": true,
  "pro.ec": true,
  "org.ec": true,
  "edu.ec": true,
  "gov.ec": true,
  "mil.ec": true,
  "com.eg": true,
  "edu.eg": true,
  "eun.eg": true,
  "gov.eg": true,
  "mil.eg": true,
  "name.eg": true,
  "net.eg": true,
  "org.eg": true,
  "sci.eg": true,
  "com.er": true,
  "edu.er": true,
  "gov.er": true,
  "mil.er": true,
  "net.er": true,
  "org.er": true,
  "ind.er": true,
  "rochest.er": true,
  "w.er": true,
  "com.es": true,
  "nom.es": true,
  "org.es": true,
  "gob.es": true,
  "edu.es": true,
  "com.et": true,
  "gov.et": true,
  "org.et": true,
  "edu.et": true,
  "net.et": true,
  "biz.et": true,
  "name.et": true,
  "info.et": true,
  "ac.fj": true,
  "biz.fj": true,
  "com.fj": true,
  "info.fj": true,
  "mil.fj": true,
  "name.fj": true,
  "net.fj": true,
  "org.fj": true,
  "pro.fj": true,
  "co.fk": true,
  "org.fk": true,
  "gov.fk": true,
  "ac.fk": true,
  "nom.fk": true,
  "net.fk": true,
  "fr": true,
  "tm.fr": true,
  "asso.fr": true,
  "nom.fr": true,
  "prd.fr": true,
  "presse.fr": true,
  "com.fr": true,
  "gouv.fr": true,
  "co.gg": true,
  "net.gg": true,
  "org.gg": true,
  "com.gh": true,
  "edu.gh": true,
  "gov.gh": true,
  "org.gh": true,
  "mil.gh": true,
  "co.gl": true,
  "com.gl": true,
  "edu.gl": true,
  "net.gl": true,
  "org.gl": true,
  "com.gn": true,
  "ac.gn": true,
  "gov.gn": true,
  "org.gn": true,
  "net.gn": true,
  "com.gr": true,
  "edu.gr": true,
  "net.gr": true,
  "org.gr": true,
  "gov.gr": true,
  "mil.gr": true,
  "com.gt": true,
  "edu.gt": true,
  "net.gt": true,
  "gob.gt": true,
  "org.gt": true,
  "mil.gt": true,
  "ind.gt": true,
  "com.gu": true,
  "net.gu": true,
  "gov.gu": true,
  "org.gu": true,
  "edu.gu": true,
  "com.hk": true,
  "edu.hk": true,
  "gov.hk": true,
  "idv.hk": true,
  "net.hk": true,
  "org.hk": true,
  "2000.hu": true,
  "agrar.hu": true,
  "bolt.hu": true,
  "casino.hu": true,
  "city.hu": true,
  "co.hu": true,
  "erotica.hu": true,
  "erotika.hu": true,
  "film.hu": true,
  "forum.hu": true,
  "games.hu": true,
  "hotel.hu": true,
  "info.hu": true,
  "ingatlan.hu": true,
  "jogasz.hu": true,
  "konyvelo.hu": true,
  "lakas.hu": true,
  "media.hu": true,
  "news.hu": true,
  "org.hu": true,
  "priv.hu": true,
  "reklam.hu": true,
  "sex.hu": true,
  "shop.hu": true,
  "sport.hu": true,
  "suli.huv": true,
  "szex.hu": true,
  "tm.hu": true,
  "tozsde.hu": true,
  "utazas.hu": true,
  "video.hu": true,
  "ac.id": true,
  "co.id": true,
  "net.id": true,
  "or.id": true,
  "web.id": true,
  "sch.id": true,
  "mil.id": true,
  "go.id": true,
  "war.net.id": true,
  "my.id": true,
  "biz.id": true,
  "ac.il": true,
  "co.il": true,
  "org.il": true,
  "net.il": true,
  "k12.il": true,
  "gov.il": true,
  "muni.il": true,
  "idf.il": true,
  "in": true,
  "4fd.in": true,
  "co.in": true,
  "firm.in": true,
  "net.in": true,
  "org.in": true,
  "gen.in": true,
  "ind.in": true,
  "ac.in": true,
  "edu.in": true,
  "res.in": true,
  "ernet.in": true,
  "gov.in": true,
  "mil.in": true,
  "nic.in": true,
  "iq": true,
  "gov.iq": true,
  "edu.iq": true,
  "com.iq": true,
  "mil.iq": true,
  "org.iq": true,
  "net.iq": true,
  "ir": true,
  "ac.ir": true,
  "co.ir": true,
  "gov.ir": true,
  "id.ir": true,
  "net.ir": true,
  "org.ir": true,
  "sch.ir": true,
  "dnssec.ir": true,
  "gov.it": true,
  "edu.it": true,
  "co.je": true,
  "net.je": true,
  "org.je": true,
  "com.jo": true,
  "net.jo": true,
  "gov.jo": true,
  "edu.jo": true,
  "org.jo": true,
  "mil.jo": true,
  "name.jo": true,
  "sch.jo": true,
  "ac.jp": true,
  "ad.jp": true,
  "co.jp": true,
  "ed.jp": true,
  "go.jp": true,
  "gr.jp": true,
  "lg.jp": true,
  "ne.jp": true,
  "or.jp": true,
  "co.ke": true,
  "or.ke": true,
  "ne.ke": true,
  "go.ke": true,
  "ac.ke": true,
  "sc.ke": true,
  "me.ke": true,
  "mobi.ke": true,
  "info.ke": true,
  "per.kh": true,
  "com.kh": true,
  "edu.kh": true,
  "gov.kh": true,
  "mil.kh": true,
  "net.kh": true,
  "org.kh": true,
  "com.ki": true,
  "biz.ki": true,
  "de.ki": true,
  "net.ki": true,
  "info.ki": true,
  "org.ki": true,
  "gov.ki": true,
  "edu.ki": true,
  "mob.ki": true,
  "tel.ki": true,
  "km": true,
  "com.km": true,
  "coop.km": true,
  "asso.km": true,
  "nom.km": true,
  "presse.km": true,
  "tm.km": true,
  "medecin.km": true,
  "notaires.km": true,
  "pharmaciens.km": true,
  "veterinaire.km": true,
  "edu.km": true,
  "gouv.km": true,
  "mil.km": true,
  "net.kn": true,
  "org.kn": true,
  "edu.kn": true,
  "gov.kn": true,
  "kr": true,
  "co.kr": true,
  "ne.kr": true,
  "or.kr": true,
  "re.kr": true,
  "pe.kr": true,
  "go.kr": true,
  "mil.kr": true,
  "ac.kr": true,
  "hs.kr": true,
  "ms.kr": true,
  "es.kr": true,
  "sc.kr": true,
  "kg.kr": true,
  "seoul.kr": true,
  "busan.kr": true,
  "daegu.kr": true,
  "incheon.kr": true,
  "gwangju.kr": true,
  "daejeon.kr": true,
  "ulsan.kr": true,
  "gyeonggi.kr": true,
  "gangwon.kr": true,
  "chungbuk.kr": true,
  "chungnam.kr": true,
  "jeonbuk.kr": true,
  "jeonnam.kr": true,
  "gyeongbuk.kr": true,
  "gyeongnam.kr": true,
  "jeju.kr": true,
  "edu.kw": true,
  "com.kw": true,
  "net.kw": true,
  "org.kw": true,
  "gov.kw": true,
  "com.ky": true,
  "org.ky": true,
  "net.ky": true,
  "edu.ky": true,
  "gov.ky": true,
  "com.kz": true,
  "edu.kz": true,
  "gov.kz": true,
  "mil.kz": true,
  "net.kz": true,
  "org.kz": true,
  "com.lb": true,
  "edu.lb": true,
  "gov.lb": true,
  "net.lb": true,
  "org.lb": true,
  "gov.lk": true,
  "sch.lk": true,
  "net.lk": true,
  "int.lk": true,
  "com.lk": true,
  "org.lk": true,
  "edu.lk": true,
  "ngo.lk": true,
  "soc.lk": true,
  "web.lk": true,
  "ltd.lk": true,
  "assn.lk": true,
  "grp.lk": true,
  "hotel.lk": true,
  "com.lr": true,
  "edu.lr": true,
  "gov.lr": true,
  "org.lr": true,
  "net.lr": true,
  "com.lv": true,
  "edu.lv": true,
  "gov.lv": true,
  "org.lv": true,
  "mil.lv": true,
  "id.lv": true,
  "net.lv": true,
  "asn.lv": true,
  "conf.lv": true,
  "com.ly": true,
  "net.ly": true,
  "gov.ly": true,
  "plc.ly": true,
  "edu.ly": true,
  "sch.ly": true,
  "med.ly": true,
  "org.ly": true,
  "id.ly": true,
  "ma": true,
  "net.ma": true,
  "ac.ma": true,
  "org.ma": true,
  "gov.ma": true,
  "press.ma": true,
  "co.ma": true,
  "tm.mc": true,
  "asso.mc": true,
  "co.me": true,
  "net.me": true,
  "org.me": true,
  "edu.me": true,
  "ac.me": true,
  "gov.me": true,
  "its.me": true,
  "priv.me": true,
  "org.mg": true,
  "nom.mg": true,
  "gov.mg": true,
  "prd.mg": true,
  "tm.mg": true,
  "edu.mg": true,
  "mil.mg": true,
  "com.mg": true,
  "com.mk": true,
  "org.mk": true,
  "net.mk": true,
  "edu.mk": true,
  "gov.mk": true,
  "inf.mk": true,
  "name.mk": true,
  "pro.mk": true,
  "com.ml": true,
  "net.ml": true,
  "org.ml": true,
  "edu.ml": true,
  "gov.ml": true,
  "presse.ml": true,
  "gov.mn": true,
  "edu.mn": true,
  "org.mn": true,
  "com.mo": true,
  "edu.mo": true,
  "gov.mo": true,
  "net.mo": true,
  "org.mo": true,
  "com.mt": true,
  "org.mt": true,
  "net.mt": true,
  "edu.mt": true,
  "gov.mt": true,
  "aero.mv": true,
  "biz.mv": true,
  "com.mv": true,
  "coop.mv": true,
  "edu.mv": true,
  "gov.mv": true,
  "info.mv": true,
  "int.mv": true,
  "mil.mv": true,
  "museum.mv": true,
  "name.mv": true,
  "net.mv": true,
  "org.mv": true,
  "pro.mv": true,
  "ac.mw": true,
  "co.mw": true,
  "com.mw": true,
  "coop.mw": true,
  "edu.mw": true,
  "gov.mw": true,
  "int.mw": true,
  "museum.mw": true,
  "net.mw": true,
  "org.mw": true,
  "com.mx": true,
  "net.mx": true,
  "org.mx": true,
  "edu.mx": true,
  "gob.mx": true,
  "com.my": true,
  "net.my": true,
  "org.my": true,
  "gov.my": true,
  "edu.my": true,
  "sch.my": true,
  "mil.my": true,
  "name.my": true,
  "com.nf": true,
  "net.nf": true,
  "arts.nf": true,
  "store.nf": true,
  "web.nf": true,
  "firm.nf": true,
  "info.nf": true,
  "other.nf": true,
  "per.nf": true,
  "rec.nf": true,
  "com.ng": true,
  "org.ng": true,
  "gov.ng": true,
  "edu.ng": true,
  "net.ng": true,
  "sch.ng": true,
  "name.ng": true,
  "mobi.ng": true,
  "biz.ng": true,
  "mil.ng": true,
  "gob.ni": true,
  "co.ni": true,
  "com.ni": true,
  "ac.ni": true,
  "edu.ni": true,
  "org.ni": true,
  "nom.ni": true,
  "net.ni": true,
  "mil.ni": true,
  "com.np": true,
  "edu.np": true,
  "gov.np": true,
  "org.np": true,
  "mil.np": true,
  "net.np": true,
  "edu.nr": true,
  "gov.nr": true,
  "biz.nr": true,
  "info.nr": true,
  "net.nr": true,
  "org.nr": true,
  "com.nr": true,
  "com.om": true,
  "co.om": true,
  "edu.om": true,
  "ac.om": true,
  "sch.om": true,
  "gov.om": true,
  "net.om": true,
  "org.om": true,
  "mil.om": true,
  "museum.om": true,
  "biz.om": true,
  "pro.om": true,
  "med.om": true,
  "edu.pe": true,
  "gob.pe": true,
  "nom.pe": true,
  "mil.pe": true,
  "sld.pe": true,
  "org.pe": true,
  "com.pe": true,
  "net.pe": true,
  "com.ph": true,
  "net.ph": true,
  "org.ph": true,
  "mil.ph": true,
  "ngo.ph": true,
  "i.ph": true,
  "gov.ph": true,
  "edu.ph": true,
  "com.pk": true,
  "net.pk": true,
  "edu.pk": true,
  "org.pk": true,
  "fam.pk": true,
  "biz.pk": true,
  "web.pk": true,
  "gov.pk": true,
  "gob.pk": true,
  "gok.pk": true,
  "gon.pk": true,
  "gop.pk": true,
  "gos.pk": true,
  "pwr.pl": true,
  "com.pl": true,
  "biz.pl": true,
  "net.pl": true,
  "art.pl": true,
  "edu.pl": true,
  "org.pl": true,
  "ngo.pl": true,
  "gov.pl": true,
  "info.pl": true,
  "mil.pl": true,
  "waw.pl": true,
  "warszawa.pl": true,
  "wroc.pl": true,
  "wroclaw.pl": true,
  "krakow.pl": true,
  "katowice.pl": true,
  "poznan.pl": true,
  "lodz.pl": true,
  "gda.pl": true,
  "gdansk.pl": true,
  "slupsk.pl": true,
  "radom.pl": true,
  "szczecin.pl": true,
  "lublin.pl": true,
  "bialystok.pl": true,
  "olsztyn.pl": true,
  "torun.pl": true,
  "gorzow.pl": true,
  "zgora.pl": true,
  "biz.pr": true,
  "com.pr": true,
  "edu.pr": true,
  "gov.pr": true,
  "info.pr": true,
  "isla.pr": true,
  "name.pr": true,
  "net.pr": true,
  "org.pr": true,
  "pro.pr": true,
  "est.pr": true,
  "prof.pr": true,
  "ac.pr": true,
  "com.ps": true,
  "net.ps": true,
  "org.ps": true,
  "edu.ps": true,
  "gov.ps": true,
  "plo.ps": true,
  "sec.ps": true,
  "co.pw": true,
  "ne.pw": true,
  "or.pw": true,
  "ed.pw": true,
  "go.pw": true,
  "belau.pw": true,
  "arts.ro": true,
  "com.ro": true,
  "firm.ro": true,
  "info.ro": true,
  "nom.ro": true,
  "nt.ro": true,
  "org.ro": true,
  "rec.ro": true,
  "store.ro": true,
  "tm.ro": true,
  "www.ro": true,
  "co.rs": true,
  "org.rs": true,
  "edu.rs": true,
  "ac.rs": true,
  "gov.rs": true,
  "in.rs": true,
  "com.sb": true,
  "net.sb": true,
  "edu.sb": true,
  "org.sb": true,
  "gov.sb": true,
  "com.sc": true,
  "net.sc": true,
  "edu.sc": true,
  "gov.sc": true,
  "org.sc": true,
  "co.sh": true,
  "com.sh": true,
  "org.sh": true,
  "gov.sh": true,
  "edu.sh": true,
  "net.sh": true,
  "nom.sh": true,
  "com.sl": true,
  "net.sl": true,
  "org.sl": true,
  "edu.sl": true,
  "gov.sl": true,
  "gov.st": true,
  "saotome.st": true,
  "principe.st": true,
  "consulado.st": true,
  "embaixada.st": true,
  "org.st": true,
  "edu.st": true,
  "net.st": true,
  "com.st": true,
  "store.st": true,
  "mil.st": true,
  "co.st": true,
  "edu.sv": true,
  "gob.sv": true,
  "com.sv": true,
  "org.sv": true,
  "red.sv": true,
  "co.sz": true,
  "ac.sz": true,
  "org.sz": true,
  "com.tr": true,
  "gen.tr": true,
  "org.tr": true,
  "biz.tr": true,
  "info.tr": true,
  "av.tr": true,
  "dr.tr": true,
  "pol.tr": true,
  "bel.tr": true,
  "tsk.tr": true,
  "bbs.tr": true,
  "k12.tr": true,
  "edu.tr": true,
  "name.tr": true,
  "net.tr": true,
  "gov.tr": true,
  "web.tr": true,
  "tel.tr": true,
  "tv.tr": true,
  "co.tt": true,
  "com.tt": true,
  "org.tt": true,
  "net.tt": true,
  "biz.tt": true,
  "info.tt": true,
  "pro.tt": true,
  "int.tt": true,
  "coop.tt": true,
  "jobs.tt": true,
  "mobi.tt": true,
  "travel.tt": true,
  "museum.tt": true,
  "aero.tt": true,
  "cat.tt": true,
  "tel.tt": true,
  "name.tt": true,
  "mil.tt": true,
  "edu.tt": true,
  "gov.tt": true,
  "edu.tw": true,
  "gov.tw": true,
  "mil.tw": true,
  "com.tw": true,
  "net.tw": true,
  "org.tw": true,
  "idv.tw": true,
  "game.tw": true,
  "ebiz.tw": true,
  "club.tw": true,
  "com.mu": true,
  "gov.mu": true,
  "net.mu": true,
  "org.mu": true,
  "ac.mu": true,
  "co.mu": true,
  "or.mu": true,
  "ac.mz": true,
  "co.mz": true,
  "edu.mz": true,
  "org.mz": true,
  "gov.mz": true,
  "com.na": true,
  "co.na": true,
  "ac.nz": true,
  "co.nz": true,
  "cri.nz": true,
  "geek.nz": true,
  "gen.nz": true,
  "govt.nz": true,
  "health.nz": true,
  "iwi.nz": true,
  "maori.nz": true,
  "mil.nz": true,
  "net.nz": true,
  "org.nz": true,
  "parliament.nz": true,
  "school.nz": true,
  "abo.pa": true,
  "ac.pa": true,
  "com.pa": true,
  "edu.pa": true,
  "gob.pa": true,
  "ing.pa": true,
  "med.pa": true,
  "net.pa": true,
  "nom.pa": true,
  "org.pa": true,
  "sld.pa": true,
  "com.pt": true,
  "edu.pt": true,
  "gov.pt": true,
  "int.pt": true,
  "net.pt": true,
  "nome.pt": true,
  "org.pt": true,
  "publ.pt": true,
  "com.py": true,
  "edu.py": true,
  "gov.py": true,
  "mil.py": true,
  "net.py": true,
  "org.py": true,
  "com.qa": true,
  "edu.qa": true,
  "gov.qa": true,
  "mil.qa": true,
  "net.qa": true,
  "org.qa": true,
  "asso.re": true,
  "com.re": true,
  "nom.re": true,
  "ac.ru": true,
  "adygeya.ru": true,
  "altai.ru": true,
  "amur.ru": true,
  "arkhangelsk.ru": true,
  "astrakhan.ru": true,
  "bashkiria.ru": true,
  "belgorod.ru": true,
  "bir.ru": true,
  "bryansk.ru": true,
  "buryatia.ru": true,
  "cbg.ru": true,
  "chel.ru": true,
  "chelyabinsk.ru": true,
  "chita.ru": true,
  "chukotka.ru": true,
  "chuvashia.ru": true,
  "com.ru": true,
  "dagestan.ru": true,
  "e-burg.ru": true,
  "edu.ru": true,
  "gov.ru": true,
  "grozny.ru": true,
  "int.ru": true,
  "irkutsk.ru": true,
  "ivanovo.ru": true,
  "izhevsk.ru": true,
  "jar.ru": true,
  "joshkar-ola.ru": true,
  "kalmykia.ru": true,
  "kaluga.ru": true,
  "kamchatka.ru": true,
  "karelia.ru": true,
  "kazan.ru": true,
  "kchr.ru": true,
  "kemerovo.ru": true,
  "khabarovsk.ru": true,
  "khakassia.ru": true,
  "khv.ru": true,
  "kirov.ru": true,
  "koenig.ru": true,
  "komi.ru": true,
  "kostroma.ru": true,
  "kranoyarsk.ru": true,
  "kuban.ru": true,
  "kurgan.ru": true,
  "kursk.ru": true,
  "lipetsk.ru": true,
  "magadan.ru": true,
  "mari.ru": true,
  "mari-el.ru": true,
  "marine.ru": true,
  "mil.ru": true,
  "mordovia.ru": true,
  "mosreg.ru": true,
  "msk.ru": true,
  "murmansk.ru": true,
  "nalchik.ru": true,
  "net.ru": true,
  "nnov.ru": true,
  "nov.ru": true,
  "novosibirsk.ru": true,
  "nsk.ru": true,
  "omsk.ru": true,
  "orenburg.ru": true,
  "org.ru": true,
  "oryol.ru": true,
  "penza.ru": true,
  "perm.ru": true,
  "pp.ru": true,
  "pskov.ru": true,
  "ptz.ru": true,
  "rnd.ru": true,
  "ryazan.ru": true,
  "sakhalin.ru": true,
  "samara.ru": true,
  "saratov.ru": true,
  "simbirsk.ru": true,
  "smolensk.ru": true,
  "spb.ru": true,
  "stavropol.ru": true,
  "stv.ru": true,
  "surgut.ru": true,
  "tambov.ru": true,
  "tatarstan.ru": true,
  "tom.ru": true,
  "tomsk.ru": true,
  "tsaritsyn.ru": true,
  "tsk.ru": true,
  "tula.ru": true,
  "tuva.ru": true,
  "tver.ru": true,
  "tyumen.ru": true,
  "udm.ru": true,
  "udmurtia.ru": true,
  "ulan-ude.ru": true,
  "vladikavkaz.ru": true,
  "vladimir.ru": true,
  "vladivostok.ru": true,
  "volgograd.ru": true,
  "vologda.ru": true,
  "voronezh.ru": true,
  "vrn.ru": true,
  "vyatka.ru": true,
  "yakutia.ru": true,
  "yamal.ru": true,
  "yekaterinburg.ru": true,
  "yuzhno-sakhalinsk.ru": true,
  "ac.rw": true,
  "co.rw": true,
  "com.rw": true,
  "edu.rw": true,
  "gouv.rw": true,
  "gov.rw": true,
  "int.rw": true,
  "mil.rw": true,
  "net.rw": true,
  "com.sa": true,
  "edu.sa": true,
  "gov.sa": true,
  "med.sa": true,
  "net.sa": true,
  "org.sa": true,
  "pub.sa": true,
  "sch.sa": true,
  "com.sd": true,
  "edu.sd": true,
  "gov.sd": true,
  "info.sd": true,
  "med.sd": true,
  "net.sd": true,
  "org.sd": true,
  "tv.sd": true,
  "a.se": true,
  "ac.se": true,
  "b.se": true,
  "bd.se": true,
  "c.se": true,
  "d.se": true,
  "e.se": true,
  "f.se": true,
  "g.se": true,
  "h.se": true,
  "i.se": true,
  "k.se": true,
  "l.se": true,
  "m.se": true,
  "n.se": true,
  "o.se": true,
  "org.se": true,
  "p.se": true,
  "parti.se": true,
  "pp.se": true,
  "press.se": true,
  "r.se": true,
  "s.se": true,
  "t.se": true,
  "tm.se": true,
  "u.se": true,
  "w.se": true,
  "x.se": true,
  "y.se": true,
  "z.se": true,
  "com.sg": true,
  "edu.sg": true,
  "gov.sg": true,
  "idn.sg": true,
  "net.sg": true,
  "org.sg": true,
  "per.sg": true,
  "art.sn": true,
  "com.sn": true,
  "edu.sn": true,
  "gouv.sn": true,
  "org.sn": true,
  "perso.sn": true,
  "univ.sn": true,
  "com.sy": true,
  "edu.sy": true,
  "gov.sy": true,
  "mil.sy": true,
  "net.sy": true,
  "news.sy": true,
  "org.sy": true,
  "ac.th": true,
  "co.th": true,
  "go.th": true,
  "in.th": true,
  "mi.th": true,
  "net.th": true,
  "or.th": true,
  "ac.tj": true,
  "biz.tj": true,
  "co.tj": true,
  "com.tj": true,
  "edu.tj": true,
  "go.tj": true,
  "gov.tj": true,
  "info.tj": true,
  "int.tj": true,
  "mil.tj": true,
  "name.tj": true,
  "net.tj": true,
  "nic.tj": true,
  "org.tj": true,
  "test.tj": true,
  "web.tj": true,
  "agrinet.tn": true,
  "com.tn": true,
  "defense.tn": true,
  "edunet.tn": true,
  "ens.tn": true,
  "fin.tn": true,
  "gov.tn": true,
  "ind.tn": true,
  "info.tn": true,
  "intl.tn": true,
  "mincom.tn": true,
  "nat.tn": true,
  "net.tn": true,
  "org.tn": true,
  "perso.tn": true,
  "rnrt.tn": true,
  "rns.tn": true,
  "rnu.tn": true,
  "tourism.tn": true,
  "ac.tz": true,
  "co.tz": true,
  "go.tz": true,
  "ne.tz": true,
  "or.tz": true,
  "biz.ua": true,
  "cherkassy.ua": true,
  "chernigov.ua": true,
  "chernovtsy.ua": true,
  "ck.ua": true,
  "cn.ua": true,
  "co.ua": true,
  "com.ua": true,
  "crimea.ua": true,
  "cv.ua": true,
  "dn.ua": true,
  "dnepropetrovsk.ua": true,
  "donetsk.ua": true,
  "dp.ua": true,
  "edu.ua": true,
  "gov.ua": true,
  "if.ua": true,
  "in.ua": true,
  "ivano-frankivsk.ua": true,
  "kh.ua": true,
  "kharkov.ua": true,
  "kherson.ua": true,
  "khmelnitskiy.ua": true,
  "kiev.ua": true,
  "kirovograd.ua": true,
  "km.ua": true,
  "kr.ua": true,
  "ks.ua": true,
  "kv.ua": true,
  "lg.ua": true,
  "lugansk.ua": true,
  "lutsk.ua": true,
  "lviv.ua": true,
  "me.ua": true,
  "mk.ua": true,
  "net.ua": true,
  "nikolaev.ua": true,
  "od.ua": true,
  "odessa.ua": true,
  "org.ua": true,
  "pl.ua": true,
  "poltava.ua": true,
  "pp.ua": true,
  "rovno.ua": true,
  "rv.ua": true,
  "sebastopol.ua": true,
  "sumy.ua": true,
  "te.ua": true,
  "ternopil.ua": true,
  "uzhgorod.ua": true,
  "vinnica.ua": true,
  "vn.ua": true,
  "zaporizhzhe.ua": true,
  "zhitomir.ua": true,
  "zp.ua": true,
  "zt.ua": true,
  "ac.ug": true,
  "co.ug": true,
  "go.ug": true,
  "ne.ug": true,
  "or.ug": true,
  "org.ug": true,
  "sc.ug": true,
  "ac.uk": true,
  "bl.uk": true,
  "british-library.uk": true,
  "co.uk": true,
  "cym.uk": true,
  "gov.uk": true,
  "govt.uk": true,
  "icnet.uk": true,
  "jet.uk": true,
  "lea.uk": true,
  "ltd.uk": true,
  "me.uk": true,
  "mil.uk": true,
  "mod.uk": true,
  "national-library-scotland.uk": true,
  "nel.uk": true,
  "net.uk": true,
  "nhs.uk": true,
  "nic.uk": true,
  "nls.uk": true,
  "org.uk": true,
  "orgn.uk": true,
  "parliament.uk": true,
  "plc.uk": true,
  "police.uk": true,
  "sch.uk": true,
  "scot.uk": true,
  "soc.uk": true,
  "4fd.us": true,
  "dni.us": true,
  "fed.us": true,
  "isa.us": true,
  "kids.us": true,
  "nsn.us": true,
  "com.uy": true,
  "edu.uy": true,
  "gub.uy": true,
  "mil.uy": true,
  "net.uy": true,
  "org.uy": true,
  "co.ve": true,
  "com.ve": true,
  "edu.ve": true,
  "gob.ve": true,
  "info.ve": true,
  "mil.ve": true,
  "net.ve": true,
  "org.ve": true,
  "web.ve": true,
  "co.vi": true,
  "com.vi": true,
  "k12.vi": true,
  "net.vi": true,
  "org.vi": true,
  "ac.vn": true,
  "biz.vn": true,
  "com.vn": true,
  "edu.vn": true,
  "gov.vn": true,
  "health.vn": true,
  "info.vn": true,
  "int.vn": true,
  "name.vn": true,
  "net.vn": true,
  "org.vn": true,
  "pro.vn": true,
  "co.ye": true,
  "com.ye": true,
  "gov.ye": true,
  "ltd.ye": true,
  "me.ye": true,
  "net.ye": true,
  "org.ye": true,
  "plc.ye": true,
  "ac.yu": true,
  "co.yu": true,
  "edu.yu": true,
  "gov.yu": true,
  "org.yu": true,
  "ac.za": true,
  "agric.za": true,
  "alt.za": true,
  "bourse.za": true,
  "city.za": true,
  "co.za": true,
  "cybernet.za": true,
  "db.za": true,
  "ecape.school.za": true,
  "edu.za": true,
  "fs.school.za": true,
  "gov.za": true,
  "gp.school.za": true,
  "grondar.za": true,
  "iaccess.za": true,
  "imt.za": true,
  "inca.za": true,
  "kzn.school.za": true,
  "landesign.za": true,
  "law.za": true,
  "lp.school.za": true,
  "mil.za": true,
  "mpm.school.za": true,
  "ncape.school.za": true,
  "net.za": true,
  "ngo.za": true,
  "nis.za": true,
  "nom.za": true,
  "nw.school.za": true,
  "olivetti.za": true,
  "org.za": true,
  "pix.za": true,
  "school.za": true,
  "tm.za": true,
  "wcape.school.za": true,
  "web.za": true,
  "ac.zm": true,
  "co.zm": true,
  "com.zm": true,
  "edu.zm": true,
  "gov.zm": true,
  "net.zm": true,
  "org.zm": true,
  "sch.zm": true
}
},{}],94:[function(require,module,exports){
module.exports=function(e,t,o,i){var n=new Blob(void 0!==i?[i,e]:[e],{type:o||"application/octet-stream"});if(void 0!==window.navigator.msSaveBlob)window.navigator.msSaveBlob(n,t);else{var d=window.URL&&window.URL.createObjectURL?window.URL.createObjectURL(n):window.webkitURL.createObjectURL(n),a=document.createElement("a");a.style.display="none",a.href=d,a.setAttribute("download",t),void 0===a.download&&a.setAttribute("target","_blank"),document.body.appendChild(a),a.click(),setTimeout((function(){document.body.removeChild(a),window.URL.revokeObjectURL(d)}),200)}};

},{}],95:[function(require,module,exports){
module.exports=[{name:"Abkhaz",local:"Аҧсуа",1:"ab",2:"abk","2T":"abk","2B":"abk",3:"abk"},{name:"Afar",local:"Afaraf",1:"aa",2:"aar","2T":"aar","2B":"aar",3:"aar"},{name:"Afrikaans",local:"Afrikaans",1:"af",2:"afr","2T":"afr","2B":"afr",3:"afr"},{name:"Akan",local:"Akan",1:"ak",2:"aka","2T":"aka","2B":"aka",3:"aka"},{name:"Albanian",local:"Shqip",1:"sq",2:"sqi","2T":"sqi","2B":"alb",3:"sqi"},{name:"Amharic",local:"አማርኛ",1:"am",2:"amh","2T":"amh","2B":"amh",3:"amh"},{name:"Arabic",local:"العربية",1:"ar",2:"ara","2T":"ara","2B":"ara",3:"ara"},{name:"Aragonese",local:"Aragonés",1:"an",2:"arg","2T":"arg","2B":"arg",3:"arg"},{name:"Armenian",local:"Հայերեն",1:"hy",2:"hye","2T":"hye","2B":"arm",3:"hye"},{name:"Assamese",local:"অসমীয়া",1:"as",2:"asm","2T":"asm","2B":"asm",3:"asm"},{name:"Avaric",local:"Авар",1:"av",2:"ava","2T":"ava","2B":"ava",3:"ava"},{name:"Avestan",local:"avesta",1:"ae",2:"ave","2T":"ave","2B":"ave",3:"ave"},{name:"Aymara",local:"Aymar",1:"ay",2:"aym","2T":"aym","2B":"aym",3:"aym"},{name:"Azerbaijani",local:"Azərbaycanca",1:"az",2:"aze","2T":"aze","2B":"aze",3:"aze"},{name:"Bambara",local:"Bamanankan",1:"bm",2:"bam","2T":"bam","2B":"bam",3:"bam"},{name:"Bashkir",local:"Башҡортса",1:"ba",2:"bak","2T":"bak","2B":"bak",3:"bak"},{name:"Basque",local:"Euskara",1:"eu",2:"eus","2T":"eus","2B":"baq",3:"eus"},{name:"Belarusian",local:"Беларуская",1:"be",2:"bel","2T":"bel","2B":"bel",3:"bel"},{name:"Bengali",local:"বাংলা",1:"bn",2:"ben","2T":"ben","2B":"ben",3:"ben"},{name:"Bihari",local:"भोजपुरी",1:"bh",2:"bih","2T":"bih","2B":"bih",3:"bih"},{name:"Bislama",local:"Bislama",1:"bi",2:"bis","2T":"bis","2B":"bis",3:"bis"},{name:"Bosnian",local:"Bosanski",1:"bs",2:"bos","2T":"bos","2B":"bos",3:"bos"},{name:"Breton",local:"Brezhoneg",1:"br",2:"bre","2T":"bre","2B":"bre",3:"bre"},{name:"Bulgarian",local:"Български",1:"bg",2:"bul","2T":"bul","2B":"bul",3:"bul"},{name:"Burmese",local:"မြန်မာဘာသာ",1:"my",2:"mya","2T":"mya","2B":"bur",3:"mya"},{name:"Catalan",local:"Català",1:"ca",2:"cat","2T":"cat","2B":"cat",3:"cat"},{name:"Chamorro",local:"Chamoru",1:"ch",2:"cha","2T":"cha","2B":"cha",3:"cha"},{name:"Chechen",local:"Нохчийн",1:"ce",2:"che","2T":"che","2B":"che",3:"che"},{name:"Chichewa",local:"Chichewa",1:"ny",2:"nya","2T":"nya","2B":"nya",3:"nya"},{name:"Chinese",local:"中文",1:"zh",2:"zho","2T":"zho","2B":"chi",3:"zho"},{name:"Chuvash",local:"Чӑвашла",1:"cv",2:"chv","2T":"chv","2B":"chv",3:"chv"},{name:"Cornish",local:"Kernewek",1:"kw",2:"cor","2T":"cor","2B":"cor",3:"cor"},{name:"Corsican",local:"Corsu",1:"co",2:"cos","2T":"cos","2B":"cos",3:"cos"},{name:"Cree",local:"ᓀᐦᐃᔭᐍᐏᐣ",1:"cr",2:"cre","2T":"cre","2B":"cre",3:"cre"},{name:"Croatian",local:"Hrvatski",1:"hr",2:"hrv","2T":"hrv","2B":"hrv",3:"hrv"},{name:"Czech",local:"Čeština",1:"cs",2:"ces","2T":"ces","2B":"cze",3:"ces"},{name:"Danish",local:"Dansk",1:"da",2:"dan","2T":"dan","2B":"dan",3:"dan"},{name:"Divehi",local:"Divehi",1:"dv",2:"div","2T":"div","2B":"div",3:"div"},{name:"Dutch",local:"Nederlands",1:"nl",2:"nld","2T":"nld","2B":"dut",3:"nld"},{name:"Dzongkha",local:"རྫོང་ཁ",1:"dz",2:"dzo","2T":"dzo","2B":"dzo",3:"dzo"},{name:"English",local:"English",1:"en",2:"eng","2T":"eng","2B":"eng",3:"eng"},{name:"Esperanto",local:"Esperanto",1:"eo",2:"epo","2T":"epo","2B":"epo",3:"epo"},{name:"Estonian",local:"Eesti",1:"et",2:"est","2T":"est","2B":"est",3:"est"},{name:"Ewe",local:"Eʋegbe",1:"ee",2:"ewe","2T":"ewe","2B":"ewe",3:"ewe"},{name:"Faroese",local:"Føroyskt",1:"fo",2:"fao","2T":"fao","2B":"fao",3:"fao"},{name:"Fijian",local:"Na Vosa Vaka-Viti",1:"fj",2:"fij","2T":"fij","2B":"fij",3:"fij"},{name:"Finnish",local:"Suomi",1:"fi",2:"fin","2T":"fin","2B":"fin",3:"fin"},{name:"French",local:"Français",1:"fr",2:"fra","2T":"fra","2B":"fre",3:"fra"},{name:"Fula",local:"Fulfulde",1:"ff",2:"ful","2T":"ful","2B":"ful",3:"ful"},{name:"Galician",local:"Galego",1:"gl",2:"glg","2T":"glg","2B":"glg",3:"glg"},{name:"Georgian",local:"ქართული",1:"ka",2:"kat","2T":"kat","2B":"geo",3:"kat"},{name:"German",local:"Deutsch",1:"de",2:"deu","2T":"deu","2B":"ger",3:"deu"},{name:"Greek",local:"Ελληνικά",1:"el",2:"ell","2T":"ell","2B":"gre",3:"ell"},{name:"Guaraní",local:"Avañe'ẽ",1:"gn",2:"grn","2T":"grn","2B":"grn",3:"grn"},{name:"Gujarati",local:"ગુજરાતી",1:"gu",2:"guj","2T":"guj","2B":"guj",3:"guj"},{name:"Haitian",local:"Kreyòl Ayisyen",1:"ht",2:"hat","2T":"hat","2B":"hat",3:"hat"},{name:"Hausa",local:"هَوُسَ",1:"ha",2:"hau","2T":"hau","2B":"hau",3:"hau"},{name:"Hebrew",local:"עברית",1:"he",2:"heb","2T":"heb","2B":"heb",3:"heb"},{name:"Herero",local:"Otjiherero",1:"hz",2:"her","2T":"her","2B":"her",3:"her"},{name:"Hindi",local:"हिन्दी",1:"hi",2:"hin","2T":"hin","2B":"hin",3:"hin"},{name:"Hiri Motu",local:"Hiri Motu",1:"ho",2:"hmo","2T":"hmo","2B":"hmo",3:"hmo"},{name:"Hungarian",local:"Magyar",1:"hu",2:"hun","2T":"hun","2B":"hun",3:"hun"},{name:"Interlingua",local:"Interlingua",1:"ia",2:"ina","2T":"ina","2B":"ina",3:"ina"},{name:"Indonesian",local:"Bahasa Indonesia",1:"id",2:"ind","2T":"ind","2B":"ind",3:"ind"},{name:"Interlingue",local:"Interlingue",1:"ie",2:"ile","2T":"ile","2B":"ile",3:"ile"},{name:"Irish",local:"Gaeilge",1:"ga",2:"gle","2T":"gle","2B":"gle",3:"gle"},{name:"Igbo",local:"Igbo",1:"ig",2:"ibo","2T":"ibo","2B":"ibo",3:"ibo"},{name:"Inupiaq",local:"Iñupiak",1:"ik",2:"ipk","2T":"ipk","2B":"ipk",3:"ipk"},{name:"Ido",local:"Ido",1:"io",2:"ido","2T":"ido","2B":"ido",3:"ido"},{name:"Icelandic",local:"Íslenska",1:"is",2:"isl","2T":"isl","2B":"ice",3:"isl"},{name:"Italian",local:"Italiano",1:"it",2:"ita","2T":"ita","2B":"ita",3:"ita"},{name:"Inuktitut",local:"ᐃᓄᒃᑎᑐᑦ",1:"iu",2:"iku","2T":"iku","2B":"iku",3:"iku"},{name:"Japanese",local:"日本語",1:"ja",2:"jpn","2T":"jpn","2B":"jpn",3:"jpn"},{name:"Javanese",local:"Basa Jawa",1:"jv",2:"jav","2T":"jav","2B":"jav",3:"jav"},{name:"Kalaallisut",local:"Kalaallisut",1:"kl",2:"kal","2T":"kal","2B":"kal",3:"kal"},{name:"Kannada",local:"ಕನ್ನಡ",1:"kn",2:"kan","2T":"kan","2B":"kan",3:"kan"},{name:"Kanuri",local:"Kanuri",1:"kr",2:"kau","2T":"kau","2B":"kau",3:"kau"},{name:"Kashmiri",local:"كشميري",1:"ks",2:"kas","2T":"kas","2B":"kas",3:"kas"},{name:"Kazakh",local:"Қазақша",1:"kk",2:"kaz","2T":"kaz","2B":"kaz",3:"kaz"},{name:"Khmer",local:"ភាសាខ្មែរ",1:"km",2:"khm","2T":"khm","2B":"khm",3:"khm"},{name:"Kikuyu",local:"Gĩkũyũ",1:"ki",2:"kik","2T":"kik","2B":"kik",3:"kik"},{name:"Kinyarwanda",local:"Kinyarwanda",1:"rw",2:"kin","2T":"kin","2B":"kin",3:"kin"},{name:"Kyrgyz",local:"Кыргызча",1:"ky",2:"kir","2T":"kir","2B":"kir",3:"kir"},{name:"Komi",local:"Коми",1:"kv",2:"kom","2T":"kom","2B":"kom",3:"kom"},{name:"Kongo",local:"Kongo",1:"kg",2:"kon","2T":"kon","2B":"kon",3:"kon"},{name:"Korean",local:"한국어",1:"ko",2:"kor","2T":"kor","2B":"kor",3:"kor"},{name:"Kurdish",local:"Kurdî",1:"ku",2:"kur","2T":"kur","2B":"kur",3:"kur"},{name:"Kwanyama",local:"Kuanyama",1:"kj",2:"kua","2T":"kua","2B":"kua",3:"kua"},{name:"Latin",local:"Latina",1:"la",2:"lat","2T":"lat","2B":"lat",3:"lat"},{name:"Luxembourgish",local:"Lëtzebuergesch",1:"lb",2:"ltz","2T":"ltz","2B":"ltz",3:"ltz"},{name:"Ganda",local:"Luganda",1:"lg",2:"lug","2T":"lug","2B":"lug",3:"lug"},{name:"Limburgish",local:"Limburgs",1:"li",2:"lim","2T":"lim","2B":"lim",3:"lim"},{name:"Lingala",local:"Lingála",1:"ln",2:"lin","2T":"lin","2B":"lin",3:"lin"},{name:"Lao",local:"ພາສາລາວ",1:"lo",2:"lao","2T":"lao","2B":"lao",3:"lao"},{name:"Lithuanian",local:"Lietuvių",1:"lt",2:"lit","2T":"lit","2B":"lit",3:"lit"},{name:"Luba-Katanga",local:"Tshiluba",1:"lu",2:"lub","2T":"lub","2B":"lub",3:"lub"},{name:"Latvian",local:"Latviešu",1:"lv",2:"lav","2T":"lav","2B":"lav",3:"lav"},{name:"Manx",local:"Gaelg",1:"gv",2:"glv","2T":"glv","2B":"glv",3:"glv"},{name:"Macedonian",local:"Македонски",1:"mk",2:"mkd","2T":"mkd","2B":"mac",3:"mkd"},{name:"Malagasy",local:"Malagasy",1:"mg",2:"mlg","2T":"mlg","2B":"mlg",3:"mlg"},{name:"Malay",local:"Bahasa Melayu",1:"ms",2:"msa","2T":"msa","2B":"may",3:"msa"},{name:"Malayalam",local:"മലയാളം",1:"ml",2:"mal","2T":"mal","2B":"mal",3:"mal"},{name:"Maltese",local:"Malti",1:"mt",2:"mlt","2T":"mlt","2B":"mlt",3:"mlt"},{name:"Māori",local:"Māori",1:"mi",2:"mri","2T":"mri","2B":"mao",3:"mri"},{name:"Marathi",local:"मराठी",1:"mr",2:"mar","2T":"mar","2B":"mar",3:"mar"},{name:"Marshallese",local:"Kajin M̧ajeļ",1:"mh",2:"mah","2T":"mah","2B":"mah",3:"mah"},{name:"Mongolian",local:"Монгол",1:"mn",2:"mon","2T":"mon","2B":"mon",3:"mon"},{name:"Nauru",local:"Dorerin Naoero",1:"na",2:"nau","2T":"nau","2B":"nau",3:"nau"},{name:"Navajo",local:"Diné Bizaad",1:"nv",2:"nav","2T":"nav","2B":"nav",3:"nav"},{name:"Northern Ndebele",local:"isiNdebele",1:"nd",2:"nde","2T":"nde","2B":"nde",3:"nde"},{name:"Nepali",local:"नेपाली",1:"ne",2:"nep","2T":"nep","2B":"nep",3:"nep"},{name:"Ndonga",local:"Owambo",1:"ng",2:"ndo","2T":"ndo","2B":"ndo",3:"ndo"},{name:"Norwegian Bokmål",local:"Norsk (Bokmål)",1:"nb",2:"nob","2T":"nob","2B":"nob",3:"nob"},{name:"Norwegian Nynorsk",local:"Norsk (Nynorsk)",1:"nn",2:"nno","2T":"nno","2B":"nno",3:"nno"},{name:"Norwegian",local:"Norsk",1:"no",2:"nor","2T":"nor","2B":"nor",3:"nor"},{name:"Nuosu",local:"ꆈꌠ꒿ Nuosuhxop",1:"ii",2:"iii","2T":"iii","2B":"iii",3:"iii"},{name:"Southern Ndebele",local:"isiNdebele",1:"nr",2:"nbl","2T":"nbl","2B":"nbl",3:"nbl"},{name:"Occitan",local:"Occitan",1:"oc",2:"oci","2T":"oci","2B":"oci",3:"oci"},{name:"Ojibwe",local:"ᐊᓂᔑᓈᐯᒧᐎᓐ",1:"oj",2:"oji","2T":"oji","2B":"oji",3:"oji"},{name:"Old Church Slavonic",local:"Словѣ́ньскъ",1:"cu",2:"chu","2T":"chu","2B":"chu",3:"chu"},{name:"Oromo",local:"Afaan Oromoo",1:"om",2:"orm","2T":"orm","2B":"orm",3:"orm"},{name:"Oriya",local:"ଓଡି଼ଆ",1:"or",2:"ori","2T":"ori","2B":"ori",3:"ori"},{name:"Ossetian",local:"Ирон æвзаг",1:"os",2:"oss","2T":"oss","2B":"oss",3:"oss"},{name:"Panjabi",local:"ਪੰਜਾਬੀ",1:"pa",2:"pan","2T":"pan","2B":"pan",3:"pan"},{name:"Pāli",local:"पाऴि",1:"pi",2:"pli","2T":"pli","2B":"pli",3:"pli"},{name:"Persian",local:"فارسی",1:"fa",2:"fas","2T":"fas","2B":"per",3:"fas"},{name:"Polish",local:"Polski",1:"pl",2:"pol","2T":"pol","2B":"pol",3:"pol"},{name:"Pashto",local:"پښتو",1:"ps",2:"pus","2T":"pus","2B":"pus",3:"pus"},{name:"Portuguese",local:"Português",1:"pt",2:"por","2T":"por","2B":"por",3:"por"},{name:"Quechua",local:"Runa Simi",1:"qu",2:"que","2T":"que","2B":"que",3:"que"},{name:"Romansh",local:"Rumantsch",1:"rm",2:"roh","2T":"roh","2B":"roh",3:"roh"},{name:"Kirundi",local:"Kirundi",1:"rn",2:"run","2T":"run","2B":"run",3:"run"},{name:"Romanian",local:"Română",1:"ro",2:"ron","2T":"ron","2B":"rum",3:"ron"},{name:"Russian",local:"Русский",1:"ru",2:"rus","2T":"rus","2B":"rus",3:"rus"},{name:"Sanskrit",local:"संस्कृतम्",1:"sa",2:"san","2T":"san","2B":"san",3:"san"},{name:"Sardinian",local:"Sardu",1:"sc",2:"srd","2T":"srd","2B":"srd",3:"srd"},{name:"Sindhi",local:"سنڌي‎",1:"sd",2:"snd","2T":"snd","2B":"snd",3:"snd"},{name:"Northern Sami",local:"Sámegiella",1:"se",2:"sme","2T":"sme","2B":"sme",3:"sme"},{name:"Samoan",local:"Gagana Sāmoa",1:"sm",2:"smo","2T":"smo","2B":"smo",3:"smo"},{name:"Sango",local:"Sängö",1:"sg",2:"sag","2T":"sag","2B":"sag",3:"sag"},{name:"Serbian",local:"Српски",1:"sr",2:"srp","2T":"srp","2B":"srp",3:"srp"},{name:"Gaelic",local:"Gàidhlig",1:"gd",2:"gla","2T":"gla","2B":"gla",3:"gla"},{name:"Shona",local:"ChiShona",1:"sn",2:"sna","2T":"sna","2B":"sna",3:"sna"},{name:"Sinhala",local:"සිංහල",1:"si",2:"sin","2T":"sin","2B":"sin",3:"sin"},{name:"Slovak",local:"Slovenčina",1:"sk",2:"slk","2T":"slk","2B":"slo",3:"slk"},{name:"Slovene",local:"Slovenščina",1:"sl",2:"slv","2T":"slv","2B":"slv",3:"slv"},{name:"Somali",local:"Soomaaliga",1:"so",2:"som","2T":"som","2B":"som",3:"som"},{name:"Southern Sotho",local:"Sesotho",1:"st",2:"sot","2T":"sot","2B":"sot",3:"sot"},{name:"Spanish",local:"Español",1:"es",2:"spa","2T":"spa","2B":"spa",3:"spa"},{name:"Sundanese",local:"Basa Sunda",1:"su",2:"sun","2T":"sun","2B":"sun",3:"sun"},{name:"Swahili",local:"Kiswahili",1:"sw",2:"swa","2T":"swa","2B":"swa",3:"swa"},{name:"Swati",local:"SiSwati",1:"ss",2:"ssw","2T":"ssw","2B":"ssw",3:"ssw"},{name:"Swedish",local:"Svenska",1:"sv",2:"swe","2T":"swe","2B":"swe",3:"swe"},{name:"Tamil",local:"தமிழ்",1:"ta",2:"tam","2T":"tam","2B":"tam",3:"tam"},{name:"Telugu",local:"తెలుగు",1:"te",2:"tel","2T":"tel","2B":"tel",3:"tel"},{name:"Tajik",local:"Тоҷикӣ",1:"tg",2:"tgk","2T":"tgk","2B":"tgk",3:"tgk"},{name:"Thai",local:"ภาษาไทย",1:"th",2:"tha","2T":"tha","2B":"tha",3:"tha"},{name:"Tigrinya",local:"ትግርኛ",1:"ti",2:"tir","2T":"tir","2B":"tir",3:"tir"},{name:"Tibetan Standard",local:"བོད་ཡིག",1:"bo",2:"bod","2T":"bod","2B":"tib",3:"bod"},{name:"Turkmen",local:"Türkmençe",1:"tk",2:"tuk","2T":"tuk","2B":"tuk",3:"tuk"},{name:"Tagalog",local:"Tagalog",1:"tl",2:"tgl","2T":"tgl","2B":"tgl",3:"tgl"},{name:"Tswana",local:"Setswana",1:"tn",2:"tsn","2T":"tsn","2B":"tsn",3:"tsn"},{name:"Tonga",local:"faka Tonga",1:"to",2:"ton","2T":"ton","2B":"ton",3:"ton"},{name:"Turkish",local:"Türkçe",1:"tr",2:"tur","2T":"tur","2B":"tur",3:"tur"},{name:"Tsonga",local:"Xitsonga",1:"ts",2:"tso","2T":"tso","2B":"tso",3:"tso"},{name:"Tatar",local:"Татарча",1:"tt",2:"tat","2T":"tat","2B":"tat",3:"tat"},{name:"Twi",local:"Twi",1:"tw",2:"twi","2T":"twi","2B":"twi",3:"twi"},{name:"Tahitian",local:"Reo Mā’ohi",1:"ty",2:"tah","2T":"tah","2B":"tah",3:"tah"},{name:"Uyghur",local:"ئۇيغۇرچه",1:"ug",2:"uig","2T":"uig","2B":"uig",3:"uig"},{name:"Ukrainian",local:"Українська",1:"uk",2:"ukr","2T":"ukr","2B":"ukr",3:"ukr"},{name:"Urdu",local:"اردو",1:"ur",2:"urd","2T":"urd","2B":"urd",3:"urd"},{name:"Uzbek",local:"O‘zbek",1:"uz",2:"uzb","2T":"uzb","2B":"uzb",3:"uzb"},{name:"Venda",local:"Tshivenḓa",1:"ve",2:"ven","2T":"ven","2B":"ven",3:"ven"},{name:"Vietnamese",local:"Tiếng Việt",1:"vi",2:"vie","2T":"vie","2B":"vie",3:"vie"},{name:"Volapük",local:"Volapük",1:"vo",2:"vol","2T":"vol","2B":"vol",3:"vol"},{name:"Walloon",local:"Walon",1:"wa",2:"wln","2T":"wln","2B":"wln",3:"wln"},{name:"Welsh",local:"Cymraeg",1:"cy",2:"cym","2T":"cym","2B":"wel",3:"cym"},{name:"Wolof",local:"Wolof",1:"wo",2:"wol","2T":"wol","2B":"wol",3:"wol"},{name:"Western Frisian",local:"Frysk",1:"fy",2:"fry","2T":"fry","2B":"fry",3:"fry"},{name:"Xhosa",local:"isiXhosa",1:"xh",2:"xho","2T":"xho","2B":"xho",3:"xho"},{name:"Yiddish",local:"ייִדיש",1:"yi",2:"yid","2T":"yid","2B":"yid",3:"yid"},{name:"Yoruba",local:"Yorùbá",1:"yo",2:"yor","2T":"yor","2B":"yor",3:"yor"},{name:"Zhuang",local:"Cuengh",1:"za",2:"zha","2T":"zha","2B":"zha",3:"zha"},{name:"Zulu",local:"isiZulu",1:"zu",2:"zul","2T":"zul","2B":"zul",3:"zul"}];

},{}],99:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.urlAlphabet=void 0;const urlAlphabet=exports.urlAlphabet="useandom-26T198340PX75pxJACKVERYMINDBUSHWOLF_GQZbfghjklqvwyzrict";

},{}],100:[function(require,module,exports){
function isUndefined(t){return void 0===t}function isNull(t){return null===t}function isBoolean(t){return"boolean"==typeof t}function isObject(t){return t===Object(t)}function isArray(t){return Array.isArray(t)}function isDate(t){return t instanceof Date}function isBlob(t,i){return i?isObject(t)&&!isUndefined(t.uri):isObject(t)&&"number"==typeof t.size&&"string"==typeof t.type&&"function"==typeof t.slice}function isFile(t,i){return isBlob(t,i)&&"string"==typeof t.name&&(isObject(t.lastModifiedDate)||"number"==typeof t.lastModified)}function initCfg(t){return!isUndefined(t)&&t}function serialize(t,i,n,e){i=i||{},n=n||new FormData,i.indices=initCfg(i.indices),i.nullsAsUndefineds=initCfg(i.nullsAsUndefineds),i.booleansAsIntegers=initCfg(i.booleansAsIntegers),i.allowEmptyArrays=initCfg(i.allowEmptyArrays),i.noAttributesWithArrayNotation=initCfg(i.noAttributesWithArrayNotation),i.noFilesWithArrayNotation=initCfg(i.noFilesWithArrayNotation),i.dotsForObjectNotation=initCfg(i.dotsForObjectNotation);const o="function"==typeof n.getParts;return isUndefined(t)||(isNull(t)?i.nullsAsUndefineds||n.append(e,""):isBoolean(t)?i.booleansAsIntegers?n.append(e,t?1:0):n.append(e,t):isArray(t)?t.length?t.forEach(((t,s)=>{let r=e+"["+(i.indices?s:"")+"]";(i.noAttributesWithArrayNotation||i.noFilesWithArrayNotation&&isFile(t,o))&&(r=e),serialize(t,i,n,r)})):i.allowEmptyArrays&&n.append(i.noAttributesWithArrayNotation?e:e+"[]",""):isDate(t)?n.append(e,t.toISOString()):isObject(t)&&!isBlob(t,o)?Object.keys(t).forEach((o=>{const s=t[o];if(isArray(s))for(;o.length>2&&o.lastIndexOf("[]")===o.length-2;)o=o.substring(0,o.length-2);const r=e?i.dotsForObjectNotation?e+"."+o:e+"["+o+"]":o;serialize(s,i,n,r)})):n.append(e,t)),n}module.exports={serialize:serialize};

},{}],101:[function(require,module,exports){
/* @license
Papa Parse
v5.4.1
https://github.com/mholt/PapaParse
License: MIT
*/
!function(e,t){"function"==typeof define&&define.amd?define([],t):"object"==typeof module&&"undefined"!=typeof exports?module.exports=t():e.Papa=t()}(this,(function e(){"use strict";var t="undefined"!=typeof self?self:"undefined"!=typeof window?window:void 0!==t?t:{},r=!t.document&&!!t.postMessage,i=t.IS_PAPA_WORKER||!1,n={},s=0,a={parse:function(r,i){var o=(i=i||{}).dynamicTyping||!1;if(b(o)&&(i.dynamicTypingFunction=o,o={}),i.dynamicTyping=o,i.transform=!!b(i.transform)&&i.transform,i.worker&&a.WORKERS_SUPPORTED){var u=function(){if(!a.WORKERS_SUPPORTED)return!1;var r,i,o=(r=t.URL||t.webkitURL||null,i=e.toString(),a.BLOB_URL||(a.BLOB_URL=r.createObjectURL(new Blob(["var global = (function() { if (typeof self !== 'undefined') { return self; } if (typeof window !== 'undefined') { return window; } if (typeof global !== 'undefined') { return global; } return {}; })(); global.IS_PAPA_WORKER=true; ","(",i,")();"],{type:"text/javascript"})))),u=new t.Worker(o);return u.onmessage=_,u.id=s++,n[u.id]=u}();return u.userStep=i.step,u.userChunk=i.chunk,u.userComplete=i.complete,u.userError=i.error,i.step=b(i.step),i.chunk=b(i.chunk),i.complete=b(i.complete),i.error=b(i.error),delete i.worker,void u.postMessage({input:r,config:i,workerId:u.id})}var c=null;return a.NODE_STREAM_INPUT,"string"==typeof r?(r=function(e){return 65279===e.charCodeAt(0)?e.slice(1):e}(r),c=i.download?new h(i):new d(i)):!0===r.readable&&b(r.read)&&b(r.on)?c=new l(i):(t.File&&r instanceof File||r instanceof Object)&&(c=new f(i)),c.stream(r)},unparse:function(e,t){var r=!1,i=!0,n=",",s="\r\n",o='"',u=o+o,h=!1,f=null,d=!1;!function(){if("object"==typeof t){if("string"!=typeof t.delimiter||a.BAD_DELIMITERS.filter((function(e){return-1!==t.delimiter.indexOf(e)})).length||(n=t.delimiter),("boolean"==typeof t.quotes||"function"==typeof t.quotes||Array.isArray(t.quotes))&&(r=t.quotes),"boolean"!=typeof t.skipEmptyLines&&"string"!=typeof t.skipEmptyLines||(h=t.skipEmptyLines),"string"==typeof t.newline&&(s=t.newline),"string"==typeof t.quoteChar&&(o=t.quoteChar),"boolean"==typeof t.header&&(i=t.header),Array.isArray(t.columns)){if(0===t.columns.length)throw new Error("Option columns is empty");f=t.columns}void 0!==t.escapeChar&&(u=t.escapeChar+o),("boolean"==typeof t.escapeFormulae||t.escapeFormulae instanceof RegExp)&&(d=t.escapeFormulae instanceof RegExp?t.escapeFormulae:/^[=+\-@\t\r].*$/)}}();var l=new RegExp(p(o),"g");if("string"==typeof e&&(e=JSON.parse(e)),Array.isArray(e)){if(!e.length||Array.isArray(e[0]))return c(null,e,h);if("object"==typeof e[0])return c(f||Object.keys(e[0]),e,h)}else if("object"==typeof e)return"string"==typeof e.data&&(e.data=JSON.parse(e.data)),Array.isArray(e.data)&&(e.fields||(e.fields=e.meta&&e.meta.fields||f),e.fields||(e.fields=Array.isArray(e.data[0])?e.fields:"object"==typeof e.data[0]?Object.keys(e.data[0]):[]),Array.isArray(e.data[0])||"object"==typeof e.data[0]||(e.data=[e.data])),c(e.fields||[],e.data||[],h);throw new Error("Unable to serialize unrecognized input");function c(e,t,r){var a="";"string"==typeof e&&(e=JSON.parse(e)),"string"==typeof t&&(t=JSON.parse(t));var o=Array.isArray(e)&&0<e.length,u=!Array.isArray(t[0]);if(o&&i){for(var h=0;h<e.length;h++)0<h&&(a+=n),a+=g(e[h],h);0<t.length&&(a+=s)}for(var f=0;f<t.length;f++){var d=o?e.length:t[f].length,l=!1,c=o?0===Object.keys(t[f]).length:0===t[f].length;if(r&&!o&&(l="greedy"===r?""===t[f].join("").trim():1===t[f].length&&0===t[f][0].length),"greedy"===r&&o){for(var p=[],_=0;_<d;_++){var m=u?e[_]:_;p.push(t[f][m])}l=""===p.join("").trim()}if(!l){for(var y=0;y<d;y++){0<y&&!c&&(a+=n);var v=o&&u?e[y]:y;a+=g(t[f][v],y)}f<t.length-1&&(!r||0<d&&!c)&&(a+=s)}}return a}function g(e,t){if(null==e)return"";if(e.constructor===Date)return JSON.stringify(e).slice(1,25);var i=!1;d&&"string"==typeof e&&d.test(e)&&(e="'"+e,i=!0);var s=e.toString().replace(l,u);return(i=i||!0===r||"function"==typeof r&&r(e,t)||Array.isArray(r)&&r[t]||function(e,t){for(var r=0;r<t.length;r++)if(-1<e.indexOf(t[r]))return!0;return!1}(s,a.BAD_DELIMITERS)||-1<s.indexOf(n)||" "===s.charAt(0)||" "===s.charAt(s.length-1))?o+s+o:s}}};if(a.RECORD_SEP=String.fromCharCode(30),a.UNIT_SEP=String.fromCharCode(31),a.BYTE_ORDER_MARK="\ufeff",a.BAD_DELIMITERS=["\r","\n",'"',a.BYTE_ORDER_MARK],a.WORKERS_SUPPORTED=!r&&!!t.Worker,a.NODE_STREAM_INPUT=1,a.LocalChunkSize=10485760,a.RemoteChunkSize=5242880,a.DefaultDelimiter=",",a.Parser=g,a.ParserHandle=c,a.NetworkStreamer=h,a.FileStreamer=f,a.StringStreamer=d,a.ReadableStreamStreamer=l,t.jQuery){var o=t.jQuery;o.fn.parse=function(e){var r=e.config||{},i=[];return this.each((function(e){if("INPUT"!==o(this).prop("tagName").toUpperCase()||"file"!==o(this).attr("type").toLowerCase()||!t.FileReader||!this.files||0===this.files.length)return!0;for(var n=0;n<this.files.length;n++)i.push({file:this.files[n],inputElem:this,instanceConfig:o.extend({},r)})})),n(),this;function n(){if(0!==i.length){var t,r,n,u=i[0];if(b(e.before)){var h=e.before(u.file,u.inputElem);if("object"==typeof h){if("abort"===h.action)return"AbortError",t=u.file,r=u.inputElem,n=h.reason,void(b(e.error)&&e.error({name:"AbortError"},t,r,n));if("skip"===h.action)return void s();"object"==typeof h.config&&(u.instanceConfig=o.extend(u.instanceConfig,h.config))}else if("skip"===h)return void s()}var f=u.instanceConfig.complete;u.instanceConfig.complete=function(e){b(f)&&f(e,u.file,u.inputElem),s()},a.parse(u.file,u.instanceConfig)}else b(e.complete)&&e.complete()}function s(){i.splice(0,1),n()}}}function u(e){this._handle=null,this._finished=!1,this._completed=!1,this._halted=!1,this._input=null,this._baseIndex=0,this._partialLine="",this._rowCount=0,this._start=0,this._nextChunk=null,this.isFirstChunk=!0,this._completeResults={data:[],errors:[],meta:{}},function(e){var t=v(e);t.chunkSize=parseInt(t.chunkSize),e.step||e.chunk||(t.chunkSize=null),this._handle=new c(t),(this._handle.streamer=this)._config=t}.call(this,e),this.parseChunk=function(e,r){if(this.isFirstChunk&&b(this._config.beforeFirstChunk)){var n=this._config.beforeFirstChunk(e);void 0!==n&&(e=n)}this.isFirstChunk=!1,this._halted=!1;var s=this._partialLine+e;this._partialLine="";var o=this._handle.parse(s,this._baseIndex,!this._finished);if(!this._handle.paused()&&!this._handle.aborted()){var u=o.meta.cursor;this._finished||(this._partialLine=s.substring(u-this._baseIndex),this._baseIndex=u),o&&o.data&&(this._rowCount+=o.data.length);var h=this._finished||this._config.preview&&this._rowCount>=this._config.preview;if(i)t.postMessage({results:o,workerId:a.WORKER_ID,finished:h});else if(b(this._config.chunk)&&!r){if(this._config.chunk(o,this._handle),this._handle.paused()||this._handle.aborted())return void(this._halted=!0);o=void 0,this._completeResults=void 0}return this._config.step||this._config.chunk||(this._completeResults.data=this._completeResults.data.concat(o.data),this._completeResults.errors=this._completeResults.errors.concat(o.errors),this._completeResults.meta=o.meta),this._completed||!h||!b(this._config.complete)||o&&o.meta.aborted||(this._config.complete(this._completeResults,this._input),this._completed=!0),h||o&&o.meta.paused||this._nextChunk(),o}this._halted=!0},this._sendError=function(e){b(this._config.error)?this._config.error(e):i&&this._config.error&&t.postMessage({workerId:a.WORKER_ID,error:e,finished:!1})}}function h(e){var t;(e=e||{}).chunkSize||(e.chunkSize=a.RemoteChunkSize),u.call(this,e),this._nextChunk=r?function(){this._readChunk(),this._chunkLoaded()}:function(){this._readChunk()},this.stream=function(e){this._input=e,this._nextChunk()},this._readChunk=function(){if(this._finished)this._chunkLoaded();else{if(t=new XMLHttpRequest,this._config.withCredentials&&(t.withCredentials=this._config.withCredentials),r||(t.onload=k(this._chunkLoaded,this),t.onerror=k(this._chunkError,this)),t.open(this._config.downloadRequestBody?"POST":"GET",this._input,!r),this._config.downloadRequestHeaders){var e=this._config.downloadRequestHeaders;for(var i in e)t.setRequestHeader(i,e[i])}if(this._config.chunkSize){var n=this._start+this._config.chunkSize-1;t.setRequestHeader("Range","bytes="+this._start+"-"+n)}try{t.send(this._config.downloadRequestBody)}catch(e){this._chunkError(e.message)}r&&0===t.status&&this._chunkError()}},this._chunkLoaded=function(){4===t.readyState&&(t.status<200||400<=t.status?this._chunkError():(this._start+=this._config.chunkSize?this._config.chunkSize:t.responseText.length,this._finished=!this._config.chunkSize||this._start>=function(e){var t=e.getResponseHeader("Content-Range");return null===t?-1:parseInt(t.substring(t.lastIndexOf("/")+1))}(t),this.parseChunk(t.responseText)))},this._chunkError=function(e){var r=t.statusText||e;this._sendError(new Error(r))}}function f(e){var t,r;(e=e||{}).chunkSize||(e.chunkSize=a.LocalChunkSize),u.call(this,e);var i="undefined"!=typeof FileReader;this.stream=function(e){this._input=e,r=e.slice||e.webkitSlice||e.mozSlice,i?((t=new FileReader).onload=k(this._chunkLoaded,this),t.onerror=k(this._chunkError,this)):t=new FileReaderSync,this._nextChunk()},this._nextChunk=function(){this._finished||this._config.preview&&!(this._rowCount<this._config.preview)||this._readChunk()},this._readChunk=function(){var e=this._input;if(this._config.chunkSize){var n=Math.min(this._start+this._config.chunkSize,this._input.size);e=r.call(e,this._start,n)}var s=t.readAsText(e,this._config.encoding);i||this._chunkLoaded({target:{result:s}})},this._chunkLoaded=function(e){this._start+=this._config.chunkSize,this._finished=!this._config.chunkSize||this._start>=this._input.size,this.parseChunk(e.target.result)},this._chunkError=function(){this._sendError(t.error)}}function d(e){var t;u.call(this,e=e||{}),this.stream=function(e){return t=e,this._nextChunk()},this._nextChunk=function(){if(!this._finished){var e,r=this._config.chunkSize;return r?(e=t.substring(0,r),t=t.substring(r)):(e=t,t=""),this._finished=!t,this.parseChunk(e)}}}function l(e){u.call(this,e=e||{});var t=[],r=!0,i=!1;this.pause=function(){u.prototype.pause.apply(this,arguments),this._input.pause()},this.resume=function(){u.prototype.resume.apply(this,arguments),this._input.resume()},this.stream=function(e){this._input=e,this._input.on("data",this._streamData),this._input.on("end",this._streamEnd),this._input.on("error",this._streamError)},this._checkIsFinished=function(){i&&1===t.length&&(this._finished=!0)},this._nextChunk=function(){this._checkIsFinished(),t.length?this.parseChunk(t.shift()):r=!0},this._streamData=k((function(e){try{t.push("string"==typeof e?e:e.toString(this._config.encoding)),r&&(r=!1,this._checkIsFinished(),this.parseChunk(t.shift()))}catch(e){this._streamError(e)}}),this),this._streamError=k((function(e){this._streamCleanUp(),this._sendError(e)}),this),this._streamEnd=k((function(){this._streamCleanUp(),i=!0,this._streamData("")}),this),this._streamCleanUp=k((function(){this._input.removeListener("data",this._streamData),this._input.removeListener("end",this._streamEnd),this._input.removeListener("error",this._streamError)}),this)}function c(e){var t,r,i,n=Math.pow(2,53),s=-n,o=/^\s*-?(\d+\.?|\.\d+|\d+\.\d+)([eE][-+]?\d+)?\s*$/,u=/^((\d{4}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d:[0-5]\d\.\d+([+-][0-2]\d:[0-5]\d|Z))|(\d{4}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d:[0-5]\d([+-][0-2]\d:[0-5]\d|Z))|(\d{4}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d([+-][0-2]\d:[0-5]\d|Z)))$/,h=this,f=0,d=0,l=!1,c=!1,_=[],m={data:[],errors:[],meta:{}};if(b(e.step)){var y=e.step;e.step=function(t){if(m=t,w())E();else{if(E(),0===m.data.length)return;f+=t.data.length,e.preview&&f>e.preview?r.abort():(m.data=m.data[0],y(m,h))}}}function k(t){return"greedy"===e.skipEmptyLines?""===t.join("").trim():1===t.length&&0===t[0].length}function E(){return m&&i&&(C("Delimiter","UndetectableDelimiter","Unable to auto-detect delimiting character; defaulted to '"+a.DefaultDelimiter+"'"),i=!1),e.skipEmptyLines&&(m.data=m.data.filter((function(e){return!k(e)}))),w()&&function(){if(m)if(Array.isArray(m.data[0])){for(var t=0;w()&&t<m.data.length;t++)m.data[t].forEach(r);m.data.splice(0,1)}else m.data.forEach(r);function r(t,r){b(e.transformHeader)&&(t=e.transformHeader(t,r)),_.push(t)}}(),function(){if(!m||!e.header&&!e.dynamicTyping&&!e.transform)return m;function t(t,r){var i,n=e.header?{}:[];for(i=0;i<t.length;i++){var s=i,a=t[i];e.header&&(s=i>=_.length?"__parsed_extra":_[i]),e.transform&&(a=e.transform(a,s)),a=R(s,a),"__parsed_extra"===s?(n[s]=n[s]||[],n[s].push(a)):n[s]=a}return e.header&&(i>_.length?C("FieldMismatch","TooManyFields","Too many fields: expected "+_.length+" fields but parsed "+i,d+r):i<_.length&&C("FieldMismatch","TooFewFields","Too few fields: expected "+_.length+" fields but parsed "+i,d+r)),n}var r=1;return!m.data.length||Array.isArray(m.data[0])?(m.data=m.data.map(t),r=m.data.length):m.data=t(m.data,0),e.header&&m.meta&&(m.meta.fields=_),d+=r,m}()}function w(){return e.header&&0===_.length}function R(t,r){return i=t,e.dynamicTypingFunction&&void 0===e.dynamicTyping[i]&&(e.dynamicTyping[i]=e.dynamicTypingFunction(i)),!0===(e.dynamicTyping[i]||e.dynamicTyping)?"true"===r||"TRUE"===r||"false"!==r&&"FALSE"!==r&&(function(e){if(o.test(e)){var t=parseFloat(e);if(s<t&&t<n)return!0}return!1}(r)?parseFloat(r):u.test(r)?new Date(r):""===r?null:r):r;var i}function C(e,t,r,i){var n={type:e,code:t,message:r};void 0!==i&&(n.row=i),m.errors.push(n)}this.parse=function(n,s,o){var u=e.quoteChar||'"';if(e.newline||(e.newline=function(e,t){e=e.substring(0,1048576);var r=new RegExp(p(t)+"([^]*?)"+p(t),"gm"),i=(e=e.replace(r,"")).split("\r"),n=e.split("\n"),s=1<n.length&&n[0].length<i[0].length;if(1===i.length||s)return"\n";for(var a=0,o=0;o<i.length;o++)"\n"===i[o][0]&&a++;return a>=i.length/2?"\r\n":"\r"}(n,u)),i=!1,e.delimiter)b(e.delimiter)&&(e.delimiter=e.delimiter(n),m.meta.delimiter=e.delimiter);else{var h=function(t,r,i,n,s){var o,u,h,f;s=s||[",","\t","|",";",a.RECORD_SEP,a.UNIT_SEP];for(var d=0;d<s.length;d++){var l=s[d],c=0,p=0,_=0;h=void 0;for(var m=new g({comments:n,delimiter:l,newline:r,preview:10}).parse(t),y=0;y<m.data.length;y++)if(i&&k(m.data[y]))_++;else{var v=m.data[y].length;p+=v,void 0!==h?0<v&&(c+=Math.abs(v-h),h=v):h=v}0<m.data.length&&(p/=m.data.length-_),(void 0===u||c<=u)&&(void 0===f||f<p)&&1.99<p&&(u=c,o=l,f=p)}return{successful:!!(e.delimiter=o),bestDelimiter:o}}(n,e.newline,e.skipEmptyLines,e.comments,e.delimitersToGuess);h.successful?e.delimiter=h.bestDelimiter:(i=!0,e.delimiter=a.DefaultDelimiter),m.meta.delimiter=e.delimiter}var f=v(e);return e.preview&&e.header&&f.preview++,t=n,r=new g(f),m=r.parse(t,s,o),E(),l?{meta:{paused:!0}}:m||{meta:{paused:!1}}},this.paused=function(){return l},this.pause=function(){l=!0,r.abort(),t=b(e.chunk)?"":t.substring(r.getCharIndex())},this.resume=function(){h.streamer._halted?(l=!1,h.streamer.parseChunk(t,!0)):setTimeout(h.resume,3)},this.aborted=function(){return c},this.abort=function(){c=!0,r.abort(),m.meta.aborted=!0,b(e.complete)&&e.complete(m),t=""}}function p(e){return e.replace(/[.*+?^${}()|[\]\\]/g,"\\$&")}function g(e){var t,r=(e=e||{}).delimiter,i=e.newline,n=e.comments,s=e.step,o=e.preview,u=e.fastMode,h=t=void 0===e.quoteChar||null===e.quoteChar?'"':e.quoteChar;if(void 0!==e.escapeChar&&(h=e.escapeChar),("string"!=typeof r||-1<a.BAD_DELIMITERS.indexOf(r))&&(r=","),n===r)throw new Error("Comment character same as delimiter");!0===n?n="#":("string"!=typeof n||-1<a.BAD_DELIMITERS.indexOf(n))&&(n=!1),"\n"!==i&&"\r"!==i&&"\r\n"!==i&&(i="\n");var f=0,d=!1;this.parse=function(a,l,c){if("string"!=typeof a)throw new Error("Input must be a string");var g=a.length,_=r.length,m=i.length,y=n.length,v=b(s),k=[],E=[],w=[],R=f=0;if(!a)return Q();if(e.header&&!l){var C=a.split(i)[0].split(r),S=[],O={},x=!1;for(var A in C){var I=C[A];b(e.transformHeader)&&(I=e.transformHeader(I,A));var T=I,D=O[I]||0;for(0<D&&(x=!0,T=I+"_"+D),O[I]=D+1;S.includes(T);)T=T+"_"+D;S.push(T)}if(x){var L=a.split(i);L[0]=S.join(r),a=L.join(i)}}if(u||!1!==u&&-1===a.indexOf(t)){for(var F=a.split(i),j=0;j<F.length;j++){if(w=F[j],f+=w.length,j!==F.length-1)f+=i.length;else if(c)return Q();if(!n||w.substring(0,y)!==n){if(v){if(k=[],B(w.split(r)),J(),d)return Q()}else B(w.split(r));if(o&&o<=j)return k=k.slice(0,o),Q(!0)}}return Q()}for(var z=a.indexOf(r,f),M=a.indexOf(i,f),P=new RegExp(p(h)+p(t),"g"),U=a.indexOf(t,f);;)if(a[f]!==t)if(n&&0===w.length&&a.substring(f,f+y)===n){if(-1===M)return Q();f=M+m,M=a.indexOf(i,f),z=a.indexOf(r,f)}else if(-1!==z&&(z<M||-1===M))w.push(a.substring(f,z)),f=z+_,z=a.indexOf(r,f);else{if(-1===M)break;if(w.push(a.substring(f,M)),H(M+m),v&&(J(),d))return Q();if(o&&k.length>=o)return Q(!0)}else for(U=f,f++;;){if(-1===(U=a.indexOf(t,U+1)))return c||E.push({type:"Quotes",code:"MissingQuotes",message:"Quoted field unterminated",row:k.length,index:f}),W();if(U===g-1)return W(a.substring(f,U).replace(P,t));if(t!==h||a[U+1]!==h){if(t===h||0===U||a[U-1]!==h){-1!==z&&z<U+1&&(z=a.indexOf(r,U+1)),-1!==M&&M<U+1&&(M=a.indexOf(i,U+1));var q=K(-1===M?z:Math.min(z,M));if(a.substr(U+1+q,_)===r){w.push(a.substring(f,U).replace(P,t)),a[f=U+1+q+_]!==t&&(U=a.indexOf(t,f)),z=a.indexOf(r,f),M=a.indexOf(i,f);break}var N=K(M);if(a.substring(U+1+N,U+1+N+m)===i){if(w.push(a.substring(f,U).replace(P,t)),H(U+1+N+m),z=a.indexOf(r,f),U=a.indexOf(t,f),v&&(J(),d))return Q();if(o&&k.length>=o)return Q(!0);break}E.push({type:"Quotes",code:"InvalidQuotes",message:"Trailing quote on quoted field is malformed",row:k.length,index:f}),U++}}else U++}return W();function B(e){k.push(e),R=f}function K(e){var t=0;if(-1!==e){var r=a.substring(U+1,e);r&&""===r.trim()&&(t=r.length)}return t}function W(e){return c||(void 0===e&&(e=a.substring(f)),w.push(e),f=g,B(w),v&&J()),Q()}function H(e){f=e,B(w),w=[],M=a.indexOf(i,f)}function Q(e){return{data:k,errors:E,meta:{delimiter:r,linebreak:i,aborted:d,truncated:!!e,cursor:R+(l||0)}}}function J(){s(Q()),k=[],E=[]}},this.abort=function(){d=!0},this.getCharIndex=function(){return f}}function _(e){var t=e.data,r=n[t.workerId],i=!1;if(t.error)r.userError(t.error,t.file);else if(t.results&&t.results.data){var s={abort:function(){i=!0,m(t.workerId,{data:[],errors:[],meta:{aborted:!0}})},pause:y,resume:y};if(b(r.userStep)){for(var a=0;a<t.results.data.length&&(r.userStep({data:t.results.data[a],errors:t.results.errors,meta:t.results.meta},s),!i);a++);delete t.results}else b(r.userChunk)&&(r.userChunk(t.results,s,t.file),delete t.results)}t.finished&&!i&&m(t.workerId,t.results)}function m(e,t){var r=n[e];b(r.userComplete)&&r.userComplete(t),r.terminate(),delete n[e]}function y(){throw new Error("Not implemented.")}function v(e){if("object"!=typeof e||null===e)return e;var t=Array.isArray(e)?[]:{};for(var r in e)t[r]=v(e[r]);return t}function k(e,t){return function(){e.apply(t,arguments)}}function b(e){return"function"==typeof e}return i&&(t.onmessage=function(e){var r=e.data;if(void 0===a.WORKER_ID&&r&&(a.WORKER_ID=r.workerId),"string"==typeof r.input)t.postMessage({workerId:a.WORKER_ID,results:a.parse(r.input,r.config),finished:!0});else if(t.File&&r.input instanceof File||r.input instanceof Object){var i=a.parse(r.input,r.config);i&&t.postMessage({workerId:a.WORKER_ID,results:i,finished:!0})}}),(h.prototype=Object.create(u.prototype)).constructor=h,(f.prototype=Object.create(u.prototype)).constructor=f,(d.prototype=Object.create(d.prototype)).constructor=d,(l.prototype=Object.create(u.prototype)).constructor=l,a}));

},{}],102:[function(require,module,exports){
function prettierBytes(e){if("number"!=typeof e||isNaN(e))throw new TypeError("Expected a number, got "+typeof e);var t=e<0,r=["B","KB","MB","GB","TB","PB","EB","ZB","YB"];if(t&&(e=-e),e<1)return(t?"-":"")+e+" B";var o=Math.min(Math.floor(Math.log(e)/Math.log(1e3)),r.length-1);e=Number(e/Math.pow(1e3,o));var B=r[o];return e>=10||e%1==0?(t?"-":"")+e.toFixed(0)+" "+B:(t?"-":"")+e.toFixed(1)+" "+B}module.exports=prettierBytes;

},{}],103:[function(require,module,exports){
var cachedSetTimeout,cachedClearTimeout,process=module.exports={};function defaultSetTimout(){throw new Error("setTimeout has not been defined")}function defaultClearTimeout(){throw new Error("clearTimeout has not been defined")}function runTimeout(e){if(cachedSetTimeout===setTimeout)return setTimeout(e,0);if((cachedSetTimeout===defaultSetTimout||!cachedSetTimeout)&&setTimeout)return cachedSetTimeout=setTimeout,setTimeout(e,0);try{return cachedSetTimeout(e,0)}catch(t){try{return cachedSetTimeout.call(null,e,0)}catch(t){return cachedSetTimeout.call(this,e,0)}}}function runClearTimeout(e){if(cachedClearTimeout===clearTimeout)return clearTimeout(e);if((cachedClearTimeout===defaultClearTimeout||!cachedClearTimeout)&&clearTimeout)return cachedClearTimeout=clearTimeout,clearTimeout(e);try{return cachedClearTimeout(e)}catch(t){try{return cachedClearTimeout.call(null,e)}catch(t){return cachedClearTimeout.call(this,e)}}}!function(){try{cachedSetTimeout="function"==typeof setTimeout?setTimeout:defaultSetTimout}catch(e){cachedSetTimeout=defaultSetTimout}try{cachedClearTimeout="function"==typeof clearTimeout?clearTimeout:defaultClearTimeout}catch(e){cachedClearTimeout=defaultClearTimeout}}();var currentQueue,queue=[],draining=!1,queueIndex=-1;function cleanUpNextTick(){draining&&currentQueue&&(draining=!1,currentQueue.length?queue=currentQueue.concat(queue):queueIndex=-1,queue.length&&drainQueue())}function drainQueue(){if(!draining){var e=runTimeout(cleanUpNextTick);draining=!0;for(var t=queue.length;t;){for(currentQueue=queue,queue=[];++queueIndex<t;)currentQueue&&currentQueue[queueIndex].run();queueIndex=-1,t=queue.length}currentQueue=null,draining=!1,runClearTimeout(e)}}function Item(e,t){this.fun=e,this.array=t}function noop(){}process.nextTick=function(e){var t=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)t[r-1]=arguments[r];queue.push(new Item(e,t)),1!==queue.length||draining||runTimeout(drainQueue)},Item.prototype.run=function(){this.fun.apply(null,this.array)},process.title="browser",process.browser=!0,process.env={},process.argv=[],process.version="",process.versions={},process.on=noop,process.addListener=noop,process.once=noop,process.off=noop,process.removeListener=noop,process.removeAllListeners=noop,process.emit=noop,process.prependListener=noop,process.prependOnceListener=noop,process.listeners=function(e){return[]},process.binding=function(e){throw new Error("process.binding is not supported")},process.cwd=function(){return"/"},process.chdir=function(e){throw new Error("process.chdir is not supported")},process.umask=function(){return 0};

},{}],104:[function(require,module,exports){
module.exports=[
"ac",
"com.ac",
"edu.ac",
"gov.ac",
"net.ac",
"mil.ac",
"org.ac",
"ad",
"nom.ad",
"ae",
"co.ae",
"net.ae",
"org.ae",
"sch.ae",
"ac.ae",
"gov.ae",
"mil.ae",
"aero",
"accident-investigation.aero",
"accident-prevention.aero",
"aerobatic.aero",
"aeroclub.aero",
"aerodrome.aero",
"agents.aero",
"aircraft.aero",
"airline.aero",
"airport.aero",
"air-surveillance.aero",
"airtraffic.aero",
"air-traffic-control.aero",
"ambulance.aero",
"amusement.aero",
"association.aero",
"author.aero",
"ballooning.aero",
"broker.aero",
"caa.aero",
"cargo.aero",
"catering.aero",
"certification.aero",
"championship.aero",
"charter.aero",
"civilaviation.aero",
"club.aero",
"conference.aero",
"consultant.aero",
"consulting.aero",
"control.aero",
"council.aero",
"crew.aero",
"design.aero",
"dgca.aero",
"educator.aero",
"emergency.aero",
"engine.aero",
"engineer.aero",
"entertainment.aero",
"equipment.aero",
"exchange.aero",
"express.aero",
"federation.aero",
"flight.aero",
"fuel.aero",
"gliding.aero",
"government.aero",
"groundhandling.aero",
"group.aero",
"hanggliding.aero",
"homebuilt.aero",
"insurance.aero",
"journal.aero",
"journalist.aero",
"leasing.aero",
"logistics.aero",
"magazine.aero",
"maintenance.aero",
"media.aero",
"microlight.aero",
"modelling.aero",
"navigation.aero",
"parachuting.aero",
"paragliding.aero",
"passenger-association.aero",
"pilot.aero",
"press.aero",
"production.aero",
"recreation.aero",
"repbody.aero",
"res.aero",
"research.aero",
"rotorcraft.aero",
"safety.aero",
"scientist.aero",
"services.aero",
"show.aero",
"skydiving.aero",
"software.aero",
"student.aero",
"trader.aero",
"trading.aero",
"trainer.aero",
"union.aero",
"workinggroup.aero",
"works.aero",
"af",
"gov.af",
"com.af",
"org.af",
"net.af",
"edu.af",
"ag",
"com.ag",
"org.ag",
"net.ag",
"co.ag",
"nom.ag",
"ai",
"off.ai",
"com.ai",
"net.ai",
"org.ai",
"al",
"com.al",
"edu.al",
"gov.al",
"mil.al",
"net.al",
"org.al",
"am",
"co.am",
"com.am",
"commune.am",
"net.am",
"org.am",
"ao",
"ed.ao",
"gv.ao",
"og.ao",
"co.ao",
"pb.ao",
"it.ao",
"aq",
"ar",
"bet.ar",
"com.ar",
"coop.ar",
"edu.ar",
"gob.ar",
"gov.ar",
"int.ar",
"mil.ar",
"musica.ar",
"mutual.ar",
"net.ar",
"org.ar",
"senasa.ar",
"tur.ar",
"arpa",
"e164.arpa",
"in-addr.arpa",
"ip6.arpa",
"iris.arpa",
"uri.arpa",
"urn.arpa",
"as",
"gov.as",
"asia",
"at",
"ac.at",
"co.at",
"gv.at",
"or.at",
"sth.ac.at",
"au",
"com.au",
"net.au",
"org.au",
"edu.au",
"gov.au",
"asn.au",
"id.au",
"info.au",
"conf.au",
"oz.au",
"act.au",
"nsw.au",
"nt.au",
"qld.au",
"sa.au",
"tas.au",
"vic.au",
"wa.au",
"act.edu.au",
"catholic.edu.au",
"nsw.edu.au",
"nt.edu.au",
"qld.edu.au",
"sa.edu.au",
"tas.edu.au",
"vic.edu.au",
"wa.edu.au",
"qld.gov.au",
"sa.gov.au",
"tas.gov.au",
"vic.gov.au",
"wa.gov.au",
"schools.nsw.edu.au",
"aw",
"com.aw",
"ax",
"az",
"com.az",
"net.az",
"int.az",
"gov.az",
"org.az",
"edu.az",
"info.az",
"pp.az",
"mil.az",
"name.az",
"pro.az",
"biz.az",
"ba",
"com.ba",
"edu.ba",
"gov.ba",
"mil.ba",
"net.ba",
"org.ba",
"bb",
"biz.bb",
"co.bb",
"com.bb",
"edu.bb",
"gov.bb",
"info.bb",
"net.bb",
"org.bb",
"store.bb",
"tv.bb",
"*.bd",
"be",
"ac.be",
"bf",
"gov.bf",
"bg",
"a.bg",
"b.bg",
"c.bg",
"d.bg",
"e.bg",
"f.bg",
"g.bg",
"h.bg",
"i.bg",
"j.bg",
"k.bg",
"l.bg",
"m.bg",
"n.bg",
"o.bg",
"p.bg",
"q.bg",
"r.bg",
"s.bg",
"t.bg",
"u.bg",
"v.bg",
"w.bg",
"x.bg",
"y.bg",
"z.bg",
"0.bg",
"1.bg",
"2.bg",
"3.bg",
"4.bg",
"5.bg",
"6.bg",
"7.bg",
"8.bg",
"9.bg",
"bh",
"com.bh",
"edu.bh",
"net.bh",
"org.bh",
"gov.bh",
"bi",
"co.bi",
"com.bi",
"edu.bi",
"or.bi",
"org.bi",
"biz",
"bj",
"asso.bj",
"barreau.bj",
"gouv.bj",
"bm",
"com.bm",
"edu.bm",
"gov.bm",
"net.bm",
"org.bm",
"bn",
"com.bn",
"edu.bn",
"gov.bn",
"net.bn",
"org.bn",
"bo",
"com.bo",
"edu.bo",
"gob.bo",
"int.bo",
"org.bo",
"net.bo",
"mil.bo",
"tv.bo",
"web.bo",
"academia.bo",
"agro.bo",
"arte.bo",
"blog.bo",
"bolivia.bo",
"ciencia.bo",
"cooperativa.bo",
"democracia.bo",
"deporte.bo",
"ecologia.bo",
"economia.bo",
"empresa.bo",
"indigena.bo",
"industria.bo",
"info.bo",
"medicina.bo",
"movimiento.bo",
"musica.bo",
"natural.bo",
"nombre.bo",
"noticias.bo",
"patria.bo",
"politica.bo",
"profesional.bo",
"plurinacional.bo",
"pueblo.bo",
"revista.bo",
"salud.bo",
"tecnologia.bo",
"tksat.bo",
"transporte.bo",
"wiki.bo",
"br",
"9guacu.br",
"abc.br",
"adm.br",
"adv.br",
"agr.br",
"aju.br",
"am.br",
"anani.br",
"aparecida.br",
"app.br",
"arq.br",
"art.br",
"ato.br",
"b.br",
"barueri.br",
"belem.br",
"bhz.br",
"bib.br",
"bio.br",
"blog.br",
"bmd.br",
"boavista.br",
"bsb.br",
"campinagrande.br",
"campinas.br",
"caxias.br",
"cim.br",
"cng.br",
"cnt.br",
"com.br",
"contagem.br",
"coop.br",
"coz.br",
"cri.br",
"cuiaba.br",
"curitiba.br",
"def.br",
"des.br",
"det.br",
"dev.br",
"ecn.br",
"eco.br",
"edu.br",
"emp.br",
"enf.br",
"eng.br",
"esp.br",
"etc.br",
"eti.br",
"far.br",
"feira.br",
"flog.br",
"floripa.br",
"fm.br",
"fnd.br",
"fortal.br",
"fot.br",
"foz.br",
"fst.br",
"g12.br",
"geo.br",
"ggf.br",
"goiania.br",
"gov.br",
"ac.gov.br",
"al.gov.br",
"am.gov.br",
"ap.gov.br",
"ba.gov.br",
"ce.gov.br",
"df.gov.br",
"es.gov.br",
"go.gov.br",
"ma.gov.br",
"mg.gov.br",
"ms.gov.br",
"mt.gov.br",
"pa.gov.br",
"pb.gov.br",
"pe.gov.br",
"pi.gov.br",
"pr.gov.br",
"rj.gov.br",
"rn.gov.br",
"ro.gov.br",
"rr.gov.br",
"rs.gov.br",
"sc.gov.br",
"se.gov.br",
"sp.gov.br",
"to.gov.br",
"gru.br",
"imb.br",
"ind.br",
"inf.br",
"jab.br",
"jampa.br",
"jdf.br",
"joinville.br",
"jor.br",
"jus.br",
"leg.br",
"lel.br",
"log.br",
"londrina.br",
"macapa.br",
"maceio.br",
"manaus.br",
"maringa.br",
"mat.br",
"med.br",
"mil.br",
"morena.br",
"mp.br",
"mus.br",
"natal.br",
"net.br",
"niteroi.br",
"*.nom.br",
"not.br",
"ntr.br",
"odo.br",
"ong.br",
"org.br",
"osasco.br",
"palmas.br",
"poa.br",
"ppg.br",
"pro.br",
"psc.br",
"psi.br",
"pvh.br",
"qsl.br",
"radio.br",
"rec.br",
"recife.br",
"rep.br",
"ribeirao.br",
"rio.br",
"riobranco.br",
"riopreto.br",
"salvador.br",
"sampa.br",
"santamaria.br",
"santoandre.br",
"saobernardo.br",
"saogonca.br",
"seg.br",
"sjc.br",
"slg.br",
"slz.br",
"sorocaba.br",
"srv.br",
"taxi.br",
"tc.br",
"tec.br",
"teo.br",
"the.br",
"tmp.br",
"trd.br",
"tur.br",
"tv.br",
"udi.br",
"vet.br",
"vix.br",
"vlog.br",
"wiki.br",
"zlg.br",
"bs",
"com.bs",
"net.bs",
"org.bs",
"edu.bs",
"gov.bs",
"bt",
"com.bt",
"edu.bt",
"gov.bt",
"net.bt",
"org.bt",
"bv",
"bw",
"co.bw",
"org.bw",
"by",
"gov.by",
"mil.by",
"com.by",
"of.by",
"bz",
"com.bz",
"net.bz",
"org.bz",
"edu.bz",
"gov.bz",
"ca",
"ab.ca",
"bc.ca",
"mb.ca",
"nb.ca",
"nf.ca",
"nl.ca",
"ns.ca",
"nt.ca",
"nu.ca",
"on.ca",
"pe.ca",
"qc.ca",
"sk.ca",
"yk.ca",
"gc.ca",
"cat",
"cc",
"cd",
"gov.cd",
"cf",
"cg",
"ch",
"ci",
"org.ci",
"or.ci",
"com.ci",
"co.ci",
"edu.ci",
"ed.ci",
"ac.ci",
"net.ci",
"go.ci",
"asso.ci",
"aéroport.ci",
"int.ci",
"presse.ci",
"md.ci",
"gouv.ci",
"*.ck",
"!www.ck",
"cl",
"co.cl",
"gob.cl",
"gov.cl",
"mil.cl",
"cm",
"co.cm",
"com.cm",
"gov.cm",
"net.cm",
"cn",
"ac.cn",
"com.cn",
"edu.cn",
"gov.cn",
"net.cn",
"org.cn",
"mil.cn",
"公司.cn",
"网络.cn",
"網絡.cn",
"ah.cn",
"bj.cn",
"cq.cn",
"fj.cn",
"gd.cn",
"gs.cn",
"gz.cn",
"gx.cn",
"ha.cn",
"hb.cn",
"he.cn",
"hi.cn",
"hl.cn",
"hn.cn",
"jl.cn",
"js.cn",
"jx.cn",
"ln.cn",
"nm.cn",
"nx.cn",
"qh.cn",
"sc.cn",
"sd.cn",
"sh.cn",
"sn.cn",
"sx.cn",
"tj.cn",
"xj.cn",
"xz.cn",
"yn.cn",
"zj.cn",
"hk.cn",
"mo.cn",
"tw.cn",
"co",
"arts.co",
"com.co",
"edu.co",
"firm.co",
"gov.co",
"info.co",
"int.co",
"mil.co",
"net.co",
"nom.co",
"org.co",
"rec.co",
"web.co",
"com",
"coop",
"cr",
"ac.cr",
"co.cr",
"ed.cr",
"fi.cr",
"go.cr",
"or.cr",
"sa.cr",
"cu",
"com.cu",
"edu.cu",
"org.cu",
"net.cu",
"gov.cu",
"inf.cu",
"cv",
"com.cv",
"edu.cv",
"int.cv",
"nome.cv",
"org.cv",
"cw",
"com.cw",
"edu.cw",
"net.cw",
"org.cw",
"cx",
"gov.cx",
"cy",
"ac.cy",
"biz.cy",
"com.cy",
"ekloges.cy",
"gov.cy",
"ltd.cy",
"mil.cy",
"net.cy",
"org.cy",
"press.cy",
"pro.cy",
"tm.cy",
"cz",
"de",
"dj",
"dk",
"dm",
"com.dm",
"net.dm",
"org.dm",
"edu.dm",
"gov.dm",
"do",
"art.do",
"com.do",
"edu.do",
"gob.do",
"gov.do",
"mil.do",
"net.do",
"org.do",
"sld.do",
"web.do",
"dz",
"art.dz",
"asso.dz",
"com.dz",
"edu.dz",
"gov.dz",
"org.dz",
"net.dz",
"pol.dz",
"soc.dz",
"tm.dz",
"ec",
"com.ec",
"info.ec",
"net.ec",
"fin.ec",
"k12.ec",
"med.ec",
"pro.ec",
"org.ec",
"edu.ec",
"gov.ec",
"gob.ec",
"mil.ec",
"edu",
"ee",
"edu.ee",
"gov.ee",
"riik.ee",
"lib.ee",
"med.ee",
"com.ee",
"pri.ee",
"aip.ee",
"org.ee",
"fie.ee",
"eg",
"com.eg",
"edu.eg",
"eun.eg",
"gov.eg",
"mil.eg",
"name.eg",
"net.eg",
"org.eg",
"sci.eg",
"*.er",
"es",
"com.es",
"nom.es",
"org.es",
"gob.es",
"edu.es",
"et",
"com.et",
"gov.et",
"org.et",
"edu.et",
"biz.et",
"name.et",
"info.et",
"net.et",
"eu",
"fi",
"aland.fi",
"fj",
"ac.fj",
"biz.fj",
"com.fj",
"gov.fj",
"info.fj",
"mil.fj",
"name.fj",
"net.fj",
"org.fj",
"pro.fj",
"*.fk",
"com.fm",
"edu.fm",
"net.fm",
"org.fm",
"fm",
"fo",
"fr",
"asso.fr",
"com.fr",
"gouv.fr",
"nom.fr",
"prd.fr",
"tm.fr",
"aeroport.fr",
"avocat.fr",
"avoues.fr",
"cci.fr",
"chambagri.fr",
"chirurgiens-dentistes.fr",
"experts-comptables.fr",
"geometre-expert.fr",
"greta.fr",
"huissier-justice.fr",
"medecin.fr",
"notaires.fr",
"pharmacien.fr",
"port.fr",
"veterinaire.fr",
"ga",
"gb",
"edu.gd",
"gov.gd",
"gd",
"ge",
"com.ge",
"edu.ge",
"gov.ge",
"org.ge",
"mil.ge",
"net.ge",
"pvt.ge",
"gf",
"gg",
"co.gg",
"net.gg",
"org.gg",
"gh",
"com.gh",
"edu.gh",
"gov.gh",
"org.gh",
"mil.gh",
"gi",
"com.gi",
"ltd.gi",
"gov.gi",
"mod.gi",
"edu.gi",
"org.gi",
"gl",
"co.gl",
"com.gl",
"edu.gl",
"net.gl",
"org.gl",
"gm",
"gn",
"ac.gn",
"com.gn",
"edu.gn",
"gov.gn",
"org.gn",
"net.gn",
"gov",
"gp",
"com.gp",
"net.gp",
"mobi.gp",
"edu.gp",
"org.gp",
"asso.gp",
"gq",
"gr",
"com.gr",
"edu.gr",
"net.gr",
"org.gr",
"gov.gr",
"gs",
"gt",
"com.gt",
"edu.gt",
"gob.gt",
"ind.gt",
"mil.gt",
"net.gt",
"org.gt",
"gu",
"com.gu",
"edu.gu",
"gov.gu",
"guam.gu",
"info.gu",
"net.gu",
"org.gu",
"web.gu",
"gw",
"gy",
"co.gy",
"com.gy",
"edu.gy",
"gov.gy",
"net.gy",
"org.gy",
"hk",
"com.hk",
"edu.hk",
"gov.hk",
"idv.hk",
"net.hk",
"org.hk",
"公司.hk",
"教育.hk",
"敎育.hk",
"政府.hk",
"個人.hk",
"个��.hk",
"箇人.hk",
"網络.hk",
"网络.hk",
"组織.hk",
"網絡.hk",
"网絡.hk",
"组织.hk",
"組織.hk",
"組织.hk",
"hm",
"hn",
"com.hn",
"edu.hn",
"org.hn",
"net.hn",
"mil.hn",
"gob.hn",
"hr",
"iz.hr",
"from.hr",
"name.hr",
"com.hr",
"ht",
"com.ht",
"shop.ht",
"firm.ht",
"info.ht",
"adult.ht",
"net.ht",
"pro.ht",
"org.ht",
"med.ht",
"art.ht",
"coop.ht",
"pol.ht",
"asso.ht",
"edu.ht",
"rel.ht",
"gouv.ht",
"perso.ht",
"hu",
"co.hu",
"info.hu",
"org.hu",
"priv.hu",
"sport.hu",
"tm.hu",
"2000.hu",
"agrar.hu",
"bolt.hu",
"casino.hu",
"city.hu",
"erotica.hu",
"erotika.hu",
"film.hu",
"forum.hu",
"games.hu",
"hotel.hu",
"ingatlan.hu",
"jogasz.hu",
"konyvelo.hu",
"lakas.hu",
"media.hu",
"news.hu",
"reklam.hu",
"sex.hu",
"shop.hu",
"suli.hu",
"szex.hu",
"tozsde.hu",
"utazas.hu",
"video.hu",
"id",
"ac.id",
"biz.id",
"co.id",
"desa.id",
"go.id",
"mil.id",
"my.id",
"net.id",
"or.id",
"ponpes.id",
"sch.id",
"web.id",
"ie",
"gov.ie",
"il",
"ac.il",
"co.il",
"gov.il",
"idf.il",
"k12.il",
"muni.il",
"net.il",
"org.il",
"im",
"ac.im",
"co.im",
"com.im",
"ltd.co.im",
"net.im",
"org.im",
"plc.co.im",
"tt.im",
"tv.im",
"in",
"co.in",
"firm.in",
"net.in",
"org.in",
"gen.in",
"ind.in",
"nic.in",
"ac.in",
"edu.in",
"res.in",
"gov.in",
"mil.in",
"info",
"int",
"eu.int",
"io",
"com.io",
"iq",
"gov.iq",
"edu.iq",
"mil.iq",
"com.iq",
"org.iq",
"net.iq",
"ir",
"ac.ir",
"co.ir",
"gov.ir",
"id.ir",
"net.ir",
"org.ir",
"sch.ir",
"ایران.ir",
"ايران.ir",
"is",
"net.is",
"com.is",
"edu.is",
"gov.is",
"org.is",
"int.is",
"it",
"gov.it",
"edu.it",
"abr.it",
"abruzzo.it",
"aosta-valley.it",
"aostavalley.it",
"bas.it",
"basilicata.it",
"cal.it",
"calabria.it",
"cam.it",
"campania.it",
"emilia-romagna.it",
"emiliaromagna.it",
"emr.it",
"friuli-v-giulia.it",
"friuli-ve-giulia.it",
"friuli-vegiulia.it",
"friuli-venezia-giulia.it",
"friuli-veneziagiulia.it",
"friuli-vgiulia.it",
"friuliv-giulia.it",
"friulive-giulia.it",
"friulivegiulia.it",
"friulivenezia-giulia.it",
"friuliveneziagiulia.it",
"friulivgiulia.it",
"fvg.it",
"laz.it",
"lazio.it",
"lig.it",
"liguria.it",
"lom.it",
"lombardia.it",
"lombardy.it",
"lucania.it",
"mar.it",
"marche.it",
"mol.it",
"molise.it",
"piedmont.it",
"piemonte.it",
"pmn.it",
"pug.it",
"puglia.it",
"sar.it",
"sardegna.it",
"sardinia.it",
"sic.it",
"sicilia.it",
"sicily.it",
"taa.it",
"tos.it",
"toscana.it",
"trentin-sud-tirol.it",
"trentin-süd-tirol.it",
"trentin-sudtirol.it",
"trentin-südtirol.it",
"trentin-sued-tirol.it",
"trentin-suedtirol.it",
"trentino-a-adige.it",
"trentino-aadige.it",
"trentino-alto-adige.it",
"trentino-altoadige.it",
"trentino-s-tirol.it",
"trentino-stirol.it",
"trentino-sud-tirol.it",
"trentino-süd-tirol.it",
"trentino-sudtirol.it",
"trentino-südtirol.it",
"trentino-sued-tirol.it",
"trentino-suedtirol.it",
"trentino.it",
"trentinoa-adige.it",
"trentinoaadige.it",
"trentinoalto-adige.it",
"trentinoaltoadige.it",
"trentinos-tirol.it",
"trentinostirol.it",
"trentinosud-tirol.it",
"trentinosüd-tirol.it",
"trentinosudtirol.it",
"trentinosüdtirol.it",
"trentinosued-tirol.it",
"trentinosuedtirol.it",
"trentinsud-tirol.it",
"trentinsüd-tirol.it",
"trentinsudtirol.it",
"trentinsüdtirol.it",
"trentinsued-tirol.it",
"trentinsuedtirol.it",
"tuscany.it",
"umb.it",
"umbria.it",
"val-d-aosta.it",
"val-daosta.it",
"vald-aosta.it",
"valdaosta.it",
"valle-aosta.it",
"valle-d-aosta.it",
"valle-daosta.it",
"valleaosta.it",
"valled-aosta.it",
"valledaosta.it",
"vallee-aoste.it",
"vallée-aoste.it",
"vallee-d-aoste.it",
"vallée-d-aoste.it",
"valleeaoste.it",
"valléeaoste.it",
"valleedaoste.it",
"valléedaoste.it",
"vao.it",
"vda.it",
"ven.it",
"veneto.it",
"ag.it",
"agrigento.it",
"al.it",
"alessandria.it",
"alto-adige.it",
"altoadige.it",
"an.it",
"ancona.it",
"andria-barletta-trani.it",
"andria-trani-barletta.it",
"andriabarlettatrani.it",
"andriatranibarletta.it",
"ao.it",
"aosta.it",
"aoste.it",
"ap.it",
"aq.it",
"aquila.it",
"ar.it",
"arezzo.it",
"ascoli-piceno.it",
"ascolipiceno.it",
"asti.it",
"at.it",
"av.it",
"avellino.it",
"ba.it",
"balsan-sudtirol.it",
"balsan-südtirol.it",
"balsan-suedtirol.it",
"balsan.it",
"bari.it",
"barletta-trani-andria.it",
"barlettatraniandria.it",
"belluno.it",
"benevento.it",
"bergamo.it",
"bg.it",
"bi.it",
"biella.it",
"bl.it",
"bn.it",
"bo.it",
"bologna.it",
"bolzano-altoadige.it",
"bolzano.it",
"bozen-sudtirol.it",
"bozen-südtirol.it",
"bozen-suedtirol.it",
"bozen.it",
"br.it",
"brescia.it",
"brindisi.it",
"bs.it",
"bt.it",
"bulsan-sudtirol.it",
"bulsan-südtirol.it",
"bulsan-suedtirol.it",
"bulsan.it",
"bz.it",
"ca.it",
"cagliari.it",
"caltanissetta.it",
"campidano-medio.it",
"campidanomedio.it",
"campobasso.it",
"carbonia-iglesias.it",
"carboniaiglesias.it",
"carrara-massa.it",
"carraramassa.it",
"caserta.it",
"catania.it",
"catanzaro.it",
"cb.it",
"ce.it",
"cesena-forli.it",
"cesena-forlì.it",
"cesenaforli.it",
"cesenaforlì.it",
"ch.it",
"chieti.it",
"ci.it",
"cl.it",
"cn.it",
"co.it",
"como.it",
"cosenza.it",
"cr.it",
"cremona.it",
"crotone.it",
"cs.it",
"ct.it",
"cuneo.it",
"cz.it",
"dell-ogliastra.it",
"dellogliastra.it",
"en.it",
"enna.it",
"fc.it",
"fe.it",
"fermo.it",
"ferrara.it",
"fg.it",
"fi.it",
"firenze.it",
"florence.it",
"fm.it",
"foggia.it",
"forli-cesena.it",
"forlì-cesena.it",
"forlicesena.it",
"forlìcesena.it",
"fr.it",
"frosinone.it",
"ge.it",
"genoa.it",
"genova.it",
"go.it",
"gorizia.it",
"gr.it",
"grosseto.it",
"iglesias-carbonia.it",
"iglesiascarbonia.it",
"im.it",
"imperia.it",
"is.it",
"isernia.it",
"kr.it",
"la-spezia.it",
"laquila.it",
"laspezia.it",
"latina.it",
"lc.it",
"le.it",
"lecce.it",
"lecco.it",
"li.it",
"livorno.it",
"lo.it",
"lodi.it",
"lt.it",
"lu.it",
"lucca.it",
"macerata.it",
"mantova.it",
"massa-carrara.it",
"massacarrara.it",
"matera.it",
"mb.it",
"mc.it",
"me.it",
"medio-campidano.it",
"mediocampidano.it",
"messina.it",
"mi.it",
"milan.it",
"milano.it",
"mn.it",
"mo.it",
"modena.it",
"monza-brianza.it",
"monza-e-della-brianza.it",
"monza.it",
"monzabrianza.it",
"monzaebrianza.it",
"monzaedellabrianza.it",
"ms.it",
"mt.it",
"na.it",
"naples.it",
"napoli.it",
"no.it",
"novara.it",
"nu.it",
"nuoro.it",
"og.it",
"ogliastra.it",
"olbia-tempio.it",
"olbiatempio.it",
"or.it",
"oristano.it",
"ot.it",
"pa.it",
"padova.it",
"padua.it",
"palermo.it",
"parma.it",
"pavia.it",
"pc.it",
"pd.it",
"pe.it",
"perugia.it",
"pesaro-urbino.it",
"pesarourbino.it",
"pescara.it",
"pg.it",
"pi.it",
"piacenza.it",
"pisa.it",
"pistoia.it",
"pn.it",
"po.it",
"pordenone.it",
"potenza.it",
"pr.it",
"prato.it",
"pt.it",
"pu.it",
"pv.it",
"pz.it",
"ra.it",
"ragusa.it",
"ravenna.it",
"rc.it",
"re.it",
"reggio-calabria.it",
"reggio-emilia.it",
"reggiocalabria.it",
"reggioemilia.it",
"rg.it",
"ri.it",
"rieti.it",
"rimini.it",
"rm.it",
"rn.it",
"ro.it",
"roma.it",
"rome.it",
"rovigo.it",
"sa.it",
"salerno.it",
"sassari.it",
"savona.it",
"si.it",
"siena.it",
"siracusa.it",
"so.it",
"sondrio.it",
"sp.it",
"sr.it",
"ss.it",
"suedtirol.it",
"südtirol.it",
"sv.it",
"ta.it",
"taranto.it",
"te.it",
"tempio-olbia.it",
"tempioolbia.it",
"teramo.it",
"terni.it",
"tn.it",
"to.it",
"torino.it",
"tp.it",
"tr.it",
"trani-andria-barletta.it",
"trani-barletta-andria.it",
"traniandriabarletta.it",
"tranibarlettaandria.it",
"trapani.it",
"trento.it",
"treviso.it",
"trieste.it",
"ts.it",
"turin.it",
"tv.it",
"ud.it",
"udine.it",
"urbino-pesaro.it",
"urbinopesaro.it",
"va.it",
"varese.it",
"vb.it",
"vc.it",
"ve.it",
"venezia.it",
"venice.it",
"verbania.it",
"vercelli.it",
"verona.it",
"vi.it",
"vibo-valentia.it",
"vibovalentia.it",
"vicenza.it",
"viterbo.it",
"vr.it",
"vs.it",
"vt.it",
"vv.it",
"je",
"co.je",
"net.je",
"org.je",
"*.jm",
"jo",
"com.jo",
"org.jo",
"net.jo",
"edu.jo",
"sch.jo",
"gov.jo",
"mil.jo",
"name.jo",
"jobs",
"jp",
"ac.jp",
"ad.jp",
"co.jp",
"ed.jp",
"go.jp",
"gr.jp",
"lg.jp",
"ne.jp",
"or.jp",
"aichi.jp",
"akita.jp",
"aomori.jp",
"chiba.jp",
"ehime.jp",
"fukui.jp",
"fukuoka.jp",
"fukushima.jp",
"gifu.jp",
"gunma.jp",
"hiroshima.jp",
"hokkaido.jp",
"hyogo.jp",
"ibaraki.jp",
"ishikawa.jp",
"iwate.jp",
"kagawa.jp",
"kagoshima.jp",
"kanagawa.jp",
"kochi.jp",
"kumamoto.jp",
"kyoto.jp",
"mie.jp",
"miyagi.jp",
"miyazaki.jp",
"nagano.jp",
"nagasaki.jp",
"nara.jp",
"niigata.jp",
"oita.jp",
"okayama.jp",
"okinawa.jp",
"osaka.jp",
"saga.jp",
"saitama.jp",
"shiga.jp",
"shimane.jp",
"shizuoka.jp",
"tochigi.jp",
"tokushima.jp",
"tokyo.jp",
"tottori.jp",
"toyama.jp",
"wakayama.jp",
"yamagata.jp",
"yamaguchi.jp",
"yamanashi.jp",
"栃木.jp",
"愛知.jp",
"愛媛.jp",
"兵庫.jp",
"熊本.jp",
"茨城.jp",
"北海道.jp",
"千葉.jp",
"和歌山.jp",
"長崎.jp",
"長野.jp",
"新潟.jp",
"青森.jp",
"静岡.jp",
"東京.jp",
"石川.jp",
"埼玉.jp",
"三重.jp",
"京都.jp",
"佐賀.jp",
"大分.jp",
"大阪.jp",
"奈良.jp",
"宮城.jp",
"宮崎.jp",
"富山.jp",
"山口.jp",
"山形.jp",
"山梨.jp",
"岩手.jp",
"岐阜.jp",
"岡山.jp",
"島根.jp",
"広島.jp",
"徳島.jp",
"沖縄.jp",
"滋賀.jp",
"神奈川.jp",
"福井.jp",
"福岡.jp",
"福島.jp",
"秋田.jp",
"群馬.jp",
"香川.jp",
"高知.jp",
"鳥取.jp",
"鹿児島.jp",
"*.kawasaki.jp",
"*.kitakyushu.jp",
"*.kobe.jp",
"*.nagoya.jp",
"*.sapporo.jp",
"*.sendai.jp",
"*.yokohama.jp",
"!city.kawasaki.jp",
"!city.kitakyushu.jp",
"!city.kobe.jp",
"!city.nagoya.jp",
"!city.sapporo.jp",
"!city.sendai.jp",
"!city.yokohama.jp",
"aisai.aichi.jp",
"ama.aichi.jp",
"anjo.aichi.jp",
"asuke.aichi.jp",
"chiryu.aichi.jp",
"chita.aichi.jp",
"fuso.aichi.jp",
"gamagori.aichi.jp",
"handa.aichi.jp",
"hazu.aichi.jp",
"hekinan.aichi.jp",
"higashiura.aichi.jp",
"ichinomiya.aichi.jp",
"inazawa.aichi.jp",
"inuyama.aichi.jp",
"isshiki.aichi.jp",
"iwakura.aichi.jp",
"kanie.aichi.jp",
"kariya.aichi.jp",
"kasugai.aichi.jp",
"kira.aichi.jp",
"kiyosu.aichi.jp",
"komaki.aichi.jp",
"konan.aichi.jp",
"kota.aichi.jp",
"mihama.aichi.jp",
"miyoshi.aichi.jp",
"nishio.aichi.jp",
"nisshin.aichi.jp",
"obu.aichi.jp",
"oguchi.aichi.jp",
"oharu.aichi.jp",
"okazaki.aichi.jp",
"owariasahi.aichi.jp",
"seto.aichi.jp",
"shikatsu.aichi.jp",
"shinshiro.aichi.jp",
"shitara.aichi.jp",
"tahara.aichi.jp",
"takahama.aichi.jp",
"tobishima.aichi.jp",
"toei.aichi.jp",
"togo.aichi.jp",
"tokai.aichi.jp",
"tokoname.aichi.jp",
"toyoake.aichi.jp",
"toyohashi.aichi.jp",
"toyokawa.aichi.jp",
"toyone.aichi.jp",
"toyota.aichi.jp",
"tsushima.aichi.jp",
"yatomi.aichi.jp",
"akita.akita.jp",
"daisen.akita.jp",
"fujisato.akita.jp",
"gojome.akita.jp",
"hachirogata.akita.jp",
"happou.akita.jp",
"higashinaruse.akita.jp",
"honjo.akita.jp",
"honjyo.akita.jp",
"ikawa.akita.jp",
"kamikoani.akita.jp",
"kamioka.akita.jp",
"katagami.akita.jp",
"kazuno.akita.jp",
"kitaakita.akita.jp",
"kosaka.akita.jp",
"kyowa.akita.jp",
"misato.akita.jp",
"mitane.akita.jp",
"moriyoshi.akita.jp",
"nikaho.akita.jp",
"noshiro.akita.jp",
"odate.akita.jp",
"oga.akita.jp",
"ogata.akita.jp",
"semboku.akita.jp",
"yokote.akita.jp",
"yurihonjo.akita.jp",
"aomori.aomori.jp",
"gonohe.aomori.jp",
"hachinohe.aomori.jp",
"hashikami.aomori.jp",
"hiranai.aomori.jp",
"hirosaki.aomori.jp",
"itayanagi.aomori.jp",
"kuroishi.aomori.jp",
"misawa.aomori.jp",
"mutsu.aomori.jp",
"nakadomari.aomori.jp",
"noheji.aomori.jp",
"oirase.aomori.jp",
"owani.aomori.jp",
"rokunohe.aomori.jp",
"sannohe.aomori.jp",
"shichinohe.aomori.jp",
"shingo.aomori.jp",
"takko.aomori.jp",
"towada.aomori.jp",
"tsugaru.aomori.jp",
"tsuruta.aomori.jp",
"abiko.chiba.jp",
"asahi.chiba.jp",
"chonan.chiba.jp",
"chosei.chiba.jp",
"choshi.chiba.jp",
"chuo.chiba.jp",
"funabashi.chiba.jp",
"futtsu.chiba.jp",
"hanamigawa.chiba.jp",
"ichihara.chiba.jp",
"ichikawa.chiba.jp",
"ichinomiya.chiba.jp",
"inzai.chiba.jp",
"isumi.chiba.jp",
"kamagaya.chiba.jp",
"kamogawa.chiba.jp",
"kashiwa.chiba.jp",
"katori.chiba.jp",
"katsuura.chiba.jp",
"kimitsu.chiba.jp",
"kisarazu.chiba.jp",
"kozaki.chiba.jp",
"kujukuri.chiba.jp",
"kyonan.chiba.jp",
"matsudo.chiba.jp",
"midori.chiba.jp",
"mihama.chiba.jp",
"minamiboso.chiba.jp",
"mobara.chiba.jp",
"mutsuzawa.chiba.jp",
"nagara.chiba.jp",
"nagareyama.chiba.jp",
"narashino.chiba.jp",
"narita.chiba.jp",
"noda.chiba.jp",
"oamishirasato.chiba.jp",
"omigawa.chiba.jp",
"onjuku.chiba.jp",
"otaki.chiba.jp",
"sakae.chiba.jp",
"sakura.chiba.jp",
"shimofusa.chiba.jp",
"shirako.chiba.jp",
"shiroi.chiba.jp",
"shisui.chiba.jp",
"sodegaura.chiba.jp",
"sosa.chiba.jp",
"tako.chiba.jp",
"tateyama.chiba.jp",
"togane.chiba.jp",
"tohnosho.chiba.jp",
"tomisato.chiba.jp",
"urayasu.chiba.jp",
"yachimata.chiba.jp",
"yachiyo.chiba.jp",
"yokaichiba.chiba.jp",
"yokoshibahikari.chiba.jp",
"yotsukaido.chiba.jp",
"ainan.ehime.jp",
"honai.ehime.jp",
"ikata.ehime.jp",
"imabari.ehime.jp",
"iyo.ehime.jp",
"kamijima.ehime.jp",
"kihoku.ehime.jp",
"kumakogen.ehime.jp",
"masaki.ehime.jp",
"matsuno.ehime.jp",
"matsuyama.ehime.jp",
"namikata.ehime.jp",
"niihama.ehime.jp",
"ozu.ehime.jp",
"saijo.ehime.jp",
"seiyo.ehime.jp",
"shikokuchuo.ehime.jp",
"tobe.ehime.jp",
"toon.ehime.jp",
"uchiko.ehime.jp",
"uwajima.ehime.jp",
"yawatahama.ehime.jp",
"echizen.fukui.jp",
"eiheiji.fukui.jp",
"fukui.fukui.jp",
"ikeda.fukui.jp",
"katsuyama.fukui.jp",
"mihama.fukui.jp",
"minamiechizen.fukui.jp",
"obama.fukui.jp",
"ohi.fukui.jp",
"ono.fukui.jp",
"sabae.fukui.jp",
"sakai.fukui.jp",
"takahama.fukui.jp",
"tsuruga.fukui.jp",
"wakasa.fukui.jp",
"ashiya.fukuoka.jp",
"buzen.fukuoka.jp",
"chikugo.fukuoka.jp",
"chikuho.fukuoka.jp",
"chikujo.fukuoka.jp",
"chikushino.fukuoka.jp",
"chikuzen.fukuoka.jp",
"chuo.fukuoka.jp",
"dazaifu.fukuoka.jp",
"fukuchi.fukuoka.jp",
"hakata.fukuoka.jp",
"higashi.fukuoka.jp",
"hirokawa.fukuoka.jp",
"hisayama.fukuoka.jp",
"iizuka.fukuoka.jp",
"inatsuki.fukuoka.jp",
"kaho.fukuoka.jp",
"kasuga.fukuoka.jp",
"kasuya.fukuoka.jp",
"kawara.fukuoka.jp",
"keisen.fukuoka.jp",
"koga.fukuoka.jp",
"kurate.fukuoka.jp",
"kurogi.fukuoka.jp",
"kurume.fukuoka.jp",
"minami.fukuoka.jp",
"miyako.fukuoka.jp",
"miyama.fukuoka.jp",
"miyawaka.fukuoka.jp",
"mizumaki.fukuoka.jp",
"munakata.fukuoka.jp",
"nakagawa.fukuoka.jp",
"nakama.fukuoka.jp",
"nishi.fukuoka.jp",
"nogata.fukuoka.jp",
"ogori.fukuoka.jp",
"okagaki.fukuoka.jp",
"okawa.fukuoka.jp",
"oki.fukuoka.jp",
"omuta.fukuoka.jp",
"onga.fukuoka.jp",
"onojo.fukuoka.jp",
"oto.fukuoka.jp",
"saigawa.fukuoka.jp",
"sasaguri.fukuoka.jp",
"shingu.fukuoka.jp",
"shinyoshitomi.fukuoka.jp",
"shonai.fukuoka.jp",
"soeda.fukuoka.jp",
"sue.fukuoka.jp",
"tachiarai.fukuoka.jp",
"tagawa.fukuoka.jp",
"takata.fukuoka.jp",
"toho.fukuoka.jp",
"toyotsu.fukuoka.jp",
"tsuiki.fukuoka.jp",
"ukiha.fukuoka.jp",
"umi.fukuoka.jp",
"usui.fukuoka.jp",
"yamada.fukuoka.jp",
"yame.fukuoka.jp",
"yanagawa.fukuoka.jp",
"yukuhashi.fukuoka.jp",
"aizubange.fukushima.jp",
"aizumisato.fukushima.jp",
"aizuwakamatsu.fukushima.jp",
"asakawa.fukushima.jp",
"bandai.fukushima.jp",
"date.fukushima.jp",
"fukushima.fukushima.jp",
"furudono.fukushima.jp",
"futaba.fukushima.jp",
"hanawa.fukushima.jp",
"higashi.fukushima.jp",
"hirata.fukushima.jp",
"hirono.fukushima.jp",
"iitate.fukushima.jp",
"inawashiro.fukushima.jp",
"ishikawa.fukushima.jp",
"iwaki.fukushima.jp",
"izumizaki.fukushima.jp",
"kagamiishi.fukushima.jp",
"kaneyama.fukushima.jp",
"kawamata.fukushima.jp",
"kitakata.fukushima.jp",
"kitashiobara.fukushima.jp",
"koori.fukushima.jp",
"koriyama.fukushima.jp",
"kunimi.fukushima.jp",
"miharu.fukushima.jp",
"mishima.fukushima.jp",
"namie.fukushima.jp",
"nango.fukushima.jp",
"nishiaizu.fukushima.jp",
"nishigo.fukushima.jp",
"okuma.fukushima.jp",
"omotego.fukushima.jp",
"ono.fukushima.jp",
"otama.fukushima.jp",
"samegawa.fukushima.jp",
"shimogo.fukushima.jp",
"shirakawa.fukushima.jp",
"showa.fukushima.jp",
"soma.fukushima.jp",
"sukagawa.fukushima.jp",
"taishin.fukushima.jp",
"tamakawa.fukushima.jp",
"tanagura.fukushima.jp",
"tenei.fukushima.jp",
"yabuki.fukushima.jp",
"yamato.fukushima.jp",
"yamatsuri.fukushima.jp",
"yanaizu.fukushima.jp",
"yugawa.fukushima.jp",
"anpachi.gifu.jp",
"ena.gifu.jp",
"gifu.gifu.jp",
"ginan.gifu.jp",
"godo.gifu.jp",
"gujo.gifu.jp",
"hashima.gifu.jp",
"hichiso.gifu.jp",
"hida.gifu.jp",
"higashishirakawa.gifu.jp",
"ibigawa.gifu.jp",
"ikeda.gifu.jp",
"kakamigahara.gifu.jp",
"kani.gifu.jp",
"kasahara.gifu.jp",
"kasamatsu.gifu.jp",
"kawaue.gifu.jp",
"kitagata.gifu.jp",
"mino.gifu.jp",
"minokamo.gifu.jp",
"mitake.gifu.jp",
"mizunami.gifu.jp",
"motosu.gifu.jp",
"nakatsugawa.gifu.jp",
"ogaki.gifu.jp",
"sakahogi.gifu.jp",
"seki.gifu.jp",
"sekigahara.gifu.jp",
"shirakawa.gifu.jp",
"tajimi.gifu.jp",
"takayama.gifu.jp",
"tarui.gifu.jp",
"toki.gifu.jp",
"tomika.gifu.jp",
"wanouchi.gifu.jp",
"yamagata.gifu.jp",
"yaotsu.gifu.jp",
"yoro.gifu.jp",
"annaka.gunma.jp",
"chiyoda.gunma.jp",
"fujioka.gunma.jp",
"higashiagatsuma.gunma.jp",
"isesaki.gunma.jp",
"itakura.gunma.jp",
"kanna.gunma.jp",
"kanra.gunma.jp",
"katashina.gunma.jp",
"kawaba.gunma.jp",
"kiryu.gunma.jp",
"kusatsu.gunma.jp",
"maebashi.gunma.jp",
"meiwa.gunma.jp",
"midori.gunma.jp",
"minakami.gunma.jp",
"naganohara.gunma.jp",
"nakanojo.gunma.jp",
"nanmoku.gunma.jp",
"numata.gunma.jp",
"oizumi.gunma.jp",
"ora.gunma.jp",
"ota.gunma.jp",
"shibukawa.gunma.jp",
"shimonita.gunma.jp",
"shinto.gunma.jp",
"showa.gunma.jp",
"takasaki.gunma.jp",
"takayama.gunma.jp",
"tamamura.gunma.jp",
"tatebayashi.gunma.jp",
"tomioka.gunma.jp",
"tsukiyono.gunma.jp",
"tsumagoi.gunma.jp",
"ueno.gunma.jp",
"yoshioka.gunma.jp",
"asaminami.hiroshima.jp",
"daiwa.hiroshima.jp",
"etajima.hiroshima.jp",
"fuchu.hiroshima.jp",
"fukuyama.hiroshima.jp",
"hatsukaichi.hiroshima.jp",
"higashihiroshima.hiroshima.jp",
"hongo.hiroshima.jp",
"jinsekikogen.hiroshima.jp",
"kaita.hiroshima.jp",
"kui.hiroshima.jp",
"kumano.hiroshima.jp",
"kure.hiroshima.jp",
"mihara.hiroshima.jp",
"miyoshi.hiroshima.jp",
"naka.hiroshima.jp",
"onomichi.hiroshima.jp",
"osakikamijima.hiroshima.jp",
"otake.hiroshima.jp",
"saka.hiroshima.jp",
"sera.hiroshima.jp",
"seranishi.hiroshima.jp",
"shinichi.hiroshima.jp",
"shobara.hiroshima.jp",
"takehara.hiroshima.jp",
"abashiri.hokkaido.jp",
"abira.hokkaido.jp",
"aibetsu.hokkaido.jp",
"akabira.hokkaido.jp",
"akkeshi.hokkaido.jp",
"asahikawa.hokkaido.jp",
"ashibetsu.hokkaido.jp",
"ashoro.hokkaido.jp",
"assabu.hokkaido.jp",
"atsuma.hokkaido.jp",
"bibai.hokkaido.jp",
"biei.hokkaido.jp",
"bifuka.hokkaido.jp",
"bihoro.hokkaido.jp",
"biratori.hokkaido.jp",
"chippubetsu.hokkaido.jp",
"chitose.hokkaido.jp",
"date.hokkaido.jp",
"ebetsu.hokkaido.jp",
"embetsu.hokkaido.jp",
"eniwa.hokkaido.jp",
"erimo.hokkaido.jp",
"esan.hokkaido.jp",
"esashi.hokkaido.jp",
"fukagawa.hokkaido.jp",
"fukushima.hokkaido.jp",
"furano.hokkaido.jp",
"furubira.hokkaido.jp",
"haboro.hokkaido.jp",
"hakodate.hokkaido.jp",
"hamatonbetsu.hokkaido.jp",
"hidaka.hokkaido.jp",
"higashikagura.hokkaido.jp",
"higashikawa.hokkaido.jp",
"hiroo.hokkaido.jp",
"hokuryu.hokkaido.jp",
"hokuto.hokkaido.jp",
"honbetsu.hokkaido.jp",
"horokanai.hokkaido.jp",
"horonobe.hokkaido.jp",
"ikeda.hokkaido.jp",
"imakane.hokkaido.jp",
"ishikari.hokkaido.jp",
"iwamizawa.hokkaido.jp",
"iwanai.hokkaido.jp",
"kamifurano.hokkaido.jp",
"kamikawa.hokkaido.jp",
"kamishihoro.hokkaido.jp",
"kamisunagawa.hokkaido.jp",
"kamoenai.hokkaido.jp",
"kayabe.hokkaido.jp",
"kembuchi.hokkaido.jp",
"kikonai.hokkaido.jp",
"kimobetsu.hokkaido.jp",
"kitahiroshima.hokkaido.jp",
"kitami.hokkaido.jp",
"kiyosato.hokkaido.jp",
"koshimizu.hokkaido.jp",
"kunneppu.hokkaido.jp",
"kuriyama.hokkaido.jp",
"kuromatsunai.hokkaido.jp",
"kushiro.hokkaido.jp",
"kutchan.hokkaido.jp",
"kyowa.hokkaido.jp",
"mashike.hokkaido.jp",
"matsumae.hokkaido.jp",
"mikasa.hokkaido.jp",
"minamifurano.hokkaido.jp",
"mombetsu.hokkaido.jp",
"moseushi.hokkaido.jp",
"mukawa.hokkaido.jp",
"muroran.hokkaido.jp",
"naie.hokkaido.jp",
"nakagawa.hokkaido.jp",
"nakasatsunai.hokkaido.jp",
"nakatombetsu.hokkaido.jp",
"nanae.hokkaido.jp",
"nanporo.hokkaido.jp",
"nayoro.hokkaido.jp",
"nemuro.hokkaido.jp",
"niikappu.hokkaido.jp",
"niki.hokkaido.jp",
"nishiokoppe.hokkaido.jp",
"noboribetsu.hokkaido.jp",
"numata.hokkaido.jp",
"obihiro.hokkaido.jp",
"obira.hokkaido.jp",
"oketo.hokkaido.jp",
"okoppe.hokkaido.jp",
"otaru.hokkaido.jp",
"otobe.hokkaido.jp",
"otofuke.hokkaido.jp",
"otoineppu.hokkaido.jp",
"oumu.hokkaido.jp",
"ozora.hokkaido.jp",
"pippu.hokkaido.jp",
"rankoshi.hokkaido.jp",
"rebun.hokkaido.jp",
"rikubetsu.hokkaido.jp",
"rishiri.hokkaido.jp",
"rishirifuji.hokkaido.jp",
"saroma.hokkaido.jp",
"sarufutsu.hokkaido.jp",
"shakotan.hokkaido.jp",
"shari.hokkaido.jp",
"shibecha.hokkaido.jp",
"shibetsu.hokkaido.jp",
"shikabe.hokkaido.jp",
"shikaoi.hokkaido.jp",
"shimamaki.hokkaido.jp",
"shimizu.hokkaido.jp",
"shimokawa.hokkaido.jp",
"shinshinotsu.hokkaido.jp",
"shintoku.hokkaido.jp",
"shiranuka.hokkaido.jp",
"shiraoi.hokkaido.jp",
"shiriuchi.hokkaido.jp",
"sobetsu.hokkaido.jp",
"sunagawa.hokkaido.jp",
"taiki.hokkaido.jp",
"takasu.hokkaido.jp",
"takikawa.hokkaido.jp",
"takinoue.hokkaido.jp",
"teshikaga.hokkaido.jp",
"tobetsu.hokkaido.jp",
"tohma.hokkaido.jp",
"tomakomai.hokkaido.jp",
"tomari.hokkaido.jp",
"toya.hokkaido.jp",
"toyako.hokkaido.jp",
"toyotomi.hokkaido.jp",
"toyoura.hokkaido.jp",
"tsubetsu.hokkaido.jp",
"tsukigata.hokkaido.jp",
"urakawa.hokkaido.jp",
"urausu.hokkaido.jp",
"uryu.hokkaido.jp",
"utashinai.hokkaido.jp",
"wakkanai.hokkaido.jp",
"wassamu.hokkaido.jp",
"yakumo.hokkaido.jp",
"yoichi.hokkaido.jp",
"aioi.hyogo.jp",
"akashi.hyogo.jp",
"ako.hyogo.jp",
"amagasaki.hyogo.jp",
"aogaki.hyogo.jp",
"asago.hyogo.jp",
"ashiya.hyogo.jp",
"awaji.hyogo.jp",
"fukusaki.hyogo.jp",
"goshiki.hyogo.jp",
"harima.hyogo.jp",
"himeji.hyogo.jp",
"ichikawa.hyogo.jp",
"inagawa.hyogo.jp",
"itami.hyogo.jp",
"kakogawa.hyogo.jp",
"kamigori.hyogo.jp",
"kamikawa.hyogo.jp",
"kasai.hyogo.jp",
"kasuga.hyogo.jp",
"kawanishi.hyogo.jp",
"miki.hyogo.jp",
"minamiawaji.hyogo.jp",
"nishinomiya.hyogo.jp",
"nishiwaki.hyogo.jp",
"ono.hyogo.jp",
"sanda.hyogo.jp",
"sannan.hyogo.jp",
"sasayama.hyogo.jp",
"sayo.hyogo.jp",
"shingu.hyogo.jp",
"shinonsen.hyogo.jp",
"shiso.hyogo.jp",
"sumoto.hyogo.jp",
"taishi.hyogo.jp",
"taka.hyogo.jp",
"takarazuka.hyogo.jp",
"takasago.hyogo.jp",
"takino.hyogo.jp",
"tamba.hyogo.jp",
"tatsuno.hyogo.jp",
"toyooka.hyogo.jp",
"yabu.hyogo.jp",
"yashiro.hyogo.jp",
"yoka.hyogo.jp",
"yokawa.hyogo.jp",
"ami.ibaraki.jp",
"asahi.ibaraki.jp",
"bando.ibaraki.jp",
"chikusei.ibaraki.jp",
"daigo.ibaraki.jp",
"fujishiro.ibaraki.jp",
"hitachi.ibaraki.jp",
"hitachinaka.ibaraki.jp",
"hitachiomiya.ibaraki.jp",
"hitachiota.ibaraki.jp",
"ibaraki.ibaraki.jp",
"ina.ibaraki.jp",
"inashiki.ibaraki.jp",
"itako.ibaraki.jp",
"iwama.ibaraki.jp",
"joso.ibaraki.jp",
"kamisu.ibaraki.jp",
"kasama.ibaraki.jp",
"kashima.ibaraki.jp",
"kasumigaura.ibaraki.jp",
"koga.ibaraki.jp",
"miho.ibaraki.jp",
"mito.ibaraki.jp",
"moriya.ibaraki.jp",
"naka.ibaraki.jp",
"namegata.ibaraki.jp",
"oarai.ibaraki.jp",
"ogawa.ibaraki.jp",
"omitama.ibaraki.jp",
"ryugasaki.ibaraki.jp",
"sakai.ibaraki.jp",
"sakuragawa.ibaraki.jp",
"shimodate.ibaraki.jp",
"shimotsuma.ibaraki.jp",
"shirosato.ibaraki.jp",
"sowa.ibaraki.jp",
"suifu.ibaraki.jp",
"takahagi.ibaraki.jp",
"tamatsukuri.ibaraki.jp",
"tokai.ibaraki.jp",
"tomobe.ibaraki.jp",
"tone.ibaraki.jp",
"toride.ibaraki.jp",
"tsuchiura.ibaraki.jp",
"tsukuba.ibaraki.jp",
"uchihara.ibaraki.jp",
"ushiku.ibaraki.jp",
"yachiyo.ibaraki.jp",
"yamagata.ibaraki.jp",
"yawara.ibaraki.jp",
"yuki.ibaraki.jp",
"anamizu.ishikawa.jp",
"hakui.ishikawa.jp",
"hakusan.ishikawa.jp",
"kaga.ishikawa.jp",
"kahoku.ishikawa.jp",
"kanazawa.ishikawa.jp",
"kawakita.ishikawa.jp",
"komatsu.ishikawa.jp",
"nakanoto.ishikawa.jp",
"nanao.ishikawa.jp",
"nomi.ishikawa.jp",
"nonoichi.ishikawa.jp",
"noto.ishikawa.jp",
"shika.ishikawa.jp",
"suzu.ishikawa.jp",
"tsubata.ishikawa.jp",
"tsurugi.ishikawa.jp",
"uchinada.ishikawa.jp",
"wajima.ishikawa.jp",
"fudai.iwate.jp",
"fujisawa.iwate.jp",
"hanamaki.iwate.jp",
"hiraizumi.iwate.jp",
"hirono.iwate.jp",
"ichinohe.iwate.jp",
"ichinoseki.iwate.jp",
"iwaizumi.iwate.jp",
"iwate.iwate.jp",
"joboji.iwate.jp",
"kamaishi.iwate.jp",
"kanegasaki.iwate.jp",
"karumai.iwate.jp",
"kawai.iwate.jp",
"kitakami.iwate.jp",
"kuji.iwate.jp",
"kunohe.iwate.jp",
"kuzumaki.iwate.jp",
"miyako.iwate.jp",
"mizusawa.iwate.jp",
"morioka.iwate.jp",
"ninohe.iwate.jp",
"noda.iwate.jp",
"ofunato.iwate.jp",
"oshu.iwate.jp",
"otsuchi.iwate.jp",
"rikuzentakata.iwate.jp",
"shiwa.iwate.jp",
"shizukuishi.iwate.jp",
"sumita.iwate.jp",
"tanohata.iwate.jp",
"tono.iwate.jp",
"yahaba.iwate.jp",
"yamada.iwate.jp",
"ayagawa.kagawa.jp",
"higashikagawa.kagawa.jp",
"kanonji.kagawa.jp",
"kotohira.kagawa.jp",
"manno.kagawa.jp",
"marugame.kagawa.jp",
"mitoyo.kagawa.jp",
"naoshima.kagawa.jp",
"sanuki.kagawa.jp",
"tadotsu.kagawa.jp",
"takamatsu.kagawa.jp",
"tonosho.kagawa.jp",
"uchinomi.kagawa.jp",
"utazu.kagawa.jp",
"zentsuji.kagawa.jp",
"akune.kagoshima.jp",
"amami.kagoshima.jp",
"hioki.kagoshima.jp",
"isa.kagoshima.jp",
"isen.kagoshima.jp",
"izumi.kagoshima.jp",
"kagoshima.kagoshima.jp",
"kanoya.kagoshima.jp",
"kawanabe.kagoshima.jp",
"kinko.kagoshima.jp",
"kouyama.kagoshima.jp",
"makurazaki.kagoshima.jp",
"matsumoto.kagoshima.jp",
"minamitane.kagoshima.jp",
"nakatane.kagoshima.jp",
"nishinoomote.kagoshima.jp",
"satsumasendai.kagoshima.jp",
"soo.kagoshima.jp",
"tarumizu.kagoshima.jp",
"yusui.kagoshima.jp",
"aikawa.kanagawa.jp",
"atsugi.kanagawa.jp",
"ayase.kanagawa.jp",
"chigasaki.kanagawa.jp",
"ebina.kanagawa.jp",
"fujisawa.kanagawa.jp",
"hadano.kanagawa.jp",
"hakone.kanagawa.jp",
"hiratsuka.kanagawa.jp",
"isehara.kanagawa.jp",
"kaisei.kanagawa.jp",
"kamakura.kanagawa.jp",
"kiyokawa.kanagawa.jp",
"matsuda.kanagawa.jp",
"minamiashigara.kanagawa.jp",
"miura.kanagawa.jp",
"nakai.kanagawa.jp",
"ninomiya.kanagawa.jp",
"odawara.kanagawa.jp",
"oi.kanagawa.jp",
"oiso.kanagawa.jp",
"sagamihara.kanagawa.jp",
"samukawa.kanagawa.jp",
"tsukui.kanagawa.jp",
"yamakita.kanagawa.jp",
"yamato.kanagawa.jp",
"yokosuka.kanagawa.jp",
"yugawara.kanagawa.jp",
"zama.kanagawa.jp",
"zushi.kanagawa.jp",
"aki.kochi.jp",
"geisei.kochi.jp",
"hidaka.kochi.jp",
"higashitsuno.kochi.jp",
"ino.kochi.jp",
"kagami.kochi.jp",
"kami.kochi.jp",
"kitagawa.kochi.jp",
"kochi.kochi.jp",
"mihara.kochi.jp",
"motoyama.kochi.jp",
"muroto.kochi.jp",
"nahari.kochi.jp",
"nakamura.kochi.jp",
"nankoku.kochi.jp",
"nishitosa.kochi.jp",
"niyodogawa.kochi.jp",
"ochi.kochi.jp",
"okawa.kochi.jp",
"otoyo.kochi.jp",
"otsuki.kochi.jp",
"sakawa.kochi.jp",
"sukumo.kochi.jp",
"susaki.kochi.jp",
"tosa.kochi.jp",
"tosashimizu.kochi.jp",
"toyo.kochi.jp",
"tsuno.kochi.jp",
"umaji.kochi.jp",
"yasuda.kochi.jp",
"yusuhara.kochi.jp",
"amakusa.kumamoto.jp",
"arao.kumamoto.jp",
"aso.kumamoto.jp",
"choyo.kumamoto.jp",
"gyokuto.kumamoto.jp",
"kamiamakusa.kumamoto.jp",
"kikuchi.kumamoto.jp",
"kumamoto.kumamoto.jp",
"mashiki.kumamoto.jp",
"mifune.kumamoto.jp",
"minamata.kumamoto.jp",
"minamioguni.kumamoto.jp",
"nagasu.kumamoto.jp",
"nishihara.kumamoto.jp",
"oguni.kumamoto.jp",
"ozu.kumamoto.jp",
"sumoto.kumamoto.jp",
"takamori.kumamoto.jp",
"uki.kumamoto.jp",
"uto.kumamoto.jp",
"yamaga.kumamoto.jp",
"yamato.kumamoto.jp",
"yatsushiro.kumamoto.jp",
"ayabe.kyoto.jp",
"fukuchiyama.kyoto.jp",
"higashiyama.kyoto.jp",
"ide.kyoto.jp",
"ine.kyoto.jp",
"joyo.kyoto.jp",
"kameoka.kyoto.jp",
"kamo.kyoto.jp",
"kita.kyoto.jp",
"kizu.kyoto.jp",
"kumiyama.kyoto.jp",
"kyotamba.kyoto.jp",
"kyotanabe.kyoto.jp",
"kyotango.kyoto.jp",
"maizuru.kyoto.jp",
"minami.kyoto.jp",
"minamiyamashiro.kyoto.jp",
"miyazu.kyoto.jp",
"muko.kyoto.jp",
"nagaokakyo.kyoto.jp",
"nakagyo.kyoto.jp",
"nantan.kyoto.jp",
"oyamazaki.kyoto.jp",
"sakyo.kyoto.jp",
"seika.kyoto.jp",
"tanabe.kyoto.jp",
"uji.kyoto.jp",
"ujitawara.kyoto.jp",
"wazuka.kyoto.jp",
"yamashina.kyoto.jp",
"yawata.kyoto.jp",
"asahi.mie.jp",
"inabe.mie.jp",
"ise.mie.jp",
"kameyama.mie.jp",
"kawagoe.mie.jp",
"kiho.mie.jp",
"kisosaki.mie.jp",
"kiwa.mie.jp",
"komono.mie.jp",
"kumano.mie.jp",
"kuwana.mie.jp",
"matsusaka.mie.jp",
"meiwa.mie.jp",
"mihama.mie.jp",
"minamiise.mie.jp",
"misugi.mie.jp",
"miyama.mie.jp",
"nabari.mie.jp",
"shima.mie.jp",
"suzuka.mie.jp",
"tado.mie.jp",
"taiki.mie.jp",
"taki.mie.jp",
"tamaki.mie.jp",
"toba.mie.jp",
"tsu.mie.jp",
"udono.mie.jp",
"ureshino.mie.jp",
"watarai.mie.jp",
"yokkaichi.mie.jp",
"furukawa.miyagi.jp",
"higashimatsushima.miyagi.jp",
"ishinomaki.miyagi.jp",
"iwanuma.miyagi.jp",
"kakuda.miyagi.jp",
"kami.miyagi.jp",
"kawasaki.miyagi.jp",
"marumori.miyagi.jp",
"matsushima.miyagi.jp",
"minamisanriku.miyagi.jp",
"misato.miyagi.jp",
"murata.miyagi.jp",
"natori.miyagi.jp",
"ogawara.miyagi.jp",
"ohira.miyagi.jp",
"onagawa.miyagi.jp",
"osaki.miyagi.jp",
"rifu.miyagi.jp",
"semine.miyagi.jp",
"shibata.miyagi.jp",
"shichikashuku.miyagi.jp",
"shikama.miyagi.jp",
"shiogama.miyagi.jp",
"shiroishi.miyagi.jp",
"tagajo.miyagi.jp",
"taiwa.miyagi.jp",
"tome.miyagi.jp",
"tomiya.miyagi.jp",
"wakuya.miyagi.jp",
"watari.miyagi.jp",
"yamamoto.miyagi.jp",
"zao.miyagi.jp",
"aya.miyazaki.jp",
"ebino.miyazaki.jp",
"gokase.miyazaki.jp",
"hyuga.miyazaki.jp",
"kadogawa.miyazaki.jp",
"kawaminami.miyazaki.jp",
"kijo.miyazaki.jp",
"kitagawa.miyazaki.jp",
"kitakata.miyazaki.jp",
"kitaura.miyazaki.jp",
"kobayashi.miyazaki.jp",
"kunitomi.miyazaki.jp",
"kushima.miyazaki.jp",
"mimata.miyazaki.jp",
"miyakonojo.miyazaki.jp",
"miyazaki.miyazaki.jp",
"morotsuka.miyazaki.jp",
"nichinan.miyazaki.jp",
"nishimera.miyazaki.jp",
"nobeoka.miyazaki.jp",
"saito.miyazaki.jp",
"shiiba.miyazaki.jp",
"shintomi.miyazaki.jp",
"takaharu.miyazaki.jp",
"takanabe.miyazaki.jp",
"takazaki.miyazaki.jp",
"tsuno.miyazaki.jp",
"achi.nagano.jp",
"agematsu.nagano.jp",
"anan.nagano.jp",
"aoki.nagano.jp",
"asahi.nagano.jp",
"azumino.nagano.jp",
"chikuhoku.nagano.jp",
"chikuma.nagano.jp",
"chino.nagano.jp",
"fujimi.nagano.jp",
"hakuba.nagano.jp",
"hara.nagano.jp",
"hiraya.nagano.jp",
"iida.nagano.jp",
"iijima.nagano.jp",
"iiyama.nagano.jp",
"iizuna.nagano.jp",
"ikeda.nagano.jp",
"ikusaka.nagano.jp",
"ina.nagano.jp",
"karuizawa.nagano.jp",
"kawakami.nagano.jp",
"kiso.nagano.jp",
"kisofukushima.nagano.jp",
"kitaaiki.nagano.jp",
"komagane.nagano.jp",
"komoro.nagano.jp",
"matsukawa.nagano.jp",
"matsumoto.nagano.jp",
"miasa.nagano.jp",
"minamiaiki.nagano.jp",
"minamimaki.nagano.jp",
"minamiminowa.nagano.jp",
"minowa.nagano.jp",
"miyada.nagano.jp",
"miyota.nagano.jp",
"mochizuki.nagano.jp",
"nagano.nagano.jp",
"nagawa.nagano.jp",
"nagiso.nagano.jp",
"nakagawa.nagano.jp",
"nakano.nagano.jp",
"nozawaonsen.nagano.jp",
"obuse.nagano.jp",
"ogawa.nagano.jp",
"okaya.nagano.jp",
"omachi.nagano.jp",
"omi.nagano.jp",
"ookuwa.nagano.jp",
"ooshika.nagano.jp",
"otaki.nagano.jp",
"otari.nagano.jp",
"sakae.nagano.jp",
"sakaki.nagano.jp",
"saku.nagano.jp",
"sakuho.nagano.jp",
"shimosuwa.nagano.jp",
"shinanomachi.nagano.jp",
"shiojiri.nagano.jp",
"suwa.nagano.jp",
"suzaka.nagano.jp",
"takagi.nagano.jp",
"takamori.nagano.jp",
"takayama.nagano.jp",
"tateshina.nagano.jp",
"tatsuno.nagano.jp",
"togakushi.nagano.jp",
"togura.nagano.jp",
"tomi.nagano.jp",
"ueda.nagano.jp",
"wada.nagano.jp",
"yamagata.nagano.jp",
"yamanouchi.nagano.jp",
"yasaka.nagano.jp",
"yasuoka.nagano.jp",
"chijiwa.nagasaki.jp",
"futsu.nagasaki.jp",
"goto.nagasaki.jp",
"hasami.nagasaki.jp",
"hirado.nagasaki.jp",
"iki.nagasaki.jp",
"isahaya.nagasaki.jp",
"kawatana.nagasaki.jp",
"kuchinotsu.nagasaki.jp",
"matsuura.nagasaki.jp",
"nagasaki.nagasaki.jp",
"obama.nagasaki.jp",
"omura.nagasaki.jp",
"oseto.nagasaki.jp",
"saikai.nagasaki.jp",
"sasebo.nagasaki.jp",
"seihi.nagasaki.jp",
"shimabara.nagasaki.jp",
"shinkamigoto.nagasaki.jp",
"togitsu.nagasaki.jp",
"tsushima.nagasaki.jp",
"unzen.nagasaki.jp",
"ando.nara.jp",
"gose.nara.jp",
"heguri.nara.jp",
"higashiyoshino.nara.jp",
"ikaruga.nara.jp",
"ikoma.nara.jp",
"kamikitayama.nara.jp",
"kanmaki.nara.jp",
"kashiba.nara.jp",
"kashihara.nara.jp",
"katsuragi.nara.jp",
"kawai.nara.jp",
"kawakami.nara.jp",
"kawanishi.nara.jp",
"koryo.nara.jp",
"kurotaki.nara.jp",
"mitsue.nara.jp",
"miyake.nara.jp",
"nara.nara.jp",
"nosegawa.nara.jp",
"oji.nara.jp",
"ouda.nara.jp",
"oyodo.nara.jp",
"sakurai.nara.jp",
"sango.nara.jp",
"shimoichi.nara.jp",
"shimokitayama.nara.jp",
"shinjo.nara.jp",
"soni.nara.jp",
"takatori.nara.jp",
"tawaramoto.nara.jp",
"tenkawa.nara.jp",
"tenri.nara.jp",
"uda.nara.jp",
"yamatokoriyama.nara.jp",
"yamatotakada.nara.jp",
"yamazoe.nara.jp",
"yoshino.nara.jp",
"aga.niigata.jp",
"agano.niigata.jp",
"gosen.niigata.jp",
"itoigawa.niigata.jp",
"izumozaki.niigata.jp",
"joetsu.niigata.jp",
"kamo.niigata.jp",
"kariwa.niigata.jp",
"kashiwazaki.niigata.jp",
"minamiuonuma.niigata.jp",
"mitsuke.niigata.jp",
"muika.niigata.jp",
"murakami.niigata.jp",
"myoko.niigata.jp",
"nagaoka.niigata.jp",
"niigata.niigata.jp",
"ojiya.niigata.jp",
"omi.niigata.jp",
"sado.niigata.jp",
"sanjo.niigata.jp",
"seiro.niigata.jp",
"seirou.niigata.jp",
"sekikawa.niigata.jp",
"shibata.niigata.jp",
"tagami.niigata.jp",
"tainai.niigata.jp",
"tochio.niigata.jp",
"tokamachi.niigata.jp",
"tsubame.niigata.jp",
"tsunan.niigata.jp",
"uonuma.niigata.jp",
"yahiko.niigata.jp",
"yoita.niigata.jp",
"yuzawa.niigata.jp",
"beppu.oita.jp",
"bungoono.oita.jp",
"bungotakada.oita.jp",
"hasama.oita.jp",
"hiji.oita.jp",
"himeshima.oita.jp",
"hita.oita.jp",
"kamitsue.oita.jp",
"kokonoe.oita.jp",
"kuju.oita.jp",
"kunisaki.oita.jp",
"kusu.oita.jp",
"oita.oita.jp",
"saiki.oita.jp",
"taketa.oita.jp",
"tsukumi.oita.jp",
"usa.oita.jp",
"usuki.oita.jp",
"yufu.oita.jp",
"akaiwa.okayama.jp",
"asakuchi.okayama.jp",
"bizen.okayama.jp",
"hayashima.okayama.jp",
"ibara.okayama.jp",
"kagamino.okayama.jp",
"kasaoka.okayama.jp",
"kibichuo.okayama.jp",
"kumenan.okayama.jp",
"kurashiki.okayama.jp",
"maniwa.okayama.jp",
"misaki.okayama.jp",
"nagi.okayama.jp",
"niimi.okayama.jp",
"nishiawakura.okayama.jp",
"okayama.okayama.jp",
"satosho.okayama.jp",
"setouchi.okayama.jp",
"shinjo.okayama.jp",
"shoo.okayama.jp",
"soja.okayama.jp",
"takahashi.okayama.jp",
"tamano.okayama.jp",
"tsuyama.okayama.jp",
"wake.okayama.jp",
"yakage.okayama.jp",
"aguni.okinawa.jp",
"ginowan.okinawa.jp",
"ginoza.okinawa.jp",
"gushikami.okinawa.jp",
"haebaru.okinawa.jp",
"higashi.okinawa.jp",
"hirara.okinawa.jp",
"iheya.okinawa.jp",
"ishigaki.okinawa.jp",
"ishikawa.okinawa.jp",
"itoman.okinawa.jp",
"izena.okinawa.jp",
"kadena.okinawa.jp",
"kin.okinawa.jp",
"kitadaito.okinawa.jp",
"kitanakagusuku.okinawa.jp",
"kumejima.okinawa.jp",
"kunigami.okinawa.jp",
"minamidaito.okinawa.jp",
"motobu.okinawa.jp",
"nago.okinawa.jp",
"naha.okinawa.jp",
"nakagusuku.okinawa.jp",
"nakijin.okinawa.jp",
"nanjo.okinawa.jp",
"nishihara.okinawa.jp",
"ogimi.okinawa.jp",
"okinawa.okinawa.jp",
"onna.okinawa.jp",
"shimoji.okinawa.jp",
"taketomi.okinawa.jp",
"tarama.okinawa.jp",
"tokashiki.okinawa.jp",
"tomigusuku.okinawa.jp",
"tonaki.okinawa.jp",
"urasoe.okinawa.jp",
"uruma.okinawa.jp",
"yaese.okinawa.jp",
"yomitan.okinawa.jp",
"yonabaru.okinawa.jp",
"yonaguni.okinawa.jp",
"zamami.okinawa.jp",
"abeno.osaka.jp",
"chihayaakasaka.osaka.jp",
"chuo.osaka.jp",
"daito.osaka.jp",
"fujiidera.osaka.jp",
"habikino.osaka.jp",
"hannan.osaka.jp",
"higashiosaka.osaka.jp",
"higashisumiyoshi.osaka.jp",
"higashiyodogawa.osaka.jp",
"hirakata.osaka.jp",
"ibaraki.osaka.jp",
"ikeda.osaka.jp",
"izumi.osaka.jp",
"izumiotsu.osaka.jp",
"izumisano.osaka.jp",
"kadoma.osaka.jp",
"kaizuka.osaka.jp",
"kanan.osaka.jp",
"kashiwara.osaka.jp",
"katano.osaka.jp",
"kawachinagano.osaka.jp",
"kishiwada.osaka.jp",
"kita.osaka.jp",
"kumatori.osaka.jp",
"matsubara.osaka.jp",
"minato.osaka.jp",
"minoh.osaka.jp",
"misaki.osaka.jp",
"moriguchi.osaka.jp",
"neyagawa.osaka.jp",
"nishi.osaka.jp",
"nose.osaka.jp",
"osakasayama.osaka.jp",
"sakai.osaka.jp",
"sayama.osaka.jp",
"sennan.osaka.jp",
"settsu.osaka.jp",
"shijonawate.osaka.jp",
"shimamoto.osaka.jp",
"suita.osaka.jp",
"tadaoka.osaka.jp",
"taishi.osaka.jp",
"tajiri.osaka.jp",
"takaishi.osaka.jp",
"takatsuki.osaka.jp",
"tondabayashi.osaka.jp",
"toyonaka.osaka.jp",
"toyono.osaka.jp",
"yao.osaka.jp",
"ariake.saga.jp",
"arita.saga.jp",
"fukudomi.saga.jp",
"genkai.saga.jp",
"hamatama.saga.jp",
"hizen.saga.jp",
"imari.saga.jp",
"kamimine.saga.jp",
"kanzaki.saga.jp",
"karatsu.saga.jp",
"kashima.saga.jp",
"kitagata.saga.jp",
"kitahata.saga.jp",
"kiyama.saga.jp",
"kouhoku.saga.jp",
"kyuragi.saga.jp",
"nishiarita.saga.jp",
"ogi.saga.jp",
"omachi.saga.jp",
"ouchi.saga.jp",
"saga.saga.jp",
"shiroishi.saga.jp",
"taku.saga.jp",
"tara.saga.jp",
"tosu.saga.jp",
"yoshinogari.saga.jp",
"arakawa.saitama.jp",
"asaka.saitama.jp",
"chichibu.saitama.jp",
"fujimi.saitama.jp",
"fujimino.saitama.jp",
"fukaya.saitama.jp",
"hanno.saitama.jp",
"hanyu.saitama.jp",
"hasuda.saitama.jp",
"hatogaya.saitama.jp",
"hatoyama.saitama.jp",
"hidaka.saitama.jp",
"higashichichibu.saitama.jp",
"higashimatsuyama.saitama.jp",
"honjo.saitama.jp",
"ina.saitama.jp",
"iruma.saitama.jp",
"iwatsuki.saitama.jp",
"kamiizumi.saitama.jp",
"kamikawa.saitama.jp",
"kamisato.saitama.jp",
"kasukabe.saitama.jp",
"kawagoe.saitama.jp",
"kawaguchi.saitama.jp",
"kawajima.saitama.jp",
"kazo.saitama.jp",
"kitamoto.saitama.jp",
"koshigaya.saitama.jp",
"kounosu.saitama.jp",
"kuki.saitama.jp",
"kumagaya.saitama.jp",
"matsubushi.saitama.jp",
"minano.saitama.jp",
"misato.saitama.jp",
"miyashiro.saitama.jp",
"miyoshi.saitama.jp",
"moroyama.saitama.jp",
"nagatoro.saitama.jp",
"namegawa.saitama.jp",
"niiza.saitama.jp",
"ogano.saitama.jp",
"ogawa.saitama.jp",
"ogose.saitama.jp",
"okegawa.saitama.jp",
"omiya.saitama.jp",
"otaki.saitama.jp",
"ranzan.saitama.jp",
"ryokami.saitama.jp",
"saitama.saitama.jp",
"sakado.saitama.jp",
"satte.saitama.jp",
"sayama.saitama.jp",
"shiki.saitama.jp",
"shiraoka.saitama.jp",
"soka.saitama.jp",
"sugito.saitama.jp",
"toda.saitama.jp",
"tokigawa.saitama.jp",
"tokorozawa.saitama.jp",
"tsurugashima.saitama.jp",
"urawa.saitama.jp",
"warabi.saitama.jp",
"yashio.saitama.jp",
"yokoze.saitama.jp",
"yono.saitama.jp",
"yorii.saitama.jp",
"yoshida.saitama.jp",
"yoshikawa.saitama.jp",
"yoshimi.saitama.jp",
"aisho.shiga.jp",
"gamo.shiga.jp",
"higashiomi.shiga.jp",
"hikone.shiga.jp",
"koka.shiga.jp",
"konan.shiga.jp",
"kosei.shiga.jp",
"koto.shiga.jp",
"kusatsu.shiga.jp",
"maibara.shiga.jp",
"moriyama.shiga.jp",
"nagahama.shiga.jp",
"nishiazai.shiga.jp",
"notogawa.shiga.jp",
"omihachiman.shiga.jp",
"otsu.shiga.jp",
"ritto.shiga.jp",
"ryuoh.shiga.jp",
"takashima.shiga.jp",
"takatsuki.shiga.jp",
"torahime.shiga.jp",
"toyosato.shiga.jp",
"yasu.shiga.jp",
"akagi.shimane.jp",
"ama.shimane.jp",
"gotsu.shimane.jp",
"hamada.shimane.jp",
"higashiizumo.shimane.jp",
"hikawa.shimane.jp",
"hikimi.shimane.jp",
"izumo.shimane.jp",
"kakinoki.shimane.jp",
"masuda.shimane.jp",
"matsue.shimane.jp",
"misato.shimane.jp",
"nishinoshima.shimane.jp",
"ohda.shimane.jp",
"okinoshima.shimane.jp",
"okuizumo.shimane.jp",
"shimane.shimane.jp",
"tamayu.shimane.jp",
"tsuwano.shimane.jp",
"unnan.shimane.jp",
"yakumo.shimane.jp",
"yasugi.shimane.jp",
"yatsuka.shimane.jp",
"arai.shizuoka.jp",
"atami.shizuoka.jp",
"fuji.shizuoka.jp",
"fujieda.shizuoka.jp",
"fujikawa.shizuoka.jp",
"fujinomiya.shizuoka.jp",
"fukuroi.shizuoka.jp",
"gotemba.shizuoka.jp",
"haibara.shizuoka.jp",
"hamamatsu.shizuoka.jp",
"higashiizu.shizuoka.jp",
"ito.shizuoka.jp",
"iwata.shizuoka.jp",
"izu.shizuoka.jp",
"izunokuni.shizuoka.jp",
"kakegawa.shizuoka.jp",
"kannami.shizuoka.jp",
"kawanehon.shizuoka.jp",
"kawazu.shizuoka.jp",
"kikugawa.shizuoka.jp",
"kosai.shizuoka.jp",
"makinohara.shizuoka.jp",
"matsuzaki.shizuoka.jp",
"minamiizu.shizuoka.jp",
"mishima.shizuoka.jp",
"morimachi.shizuoka.jp",
"nishiizu.shizuoka.jp",
"numazu.shizuoka.jp",
"omaezaki.shizuoka.jp",
"shimada.shizuoka.jp",
"shimizu.shizuoka.jp",
"shimoda.shizuoka.jp",
"shizuoka.shizuoka.jp",
"susono.shizuoka.jp",
"yaizu.shizuoka.jp",
"yoshida.shizuoka.jp",
"ashikaga.tochigi.jp",
"bato.tochigi.jp",
"haga.tochigi.jp",
"ichikai.tochigi.jp",
"iwafune.tochigi.jp",
"kaminokawa.tochigi.jp",
"kanuma.tochigi.jp",
"karasuyama.tochigi.jp",
"kuroiso.tochigi.jp",
"mashiko.tochigi.jp",
"mibu.tochigi.jp",
"moka.tochigi.jp",
"motegi.tochigi.jp",
"nasu.tochigi.jp",
"nasushiobara.tochigi.jp",
"nikko.tochigi.jp",
"nishikata.tochigi.jp",
"nogi.tochigi.jp",
"ohira.tochigi.jp",
"ohtawara.tochigi.jp",
"oyama.tochigi.jp",
"sakura.tochigi.jp",
"sano.tochigi.jp",
"shimotsuke.tochigi.jp",
"shioya.tochigi.jp",
"takanezawa.tochigi.jp",
"tochigi.tochigi.jp",
"tsuga.tochigi.jp",
"ujiie.tochigi.jp",
"utsunomiya.tochigi.jp",
"yaita.tochigi.jp",
"aizumi.tokushima.jp",
"anan.tokushima.jp",
"ichiba.tokushima.jp",
"itano.tokushima.jp",
"kainan.tokushima.jp",
"komatsushima.tokushima.jp",
"matsushige.tokushima.jp",
"mima.tokushima.jp",
"minami.tokushima.jp",
"miyoshi.tokushima.jp",
"mugi.tokushima.jp",
"nakagawa.tokushima.jp",
"naruto.tokushima.jp",
"sanagochi.tokushima.jp",
"shishikui.tokushima.jp",
"tokushima.tokushima.jp",
"wajiki.tokushima.jp",
"adachi.tokyo.jp",
"akiruno.tokyo.jp",
"akishima.tokyo.jp",
"aogashima.tokyo.jp",
"arakawa.tokyo.jp",
"bunkyo.tokyo.jp",
"chiyoda.tokyo.jp",
"chofu.tokyo.jp",
"chuo.tokyo.jp",
"edogawa.tokyo.jp",
"fuchu.tokyo.jp",
"fussa.tokyo.jp",
"hachijo.tokyo.jp",
"hachioji.tokyo.jp",
"hamura.tokyo.jp",
"higashikurume.tokyo.jp",
"higashimurayama.tokyo.jp",
"higashiyamato.tokyo.jp",
"hino.tokyo.jp",
"hinode.tokyo.jp",
"hinohara.tokyo.jp",
"inagi.tokyo.jp",
"itabashi.tokyo.jp",
"katsushika.tokyo.jp",
"kita.tokyo.jp",
"kiyose.tokyo.jp",
"kodaira.tokyo.jp",
"koganei.tokyo.jp",
"kokubunji.tokyo.jp",
"komae.tokyo.jp",
"koto.tokyo.jp",
"kouzushima.tokyo.jp",
"kunitachi.tokyo.jp",
"machida.tokyo.jp",
"meguro.tokyo.jp",
"minato.tokyo.jp",
"mitaka.tokyo.jp",
"mizuho.tokyo.jp",
"musashimurayama.tokyo.jp",
"musashino.tokyo.jp",
"nakano.tokyo.jp",
"nerima.tokyo.jp",
"ogasawara.tokyo.jp",
"okutama.tokyo.jp",
"ome.tokyo.jp",
"oshima.tokyo.jp",
"ota.tokyo.jp",
"setagaya.tokyo.jp",
"shibuya.tokyo.jp",
"shinagawa.tokyo.jp",
"shinjuku.tokyo.jp",
"suginami.tokyo.jp",
"sumida.tokyo.jp",
"tachikawa.tokyo.jp",
"taito.tokyo.jp",
"tama.tokyo.jp",
"toshima.tokyo.jp",
"chizu.tottori.jp",
"hino.tottori.jp",
"kawahara.tottori.jp",
"koge.tottori.jp",
"kotoura.tottori.jp",
"misasa.tottori.jp",
"nanbu.tottori.jp",
"nichinan.tottori.jp",
"sakaiminato.tottori.jp",
"tottori.tottori.jp",
"wakasa.tottori.jp",
"yazu.tottori.jp",
"yonago.tottori.jp",
"asahi.toyama.jp",
"fuchu.toyama.jp",
"fukumitsu.toyama.jp",
"funahashi.toyama.jp",
"himi.toyama.jp",
"imizu.toyama.jp",
"inami.toyama.jp",
"johana.toyama.jp",
"kamiichi.toyama.jp",
"kurobe.toyama.jp",
"nakaniikawa.toyama.jp",
"namerikawa.toyama.jp",
"nanto.toyama.jp",
"nyuzen.toyama.jp",
"oyabe.toyama.jp",
"taira.toyama.jp",
"takaoka.toyama.jp",
"tateyama.toyama.jp",
"toga.toyama.jp",
"tonami.toyama.jp",
"toyama.toyama.jp",
"unazuki.toyama.jp",
"uozu.toyama.jp",
"yamada.toyama.jp",
"arida.wakayama.jp",
"aridagawa.wakayama.jp",
"gobo.wakayama.jp",
"hashimoto.wakayama.jp",
"hidaka.wakayama.jp",
"hirogawa.wakayama.jp",
"inami.wakayama.jp",
"iwade.wakayama.jp",
"kainan.wakayama.jp",
"kamitonda.wakayama.jp",
"katsuragi.wakayama.jp",
"kimino.wakayama.jp",
"kinokawa.wakayama.jp",
"kitayama.wakayama.jp",
"koya.wakayama.jp",
"koza.wakayama.jp",
"kozagawa.wakayama.jp",
"kudoyama.wakayama.jp",
"kushimoto.wakayama.jp",
"mihama.wakayama.jp",
"misato.wakayama.jp",
"nachikatsuura.wakayama.jp",
"shingu.wakayama.jp",
"shirahama.wakayama.jp",
"taiji.wakayama.jp",
"tanabe.wakayama.jp",
"wakayama.wakayama.jp",
"yuasa.wakayama.jp",
"yura.wakayama.jp",
"asahi.yamagata.jp",
"funagata.yamagata.jp",
"higashine.yamagata.jp",
"iide.yamagata.jp",
"kahoku.yamagata.jp",
"kaminoyama.yamagata.jp",
"kaneyama.yamagata.jp",
"kawanishi.yamagata.jp",
"mamurogawa.yamagata.jp",
"mikawa.yamagata.jp",
"murayama.yamagata.jp",
"nagai.yamagata.jp",
"nakayama.yamagata.jp",
"nanyo.yamagata.jp",
"nishikawa.yamagata.jp",
"obanazawa.yamagata.jp",
"oe.yamagata.jp",
"oguni.yamagata.jp",
"ohkura.yamagata.jp",
"oishida.yamagata.jp",
"sagae.yamagata.jp",
"sakata.yamagata.jp",
"sakegawa.yamagata.jp",
"shinjo.yamagata.jp",
"shirataka.yamagata.jp",
"shonai.yamagata.jp",
"takahata.yamagata.jp",
"tendo.yamagata.jp",
"tozawa.yamagata.jp",
"tsuruoka.yamagata.jp",
"yamagata.yamagata.jp",
"yamanobe.yamagata.jp",
"yonezawa.yamagata.jp",
"yuza.yamagata.jp",
"abu.yamaguchi.jp",
"hagi.yamaguchi.jp",
"hikari.yamaguchi.jp",
"hofu.yamaguchi.jp",
"iwakuni.yamaguchi.jp",
"kudamatsu.yamaguchi.jp",
"mitou.yamaguchi.jp",
"nagato.yamaguchi.jp",
"oshima.yamaguchi.jp",
"shimonoseki.yamaguchi.jp",
"shunan.yamaguchi.jp",
"tabuse.yamaguchi.jp",
"tokuyama.yamaguchi.jp",
"toyota.yamaguchi.jp",
"ube.yamaguchi.jp",
"yuu.yamaguchi.jp",
"chuo.yamanashi.jp",
"doshi.yamanashi.jp",
"fuefuki.yamanashi.jp",
"fujikawa.yamanashi.jp",
"fujikawaguchiko.yamanashi.jp",
"fujiyoshida.yamanashi.jp",
"hayakawa.yamanashi.jp",
"hokuto.yamanashi.jp",
"ichikawamisato.yamanashi.jp",
"kai.yamanashi.jp",
"kofu.yamanashi.jp",
"koshu.yamanashi.jp",
"kosuge.yamanashi.jp",
"minami-alps.yamanashi.jp",
"minobu.yamanashi.jp",
"nakamichi.yamanashi.jp",
"nanbu.yamanashi.jp",
"narusawa.yamanashi.jp",
"nirasaki.yamanashi.jp",
"nishikatsura.yamanashi.jp",
"oshino.yamanashi.jp",
"otsuki.yamanashi.jp",
"showa.yamanashi.jp",
"tabayama.yamanashi.jp",
"tsuru.yamanashi.jp",
"uenohara.yamanashi.jp",
"yamanakako.yamanashi.jp",
"yamanashi.yamanashi.jp",
"ke",
"ac.ke",
"co.ke",
"go.ke",
"info.ke",
"me.ke",
"mobi.ke",
"ne.ke",
"or.ke",
"sc.ke",
"kg",
"org.kg",
"net.kg",
"com.kg",
"edu.kg",
"gov.kg",
"mil.kg",
"*.kh",
"ki",
"edu.ki",
"biz.ki",
"net.ki",
"org.ki",
"gov.ki",
"info.ki",
"com.ki",
"km",
"org.km",
"nom.km",
"gov.km",
"prd.km",
"tm.km",
"edu.km",
"mil.km",
"ass.km",
"com.km",
"coop.km",
"asso.km",
"presse.km",
"medecin.km",
"notaires.km",
"pharmaciens.km",
"veterinaire.km",
"gouv.km",
"kn",
"net.kn",
"org.kn",
"edu.kn",
"gov.kn",
"kp",
"com.kp",
"edu.kp",
"gov.kp",
"org.kp",
"rep.kp",
"tra.kp",
"kr",
"ac.kr",
"co.kr",
"es.kr",
"go.kr",
"hs.kr",
"kg.kr",
"mil.kr",
"ms.kr",
"ne.kr",
"or.kr",
"pe.kr",
"re.kr",
"sc.kr",
"busan.kr",
"chungbuk.kr",
"chungnam.kr",
"daegu.kr",
"daejeon.kr",
"gangwon.kr",
"gwangju.kr",
"gyeongbuk.kr",
"gyeonggi.kr",
"gyeongnam.kr",
"incheon.kr",
"jeju.kr",
"jeonbuk.kr",
"jeonnam.kr",
"seoul.kr",
"ulsan.kr",
"kw",
"com.kw",
"edu.kw",
"emb.kw",
"gov.kw",
"ind.kw",
"net.kw",
"org.kw",
"ky",
"com.ky",
"edu.ky",
"net.ky",
"org.ky",
"kz",
"org.kz",
"edu.kz",
"net.kz",
"gov.kz",
"mil.kz",
"com.kz",
"la",
"int.la",
"net.la",
"info.la",
"edu.la",
"gov.la",
"per.la",
"com.la",
"org.la",
"lb",
"com.lb",
"edu.lb",
"gov.lb",
"net.lb",
"org.lb",
"lc",
"com.lc",
"net.lc",
"co.lc",
"org.lc",
"edu.lc",
"gov.lc",
"li",
"lk",
"gov.lk",
"sch.lk",
"net.lk",
"int.lk",
"com.lk",
"org.lk",
"edu.lk",
"ngo.lk",
"soc.lk",
"web.lk",
"ltd.lk",
"assn.lk",
"grp.lk",
"hotel.lk",
"ac.lk",
"lr",
"com.lr",
"edu.lr",
"gov.lr",
"org.lr",
"net.lr",
"ls",
"ac.ls",
"biz.ls",
"co.ls",
"edu.ls",
"gov.ls",
"info.ls",
"net.ls",
"org.ls",
"sc.ls",
"lt",
"gov.lt",
"lu",
"lv",
"com.lv",
"edu.lv",
"gov.lv",
"org.lv",
"mil.lv",
"id.lv",
"net.lv",
"asn.lv",
"conf.lv",
"ly",
"com.ly",
"net.ly",
"gov.ly",
"plc.ly",
"edu.ly",
"sch.ly",
"med.ly",
"org.ly",
"id.ly",
"ma",
"co.ma",
"net.ma",
"gov.ma",
"org.ma",
"ac.ma",
"press.ma",
"mc",
"tm.mc",
"asso.mc",
"md",
"me",
"co.me",
"net.me",
"org.me",
"edu.me",
"ac.me",
"gov.me",
"its.me",
"priv.me",
"mg",
"org.mg",
"nom.mg",
"gov.mg",
"prd.mg",
"tm.mg",
"edu.mg",
"mil.mg",
"com.mg",
"co.mg",
"mh",
"mil",
"mk",
"com.mk",
"org.mk",
"net.mk",
"edu.mk",
"gov.mk",
"inf.mk",
"name.mk",
"ml",
"com.ml",
"edu.ml",
"gouv.ml",
"gov.ml",
"net.ml",
"org.ml",
"presse.ml",
"*.mm",
"mn",
"gov.mn",
"edu.mn",
"org.mn",
"mo",
"com.mo",
"net.mo",
"org.mo",
"edu.mo",
"gov.mo",
"mobi",
"mp",
"mq",
"mr",
"gov.mr",
"ms",
"com.ms",
"edu.ms",
"gov.ms",
"net.ms",
"org.ms",
"mt",
"com.mt",
"edu.mt",
"net.mt",
"org.mt",
"mu",
"com.mu",
"net.mu",
"org.mu",
"gov.mu",
"ac.mu",
"co.mu",
"or.mu",
"museum",
"academy.museum",
"agriculture.museum",
"air.museum",
"airguard.museum",
"alabama.museum",
"alaska.museum",
"amber.museum",
"ambulance.museum",
"american.museum",
"americana.museum",
"americanantiques.museum",
"americanart.museum",
"amsterdam.museum",
"and.museum",
"annefrank.museum",
"anthro.museum",
"anthropology.museum",
"antiques.museum",
"aquarium.museum",
"arboretum.museum",
"archaeological.museum",
"archaeology.museum",
"architecture.museum",
"art.museum",
"artanddesign.museum",
"artcenter.museum",
"artdeco.museum",
"arteducation.museum",
"artgallery.museum",
"arts.museum",
"artsandcrafts.museum",
"asmatart.museum",
"assassination.museum",
"assisi.museum",
"association.museum",
"astronomy.museum",
"atlanta.museum",
"austin.museum",
"australia.museum",
"automotive.museum",
"aviation.museum",
"axis.museum",
"badajoz.museum",
"baghdad.museum",
"bahn.museum",
"bale.museum",
"baltimore.museum",
"barcelona.museum",
"baseball.museum",
"basel.museum",
"baths.museum",
"bauern.museum",
"beauxarts.museum",
"beeldengeluid.museum",
"bellevue.museum",
"bergbau.museum",
"berkeley.museum",
"berlin.museum",
"bern.museum",
"bible.museum",
"bilbao.museum",
"bill.museum",
"birdart.museum",
"birthplace.museum",
"bonn.museum",
"boston.museum",
"botanical.museum",
"botanicalgarden.museum",
"botanicgarden.museum",
"botany.museum",
"brandywinevalley.museum",
"brasil.museum",
"bristol.museum",
"british.museum",
"britishcolumbia.museum",
"broadcast.museum",
"brunel.museum",
"brussel.museum",
"brussels.museum",
"bruxelles.museum",
"building.museum",
"burghof.museum",
"bus.museum",
"bushey.museum",
"cadaques.museum",
"california.museum",
"cambridge.museum",
"can.museum",
"canada.museum",
"capebreton.museum",
"carrier.museum",
"cartoonart.museum",
"casadelamoneda.museum",
"castle.museum",
"castres.museum",
"celtic.museum",
"center.museum",
"chattanooga.museum",
"cheltenham.museum",
"chesapeakebay.museum",
"chicago.museum",
"children.museum",
"childrens.museum",
"childrensgarden.museum",
"chiropractic.museum",
"chocolate.museum",
"christiansburg.museum",
"cincinnati.museum",
"cinema.museum",
"circus.museum",
"civilisation.museum",
"civilization.museum",
"civilwar.museum",
"clinton.museum",
"clock.museum",
"coal.museum",
"coastaldefence.museum",
"cody.museum",
"coldwar.museum",
"collection.museum",
"colonialwilliamsburg.museum",
"coloradoplateau.museum",
"columbia.museum",
"columbus.museum",
"communication.museum",
"communications.museum",
"community.museum",
"computer.museum",
"computerhistory.museum",
"comunicações.museum",
"contemporary.museum",
"contemporaryart.museum",
"convent.museum",
"copenhagen.museum",
"corporation.museum",
"correios-e-telecomunicações.museum",
"corvette.museum",
"costume.museum",
"countryestate.museum",
"county.museum",
"crafts.museum",
"cranbrook.museum",
"creation.museum",
"cultural.museum",
"culturalcenter.museum",
"culture.museum",
"cyber.museum",
"cymru.museum",
"dali.museum",
"dallas.museum",
"database.museum",
"ddr.museum",
"decorativearts.museum",
"delaware.museum",
"delmenhorst.museum",
"denmark.museum",
"depot.museum",
"design.museum",
"detroit.museum",
"dinosaur.museum",
"discovery.museum",
"dolls.museum",
"donostia.museum",
"durham.museum",
"eastafrica.museum",
"eastcoast.museum",
"education.museum",
"educational.museum",
"egyptian.museum",
"eisenbahn.museum",
"elburg.museum",
"elvendrell.museum",
"embroidery.museum",
"encyclopedic.museum",
"england.museum",
"entomology.museum",
"environment.museum",
"environmentalconservation.museum",
"epilepsy.museum",
"essex.museum",
"estate.museum",
"ethnology.museum",
"exeter.museum",
"exhibition.museum",
"family.museum",
"farm.museum",
"farmequipment.museum",
"farmers.museum",
"farmstead.museum",
"field.museum",
"figueres.museum",
"filatelia.museum",
"film.museum",
"fineart.museum",
"finearts.museum",
"finland.museum",
"flanders.museum",
"florida.museum",
"force.museum",
"fortmissoula.museum",
"fortworth.museum",
"foundation.museum",
"francaise.museum",
"frankfurt.museum",
"franziskaner.museum",
"freemasonry.museum",
"freiburg.museum",
"fribourg.museum",
"frog.museum",
"fundacio.museum",
"furniture.museum",
"gallery.museum",
"garden.museum",
"gateway.museum",
"geelvinck.museum",
"gemological.museum",
"geology.museum",
"georgia.museum",
"giessen.museum",
"glas.museum",
"glass.museum",
"gorge.museum",
"grandrapids.museum",
"graz.museum",
"guernsey.museum",
"halloffame.museum",
"hamburg.museum",
"handson.museum",
"harvestcelebration.museum",
"hawaii.museum",
"health.museum",
"heimatunduhren.museum",
"hellas.museum",
"helsinki.museum",
"hembygdsforbund.museum",
"heritage.museum",
"histoire.museum",
"historical.museum",
"historicalsociety.museum",
"historichouses.museum",
"historisch.museum",
"historisches.museum",
"history.museum",
"historyofscience.museum",
"horology.museum",
"house.museum",
"humanities.museum",
"illustration.museum",
"imageandsound.museum",
"indian.museum",
"indiana.museum",
"indianapolis.museum",
"indianmarket.museum",
"intelligence.museum",
"interactive.museum",
"iraq.museum",
"iron.museum",
"isleofman.museum",
"jamison.museum",
"jefferson.museum",
"jerusalem.museum",
"jewelry.museum",
"jewish.museum",
"jewishart.museum",
"jfk.museum",
"journalism.museum",
"judaica.museum",
"judygarland.museum",
"juedisches.museum",
"juif.museum",
"karate.museum",
"karikatur.museum",
"kids.museum",
"koebenhavn.museum",
"koeln.museum",
"kunst.museum",
"kunstsammlung.museum",
"kunstunddesign.museum",
"labor.museum",
"labour.museum",
"lajolla.museum",
"lancashire.museum",
"landes.museum",
"lans.museum",
"läns.museum",
"larsson.museum",
"lewismiller.museum",
"lincoln.museum",
"linz.museum",
"living.museum",
"livinghistory.museum",
"localhistory.museum",
"london.museum",
"losangeles.museum",
"louvre.museum",
"loyalist.museum",
"lucerne.museum",
"luxembourg.museum",
"luzern.museum",
"mad.museum",
"madrid.museum",
"mallorca.museum",
"manchester.museum",
"mansion.museum",
"mansions.museum",
"manx.museum",
"marburg.museum",
"maritime.museum",
"maritimo.museum",
"maryland.museum",
"marylhurst.museum",
"media.museum",
"medical.museum",
"medizinhistorisches.museum",
"meeres.museum",
"memorial.museum",
"mesaverde.museum",
"michigan.museum",
"midatlantic.museum",
"military.museum",
"mill.museum",
"miners.museum",
"mining.museum",
"minnesota.museum",
"missile.museum",
"missoula.museum",
"modern.museum",
"moma.museum",
"money.museum",
"monmouth.museum",
"monticello.museum",
"montreal.museum",
"moscow.museum",
"motorcycle.museum",
"muenchen.museum",
"muenster.museum",
"mulhouse.museum",
"muncie.museum",
"museet.museum",
"museumcenter.museum",
"museumvereniging.museum",
"music.museum",
"national.museum",
"nationalfirearms.museum",
"nationalheritage.museum",
"nativeamerican.museum",
"naturalhistory.museum",
"naturalhistorymuseum.museum",
"naturalsciences.museum",
"nature.museum",
"naturhistorisches.museum",
"natuurwetenschappen.museum",
"naumburg.museum",
"naval.museum",
"nebraska.museum",
"neues.museum",
"newhampshire.museum",
"newjersey.museum",
"newmexico.museum",
"newport.museum",
"newspaper.museum",
"newyork.museum",
"niepce.museum",
"norfolk.museum",
"north.museum",
"nrw.museum",
"nyc.museum",
"nyny.museum",
"oceanographic.museum",
"oceanographique.museum",
"omaha.museum",
"online.museum",
"ontario.museum",
"openair.museum",
"oregon.museum",
"oregontrail.museum",
"otago.museum",
"oxford.museum",
"pacific.museum",
"paderborn.museum",
"palace.museum",
"paleo.museum",
"palmsprings.museum",
"panama.museum",
"paris.museum",
"pasadena.museum",
"pharmacy.museum",
"philadelphia.museum",
"philadelphiaarea.museum",
"philately.museum",
"phoenix.museum",
"photography.museum",
"pilots.museum",
"pittsburgh.museum",
"planetarium.museum",
"plantation.museum",
"plants.museum",
"plaza.museum",
"portal.museum",
"portland.museum",
"portlligat.museum",
"posts-and-telecommunications.museum",
"preservation.museum",
"presidio.museum",
"press.museum",
"project.museum",
"public.museum",
"pubol.museum",
"quebec.museum",
"railroad.museum",
"railway.museum",
"research.museum",
"resistance.museum",
"riodejaneiro.museum",
"rochester.museum",
"rockart.museum",
"roma.museum",
"russia.museum",
"saintlouis.museum",
"salem.museum",
"salvadordali.museum",
"salzburg.museum",
"sandiego.museum",
"sanfrancisco.museum",
"santabarbara.museum",
"santacruz.museum",
"santafe.museum",
"saskatchewan.museum",
"satx.museum",
"savannahga.museum",
"schlesisches.museum",
"schoenbrunn.museum",
"schokoladen.museum",
"school.museum",
"schweiz.museum",
"science.museum",
"scienceandhistory.museum",
"scienceandindustry.museum",
"sciencecenter.museum",
"sciencecenters.museum",
"science-fiction.museum",
"sciencehistory.museum",
"sciences.museum",
"sciencesnaturelles.museum",
"scotland.museum",
"seaport.museum",
"settlement.museum",
"settlers.museum",
"shell.museum",
"sherbrooke.museum",
"sibenik.museum",
"silk.museum",
"ski.museum",
"skole.museum",
"society.museum",
"sologne.museum",
"soundandvision.museum",
"southcarolina.museum",
"southwest.museum",
"space.museum",
"spy.museum",
"square.museum",
"stadt.museum",
"stalbans.museum",
"starnberg.museum",
"state.museum",
"stateofdelaware.museum",
"station.museum",
"steam.museum",
"steiermark.museum",
"stjohn.museum",
"stockholm.museum",
"stpetersburg.museum",
"stuttgart.museum",
"suisse.museum",
"surgeonshall.museum",
"surrey.museum",
"svizzera.museum",
"sweden.museum",
"sydney.museum",
"tank.museum",
"tcm.museum",
"technology.museum",
"telekommunikation.museum",
"television.museum",
"texas.museum",
"textile.museum",
"theater.museum",
"time.museum",
"timekeeping.museum",
"topology.museum",
"torino.museum",
"touch.museum",
"town.museum",
"transport.museum",
"tree.museum",
"trolley.museum",
"trust.museum",
"trustee.museum",
"uhren.museum",
"ulm.museum",
"undersea.museum",
"university.museum",
"usa.museum",
"usantiques.museum",
"usarts.museum",
"uscountryestate.museum",
"usculture.museum",
"usdecorativearts.museum",
"usgarden.museum",
"ushistory.museum",
"ushuaia.museum",
"uslivinghistory.museum",
"utah.museum",
"uvic.museum",
"valley.museum",
"vantaa.museum",
"versailles.museum",
"viking.museum",
"village.museum",
"virginia.museum",
"virtual.museum",
"virtuel.museum",
"vlaanderen.museum",
"volkenkunde.museum",
"wales.museum",
"wallonie.museum",
"war.museum",
"washingtondc.museum",
"watchandclock.museum",
"watch-and-clock.museum",
"western.museum",
"westfalen.museum",
"whaling.museum",
"wildlife.museum",
"williamsburg.museum",
"windmill.museum",
"workshop.museum",
"york.museum",
"yorkshire.museum",
"yosemite.museum",
"youth.museum",
"zoological.museum",
"zoology.museum",
"ירושלים.museum",
"иком.museum",
"mv",
"aero.mv",
"biz.mv",
"com.mv",
"coop.mv",
"edu.mv",
"gov.mv",
"info.mv",
"int.mv",
"mil.mv",
"museum.mv",
"name.mv",
"net.mv",
"org.mv",
"pro.mv",
"mw",
"ac.mw",
"biz.mw",
"co.mw",
"com.mw",
"coop.mw",
"edu.mw",
"gov.mw",
"int.mw",
"museum.mw",
"net.mw",
"org.mw",
"mx",
"com.mx",
"org.mx",
"gob.mx",
"edu.mx",
"net.mx",
"my",
"biz.my",
"com.my",
"edu.my",
"gov.my",
"mil.my",
"name.my",
"net.my",
"org.my",
"mz",
"ac.mz",
"adv.mz",
"co.mz",
"edu.mz",
"gov.mz",
"mil.mz",
"net.mz",
"org.mz",
"na",
"info.na",
"pro.na",
"name.na",
"school.na",
"or.na",
"dr.na",
"us.na",
"mx.na",
"ca.na",
"in.na",
"cc.na",
"tv.na",
"ws.na",
"mobi.na",
"co.na",
"com.na",
"org.na",
"name",
"nc",
"asso.nc",
"nom.nc",
"ne",
"net",
"nf",
"com.nf",
"net.nf",
"per.nf",
"rec.nf",
"web.nf",
"arts.nf",
"firm.nf",
"info.nf",
"other.nf",
"store.nf",
"ng",
"com.ng",
"edu.ng",
"gov.ng",
"i.ng",
"mil.ng",
"mobi.ng",
"name.ng",
"net.ng",
"org.ng",
"sch.ng",
"ni",
"ac.ni",
"biz.ni",
"co.ni",
"com.ni",
"edu.ni",
"gob.ni",
"in.ni",
"info.ni",
"int.ni",
"mil.ni",
"net.ni",
"nom.ni",
"org.ni",
"web.ni",
"nl",
"no",
"fhs.no",
"vgs.no",
"fylkesbibl.no",
"folkebibl.no",
"museum.no",
"idrett.no",
"priv.no",
"mil.no",
"stat.no",
"dep.no",
"kommune.no",
"herad.no",
"aa.no",
"ah.no",
"bu.no",
"fm.no",
"hl.no",
"hm.no",
"jan-mayen.no",
"mr.no",
"nl.no",
"nt.no",
"of.no",
"ol.no",
"oslo.no",
"rl.no",
"sf.no",
"st.no",
"svalbard.no",
"tm.no",
"tr.no",
"va.no",
"vf.no",
"gs.aa.no",
"gs.ah.no",
"gs.bu.no",
"gs.fm.no",
"gs.hl.no",
"gs.hm.no",
"gs.jan-mayen.no",
"gs.mr.no",
"gs.nl.no",
"gs.nt.no",
"gs.of.no",
"gs.ol.no",
"gs.oslo.no",
"gs.rl.no",
"gs.sf.no",
"gs.st.no",
"gs.svalbard.no",
"gs.tm.no",
"gs.tr.no",
"gs.va.no",
"gs.vf.no",
"akrehamn.no",
"åkrehamn.no",
"algard.no",
"ålgård.no",
"arna.no",
"brumunddal.no",
"bryne.no",
"bronnoysund.no",
"brønnøysund.no",
"drobak.no",
"drøbak.no",
"egersund.no",
"fetsund.no",
"floro.no",
"florø.no",
"fredrikstad.no",
"hokksund.no",
"honefoss.no",
"hønefoss.no",
"jessheim.no",
"jorpeland.no",
"jørpeland.no",
"kirkenes.no",
"kopervik.no",
"krokstadelva.no",
"langevag.no",
"langevåg.no",
"leirvik.no",
"mjondalen.no",
"mjøndalen.no",
"mo-i-rana.no",
"mosjoen.no",
"mosjøen.no",
"nesoddtangen.no",
"orkanger.no",
"osoyro.no",
"osøyro.no",
"raholt.no",
"råholt.no",
"sandnessjoen.no",
"sandnessjøen.no",
"skedsmokorset.no",
"slattum.no",
"spjelkavik.no",
"stathelle.no",
"stavern.no",
"stjordalshalsen.no",
"stjørdalshalsen.no",
"tananger.no",
"tranby.no",
"vossevangen.no",
"afjord.no",
"åfjord.no",
"agdenes.no",
"al.no",
"ål.no",
"alesund.no",
"ålesund.no",
"alstahaug.no",
"alta.no",
"áltá.no",
"alaheadju.no",
"álaheadju.no",
"alvdal.no",
"amli.no",
"åmli.no",
"amot.no",
"åmot.no",
"andebu.no",
"andoy.no",
"andøy.no",
"andasuolo.no",
"ardal.no",
"årdal.no",
"aremark.no",
"arendal.no",
"ås.no",
"aseral.no",
"åseral.no",
"asker.no",
"askim.no",
"askvoll.no",
"askoy.no",
"askøy.no",
"asnes.no",
"åsnes.no",
"audnedaln.no",
"aukra.no",
"aure.no",
"aurland.no",
"aurskog-holand.no",
"aurskog-høland.no",
"austevoll.no",
"austrheim.no",
"averoy.no",
"averøy.no",
"balestrand.no",
"ballangen.no",
"balat.no",
"bálát.no",
"balsfjord.no",
"bahccavuotna.no",
"báhccavuotna.no",
"bamble.no",
"bardu.no",
"beardu.no",
"beiarn.no",
"bajddar.no",
"bájddar.no",
"baidar.no",
"báidár.no",
"berg.no",
"bergen.no",
"berlevag.no",
"berlevåg.no",
"bearalvahki.no",
"bearalváhki.no",
"bindal.no",
"birkenes.no",
"bjarkoy.no",
"bjarkøy.no",
"bjerkreim.no",
"bjugn.no",
"bodo.no",
"bodø.no",
"badaddja.no",
"bådåddjå.no",
"budejju.no",
"bokn.no",
"bremanger.no",
"bronnoy.no",
"brønnøy.no",
"bygland.no",
"bykle.no",
"barum.no",
"bærum.no",
"bo.telemark.no",
"bø.telemark.no",
"bo.nordland.no",
"bø.nordland.no",
"bievat.no",
"bievát.no",
"bomlo.no",
"bømlo.no",
"batsfjord.no",
"båtsfjord.no",
"bahcavuotna.no",
"báhcavuotna.no",
"dovre.no",
"drammen.no",
"drangedal.no",
"dyroy.no",
"dyrøy.no",
"donna.no",
"dønna.no",
"eid.no",
"eidfjord.no",
"eidsberg.no",
"eidskog.no",
"eidsvoll.no",
"eigersund.no",
"elverum.no",
"enebakk.no",
"engerdal.no",
"etne.no",
"etnedal.no",
"evenes.no",
"evenassi.no",
"evenášši.no",
"evje-og-hornnes.no",
"farsund.no",
"fauske.no",
"fuossko.no",
"fuoisku.no",
"fedje.no",
"fet.no",
"finnoy.no",
"finnøy.no",
"fitjar.no",
"fjaler.no",
"fjell.no",
"flakstad.no",
"flatanger.no",
"flekkefjord.no",
"flesberg.no",
"flora.no",
"fla.no",
"flå.no",
"folldal.no",
"forsand.no",
"fosnes.no",
"frei.no",
"frogn.no",
"froland.no",
"frosta.no",
"frana.no",
"fræna.no",
"froya.no",
"frøya.no",
"fusa.no",
"fyresdal.no",
"forde.no",
"førde.no",
"gamvik.no",
"gangaviika.no",
"gáŋgaviika.no",
"gaular.no",
"gausdal.no",
"gildeskal.no",
"gildeskål.no",
"giske.no",
"gjemnes.no",
"gjerdrum.no",
"gjerstad.no",
"gjesdal.no",
"gjovik.no",
"gjøvik.no",
"gloppen.no",
"gol.no",
"gran.no",
"grane.no",
"granvin.no",
"gratangen.no",
"grimstad.no",
"grong.no",
"kraanghke.no",
"kråanghke.no",
"grue.no",
"gulen.no",
"hadsel.no",
"halden.no",
"halsa.no",
"hamar.no",
"hamaroy.no",
"habmer.no",
"hábmer.no",
"hapmir.no",
"hápmir.no",
"hammerfest.no",
"hammarfeasta.no",
"hámmárfeasta.no",
"haram.no",
"hareid.no",
"harstad.no",
"hasvik.no",
"aknoluokta.no",
"ákŋoluokta.no",
"hattfjelldal.no",
"aarborte.no",
"haugesund.no",
"hemne.no",
"hemnes.no",
"hemsedal.no",
"heroy.more-og-romsdal.no",
"herøy.møre-og-romsdal.no",
"heroy.nordland.no",
"herøy.nordland.no",
"hitra.no",
"hjartdal.no",
"hjelmeland.no",
"hobol.no",
"hobøl.no",
"hof.no",
"hol.no",
"hole.no",
"holmestrand.no",
"holtalen.no",
"holtålen.no",
"hornindal.no",
"horten.no",
"hurdal.no",
"hurum.no",
"hvaler.no",
"hyllestad.no",
"hagebostad.no",
"hægebostad.no",
"hoyanger.no",
"høyanger.no",
"hoylandet.no",
"høylandet.no",
"ha.no",
"hå.no",
"ibestad.no",
"inderoy.no",
"inderøy.no",
"iveland.no",
"jevnaker.no",
"jondal.no",
"jolster.no",
"jølster.no",
"karasjok.no",
"karasjohka.no",
"kárášjohka.no",
"karlsoy.no",
"galsa.no",
"gálsá.no",
"karmoy.no",
"karmøy.no",
"kautokeino.no",
"guovdageaidnu.no",
"klepp.no",
"klabu.no",
"klæbu.no",
"kongsberg.no",
"kongsvinger.no",
"kragero.no",
"kragerø.no",
"kristiansand.no",
"kristiansund.no",
"krodsherad.no",
"krødsherad.no",
"kvalsund.no",
"rahkkeravju.no",
"ráhkkerávju.no",
"kvam.no",
"kvinesdal.no",
"kvinnherad.no",
"kviteseid.no",
"kvitsoy.no",
"kvitsøy.no",
"kvafjord.no",
"kvæfjord.no",
"giehtavuoatna.no",
"kvanangen.no",
"kvænangen.no",
"navuotna.no",
"návuotna.no",
"kafjord.no",
"kåfjord.no",
"gaivuotna.no",
"gáivuotna.no",
"larvik.no",
"lavangen.no",
"lavagis.no",
"loabat.no",
"loabát.no",
"lebesby.no",
"davvesiida.no",
"leikanger.no",
"leirfjord.no",
"leka.no",
"leksvik.no",
"lenvik.no",
"leangaviika.no",
"leaŋgaviika.no",
"lesja.no",
"levanger.no",
"lier.no",
"lierne.no",
"lillehammer.no",
"lillesand.no",
"lindesnes.no",
"lindas.no",
"lindås.no",
"lom.no",
"loppa.no",
"lahppi.no",
"láhppi.no",
"lund.no",
"lunner.no",
"luroy.no",
"lurøy.no",
"luster.no",
"lyngdal.no",
"lyngen.no",
"ivgu.no",
"lardal.no",
"lerdal.no",
"lærdal.no",
"lodingen.no",
"lødingen.no",
"lorenskog.no",
"lørenskog.no",
"loten.no",
"løten.no",
"malvik.no",
"masoy.no",
"måsøy.no",
"muosat.no",
"muosát.no",
"mandal.no",
"marker.no",
"marnardal.no",
"masfjorden.no",
"meland.no",
"meldal.no",
"melhus.no",
"meloy.no",
"meløy.no",
"meraker.no",
"meråker.no",
"moareke.no",
"moåreke.no",
"midsund.no",
"midtre-gauldal.no",
"modalen.no",
"modum.no",
"molde.no",
"moskenes.no",
"moss.no",
"mosvik.no",
"malselv.no",
"målselv.no",
"malatvuopmi.no",
"málatvuopmi.no",
"namdalseid.no",
"aejrie.no",
"namsos.no",
"namsskogan.no",
"naamesjevuemie.no",
"nååmesjevuemie.no",
"laakesvuemie.no",
"nannestad.no",
"narvik.no",
"narviika.no",
"naustdal.no",
"nedre-eiker.no",
"nes.akershus.no",
"nes.buskerud.no",
"nesna.no",
"nesodden.no",
"nesseby.no",
"unjarga.no",
"unjárga.no",
"nesset.no",
"nissedal.no",
"nittedal.no",
"nord-aurdal.no",
"nord-fron.no",
"nord-odal.no",
"norddal.no",
"nordkapp.no",
"davvenjarga.no",
"davvenjárga.no",
"nordre-land.no",
"nordreisa.no",
"raisa.no",
"ráisa.no",
"nore-og-uvdal.no",
"notodden.no",
"naroy.no",
"nærøy.no",
"notteroy.no",
"nøtterøy.no",
"odda.no",
"oksnes.no",
"øksnes.no",
"oppdal.no",
"oppegard.no",
"oppegård.no",
"orkdal.no",
"orland.no",
"ørland.no",
"orskog.no",
"ørskog.no",
"orsta.no",
"ørsta.no",
"os.hedmark.no",
"os.hordaland.no",
"osen.no",
"osteroy.no",
"osterøy.no",
"ostre-toten.no",
"østre-toten.no",
"overhalla.no",
"ovre-eiker.no",
"øvre-eiker.no",
"oyer.no",
"øyer.no",
"oygarden.no",
"øygarden.no",
"oystre-slidre.no",
"øystre-slidre.no",
"porsanger.no",
"porsangu.no",
"porsáŋgu.no",
"porsgrunn.no",
"radoy.no",
"radøy.no",
"rakkestad.no",
"rana.no",
"ruovat.no",
"randaberg.no",
"rauma.no",
"rendalen.no",
"rennebu.no",
"rennesoy.no",
"rennesøy.no",
"rindal.no",
"ringebu.no",
"ringerike.no",
"ringsaker.no",
"rissa.no",
"risor.no",
"risør.no",
"roan.no",
"rollag.no",
"rygge.no",
"ralingen.no",
"rælingen.no",
"rodoy.no",
"rødøy.no",
"romskog.no",
"rømskog.no",
"roros.no",
"røros.no",
"rost.no",
"røst.no",
"royken.no",
"røyken.no",
"royrvik.no",
"røyrvik.no",
"rade.no",
"råde.no",
"salangen.no",
"siellak.no",
"saltdal.no",
"salat.no",
"sálát.no",
"sálat.no",
"samnanger.no",
"sande.more-og-romsdal.no",
"sande.møre-og-romsdal.no",
"sande.vestfold.no",
"sandefjord.no",
"sandnes.no",
"sandoy.no",
"sandøy.no",
"sarpsborg.no",
"sauda.no",
"sauherad.no",
"sel.no",
"selbu.no",
"selje.no",
"seljord.no",
"sigdal.no",
"siljan.no",
"sirdal.no",
"skaun.no",
"skedsmo.no",
"ski.no",
"skien.no",
"skiptvet.no",
"skjervoy.no",
"skjervøy.no",
"skierva.no",
"skiervá.no",
"skjak.no",
"skjåk.no",
"skodje.no",
"skanland.no",
"skånland.no",
"skanit.no",
"skánit.no",
"smola.no",
"smøla.no",
"snillfjord.no",
"snasa.no",
"snåsa.no",
"snoasa.no",
"snaase.no",
"snåase.no",
"sogndal.no",
"sokndal.no",
"sola.no",
"solund.no",
"songdalen.no",
"sortland.no",
"spydeberg.no",
"stange.no",
"stavanger.no",
"steigen.no",
"steinkjer.no",
"stjordal.no",
"stjørdal.no",
"stokke.no",
"stor-elvdal.no",
"stord.no",
"stordal.no",
"storfjord.no",
"omasvuotna.no",
"strand.no",
"stranda.no",
"stryn.no",
"sula.no",
"suldal.no",
"sund.no",
"sunndal.no",
"surnadal.no",
"sveio.no",
"svelvik.no",
"sykkylven.no",
"sogne.no",
"søgne.no",
"somna.no",
"sømna.no",
"sondre-land.no",
"søndre-land.no",
"sor-aurdal.no",
"sør-aurdal.no",
"sor-fron.no",
"sør-fron.no",
"sor-odal.no",
"sør-odal.no",
"sor-varanger.no",
"sør-varanger.no",
"matta-varjjat.no",
"mátta-várjjat.no",
"sorfold.no",
"sørfold.no",
"sorreisa.no",
"sørreisa.no",
"sorum.no",
"sørum.no",
"tana.no",
"deatnu.no",
"time.no",
"tingvoll.no",
"tinn.no",
"tjeldsund.no",
"dielddanuorri.no",
"tjome.no",
"tjøme.no",
"tokke.no",
"tolga.no",
"torsken.no",
"tranoy.no",
"tranøy.no",
"tromso.no",
"tromsø.no",
"tromsa.no",
"romsa.no",
"trondheim.no",
"troandin.no",
"trysil.no",
"trana.no",
"træna.no",
"trogstad.no",
"trøgstad.no",
"tvedestrand.no",
"tydal.no",
"tynset.no",
"tysfjord.no",
"divtasvuodna.no",
"divttasvuotna.no",
"tysnes.no",
"tysvar.no",
"tysvær.no",
"tonsberg.no",
"tønsberg.no",
"ullensaker.no",
"ullensvang.no",
"ulvik.no",
"utsira.no",
"vadso.no",
"vadsø.no",
"cahcesuolo.no",
"čáhcesuolo.no",
"vaksdal.no",
"valle.no",
"vang.no",
"vanylven.no",
"vardo.no",
"vardø.no",
"varggat.no",
"várggát.no",
"vefsn.no",
"vaapste.no",
"vega.no",
"vegarshei.no",
"vegårshei.no",
"vennesla.no",
"verdal.no",
"verran.no",
"vestby.no",
"vestnes.no",
"vestre-slidre.no",
"vestre-toten.no",
"vestvagoy.no",
"vestvågøy.no",
"vevelstad.no",
"vik.no",
"vikna.no",
"vindafjord.no",
"volda.no",
"voss.no",
"varoy.no",
"værøy.no",
"vagan.no",
"vågan.no",
"voagat.no",
"vagsoy.no",
"vågsøy.no",
"vaga.no",
"vågå.no",
"valer.ostfold.no",
"våler.østfold.no",
"valer.hedmark.no",
"våler.hedmark.no",
"*.np",
"nr",
"biz.nr",
"info.nr",
"gov.nr",
"edu.nr",
"org.nr",
"net.nr",
"com.nr",
"nu",
"nz",
"ac.nz",
"co.nz",
"cri.nz",
"geek.nz",
"gen.nz",
"govt.nz",
"health.nz",
"iwi.nz",
"kiwi.nz",
"maori.nz",
"mil.nz",
"māori.nz",
"net.nz",
"org.nz",
"parliament.nz",
"school.nz",
"om",
"co.om",
"com.om",
"edu.om",
"gov.om",
"med.om",
"museum.om",
"net.om",
"org.om",
"pro.om",
"onion",
"org",
"pa",
"ac.pa",
"gob.pa",
"com.pa",
"org.pa",
"sld.pa",
"edu.pa",
"net.pa",
"ing.pa",
"abo.pa",
"med.pa",
"nom.pa",
"pe",
"edu.pe",
"gob.pe",
"nom.pe",
"mil.pe",
"org.pe",
"com.pe",
"net.pe",
"pf",
"com.pf",
"org.pf",
"edu.pf",
"*.pg",
"ph",
"com.ph",
"net.ph",
"org.ph",
"gov.ph",
"edu.ph",
"ngo.ph",
"mil.ph",
"i.ph",
"pk",
"com.pk",
"net.pk",
"edu.pk",
"org.pk",
"fam.pk",
"biz.pk",
"web.pk",
"gov.pk",
"gob.pk",
"gok.pk",
"gon.pk",
"gop.pk",
"gos.pk",
"info.pk",
"pl",
"com.pl",
"net.pl",
"org.pl",
"aid.pl",
"agro.pl",
"atm.pl",
"auto.pl",
"biz.pl",
"edu.pl",
"gmina.pl",
"gsm.pl",
"info.pl",
"mail.pl",
"miasta.pl",
"media.pl",
"mil.pl",
"nieruchomosci.pl",
"nom.pl",
"pc.pl",
"powiat.pl",
"priv.pl",
"realestate.pl",
"rel.pl",
"sex.pl",
"shop.pl",
"sklep.pl",
"sos.pl",
"szkola.pl",
"targi.pl",
"tm.pl",
"tourism.pl",
"travel.pl",
"turystyka.pl",
"gov.pl",
"ap.gov.pl",
"ic.gov.pl",
"is.gov.pl",
"us.gov.pl",
"kmpsp.gov.pl",
"kppsp.gov.pl",
"kwpsp.gov.pl",
"psp.gov.pl",
"wskr.gov.pl",
"kwp.gov.pl",
"mw.gov.pl",
"ug.gov.pl",
"um.gov.pl",
"umig.gov.pl",
"ugim.gov.pl",
"upow.gov.pl",
"uw.gov.pl",
"starostwo.gov.pl",
"pa.gov.pl",
"po.gov.pl",
"psse.gov.pl",
"pup.gov.pl",
"rzgw.gov.pl",
"sa.gov.pl",
"so.gov.pl",
"sr.gov.pl",
"wsa.gov.pl",
"sko.gov.pl",
"uzs.gov.pl",
"wiih.gov.pl",
"winb.gov.pl",
"pinb.gov.pl",
"wios.gov.pl",
"witd.gov.pl",
"wzmiuw.gov.pl",
"piw.gov.pl",
"wiw.gov.pl",
"griw.gov.pl",
"wif.gov.pl",
"oum.gov.pl",
"sdn.gov.pl",
"zp.gov.pl",
"uppo.gov.pl",
"mup.gov.pl",
"wuoz.gov.pl",
"konsulat.gov.pl",
"oirm.gov.pl",
"augustow.pl",
"babia-gora.pl",
"bedzin.pl",
"beskidy.pl",
"bialowieza.pl",
"bialystok.pl",
"bielawa.pl",
"bieszczady.pl",
"boleslawiec.pl",
"bydgoszcz.pl",
"bytom.pl",
"cieszyn.pl",
"czeladz.pl",
"czest.pl",
"dlugoleka.pl",
"elblag.pl",
"elk.pl",
"glogow.pl",
"gniezno.pl",
"gorlice.pl",
"grajewo.pl",
"ilawa.pl",
"jaworzno.pl",
"jelenia-gora.pl",
"jgora.pl",
"kalisz.pl",
"kazimierz-dolny.pl",
"karpacz.pl",
"kartuzy.pl",
"kaszuby.pl",
"katowice.pl",
"kepno.pl",
"ketrzyn.pl",
"klodzko.pl",
"kobierzyce.pl",
"kolobrzeg.pl",
"konin.pl",
"konskowola.pl",
"kutno.pl",
"lapy.pl",
"lebork.pl",
"legnica.pl",
"lezajsk.pl",
"limanowa.pl",
"lomza.pl",
"lowicz.pl",
"lubin.pl",
"lukow.pl",
"malbork.pl",
"malopolska.pl",
"mazowsze.pl",
"mazury.pl",
"mielec.pl",
"mielno.pl",
"mragowo.pl",
"naklo.pl",
"nowaruda.pl",
"nysa.pl",
"olawa.pl",
"olecko.pl",
"olkusz.pl",
"olsztyn.pl",
"opoczno.pl",
"opole.pl",
"ostroda.pl",
"ostroleka.pl",
"ostrowiec.pl",
"ostrowwlkp.pl",
"pila.pl",
"pisz.pl",
"podhale.pl",
"podlasie.pl",
"polkowice.pl",
"pomorze.pl",
"pomorskie.pl",
"prochowice.pl",
"pruszkow.pl",
"przeworsk.pl",
"pulawy.pl",
"radom.pl",
"rawa-maz.pl",
"rybnik.pl",
"rzeszow.pl",
"sanok.pl",
"sejny.pl",
"slask.pl",
"slupsk.pl",
"sosnowiec.pl",
"stalowa-wola.pl",
"skoczow.pl",
"starachowice.pl",
"stargard.pl",
"suwalki.pl",
"swidnica.pl",
"swiebodzin.pl",
"swinoujscie.pl",
"szczecin.pl",
"szczytno.pl",
"tarnobrzeg.pl",
"tgory.pl",
"turek.pl",
"tychy.pl",
"ustka.pl",
"walbrzych.pl",
"warmia.pl",
"warszawa.pl",
"waw.pl",
"wegrow.pl",
"wielun.pl",
"wlocl.pl",
"wloclawek.pl",
"wodzislaw.pl",
"wolomin.pl",
"wroclaw.pl",
"zachpomor.pl",
"zagan.pl",
"zarow.pl",
"zgora.pl",
"zgorzelec.pl",
"pm",
"pn",
"gov.pn",
"co.pn",
"org.pn",
"edu.pn",
"net.pn",
"post",
"pr",
"com.pr",
"net.pr",
"org.pr",
"gov.pr",
"edu.pr",
"isla.pr",
"pro.pr",
"biz.pr",
"info.pr",
"name.pr",
"est.pr",
"prof.pr",
"ac.pr",
"pro",
"aaa.pro",
"aca.pro",
"acct.pro",
"avocat.pro",
"bar.pro",
"cpa.pro",
"eng.pro",
"jur.pro",
"law.pro",
"med.pro",
"recht.pro",
"ps",
"edu.ps",
"gov.ps",
"sec.ps",
"plo.ps",
"com.ps",
"org.ps",
"net.ps",
"pt",
"net.pt",
"gov.pt",
"org.pt",
"edu.pt",
"int.pt",
"publ.pt",
"com.pt",
"nome.pt",
"pw",
"co.pw",
"ne.pw",
"or.pw",
"ed.pw",
"go.pw",
"belau.pw",
"py",
"com.py",
"coop.py",
"edu.py",
"gov.py",
"mil.py",
"net.py",
"org.py",
"qa",
"com.qa",
"edu.qa",
"gov.qa",
"mil.qa",
"name.qa",
"net.qa",
"org.qa",
"sch.qa",
"re",
"asso.re",
"com.re",
"nom.re",
"ro",
"arts.ro",
"com.ro",
"firm.ro",
"info.ro",
"nom.ro",
"nt.ro",
"org.ro",
"rec.ro",
"store.ro",
"tm.ro",
"www.ro",
"rs",
"ac.rs",
"co.rs",
"edu.rs",
"gov.rs",
"in.rs",
"org.rs",
"ru",
"rw",
"ac.rw",
"co.rw",
"coop.rw",
"gov.rw",
"mil.rw",
"net.rw",
"org.rw",
"sa",
"com.sa",
"net.sa",
"org.sa",
"gov.sa",
"med.sa",
"pub.sa",
"edu.sa",
"sch.sa",
"sb",
"com.sb",
"edu.sb",
"gov.sb",
"net.sb",
"org.sb",
"sc",
"com.sc",
"gov.sc",
"net.sc",
"org.sc",
"edu.sc",
"sd",
"com.sd",
"net.sd",
"org.sd",
"edu.sd",
"med.sd",
"tv.sd",
"gov.sd",
"info.sd",
"se",
"a.se",
"ac.se",
"b.se",
"bd.se",
"brand.se",
"c.se",
"d.se",
"e.se",
"f.se",
"fh.se",
"fhsk.se",
"fhv.se",
"g.se",
"h.se",
"i.se",
"k.se",
"komforb.se",
"kommunalforbund.se",
"komvux.se",
"l.se",
"lanbib.se",
"m.se",
"n.se",
"naturbruksgymn.se",
"o.se",
"org.se",
"p.se",
"parti.se",
"pp.se",
"press.se",
"r.se",
"s.se",
"t.se",
"tm.se",
"u.se",
"w.se",
"x.se",
"y.se",
"z.se",
"sg",
"com.sg",
"net.sg",
"org.sg",
"gov.sg",
"edu.sg",
"per.sg",
"sh",
"com.sh",
"net.sh",
"gov.sh",
"org.sh",
"mil.sh",
"si",
"sj",
"sk",
"sl",
"com.sl",
"net.sl",
"edu.sl",
"gov.sl",
"org.sl",
"sm",
"sn",
"art.sn",
"com.sn",
"edu.sn",
"gouv.sn",
"org.sn",
"perso.sn",
"univ.sn",
"so",
"com.so",
"edu.so",
"gov.so",
"me.so",
"net.so",
"org.so",
"sr",
"ss",
"biz.ss",
"com.ss",
"edu.ss",
"gov.ss",
"me.ss",
"net.ss",
"org.ss",
"sch.ss",
"st",
"co.st",
"com.st",
"consulado.st",
"edu.st",
"embaixada.st",
"mil.st",
"net.st",
"org.st",
"principe.st",
"saotome.st",
"store.st",
"su",
"sv",
"com.sv",
"edu.sv",
"gob.sv",
"org.sv",
"red.sv",
"sx",
"gov.sx",
"sy",
"edu.sy",
"gov.sy",
"net.sy",
"mil.sy",
"com.sy",
"org.sy",
"sz",
"co.sz",
"ac.sz",
"org.sz",
"tc",
"td",
"tel",
"tf",
"tg",
"th",
"ac.th",
"co.th",
"go.th",
"in.th",
"mi.th",
"net.th",
"or.th",
"tj",
"ac.tj",
"biz.tj",
"co.tj",
"com.tj",
"edu.tj",
"go.tj",
"gov.tj",
"int.tj",
"mil.tj",
"name.tj",
"net.tj",
"nic.tj",
"org.tj",
"test.tj",
"web.tj",
"tk",
"tl",
"gov.tl",
"tm",
"com.tm",
"co.tm",
"org.tm",
"net.tm",
"nom.tm",
"gov.tm",
"mil.tm",
"edu.tm",
"tn",
"com.tn",
"ens.tn",
"fin.tn",
"gov.tn",
"ind.tn",
"info.tn",
"intl.tn",
"mincom.tn",
"nat.tn",
"net.tn",
"org.tn",
"perso.tn",
"tourism.tn",
"to",
"com.to",
"gov.to",
"net.to",
"org.to",
"edu.to",
"mil.to",
"tr",
"av.tr",
"bbs.tr",
"bel.tr",
"biz.tr",
"com.tr",
"dr.tr",
"edu.tr",
"gen.tr",
"gov.tr",
"info.tr",
"mil.tr",
"k12.tr",
"kep.tr",
"name.tr",
"net.tr",
"org.tr",
"pol.tr",
"tel.tr",
"tsk.tr",
"tv.tr",
"web.tr",
"nc.tr",
"gov.nc.tr",
"tt",
"co.tt",
"com.tt",
"org.tt",
"net.tt",
"biz.tt",
"info.tt",
"pro.tt",
"int.tt",
"coop.tt",
"jobs.tt",
"mobi.tt",
"travel.tt",
"museum.tt",
"aero.tt",
"name.tt",
"gov.tt",
"edu.tt",
"tv",
"tw",
"edu.tw",
"gov.tw",
"mil.tw",
"com.tw",
"net.tw",
"org.tw",
"idv.tw",
"game.tw",
"ebiz.tw",
"club.tw",
"網路.tw",
"組織.tw",
"商業.tw",
"tz",
"ac.tz",
"co.tz",
"go.tz",
"hotel.tz",
"info.tz",
"me.tz",
"mil.tz",
"mobi.tz",
"ne.tz",
"or.tz",
"sc.tz",
"tv.tz",
"ua",
"com.ua",
"edu.ua",
"gov.ua",
"in.ua",
"net.ua",
"org.ua",
"cherkassy.ua",
"cherkasy.ua",
"chernigov.ua",
"chernihiv.ua",
"chernivtsi.ua",
"chernovtsy.ua",
"ck.ua",
"cn.ua",
"cr.ua",
"crimea.ua",
"cv.ua",
"dn.ua",
"dnepropetrovsk.ua",
"dnipropetrovsk.ua",
"donetsk.ua",
"dp.ua",
"if.ua",
"ivano-frankivsk.ua",
"kh.ua",
"kharkiv.ua",
"kharkov.ua",
"kherson.ua",
"khmelnitskiy.ua",
"khmelnytskyi.ua",
"kiev.ua",
"kirovograd.ua",
"km.ua",
"kr.ua",
"krym.ua",
"ks.ua",
"kv.ua",
"kyiv.ua",
"lg.ua",
"lt.ua",
"lugansk.ua",
"lutsk.ua",
"lv.ua",
"lviv.ua",
"mk.ua",
"mykolaiv.ua",
"nikolaev.ua",
"od.ua",
"odesa.ua",
"odessa.ua",
"pl.ua",
"poltava.ua",
"rivne.ua",
"rovno.ua",
"rv.ua",
"sb.ua",
"sebastopol.ua",
"sevastopol.ua",
"sm.ua",
"sumy.ua",
"te.ua",
"ternopil.ua",
"uz.ua",
"uzhgorod.ua",
"vinnica.ua",
"vinnytsia.ua",
"vn.ua",
"volyn.ua",
"yalta.ua",
"zaporizhzhe.ua",
"zaporizhzhia.ua",
"zhitomir.ua",
"zhytomyr.ua",
"zp.ua",
"zt.ua",
"ug",
"co.ug",
"or.ug",
"ac.ug",
"sc.ug",
"go.ug",
"ne.ug",
"com.ug",
"org.ug",
"uk",
"ac.uk",
"co.uk",
"gov.uk",
"ltd.uk",
"me.uk",
"net.uk",
"nhs.uk",
"org.uk",
"plc.uk",
"police.uk",
"*.sch.uk",
"us",
"dni.us",
"fed.us",
"isa.us",
"kids.us",
"nsn.us",
"ak.us",
"al.us",
"ar.us",
"as.us",
"az.us",
"ca.us",
"co.us",
"ct.us",
"dc.us",
"de.us",
"fl.us",
"ga.us",
"gu.us",
"hi.us",
"ia.us",
"id.us",
"il.us",
"in.us",
"ks.us",
"ky.us",
"la.us",
"ma.us",
"md.us",
"me.us",
"mi.us",
"mn.us",
"mo.us",
"ms.us",
"mt.us",
"nc.us",
"nd.us",
"ne.us",
"nh.us",
"nj.us",
"nm.us",
"nv.us",
"ny.us",
"oh.us",
"ok.us",
"or.us",
"pa.us",
"pr.us",
"ri.us",
"sc.us",
"sd.us",
"tn.us",
"tx.us",
"ut.us",
"vi.us",
"vt.us",
"va.us",
"wa.us",
"wi.us",
"wv.us",
"wy.us",
"k12.ak.us",
"k12.al.us",
"k12.ar.us",
"k12.as.us",
"k12.az.us",
"k12.ca.us",
"k12.co.us",
"k12.ct.us",
"k12.dc.us",
"k12.de.us",
"k12.fl.us",
"k12.ga.us",
"k12.gu.us",
"k12.ia.us",
"k12.id.us",
"k12.il.us",
"k12.in.us",
"k12.ks.us",
"k12.ky.us",
"k12.la.us",
"k12.ma.us",
"k12.md.us",
"k12.me.us",
"k12.mi.us",
"k12.mn.us",
"k12.mo.us",
"k12.ms.us",
"k12.mt.us",
"k12.nc.us",
"k12.ne.us",
"k12.nh.us",
"k12.nj.us",
"k12.nm.us",
"k12.nv.us",
"k12.ny.us",
"k12.oh.us",
"k12.ok.us",
"k12.or.us",
"k12.pa.us",
"k12.pr.us",
"k12.sc.us",
"k12.tn.us",
"k12.tx.us",
"k12.ut.us",
"k12.vi.us",
"k12.vt.us",
"k12.va.us",
"k12.wa.us",
"k12.wi.us",
"k12.wy.us",
"cc.ak.us",
"cc.al.us",
"cc.ar.us",
"cc.as.us",
"cc.az.us",
"cc.ca.us",
"cc.co.us",
"cc.ct.us",
"cc.dc.us",
"cc.de.us",
"cc.fl.us",
"cc.ga.us",
"cc.gu.us",
"cc.hi.us",
"cc.ia.us",
"cc.id.us",
"cc.il.us",
"cc.in.us",
"cc.ks.us",
"cc.ky.us",
"cc.la.us",
"cc.ma.us",
"cc.md.us",
"cc.me.us",
"cc.mi.us",
"cc.mn.us",
"cc.mo.us",
"cc.ms.us",
"cc.mt.us",
"cc.nc.us",
"cc.nd.us",
"cc.ne.us",
"cc.nh.us",
"cc.nj.us",
"cc.nm.us",
"cc.nv.us",
"cc.ny.us",
"cc.oh.us",
"cc.ok.us",
"cc.or.us",
"cc.pa.us",
"cc.pr.us",
"cc.ri.us",
"cc.sc.us",
"cc.sd.us",
"cc.tn.us",
"cc.tx.us",
"cc.ut.us",
"cc.vi.us",
"cc.vt.us",
"cc.va.us",
"cc.wa.us",
"cc.wi.us",
"cc.wv.us",
"cc.wy.us",
"lib.ak.us",
"lib.al.us",
"lib.ar.us",
"lib.as.us",
"lib.az.us",
"lib.ca.us",
"lib.co.us",
"lib.ct.us",
"lib.dc.us",
"lib.fl.us",
"lib.ga.us",
"lib.gu.us",
"lib.hi.us",
"lib.ia.us",
"lib.id.us",
"lib.il.us",
"lib.in.us",
"lib.ks.us",
"lib.ky.us",
"lib.la.us",
"lib.ma.us",
"lib.md.us",
"lib.me.us",
"lib.mi.us",
"lib.mn.us",
"lib.mo.us",
"lib.ms.us",
"lib.mt.us",
"lib.nc.us",
"lib.nd.us",
"lib.ne.us",
"lib.nh.us",
"lib.nj.us",
"lib.nm.us",
"lib.nv.us",
"lib.ny.us",
"lib.oh.us",
"lib.ok.us",
"lib.or.us",
"lib.pa.us",
"lib.pr.us",
"lib.ri.us",
"lib.sc.us",
"lib.sd.us",
"lib.tn.us",
"lib.tx.us",
"lib.ut.us",
"lib.vi.us",
"lib.vt.us",
"lib.va.us",
"lib.wa.us",
"lib.wi.us",
"lib.wy.us",
"pvt.k12.ma.us",
"chtr.k12.ma.us",
"paroch.k12.ma.us",
"ann-arbor.mi.us",
"cog.mi.us",
"dst.mi.us",
"eaton.mi.us",
"gen.mi.us",
"mus.mi.us",
"tec.mi.us",
"washtenaw.mi.us",
"uy",
"com.uy",
"edu.uy",
"gub.uy",
"mil.uy",
"net.uy",
"org.uy",
"uz",
"co.uz",
"com.uz",
"net.uz",
"org.uz",
"va",
"vc",
"com.vc",
"net.vc",
"org.vc",
"gov.vc",
"mil.vc",
"edu.vc",
"ve",
"arts.ve",
"bib.ve",
"co.ve",
"com.ve",
"e12.ve",
"edu.ve",
"firm.ve",
"gob.ve",
"gov.ve",
"info.ve",
"int.ve",
"mil.ve",
"net.ve",
"nom.ve",
"org.ve",
"rar.ve",
"rec.ve",
"store.ve",
"tec.ve",
"web.ve",
"vg",
"vi",
"co.vi",
"com.vi",
"k12.vi",
"net.vi",
"org.vi",
"vn",
"com.vn",
"net.vn",
"org.vn",
"edu.vn",
"gov.vn",
"int.vn",
"ac.vn",
"biz.vn",
"info.vn",
"name.vn",
"pro.vn",
"health.vn",
"vu",
"com.vu",
"edu.vu",
"net.vu",
"org.vu",
"wf",
"ws",
"com.ws",
"net.ws",
"org.ws",
"gov.ws",
"edu.ws",
"yt",
"امارات",
"հայ",
"বাংলা",
"бг",
"البحرين",
"бел",
"中国",
"中國",
"الجزائر",
"مصر",
"ею",
"ευ",
"موريتانيا",
"გე",
"ελ",
"香港",
"公司.香港",
"教育.香港",
"政府.香港",
"個人.香港",
"網絡.香港",
"組織.香港",
"ಭಾರತ",
"ଭାରତ",
"ভাৰত",
"भारतम्",
"भारोत",
"ڀارت",
"ഭാരതം",
"भारत",
"بارت",
"بھارت",
"భారత్",
"ભારત",
"ਭਾਰਤ",
"ভারত",
"இந்தியா",
"ایران",
"ايران",
"عراق",
"الاردن",
"한국",
"қаз",
"ລາວ",
"ලංකා",
"இலங்கை",
"المغرب",
"мкд",
"мон",
"澳門",
"澳门",
"مليسيا",
"عمان",
"پاکستان",
"پاكستان",
"فلسطين",
"срб",
"пр.срб",
"орг.срб",
"обр.срб",
"од.срб",
"упр.срб",
"ак.срб",
"рф",
"قطر",
"السعودية",
"السعودیة",
"السعودیۃ",
"السعوديه",
"سودان",
"新加坡",
"சிங்கப்பூர்",
"سورية",
"سوريا",
"ไทย",
"ศึกษา.ไทย",
"ธุรกิจ.ไทย",
"รัฐบาล.ไทย",
"ทหาร.ไทย",
"เน็ต.ไทย",
"องค์กร.ไทย",
"تونس",
"台灣",
"台湾",
"臺灣",
"укр",
"اليمن",
"xxx",
"ye",
"com.ye",
"edu.ye",
"gov.ye",
"net.ye",
"mil.ye",
"org.ye",
"ac.za",
"agric.za",
"alt.za",
"co.za",
"edu.za",
"gov.za",
"grondar.za",
"law.za",
"mil.za",
"net.za",
"ngo.za",
"nic.za",
"nis.za",
"nom.za",
"org.za",
"school.za",
"tm.za",
"web.za",
"zm",
"ac.zm",
"biz.zm",
"co.zm",
"com.zm",
"edu.zm",
"gov.zm",
"info.zm",
"mil.zm",
"net.zm",
"org.zm",
"sch.zm",
"zw",
"ac.zw",
"co.zw",
"gov.zw",
"mil.zw",
"org.zw",
"aaa",
"aarp",
"abarth",
"abb",
"abbott",
"abbvie",
"abc",
"able",
"abogado",
"abudhabi",
"academy",
"accenture",
"accountant",
"accountants",
"aco",
"actor",
"adac",
"ads",
"adult",
"aeg",
"aetna",
"afl",
"africa",
"agakhan",
"agency",
"aig",
"airbus",
"airforce",
"airtel",
"akdn",
"alfaromeo",
"alibaba",
"alipay",
"allfinanz",
"allstate",
"ally",
"alsace",
"alstom",
"amazon",
"americanexpress",
"americanfamily",
"amex",
"amfam",
"amica",
"amsterdam",
"analytics",
"android",
"anquan",
"anz",
"aol",
"apartments",
"app",
"apple",
"aquarelle",
"arab",
"aramco",
"archi",
"army",
"art",
"arte",
"asda",
"associates",
"athleta",
"attorney",
"auction",
"audi",
"audible",
"audio",
"auspost",
"author",
"auto",
"autos",
"avianca",
"aws",
"axa",
"azure",
"baby",
"baidu",
"banamex",
"bananarepublic",
"band",
"bank",
"bar",
"barcelona",
"barclaycard",
"barclays",
"barefoot",
"bargains",
"baseball",
"basketball",
"bauhaus",
"bayern",
"bbc",
"bbt",
"bbva",
"bcg",
"bcn",
"beats",
"beauty",
"beer",
"bentley",
"berlin",
"best",
"bestbuy",
"bet",
"bharti",
"bible",
"bid",
"bike",
"bing",
"bingo",
"bio",
"black",
"blackfriday",
"blockbuster",
"blog",
"bloomberg",
"blue",
"bms",
"bmw",
"bnpparibas",
"boats",
"boehringer",
"bofa",
"bom",
"bond",
"boo",
"book",
"booking",
"bosch",
"bostik",
"boston",
"bot",
"boutique",
"box",
"bradesco",
"bridgestone",
"broadway",
"broker",
"brother",
"brussels",
"bugatti",
"build",
"builders",
"business",
"buy",
"buzz",
"bzh",
"cab",
"cafe",
"cal",
"call",
"calvinklein",
"cam",
"camera",
"camp",
"cancerresearch",
"canon",
"capetown",
"capital",
"capitalone",
"car",
"caravan",
"cards",
"care",
"career",
"careers",
"cars",
"casa",
"case",
"cash",
"casino",
"catering",
"catholic",
"cba",
"cbn",
"cbre",
"cbs",
"center",
"ceo",
"cern",
"cfa",
"cfd",
"chanel",
"channel",
"charity",
"chase",
"chat",
"cheap",
"chintai",
"christmas",
"chrome",
"church",
"cipriani",
"circle",
"cisco",
"citadel",
"citi",
"citic",
"city",
"cityeats",
"claims",
"cleaning",
"click",
"clinic",
"clinique",
"clothing",
"cloud",
"club",
"clubmed",
"coach",
"codes",
"coffee",
"college",
"cologne",
"comcast",
"commbank",
"community",
"company",
"compare",
"computer",
"comsec",
"condos",
"construction",
"consulting",
"contact",
"contractors",
"cooking",
"cookingchannel",
"cool",
"corsica",
"country",
"coupon",
"coupons",
"courses",
"cpa",
"credit",
"creditcard",
"creditunion",
"cricket",
"crown",
"crs",
"cruise",
"cruises",
"cuisinella",
"cymru",
"cyou",
"dabur",
"dad",
"dance",
"data",
"date",
"dating",
"datsun",
"day",
"dclk",
"dds",
"deal",
"dealer",
"deals",
"degree",
"delivery",
"dell",
"deloitte",
"delta",
"democrat",
"dental",
"dentist",
"desi",
"design",
"dev",
"dhl",
"diamonds",
"diet",
"digital",
"direct",
"directory",
"discount",
"discover",
"dish",
"diy",
"dnp",
"docs",
"doctor",
"dog",
"domains",
"dot",
"download",
"drive",
"dtv",
"dubai",
"dunlop",
"dupont",
"durban",
"dvag",
"dvr",
"earth",
"eat",
"eco",
"edeka",
"education",
"email",
"emerck",
"energy",
"engineer",
"engineering",
"enterprises",
"epson",
"equipment",
"ericsson",
"erni",
"esq",
"estate",
"etisalat",
"eurovision",
"eus",
"events",
"exchange",
"expert",
"exposed",
"express",
"extraspace",
"fage",
"fail",
"fairwinds",
"faith",
"family",
"fan",
"fans",
"farm",
"farmers",
"fashion",
"fast",
"fedex",
"feedback",
"ferrari",
"ferrero",
"fiat",
"fidelity",
"fido",
"film",
"final",
"finance",
"financial",
"fire",
"firestone",
"firmdale",
"fish",
"fishing",
"fit",
"fitness",
"flickr",
"flights",
"flir",
"florist",
"flowers",
"fly",
"foo",
"food",
"foodnetwork",
"football",
"ford",
"forex",
"forsale",
"forum",
"foundation",
"fox",
"free",
"fresenius",
"frl",
"frogans",
"frontdoor",
"frontier",
"ftr",
"fujitsu",
"fun",
"fund",
"furniture",
"futbol",
"fyi",
"gal",
"gallery",
"gallo",
"gallup",
"game",
"games",
"gap",
"garden",
"gay",
"gbiz",
"gdn",
"gea",
"gent",
"genting",
"george",
"ggee",
"gift",
"gifts",
"gives",
"giving",
"glass",
"gle",
"global",
"globo",
"gmail",
"gmbh",
"gmo",
"gmx",
"godaddy",
"gold",
"goldpoint",
"golf",
"goo",
"goodyear",
"goog",
"google",
"gop",
"got",
"grainger",
"graphics",
"gratis",
"green",
"gripe",
"grocery",
"group",
"guardian",
"gucci",
"guge",
"guide",
"guitars",
"guru",
"hair",
"hamburg",
"hangout",
"haus",
"hbo",
"hdfc",
"hdfcbank",
"health",
"healthcare",
"help",
"helsinki",
"here",
"hermes",
"hgtv",
"hiphop",
"hisamitsu",
"hitachi",
"hiv",
"hkt",
"hockey",
"holdings",
"holiday",
"homedepot",
"homegoods",
"homes",
"homesense",
"honda",
"horse",
"hospital",
"host",
"hosting",
"hot",
"hoteles",
"hotels",
"hotmail",
"house",
"how",
"hsbc",
"hughes",
"hyatt",
"hyundai",
"ibm",
"icbc",
"ice",
"icu",
"ieee",
"ifm",
"ikano",
"imamat",
"imdb",
"immo",
"immobilien",
"inc",
"industries",
"infiniti",
"ing",
"ink",
"institute",
"insurance",
"insure",
"international",
"intuit",
"investments",
"ipiranga",
"irish",
"ismaili",
"ist",
"istanbul",
"itau",
"itv",
"jaguar",
"java",
"jcb",
"jeep",
"jetzt",
"jewelry",
"jio",
"jll",
"jmp",
"jnj",
"joburg",
"jot",
"joy",
"jpmorgan",
"jprs",
"juegos",
"juniper",
"kaufen",
"kddi",
"kerryhotels",
"kerrylogistics",
"kerryproperties",
"kfh",
"kia",
"kids",
"kim",
"kinder",
"kindle",
"kitchen",
"kiwi",
"koeln",
"komatsu",
"kosher",
"kpmg",
"kpn",
"krd",
"kred",
"kuokgroup",
"kyoto",
"lacaixa",
"lamborghini",
"lamer",
"lancaster",
"lancia",
"land",
"landrover",
"lanxess",
"lasalle",
"lat",
"latino",
"latrobe",
"law",
"lawyer",
"lds",
"lease",
"leclerc",
"lefrak",
"legal",
"lego",
"lexus",
"lgbt",
"lidl",
"life",
"lifeinsurance",
"lifestyle",
"lighting",
"like",
"lilly",
"limited",
"limo",
"lincoln",
"linde",
"link",
"lipsy",
"live",
"living",
"llc",
"llp",
"loan",
"loans",
"locker",
"locus",
"loft",
"lol",
"london",
"lotte",
"lotto",
"love",
"lpl",
"lplfinancial",
"ltd",
"ltda",
"lundbeck",
"luxe",
"luxury",
"macys",
"madrid",
"maif",
"maison",
"makeup",
"man",
"management",
"mango",
"map",
"market",
"marketing",
"markets",
"marriott",
"marshalls",
"maserati",
"mattel",
"mba",
"mckinsey",
"med",
"media",
"meet",
"melbourne",
"meme",
"memorial",
"men",
"menu",
"merckmsd",
"miami",
"microsoft",
"mini",
"mint",
"mit",
"mitsubishi",
"mlb",
"mls",
"mma",
"mobile",
"moda",
"moe",
"moi",
"mom",
"monash",
"money",
"monster",
"mormon",
"mortgage",
"moscow",
"moto",
"motorcycles",
"mov",
"movie",
"msd",
"mtn",
"mtr",
"music",
"mutual",
"nab",
"nagoya",
"natura",
"navy",
"nba",
"nec",
"netbank",
"netflix",
"network",
"neustar",
"new",
"news",
"next",
"nextdirect",
"nexus",
"nfl",
"ngo",
"nhk",
"nico",
"nike",
"nikon",
"ninja",
"nissan",
"nissay",
"nokia",
"northwesternmutual",
"norton",
"now",
"nowruz",
"nowtv",
"nra",
"nrw",
"ntt",
"nyc",
"obi",
"observer",
"office",
"okinawa",
"olayan",
"olayangroup",
"oldnavy",
"ollo",
"omega",
"one",
"ong",
"onl",
"online",
"ooo",
"open",
"oracle",
"orange",
"organic",
"origins",
"osaka",
"otsuka",
"ott",
"ovh",
"page",
"panasonic",
"paris",
"pars",
"partners",
"parts",
"party",
"passagens",
"pay",
"pccw",
"pet",
"pfizer",
"pharmacy",
"phd",
"philips",
"phone",
"photo",
"photography",
"photos",
"physio",
"pics",
"pictet",
"pictures",
"pid",
"pin",
"ping",
"pink",
"pioneer",
"pizza",
"place",
"play",
"playstation",
"plumbing",
"plus",
"pnc",
"pohl",
"poker",
"politie",
"porn",
"pramerica",
"praxi",
"press",
"prime",
"prod",
"productions",
"prof",
"progressive",
"promo",
"properties",
"property",
"protection",
"pru",
"prudential",
"pub",
"pwc",
"qpon",
"quebec",
"quest",
"racing",
"radio",
"read",
"realestate",
"realtor",
"realty",
"recipes",
"red",
"redstone",
"redumbrella",
"rehab",
"reise",
"reisen",
"reit",
"reliance",
"ren",
"rent",
"rentals",
"repair",
"report",
"republican",
"rest",
"restaurant",
"review",
"reviews",
"rexroth",
"rich",
"richardli",
"ricoh",
"ril",
"rio",
"rip",
"rocher",
"rocks",
"rodeo",
"rogers",
"room",
"rsvp",
"rugby",
"ruhr",
"run",
"rwe",
"ryukyu",
"saarland",
"safe",
"safety",
"sakura",
"sale",
"salon",
"samsclub",
"samsung",
"sandvik",
"sandvikcoromant",
"sanofi",
"sap",
"sarl",
"sas",
"save",
"saxo",
"sbi",
"sbs",
"sca",
"scb",
"schaeffler",
"schmidt",
"scholarships",
"school",
"schule",
"schwarz",
"science",
"scot",
"search",
"seat",
"secure",
"security",
"seek",
"select",
"sener",
"services",
"ses",
"seven",
"sew",
"sex",
"sexy",
"sfr",
"shangrila",
"sharp",
"shaw",
"shell",
"shia",
"shiksha",
"shoes",
"shop",
"shopping",
"shouji",
"show",
"showtime",
"silk",
"sina",
"singles",
"site",
"ski",
"skin",
"sky",
"skype",
"sling",
"smart",
"smile",
"sncf",
"soccer",
"social",
"softbank",
"software",
"sohu",
"solar",
"solutions",
"song",
"sony",
"soy",
"spa",
"space",
"sport",
"spot",
"srl",
"stada",
"staples",
"star",
"statebank",
"statefarm",
"stc",
"stcgroup",
"stockholm",
"storage",
"store",
"stream",
"studio",
"study",
"style",
"sucks",
"supplies",
"supply",
"support",
"surf",
"surgery",
"suzuki",
"swatch",
"swiss",
"sydney",
"systems",
"tab",
"taipei",
"talk",
"taobao",
"target",
"tatamotors",
"tatar",
"tattoo",
"tax",
"taxi",
"tci",
"tdk",
"team",
"tech",
"technology",
"temasek",
"tennis",
"teva",
"thd",
"theater",
"theatre",
"tiaa",
"tickets",
"tienda",
"tiffany",
"tips",
"tires",
"tirol",
"tjmaxx",
"tjx",
"tkmaxx",
"tmall",
"today",
"tokyo",
"tools",
"top",
"toray",
"toshiba",
"total",
"tours",
"town",
"toyota",
"toys",
"trade",
"trading",
"training",
"travel",
"travelchannel",
"travelers",
"travelersinsurance",
"trust",
"trv",
"tube",
"tui",
"tunes",
"tushu",
"tvs",
"ubank",
"ubs",
"unicom",
"university",
"uno",
"uol",
"ups",
"vacations",
"vana",
"vanguard",
"vegas",
"ventures",
"verisign",
"versicherung",
"vet",
"viajes",
"video",
"vig",
"viking",
"villas",
"vin",
"vip",
"virgin",
"visa",
"vision",
"viva",
"vivo",
"vlaanderen",
"vodka",
"volkswagen",
"volvo",
"vote",
"voting",
"voto",
"voyage",
"vuelos",
"wales",
"walmart",
"walter",
"wang",
"wanggou",
"watch",
"watches",
"weather",
"weatherchannel",
"webcam",
"weber",
"website",
"wedding",
"weibo",
"weir",
"whoswho",
"wien",
"wiki",
"williamhill",
"win",
"windows",
"wine",
"winners",
"wme",
"wolterskluwer",
"woodside",
"work",
"works",
"world",
"wow",
"wtc",
"wtf",
"xbox",
"xerox",
"xfinity",
"xihuan",
"xin",
"कॉम",
"セール",
"佛山",
"慈善",
"集团",
"在线",
"点看",
"คอม",
"八卦",
"موقع",
"公益",
"公司",
"香格里拉",
"网站",
"移动",
"我爱你",
"москва",
"католик",
"онлайн",
"сайт",
"联通",
"קום",
"时尚",
"微博",
"淡马锡",
"ファッション",
"орг",
"नेट",
"ストア",
"アマゾン",
"삼성",
"商标",
"商店",
"商城",
"дети",
"ポイント",
"新闻",
"家電",
"كوم",
"中文网",
"中信",
"娱乐",
"谷歌",
"電訊盈科",
"购物",
"クラウド",
"通販",
"网店",
"संगठन",
"餐厅",
"网络",
"ком",
"亚马逊",
"诺基亚",
"食品",
"飞利浦",
"手机",
"ارامكو",
"العليان",
"اتصالات",
"بازار",
"ابوظبي",
"كاثوليك",
"همراه",
"닷컴",
"政府",
"شبكة",
"بيتك",
"عرب",
"机构",
"组织机构",
"健康",
"招聘",
"рус",
"大拿",
"みんな",
"グーグル",
"世界",
"書籍",
"网址",
"닷넷",
"コム",
"天主教",
"游戏",
"vermögensberater",
"vermögensberatung",
"企业",
"信息",
"嘉里大酒店",
"嘉里",
"广东",
"政务",
"xyz",
"yachts",
"yahoo",
"yamaxun",
"yandex",
"yodobashi",
"yoga",
"yokohama",
"you",
"youtube",
"yun",
"zappos",
"zara",
"zero",
"zip",
"zone",
"zuerich",
"cc.ua",
"inf.ua",
"ltd.ua",
"611.to",
"graphox.us",
"*.devcdnaccesso.com",
"adobeaemcloud.com",
"*.dev.adobeaemcloud.com",
"hlx.live",
"adobeaemcloud.net",
"hlx.page",
"hlx3.page",
"beep.pl",
"airkitapps.com",
"airkitapps-au.com",
"airkitapps.eu",
"aivencloud.com",
"barsy.ca",
"*.compute.estate",
"*.alces.network",
"kasserver.com",
"altervista.org",
"alwaysdata.net",
"cloudfront.net",
"*.compute.amazonaws.com",
"*.compute-1.amazonaws.com",
"*.compute.amazonaws.com.cn",
"us-east-1.amazonaws.com",
"cn-north-1.eb.amazonaws.com.cn",
"cn-northwest-1.eb.amazonaws.com.cn",
"elasticbeanstalk.com",
"ap-northeast-1.elasticbeanstalk.com",
"ap-northeast-2.elasticbeanstalk.com",
"ap-northeast-3.elasticbeanstalk.com",
"ap-south-1.elasticbeanstalk.com",
"ap-southeast-1.elasticbeanstalk.com",
"ap-southeast-2.elasticbeanstalk.com",
"ca-central-1.elasticbeanstalk.com",
"eu-central-1.elasticbeanstalk.com",
"eu-west-1.elasticbeanstalk.com",
"eu-west-2.elasticbeanstalk.com",
"eu-west-3.elasticbeanstalk.com",
"sa-east-1.elasticbeanstalk.com",
"us-east-1.elasticbeanstalk.com",
"us-east-2.elasticbeanstalk.com",
"us-gov-west-1.elasticbeanstalk.com",
"us-west-1.elasticbeanstalk.com",
"us-west-2.elasticbeanstalk.com",
"*.elb.amazonaws.com",
"*.elb.amazonaws.com.cn",
"awsglobalaccelerator.com",
"s3.amazonaws.com",
"s3-ap-northeast-1.amazonaws.com",
"s3-ap-northeast-2.amazonaws.com",
"s3-ap-south-1.amazonaws.com",
"s3-ap-southeast-1.amazonaws.com",
"s3-ap-southeast-2.amazonaws.com",
"s3-ca-central-1.amazonaws.com",
"s3-eu-central-1.amazonaws.com",
"s3-eu-west-1.amazonaws.com",
"s3-eu-west-2.amazonaws.com",
"s3-eu-west-3.amazonaws.com",
"s3-external-1.amazonaws.com",
"s3-fips-us-gov-west-1.amazonaws.com",
"s3-sa-east-1.amazonaws.com",
"s3-us-gov-west-1.amazonaws.com",
"s3-us-east-2.amazonaws.com",
"s3-us-west-1.amazonaws.com",
"s3-us-west-2.amazonaws.com",
"s3.ap-northeast-2.amazonaws.com",
"s3.ap-south-1.amazonaws.com",
"s3.cn-north-1.amazonaws.com.cn",
"s3.ca-central-1.amazonaws.com",
"s3.eu-central-1.amazonaws.com",
"s3.eu-west-2.amazonaws.com",
"s3.eu-west-3.amazonaws.com",
"s3.us-east-2.amazonaws.com",
"s3.dualstack.ap-northeast-1.amazonaws.com",
"s3.dualstack.ap-northeast-2.amazonaws.com",
"s3.dualstack.ap-south-1.amazonaws.com",
"s3.dualstack.ap-southeast-1.amazonaws.com",
"s3.dualstack.ap-southeast-2.amazonaws.com",
"s3.dualstack.ca-central-1.amazonaws.com",
"s3.dualstack.eu-central-1.amazonaws.com",
"s3.dualstack.eu-west-1.amazonaws.com",
"s3.dualstack.eu-west-2.amazonaws.com",
"s3.dualstack.eu-west-3.amazonaws.com",
"s3.dualstack.sa-east-1.amazonaws.com",
"s3.dualstack.us-east-1.amazonaws.com",
"s3.dualstack.us-east-2.amazonaws.com",
"s3-website-us-east-1.amazonaws.com",
"s3-website-us-west-1.amazonaws.com",
"s3-website-us-west-2.amazonaws.com",
"s3-website-ap-northeast-1.amazonaws.com",
"s3-website-ap-southeast-1.amazonaws.com",
"s3-website-ap-southeast-2.amazonaws.com",
"s3-website-eu-west-1.amazonaws.com",
"s3-website-sa-east-1.amazonaws.com",
"s3-website.ap-northeast-2.amazonaws.com",
"s3-website.ap-south-1.amazonaws.com",
"s3-website.ca-central-1.amazonaws.com",
"s3-website.eu-central-1.amazonaws.com",
"s3-website.eu-west-2.amazonaws.com",
"s3-website.eu-west-3.amazonaws.com",
"s3-website.us-east-2.amazonaws.com",
"t3l3p0rt.net",
"tele.amune.org",
"apigee.io",
"siiites.com",
"appspacehosted.com",
"appspaceusercontent.com",
"appudo.net",
"on-aptible.com",
"user.aseinet.ne.jp",
"gv.vc",
"d.gv.vc",
"user.party.eus",
"pimienta.org",
"poivron.org",
"potager.org",
"sweetpepper.org",
"myasustor.com",
"cdn.prod.atlassian-dev.net",
"translated.page",
"myfritz.net",
"onavstack.net",
"*.awdev.ca",
"*.advisor.ws",
"ecommerce-shop.pl",
"b-data.io",
"backplaneapp.io",
"balena-devices.com",
"rs.ba",
"*.banzai.cloud",
"app.banzaicloud.io",
"*.backyards.banzaicloud.io",
"base.ec",
"official.ec",
"buyshop.jp",
"fashionstore.jp",
"handcrafted.jp",
"kawaiishop.jp",
"supersale.jp",
"theshop.jp",
"shopselect.net",
"base.shop",
"*.beget.app",
"betainabox.com",
"bnr.la",
"bitbucket.io",
"blackbaudcdn.net",
"of.je",
"bluebite.io",
"boomla.net",
"boutir.com",
"boxfuse.io",
"square7.ch",
"bplaced.com",
"bplaced.de",
"square7.de",
"bplaced.net",
"square7.net",
"shop.brendly.rs",
"browsersafetymark.io",
"uk0.bigv.io",
"dh.bytemark.co.uk",
"vm.bytemark.co.uk",
"cafjs.com",
"mycd.eu",
"drr.ac",
"uwu.ai",
"carrd.co",
"crd.co",
"ju.mp",
"ae.org",
"br.com",
"cn.com",
"com.de",
"com.se",
"de.com",
"eu.com",
"gb.net",
"hu.net",
"jp.net",
"jpn.com",
"mex.com",
"ru.com",
"sa.com",
"se.net",
"uk.com",
"uk.net",
"us.com",
"za.bz",
"za.com",
"ar.com",
"hu.com",
"kr.com",
"no.com",
"qc.com",
"uy.com",
"africa.com",
"gr.com",
"in.net",
"web.in",
"us.org",
"co.com",
"aus.basketball",
"nz.basketball",
"radio.am",
"radio.fm",
"c.la",
"certmgr.org",
"cx.ua",
"discourse.group",
"discourse.team",
"cleverapps.io",
"clerk.app",
"clerkstage.app",
"*.lcl.dev",
"*.lclstage.dev",
"*.stg.dev",
"*.stgstage.dev",
"clickrising.net",
"c66.me",
"cloud66.ws",
"cloud66.zone",
"jdevcloud.com",
"wpdevcloud.com",
"cloudaccess.host",
"freesite.host",
"cloudaccess.net",
"cloudcontrolled.com",
"cloudcontrolapp.com",
"*.cloudera.site",
"pages.dev",
"trycloudflare.com",
"workers.dev",
"wnext.app",
"co.ca",
"*.otap.co",
"co.cz",
"c.cdn77.org",
"cdn77-ssl.net",
"r.cdn77.net",
"rsc.cdn77.org",
"ssl.origin.cdn77-secure.org",
"cloudns.asia",
"cloudns.biz",
"cloudns.club",
"cloudns.cc",
"cloudns.eu",
"cloudns.in",
"cloudns.info",
"cloudns.org",
"cloudns.pro",
"cloudns.pw",
"cloudns.us",
"cnpy.gdn",
"codeberg.page",
"co.nl",
"co.no",
"webhosting.be",
"hosting-cluster.nl",
"ac.ru",
"edu.ru",
"gov.ru",
"int.ru",
"mil.ru",
"test.ru",
"dyn.cosidns.de",
"dynamisches-dns.de",
"dnsupdater.de",
"internet-dns.de",
"l-o-g-i-n.de",
"dynamic-dns.info",
"feste-ip.net",
"knx-server.net",
"static-access.net",
"realm.cz",
"*.cryptonomic.net",
"cupcake.is",
"curv.dev",
"*.customer-oci.com",
"*.oci.customer-oci.com",
"*.ocp.customer-oci.com",
"*.ocs.customer-oci.com",
"cyon.link",
"cyon.site",
"fnwk.site",
"folionetwork.site",
"platform0.app",
"daplie.me",
"localhost.daplie.me",
"dattolocal.com",
"dattorelay.com",
"dattoweb.com",
"mydatto.com",
"dattolocal.net",
"mydatto.net",
"biz.dk",
"co.dk",
"firm.dk",
"reg.dk",
"store.dk",
"dyndns.dappnode.io",
"*.dapps.earth",
"*.bzz.dapps.earth",
"builtwithdark.com",
"demo.datadetect.com",
"instance.datadetect.com",
"edgestack.me",
"ddns5.com",
"debian.net",
"deno.dev",
"deno-staging.dev",
"dedyn.io",
"deta.app",
"deta.dev",
"*.rss.my.id",
"*.diher.solutions",
"discordsays.com",
"discordsez.com",
"jozi.biz",
"dnshome.de",
"online.th",
"shop.th",
"drayddns.com",
"shoparena.pl",
"dreamhosters.com",
"mydrobo.com",
"drud.io",
"drud.us",
"duckdns.org",
"bip.sh",
"bitbridge.net",
"dy.fi",
"tunk.org",
"dyndns-at-home.com",
"dyndns-at-work.com",
"dyndns-blog.com",
"dyndns-free.com",
"dyndns-home.com",
"dyndns-ip.com",
"dyndns-mail.com",
"dyndns-office.com",
"dyndns-pics.com",
"dyndns-remote.com",
"dyndns-server.com",
"dyndns-web.com",
"dyndns-wiki.com",
"dyndns-work.com",
"dyndns.biz",
"dyndns.info",
"dyndns.org",
"dyndns.tv",
"at-band-camp.net",
"ath.cx",
"barrel-of-knowledge.info",
"barrell-of-knowledge.info",
"better-than.tv",
"blogdns.com",
"blogdns.net",
"blogdns.org",
"blogsite.org",
"boldlygoingnowhere.org",
"broke-it.net",
"buyshouses.net",
"cechire.com",
"dnsalias.com",
"dnsalias.net",
"dnsalias.org",
"dnsdojo.com",
"dnsdojo.net",
"dnsdojo.org",
"does-it.net",
"doesntexist.com",
"doesntexist.org",
"dontexist.com",
"dontexist.net",
"dontexist.org",
"doomdns.com",
"doomdns.org",
"dvrdns.org",
"dyn-o-saur.com",
"dynalias.com",
"dynalias.net",
"dynalias.org",
"dynathome.net",
"dyndns.ws",
"endofinternet.net",
"endofinternet.org",
"endoftheinternet.org",
"est-a-la-maison.com",
"est-a-la-masion.com",
"est-le-patron.com",
"est-mon-blogueur.com",
"for-better.biz",
"for-more.biz",
"for-our.info",
"for-some.biz",
"for-the.biz",
"forgot.her.name",
"forgot.his.name",
"from-ak.com",
"from-al.com",
"from-ar.com",
"from-az.net",
"from-ca.com",
"from-co.net",
"from-ct.com",
"from-dc.com",
"from-de.com",
"from-fl.com",
"from-ga.com",
"from-hi.com",
"from-ia.com",
"from-id.com",
"from-il.com",
"from-in.com",
"from-ks.com",
"from-ky.com",
"from-la.net",
"from-ma.com",
"from-md.com",
"from-me.org",
"from-mi.com",
"from-mn.com",
"from-mo.com",
"from-ms.com",
"from-mt.com",
"from-nc.com",
"from-nd.com",
"from-ne.com",
"from-nh.com",
"from-nj.com",
"from-nm.com",
"from-nv.com",
"from-ny.net",
"from-oh.com",
"from-ok.com",
"from-or.com",
"from-pa.com",
"from-pr.com",
"from-ri.com",
"from-sc.com",
"from-sd.com",
"from-tn.com",
"from-tx.com",
"from-ut.com",
"from-va.com",
"from-vt.com",
"from-wa.com",
"from-wi.com",
"from-wv.com",
"from-wy.com",
"ftpaccess.cc",
"fuettertdasnetz.de",
"game-host.org",
"game-server.cc",
"getmyip.com",
"gets-it.net",
"go.dyndns.org",
"gotdns.com",
"gotdns.org",
"groks-the.info",
"groks-this.info",
"ham-radio-op.net",
"here-for-more.info",
"hobby-site.com",
"hobby-site.org",
"home.dyndns.org",
"homedns.org",
"homeftp.net",
"homeftp.org",
"homeip.net",
"homelinux.com",
"homelinux.net",
"homelinux.org",
"homeunix.com",
"homeunix.net",
"homeunix.org",
"iamallama.com",
"in-the-band.net",
"is-a-anarchist.com",
"is-a-blogger.com",
"is-a-bookkeeper.com",
"is-a-bruinsfan.org",
"is-a-bulls-fan.com",
"is-a-candidate.org",
"is-a-caterer.com",
"is-a-celticsfan.org",
"is-a-chef.com",
"is-a-chef.net",
"is-a-chef.org",
"is-a-conservative.com",
"is-a-cpa.com",
"is-a-cubicle-slave.com",
"is-a-democrat.com",
"is-a-designer.com",
"is-a-doctor.com",
"is-a-financialadvisor.com",
"is-a-geek.com",
"is-a-geek.net",
"is-a-geek.org",
"is-a-green.com",
"is-a-guru.com",
"is-a-hard-worker.com",
"is-a-hunter.com",
"is-a-knight.org",
"is-a-landscaper.com",
"is-a-lawyer.com",
"is-a-liberal.com",
"is-a-libertarian.com",
"is-a-linux-user.org",
"is-a-llama.com",
"is-a-musician.com",
"is-a-nascarfan.com",
"is-a-nurse.com",
"is-a-painter.com",
"is-a-patsfan.org",
"is-a-personaltrainer.com",
"is-a-photographer.com",
"is-a-player.com",
"is-a-republican.com",
"is-a-rockstar.com",
"is-a-socialist.com",
"is-a-soxfan.org",
"is-a-student.com",
"is-a-teacher.com",
"is-a-techie.com",
"is-a-therapist.com",
"is-an-accountant.com",
"is-an-actor.com",
"is-an-actress.com",
"is-an-anarchist.com",
"is-an-artist.com",
"is-an-engineer.com",
"is-an-entertainer.com",
"is-by.us",
"is-certified.com",
"is-found.org",
"is-gone.com",
"is-into-anime.com",
"is-into-cars.com",
"is-into-cartoons.com",
"is-into-games.com",
"is-leet.com",
"is-lost.org",
"is-not-certified.com",
"is-saved.org",
"is-slick.com",
"is-uberleet.com",
"is-very-bad.org",
"is-very-evil.org",
"is-very-good.org",
"is-very-nice.org",
"is-very-sweet.org",
"is-with-theband.com",
"isa-geek.com",
"isa-geek.net",
"isa-geek.org",
"isa-hockeynut.com",
"issmarterthanyou.com",
"isteingeek.de",
"istmein.de",
"kicks-ass.net",
"kicks-ass.org",
"knowsitall.info",
"land-4-sale.us",
"lebtimnetz.de",
"leitungsen.de",
"likes-pie.com",
"likescandy.com",
"merseine.nu",
"mine.nu",
"misconfused.org",
"mypets.ws",
"myphotos.cc",
"neat-url.com",
"office-on-the.net",
"on-the-web.tv",
"podzone.net",
"podzone.org",
"readmyblog.org",
"saves-the-whales.com",
"scrapper-site.net",
"scrapping.cc",
"selfip.biz",
"selfip.com",
"selfip.info",
"selfip.net",
"selfip.org",
"sells-for-less.com",
"sells-for-u.com",
"sells-it.net",
"sellsyourhome.org",
"servebbs.com",
"servebbs.net",
"servebbs.org",
"serveftp.net",
"serveftp.org",
"servegame.org",
"shacknet.nu",
"simple-url.com",
"space-to-rent.com",
"stuff-4-sale.org",
"stuff-4-sale.us",
"teaches-yoga.com",
"thruhere.net",
"traeumtgerade.de",
"webhop.biz",
"webhop.info",
"webhop.net",
"webhop.org",
"worse-than.tv",
"writesthisblog.com",
"ddnss.de",
"dyn.ddnss.de",
"dyndns.ddnss.de",
"dyndns1.de",
"dyn-ip24.de",
"home-webserver.de",
"dyn.home-webserver.de",
"myhome-server.de",
"ddnss.org",
"definima.net",
"definima.io",
"ondigitalocean.app",
"*.digitaloceanspaces.com",
"bci.dnstrace.pro",
"ddnsfree.com",
"ddnsgeek.com",
"giize.com",
"gleeze.com",
"kozow.com",
"loseyourip.com",
"ooguy.com",
"theworkpc.com",
"casacam.net",
"dynu.net",
"accesscam.org",
"camdvr.org",
"freeddns.org",
"mywire.org",
"webredirect.org",
"myddns.rocks",
"blogsite.xyz",
"dynv6.net",
"e4.cz",
"eero.online",
"eero-stage.online",
"elementor.cloud",
"elementor.cool",
"en-root.fr",
"mytuleap.com",
"tuleap-partners.com",
"encr.app",
"encoreapi.com",
"onred.one",
"staging.onred.one",
"eu.encoway.cloud",
"eu.org",
"al.eu.org",
"asso.eu.org",
"at.eu.org",
"au.eu.org",
"be.eu.org",
"bg.eu.org",
"ca.eu.org",
"cd.eu.org",
"ch.eu.org",
"cn.eu.org",
"cy.eu.org",
"cz.eu.org",
"de.eu.org",
"dk.eu.org",
"edu.eu.org",
"ee.eu.org",
"es.eu.org",
"fi.eu.org",
"fr.eu.org",
"gr.eu.org",
"hr.eu.org",
"hu.eu.org",
"ie.eu.org",
"il.eu.org",
"in.eu.org",
"int.eu.org",
"is.eu.org",
"it.eu.org",
"jp.eu.org",
"kr.eu.org",
"lt.eu.org",
"lu.eu.org",
"lv.eu.org",
"mc.eu.org",
"me.eu.org",
"mk.eu.org",
"mt.eu.org",
"my.eu.org",
"net.eu.org",
"ng.eu.org",
"nl.eu.org",
"no.eu.org",
"nz.eu.org",
"paris.eu.org",
"pl.eu.org",
"pt.eu.org",
"q-a.eu.org",
"ro.eu.org",
"ru.eu.org",
"se.eu.org",
"si.eu.org",
"sk.eu.org",
"tr.eu.org",
"uk.eu.org",
"us.eu.org",
"eurodir.ru",
"eu-1.evennode.com",
"eu-2.evennode.com",
"eu-3.evennode.com",
"eu-4.evennode.com",
"us-1.evennode.com",
"us-2.evennode.com",
"us-3.evennode.com",
"us-4.evennode.com",
"twmail.cc",
"twmail.net",
"twmail.org",
"mymailer.com.tw",
"url.tw",
"onfabrica.com",
"apps.fbsbx.com",
"ru.net",
"adygeya.ru",
"bashkiria.ru",
"bir.ru",
"cbg.ru",
"com.ru",
"dagestan.ru",
"grozny.ru",
"kalmykia.ru",
"kustanai.ru",
"marine.ru",
"mordovia.ru",
"msk.ru",
"mytis.ru",
"nalchik.ru",
"nov.ru",
"pyatigorsk.ru",
"spb.ru",
"vladikavkaz.ru",
"vladimir.ru",
"abkhazia.su",
"adygeya.su",
"aktyubinsk.su",
"arkhangelsk.su",
"armenia.su",
"ashgabad.su",
"azerbaijan.su",
"balashov.su",
"bashkiria.su",
"bryansk.su",
"bukhara.su",
"chimkent.su",
"dagestan.su",
"east-kazakhstan.su",
"exnet.su",
"georgia.su",
"grozny.su",
"ivanovo.su",
"jambyl.su",
"kalmykia.su",
"kaluga.su",
"karacol.su",
"karaganda.su",
"karelia.su",
"khakassia.su",
"krasnodar.su",
"kurgan.su",
"kustanai.su",
"lenug.su",
"mangyshlak.su",
"mordovia.su",
"msk.su",
"murmansk.su",
"nalchik.su",
"navoi.su",
"north-kazakhstan.su",
"nov.su",
"obninsk.su",
"penza.su",
"pokrovsk.su",
"sochi.su",
"spb.su",
"tashkent.su",
"termez.su",
"togliatti.su",
"troitsk.su",
"tselinograd.su",
"tula.su",
"tuva.su",
"vladikavkaz.su",
"vladimir.su",
"vologda.su",
"channelsdvr.net",
"u.channelsdvr.net",
"edgecompute.app",
"fastly-terrarium.com",
"fastlylb.net",
"map.fastlylb.net",
"freetls.fastly.net",
"map.fastly.net",
"a.prod.fastly.net",
"global.prod.fastly.net",
"a.ssl.fastly.net",
"b.ssl.fastly.net",
"global.ssl.fastly.net",
"fastvps-server.com",
"fastvps.host",
"myfast.host",
"fastvps.site",
"myfast.space",
"fedorainfracloud.org",
"fedorapeople.org",
"cloud.fedoraproject.org",
"app.os.fedoraproject.org",
"app.os.stg.fedoraproject.org",
"conn.uk",
"copro.uk",
"hosp.uk",
"mydobiss.com",
"fh-muenster.io",
"filegear.me",
"filegear-au.me",
"filegear-de.me",
"filegear-gb.me",
"filegear-ie.me",
"filegear-jp.me",
"filegear-sg.me",
"firebaseapp.com",
"fireweb.app",
"flap.id",
"onflashdrive.app",
"fldrv.com",
"fly.dev",
"edgeapp.net",
"shw.io",
"flynnhosting.net",
"forgeblocks.com",
"id.forgerock.io",
"framer.app",
"framercanvas.com",
"*.frusky.de",
"ravpage.co.il",
"0e.vc",
"freebox-os.com",
"freeboxos.com",
"fbx-os.fr",
"fbxos.fr",
"freebox-os.fr",
"freeboxos.fr",
"freedesktop.org",
"freemyip.com",
"wien.funkfeuer.at",
"*.futurecms.at",
"*.ex.futurecms.at",
"*.in.futurecms.at",
"futurehosting.at",
"futuremailing.at",
"*.ex.ortsinfo.at",
"*.kunden.ortsinfo.at",
"*.statics.cloud",
"independent-commission.uk",
"independent-inquest.uk",
"independent-inquiry.uk",
"independent-panel.uk",
"independent-review.uk",
"public-inquiry.uk",
"royal-commission.uk",
"campaign.gov.uk",
"service.gov.uk",
"api.gov.uk",
"gehirn.ne.jp",
"usercontent.jp",
"gentapps.com",
"gentlentapis.com",
"lab.ms",
"cdn-edges.net",
"ghost.io",
"gsj.bz",
"githubusercontent.com",
"githubpreview.dev",
"github.io",
"gitlab.io",
"gitapp.si",
"gitpage.si",
"glitch.me",
"nog.community",
"co.ro",
"shop.ro",
"lolipop.io",
"angry.jp",
"babyblue.jp",
"babymilk.jp",
"backdrop.jp",
"bambina.jp",
"bitter.jp",
"blush.jp",
"boo.jp",
"boy.jp",
"boyfriend.jp",
"but.jp",
"candypop.jp",
"capoo.jp",
"catfood.jp",
"cheap.jp",
"chicappa.jp",
"chillout.jp",
"chips.jp",
"chowder.jp",
"chu.jp",
"ciao.jp",
"cocotte.jp",
"coolblog.jp",
"cranky.jp",
"cutegirl.jp",
"daa.jp",
"deca.jp",
"deci.jp",
"digick.jp",
"egoism.jp",
"fakefur.jp",
"fem.jp",
"flier.jp",
"floppy.jp",
"fool.jp",
"frenchkiss.jp",
"girlfriend.jp",
"girly.jp",
"gloomy.jp",
"gonna.jp",
"greater.jp",
"hacca.jp",
"heavy.jp",
"her.jp",
"hiho.jp",
"hippy.jp",
"holy.jp",
"hungry.jp",
"icurus.jp",
"itigo.jp",
"jellybean.jp",
"kikirara.jp",
"kill.jp",
"kilo.jp",
"kuron.jp",
"littlestar.jp",
"lolipopmc.jp",
"lolitapunk.jp",
"lomo.jp",
"lovepop.jp",
"lovesick.jp",
"main.jp",
"mods.jp",
"mond.jp",
"mongolian.jp",
"moo.jp",
"namaste.jp",
"nikita.jp",
"nobushi.jp",
"noor.jp",
"oops.jp",
"parallel.jp",
"parasite.jp",
"pecori.jp",
"peewee.jp",
"penne.jp",
"pepper.jp",
"perma.jp",
"pigboat.jp",
"pinoko.jp",
"punyu.jp",
"pupu.jp",
"pussycat.jp",
"pya.jp",
"raindrop.jp",
"readymade.jp",
"sadist.jp",
"schoolbus.jp",
"secret.jp",
"staba.jp",
"stripper.jp",
"sub.jp",
"sunnyday.jp",
"thick.jp",
"tonkotsu.jp",
"under.jp",
"upper.jp",
"velvet.jp",
"verse.jp",
"versus.jp",
"vivian.jp",
"watson.jp",
"weblike.jp",
"whitesnow.jp",
"zombie.jp",
"heteml.net",
"cloudapps.digital",
"london.cloudapps.digital",
"pymnt.uk",
"homeoffice.gov.uk",
"ro.im",
"goip.de",
"run.app",
"a.run.app",
"web.app",
"*.0emm.com",
"appspot.com",
"*.r.appspot.com",
"codespot.com",
"googleapis.com",
"googlecode.com",
"pagespeedmobilizer.com",
"publishproxy.com",
"withgoogle.com",
"withyoutube.com",
"*.gateway.dev",
"cloud.goog",
"translate.goog",
"*.usercontent.goog",
"cloudfunctions.net",
"blogspot.ae",
"blogspot.al",
"blogspot.am",
"blogspot.ba",
"blogspot.be",
"blogspot.bg",
"blogspot.bj",
"blogspot.ca",
"blogspot.cf",
"blogspot.ch",
"blogspot.cl",
"blogspot.co.at",
"blogspot.co.id",
"blogspot.co.il",
"blogspot.co.ke",
"blogspot.co.nz",
"blogspot.co.uk",
"blogspot.co.za",
"blogspot.com",
"blogspot.com.ar",
"blogspot.com.au",
"blogspot.com.br",
"blogspot.com.by",
"blogspot.com.co",
"blogspot.com.cy",
"blogspot.com.ee",
"blogspot.com.eg",
"blogspot.com.es",
"blogspot.com.mt",
"blogspot.com.ng",
"blogspot.com.tr",
"blogspot.com.uy",
"blogspot.cv",
"blogspot.cz",
"blogspot.de",
"blogspot.dk",
"blogspot.fi",
"blogspot.fr",
"blogspot.gr",
"blogspot.hk",
"blogspot.hr",
"blogspot.hu",
"blogspot.ie",
"blogspot.in",
"blogspot.is",
"blogspot.it",
"blogspot.jp",
"blogspot.kr",
"blogspot.li",
"blogspot.lt",
"blogspot.lu",
"blogspot.md",
"blogspot.mk",
"blogspot.mr",
"blogspot.mx",
"blogspot.my",
"blogspot.nl",
"blogspot.no",
"blogspot.pe",
"blogspot.pt",
"blogspot.qa",
"blogspot.re",
"blogspot.ro",
"blogspot.rs",
"blogspot.ru",
"blogspot.se",
"blogspot.sg",
"blogspot.si",
"blogspot.sk",
"blogspot.sn",
"blogspot.td",
"blogspot.tw",
"blogspot.ug",
"blogspot.vn",
"goupile.fr",
"gov.nl",
"awsmppl.com",
"günstigbestellen.de",
"günstigliefern.de",
"fin.ci",
"free.hr",
"caa.li",
"ua.rs",
"conf.se",
"hs.zone",
"hs.run",
"hashbang.sh",
"hasura.app",
"hasura-app.io",
"pages.it.hs-heilbronn.de",
"hepforge.org",
"herokuapp.com",
"herokussl.com",
"ravendb.cloud",
"myravendb.com",
"ravendb.community",
"ravendb.me",
"development.run",
"ravendb.run",
"homesklep.pl",
"secaas.hk",
"hoplix.shop",
"orx.biz",
"biz.gl",
"col.ng",
"firm.ng",
"gen.ng",
"ltd.ng",
"ngo.ng",
"edu.scot",
"sch.so",
"hostyhosting.io",
"häkkinen.fi",
"*.moonscale.io",
"moonscale.net",
"iki.fi",
"ibxos.it",
"iliadboxos.it",
"impertrixcdn.com",
"impertrix.com",
"smushcdn.com",
"wphostedmail.com",
"wpmucdn.com",
"tempurl.host",
"wpmudev.host",
"dyn-berlin.de",
"in-berlin.de",
"in-brb.de",
"in-butter.de",
"in-dsl.de",
"in-dsl.net",
"in-dsl.org",
"in-vpn.de",
"in-vpn.net",
"in-vpn.org",
"biz.at",
"info.at",
"info.cx",
"ac.leg.br",
"al.leg.br",
"am.leg.br",
"ap.leg.br",
"ba.leg.br",
"ce.leg.br",
"df.leg.br",
"es.leg.br",
"go.leg.br",
"ma.leg.br",
"mg.leg.br",
"ms.leg.br",
"mt.leg.br",
"pa.leg.br",
"pb.leg.br",
"pe.leg.br",
"pi.leg.br",
"pr.leg.br",
"rj.leg.br",
"rn.leg.br",
"ro.leg.br",
"rr.leg.br",
"rs.leg.br",
"sc.leg.br",
"se.leg.br",
"sp.leg.br",
"to.leg.br",
"pixolino.com",
"na4u.ru",
"iopsys.se",
"ipifony.net",
"iservschule.de",
"mein-iserv.de",
"schulplattform.de",
"schulserver.de",
"test-iserv.de",
"iserv.dev",
"iobb.net",
"mel.cloudlets.com.au",
"cloud.interhostsolutions.be",
"users.scale.virtualcloud.com.br",
"mycloud.by",
"alp1.ae.flow.ch",
"appengine.flow.ch",
"es-1.axarnet.cloud",
"diadem.cloud",
"vip.jelastic.cloud",
"jele.cloud",
"it1.eur.aruba.jenv-aruba.cloud",
"it1.jenv-aruba.cloud",
"keliweb.cloud",
"cs.keliweb.cloud",
"oxa.cloud",
"tn.oxa.cloud",
"uk.oxa.cloud",
"primetel.cloud",
"uk.primetel.cloud",
"ca.reclaim.cloud",
"uk.reclaim.cloud",
"us.reclaim.cloud",
"ch.trendhosting.cloud",
"de.trendhosting.cloud",
"jele.club",
"amscompute.com",
"clicketcloud.com",
"dopaas.com",
"hidora.com",
"paas.hosted-by-previder.com",
"rag-cloud.hosteur.com",
"rag-cloud-ch.hosteur.com",
"jcloud.ik-server.com",
"jcloud-ver-jpc.ik-server.com",
"demo.jelastic.com",
"kilatiron.com",
"paas.massivegrid.com",
"jed.wafaicloud.com",
"lon.wafaicloud.com",
"ryd.wafaicloud.com",
"j.scaleforce.com.cy",
"jelastic.dogado.eu",
"fi.cloudplatform.fi",
"demo.datacenter.fi",
"paas.datacenter.fi",
"jele.host",
"mircloud.host",
"paas.beebyte.io",
"sekd1.beebyteapp.io",
"jele.io",
"cloud-fr1.unispace.io",
"jc.neen.it",
"cloud.jelastic.open.tim.it",
"jcloud.kz",
"upaas.kazteleport.kz",
"cloudjiffy.net",
"fra1-de.cloudjiffy.net",
"west1-us.cloudjiffy.net",
"jls-sto1.elastx.net",
"jls-sto2.elastx.net",
"jls-sto3.elastx.net",
"faststacks.net",
"fr-1.paas.massivegrid.net",
"lon-1.paas.massivegrid.net",
"lon-2.paas.massivegrid.net",
"ny-1.paas.massivegrid.net",
"ny-2.paas.massivegrid.net",
"sg-1.paas.massivegrid.net",
"jelastic.saveincloud.net",
"nordeste-idc.saveincloud.net",
"j.scaleforce.net",
"jelastic.tsukaeru.net",
"sdscloud.pl",
"unicloud.pl",
"mircloud.ru",
"jelastic.regruhosting.ru",
"enscaled.sg",
"jele.site",
"jelastic.team",
"orangecloud.tn",
"j.layershift.co.uk",
"phx.enscaled.us",
"mircloud.us",
"myjino.ru",
"*.hosting.myjino.ru",
"*.landing.myjino.ru",
"*.spectrum.myjino.ru",
"*.vps.myjino.ru",
"jotelulu.cloud",
"*.triton.zone",
"*.cns.joyent.com",
"js.org",
"kaas.gg",
"khplay.nl",
"ktistory.com",
"kapsi.fi",
"keymachine.de",
"kinghost.net",
"uni5.net",
"knightpoint.systems",
"koobin.events",
"oya.to",
"kuleuven.cloud",
"ezproxy.kuleuven.be",
"co.krd",
"edu.krd",
"krellian.net",
"webthings.io",
"git-repos.de",
"lcube-server.de",
"svn-repos.de",
"leadpages.co",
"lpages.co",
"lpusercontent.com",
"lelux.site",
"co.business",
"co.education",
"co.events",
"co.financial",
"co.network",
"co.place",
"co.technology",
"app.lmpm.com",
"linkyard.cloud",
"linkyard-cloud.ch",
"members.linode.com",
"*.nodebalancer.linode.com",
"*.linodeobjects.com",
"ip.linodeusercontent.com",
"we.bs",
"*.user.localcert.dev",
"localzone.xyz",
"loginline.app",
"loginline.dev",
"loginline.io",
"loginline.services",
"loginline.site",
"servers.run",
"lohmus.me",
"krasnik.pl",
"leczna.pl",
"lubartow.pl",
"lublin.pl",
"poniatowa.pl",
"swidnik.pl",
"glug.org.uk",
"lug.org.uk",
"lugs.org.uk",
"barsy.bg",
"barsy.co.uk",
"barsyonline.co.uk",
"barsycenter.com",
"barsyonline.com",
"barsy.club",
"barsy.de",
"barsy.eu",
"barsy.in",
"barsy.info",
"barsy.io",
"barsy.me",
"barsy.menu",
"barsy.mobi",
"barsy.net",
"barsy.online",
"barsy.org",
"barsy.pro",
"barsy.pub",
"barsy.ro",
"barsy.shop",
"barsy.site",
"barsy.support",
"barsy.uk",
"*.magentosite.cloud",
"mayfirst.info",
"mayfirst.org",
"hb.cldmail.ru",
"cn.vu",
"mazeplay.com",
"mcpe.me",
"mcdir.me",
"mcdir.ru",
"mcpre.ru",
"vps.mcdir.ru",
"mediatech.by",
"mediatech.dev",
"hra.health",
"miniserver.com",
"memset.net",
"messerli.app",
"*.cloud.metacentrum.cz",
"custom.metacentrum.cz",
"flt.cloud.muni.cz",
"usr.cloud.muni.cz",
"meteorapp.com",
"eu.meteorapp.com",
"co.pl",
"*.azurecontainer.io",
"azurewebsites.net",
"azure-mobile.net",
"cloudapp.net",
"azurestaticapps.net",
"1.azurestaticapps.net",
"centralus.azurestaticapps.net",
"eastasia.azurestaticapps.net",
"eastus2.azurestaticapps.net",
"westeurope.azurestaticapps.net",
"westus2.azurestaticapps.net",
"csx.cc",
"mintere.site",
"forte.id",
"mozilla-iot.org",
"bmoattachments.org",
"net.ru",
"org.ru",
"pp.ru",
"hostedpi.com",
"customer.mythic-beasts.com",
"caracal.mythic-beasts.com",
"fentiger.mythic-beasts.com",
"lynx.mythic-beasts.com",
"ocelot.mythic-beasts.com",
"oncilla.mythic-beasts.com",
"onza.mythic-beasts.com",
"sphinx.mythic-beasts.com",
"vs.mythic-beasts.com",
"x.mythic-beasts.com",
"yali.mythic-beasts.com",
"cust.retrosnub.co.uk",
"ui.nabu.casa",
"pony.club",
"of.fashion",
"in.london",
"of.london",
"from.marketing",
"with.marketing",
"for.men",
"repair.men",
"and.mom",
"for.mom",
"for.one",
"under.one",
"for.sale",
"that.win",
"from.work",
"to.work",
"cloud.nospamproxy.com",
"netlify.app",
"4u.com",
"ngrok.io",
"nh-serv.co.uk",
"nfshost.com",
"*.developer.app",
"noop.app",
"*.northflank.app",
"*.build.run",
"*.code.run",
"*.database.run",
"*.migration.run",
"noticeable.news",
"dnsking.ch",
"mypi.co",
"n4t.co",
"001www.com",
"ddnslive.com",
"myiphost.com",
"forumz.info",
"16-b.it",
"32-b.it",
"64-b.it",
"soundcast.me",
"tcp4.me",
"dnsup.net",
"hicam.net",
"now-dns.net",
"ownip.net",
"vpndns.net",
"dynserv.org",
"now-dns.org",
"x443.pw",
"now-dns.top",
"ntdll.top",
"freeddns.us",
"crafting.xyz",
"zapto.xyz",
"nsupdate.info",
"nerdpol.ovh",
"blogsyte.com",
"brasilia.me",
"cable-modem.org",
"ciscofreak.com",
"collegefan.org",
"couchpotatofries.org",
"damnserver.com",
"ddns.me",
"ditchyourip.com",
"dnsfor.me",
"dnsiskinky.com",
"dvrcam.info",
"dynns.com",
"eating-organic.net",
"fantasyleague.cc",
"geekgalaxy.com",
"golffan.us",
"health-carereform.com",
"homesecuritymac.com",
"homesecuritypc.com",
"hopto.me",
"ilovecollege.info",
"loginto.me",
"mlbfan.org",
"mmafan.biz",
"myactivedirectory.com",
"mydissent.net",
"myeffect.net",
"mymediapc.net",
"mypsx.net",
"mysecuritycamera.com",
"mysecuritycamera.net",
"mysecuritycamera.org",
"net-freaks.com",
"nflfan.org",
"nhlfan.net",
"no-ip.ca",
"no-ip.co.uk",
"no-ip.net",
"noip.us",
"onthewifi.com",
"pgafan.net",
"point2this.com",
"pointto.us",
"privatizehealthinsurance.net",
"quicksytes.com",
"read-books.org",
"securitytactics.com",
"serveexchange.com",
"servehumour.com",
"servep2p.com",
"servesarcasm.com",
"stufftoread.com",
"ufcfan.org",
"unusualperson.com",
"workisboring.com",
"3utilities.com",
"bounceme.net",
"ddns.net",
"ddnsking.com",
"gotdns.ch",
"hopto.org",
"myftp.biz",
"myftp.org",
"myvnc.com",
"no-ip.biz",
"no-ip.info",
"no-ip.org",
"noip.me",
"redirectme.net",
"servebeer.com",
"serveblog.net",
"servecounterstrike.com",
"serveftp.com",
"servegame.com",
"servehalflife.com",
"servehttp.com",
"serveirc.com",
"serveminecraft.net",
"servemp3.com",
"servepics.com",
"servequake.com",
"sytes.net",
"webhop.me",
"zapto.org",
"stage.nodeart.io",
"pcloud.host",
"nyc.mn",
"static.observableusercontent.com",
"cya.gg",
"omg.lol",
"cloudycluster.net",
"omniwe.site",
"service.one",
"nid.io",
"opensocial.site",
"opencraft.hosting",
"orsites.com",
"operaunite.com",
"tech.orange",
"authgear-staging.com",
"authgearapps.com",
"skygearapp.com",
"outsystemscloud.com",
"*.webpaas.ovh.net",
"*.hosting.ovh.net",
"ownprovider.com",
"own.pm",
"*.owo.codes",
"ox.rs",
"oy.lc",
"pgfog.com",
"pagefrontapp.com",
"pagexl.com",
"*.paywhirl.com",
"bar0.net",
"bar1.net",
"bar2.net",
"rdv.to",
"art.pl",
"gliwice.pl",
"krakow.pl",
"poznan.pl",
"wroc.pl",
"zakopane.pl",
"pantheonsite.io",
"gotpantheon.com",
"mypep.link",
"perspecta.cloud",
"lk3.ru",
"on-web.fr",
"bc.platform.sh",
"ent.platform.sh",
"eu.platform.sh",
"us.platform.sh",
"*.platformsh.site",
"*.tst.site",
"platter-app.com",
"platter-app.dev",
"platterp.us",
"pdns.page",
"plesk.page",
"pleskns.com",
"dyn53.io",
"onporter.run",
"co.bn",
"postman-echo.com",
"pstmn.io",
"mock.pstmn.io",
"httpbin.org",
"prequalifyme.today",
"xen.prgmr.com",
"priv.at",
"prvcy.page",
"*.dweb.link",
"protonet.io",
"chirurgiens-dentistes-en-france.fr",
"byen.site",
"pubtls.org",
"pythonanywhere.com",
"eu.pythonanywhere.com",
"qoto.io",
"qualifioapp.com",
"qbuser.com",
"cloudsite.builders",
"instances.spawn.cc",
"instantcloud.cn",
"ras.ru",
"qa2.com",
"qcx.io",
"*.sys.qcx.io",
"dev-myqnapcloud.com",
"alpha-myqnapcloud.com",
"myqnapcloud.com",
"*.quipelements.com",
"vapor.cloud",
"vaporcloud.io",
"rackmaze.com",
"rackmaze.net",
"g.vbrplsbx.io",
"*.on-k3s.io",
"*.on-rancher.cloud",
"*.on-rio.io",
"readthedocs.io",
"rhcloud.com",
"app.render.com",
"onrender.com",
"repl.co",
"id.repl.co",
"repl.run",
"resindevice.io",
"devices.resinstaging.io",
"hzc.io",
"wellbeingzone.eu",
"wellbeingzone.co.uk",
"adimo.co.uk",
"itcouldbewor.se",
"git-pages.rit.edu",
"rocky.page",
"биз.рус",
"ком.рус",
"крым.рус",
"мир.рус",
"мск.рус",
"орг.рус",
"самара.рус",
"сочи.рус",
"спб.рус",
"я.рус",
"*.builder.code.com",
"*.dev-builder.code.com",
"*.stg-builder.code.com",
"sandcats.io",
"logoip.de",
"logoip.com",
"fr-par-1.baremetal.scw.cloud",
"fr-par-2.baremetal.scw.cloud",
"nl-ams-1.baremetal.scw.cloud",
"fnc.fr-par.scw.cloud",
"functions.fnc.fr-par.scw.cloud",
"k8s.fr-par.scw.cloud",
"nodes.k8s.fr-par.scw.cloud",
"s3.fr-par.scw.cloud",
"s3-website.fr-par.scw.cloud",
"whm.fr-par.scw.cloud",
"priv.instances.scw.cloud",
"pub.instances.scw.cloud",
"k8s.scw.cloud",
"k8s.nl-ams.scw.cloud",
"nodes.k8s.nl-ams.scw.cloud",
"s3.nl-ams.scw.cloud",
"s3-website.nl-ams.scw.cloud",
"whm.nl-ams.scw.cloud",
"k8s.pl-waw.scw.cloud",
"nodes.k8s.pl-waw.scw.cloud",
"s3.pl-waw.scw.cloud",
"s3-website.pl-waw.scw.cloud",
"scalebook.scw.cloud",
"smartlabeling.scw.cloud",
"dedibox.fr",
"schokokeks.net",
"gov.scot",
"service.gov.scot",
"scrysec.com",
"firewall-gateway.com",
"firewall-gateway.de",
"my-gateway.de",
"my-router.de",
"spdns.de",
"spdns.eu",
"firewall-gateway.net",
"my-firewall.org",
"myfirewall.org",
"spdns.org",
"seidat.net",
"sellfy.store",
"senseering.net",
"minisite.ms",
"magnet.page",
"biz.ua",
"co.ua",
"pp.ua",
"shiftcrypto.dev",
"shiftcrypto.io",
"shiftedit.io",
"myshopblocks.com",
"myshopify.com",
"shopitsite.com",
"shopware.store",
"mo-siemens.io",
"1kapp.com",
"appchizi.com",
"applinzi.com",
"sinaapp.com",
"vipsinaapp.com",
"siteleaf.net",
"bounty-full.com",
"alpha.bounty-full.com",
"beta.bounty-full.com",
"small-web.org",
"vp4.me",
"try-snowplow.com",
"srht.site",
"stackhero-network.com",
"musician.io",
"novecore.site",
"static.land",
"dev.static.land",
"sites.static.land",
"storebase.store",
"vps-host.net",
"atl.jelastic.vps-host.net",
"njs.jelastic.vps-host.net",
"ric.jelastic.vps-host.net",
"playstation-cloud.com",
"apps.lair.io",
"*.stolos.io",
"spacekit.io",
"customer.speedpartner.de",
"myspreadshop.at",
"myspreadshop.com.au",
"myspreadshop.be",
"myspreadshop.ca",
"myspreadshop.ch",
"myspreadshop.com",
"myspreadshop.de",
"myspreadshop.dk",
"myspreadshop.es",
"myspreadshop.fi",
"myspreadshop.fr",
"myspreadshop.ie",
"myspreadshop.it",
"myspreadshop.net",
"myspreadshop.nl",
"myspreadshop.no",
"myspreadshop.pl",
"myspreadshop.se",
"myspreadshop.co.uk",
"api.stdlib.com",
"storj.farm",
"utwente.io",
"soc.srcf.net",
"user.srcf.net",
"temp-dns.com",
"supabase.co",
"supabase.in",
"supabase.net",
"su.paba.se",
"*.s5y.io",
"*.sensiosite.cloud",
"syncloud.it",
"dscloud.biz",
"direct.quickconnect.cn",
"dsmynas.com",
"familyds.com",
"diskstation.me",
"dscloud.me",
"i234.me",
"myds.me",
"synology.me",
"dscloud.mobi",
"dsmynas.net",
"familyds.net",
"dsmynas.org",
"familyds.org",
"vpnplus.to",
"direct.quickconnect.to",
"tabitorder.co.il",
"taifun-dns.de",
"beta.tailscale.net",
"ts.net",
"gda.pl",
"gdansk.pl",
"gdynia.pl",
"med.pl",
"sopot.pl",
"site.tb-hosting.com",
"edugit.io",
"s3.teckids.org",
"telebit.app",
"telebit.io",
"*.telebit.xyz",
"gwiddle.co.uk",
"*.firenet.ch",
"*.svc.firenet.ch",
"reservd.com",
"thingdustdata.com",
"cust.dev.thingdust.io",
"cust.disrec.thingdust.io",
"cust.prod.thingdust.io",
"cust.testing.thingdust.io",
"reservd.dev.thingdust.io",
"reservd.disrec.thingdust.io",
"reservd.testing.thingdust.io",
"tickets.io",
"arvo.network",
"azimuth.network",
"tlon.network",
"torproject.net",
"pages.torproject.net",
"bloxcms.com",
"townnews-staging.com",
"tbits.me",
"12hp.at",
"2ix.at",
"4lima.at",
"lima-city.at",
"12hp.ch",
"2ix.ch",
"4lima.ch",
"lima-city.ch",
"trafficplex.cloud",
"de.cool",
"12hp.de",
"2ix.de",
"4lima.de",
"lima-city.de",
"1337.pictures",
"clan.rip",
"lima-city.rocks",
"webspace.rocks",
"lima.zone",
"*.transurl.be",
"*.transurl.eu",
"*.transurl.nl",
"site.transip.me",
"tuxfamily.org",
"dd-dns.de",
"diskstation.eu",
"diskstation.org",
"dray-dns.de",
"draydns.de",
"dyn-vpn.de",
"dynvpn.de",
"mein-vigor.de",
"my-vigor.de",
"my-wan.de",
"syno-ds.de",
"synology-diskstation.de",
"synology-ds.de",
"typedream.app",
"pro.typeform.com",
"uber.space",
"*.uberspace.de",
"hk.com",
"hk.org",
"ltd.hk",
"inc.hk",
"name.pm",
"sch.tf",
"biz.wf",
"sch.wf",
"org.yt",
"virtualuser.de",
"virtual-user.de",
"upli.io",
"urown.cloud",
"dnsupdate.info",
"lib.de.us",
"2038.io",
"vercel.app",
"vercel.dev",
"now.sh",
"router.management",
"v-info.info",
"voorloper.cloud",
"neko.am",
"nyaa.am",
"be.ax",
"cat.ax",
"es.ax",
"eu.ax",
"gg.ax",
"mc.ax",
"us.ax",
"xy.ax",
"nl.ci",
"xx.gl",
"app.gp",
"blog.gt",
"de.gt",
"to.gt",
"be.gy",
"cc.hn",
"blog.kg",
"io.kg",
"jp.kg",
"tv.kg",
"uk.kg",
"us.kg",
"de.ls",
"at.md",
"de.md",
"jp.md",
"to.md",
"indie.porn",
"vxl.sh",
"ch.tc",
"me.tc",
"we.tc",
"nyan.to",
"at.vg",
"blog.vu",
"dev.vu",
"me.vu",
"v.ua",
"*.vultrobjects.com",
"wafflecell.com",
"*.webhare.dev",
"reserve-online.net",
"reserve-online.com",
"bookonline.app",
"hotelwithflight.com",
"wedeploy.io",
"wedeploy.me",
"wedeploy.sh",
"remotewd.com",
"pages.wiardweb.com",
"wmflabs.org",
"toolforge.org",
"wmcloud.org",
"panel.gg",
"daemon.panel.gg",
"messwithdns.com",
"woltlab-demo.com",
"myforum.community",
"community-pro.de",
"diskussionsbereich.de",
"community-pro.net",
"meinforum.net",
"affinitylottery.org.uk",
"raffleentry.org.uk",
"weeklylottery.org.uk",
"wpenginepowered.com",
"js.wpenginepowered.com",
"wixsite.com",
"editorx.io",
"half.host",
"xnbay.com",
"u2.xnbay.com",
"u2-local.xnbay.com",
"cistron.nl",
"demon.nl",
"xs4all.space",
"yandexcloud.net",
"storage.yandexcloud.net",
"website.yandexcloud.net",
"official.academy",
"yolasite.com",
"ybo.faith",
"yombo.me",
"homelink.one",
"ybo.party",
"ybo.review",
"ybo.science",
"ybo.trade",
"ynh.fr",
"nohost.me",
"noho.st",
"za.net",
"za.org",
"bss.design",
"basicserver.io",
"virtualserver.io",
"enterprisecloud.nu"
]
},{}],106:[function(require,module,exports){
(function (global){(function (){
/*! https://mths.be/punycode v1.4.1 by @mathias */
!function(e){var o="object"==typeof exports&&exports&&!exports.nodeType&&exports,n="object"==typeof module&&module&&!module.nodeType&&module,t="object"==typeof global&&global;t.global!==t&&t.window!==t&&t.self!==t||(e=t);var r,u,i=2147483647,f=36,c=1,l=26,s=38,d=700,p=72,a=128,h="-",v=/^xn--/,g=/[^\x20-\x7E]/,w=/[\x2E\u3002\uFF0E\uFF61]/g,x={overflow:"Overflow: input needs wider integers to process","not-basic":"Illegal input >= 0x80 (not a basic code point)","invalid-input":"Invalid input"},b=f-c,y=Math.floor,C=String.fromCharCode;function m(e){throw new RangeError(x[e])}function j(e,o){for(var n=e.length,t=[];n--;)t[n]=o(e[n]);return t}function A(e,o){var n=e.split("@"),t="";return n.length>1&&(t=n[0]+"@",e=n[1]),t+j((e=e.replace(w,".")).split("."),o).join(".")}function I(e){for(var o,n,t=[],r=0,u=e.length;r<u;)(o=e.charCodeAt(r++))>=55296&&o<=56319&&r<u?56320==(64512&(n=e.charCodeAt(r++)))?t.push(((1023&o)<<10)+(1023&n)+65536):(t.push(o),r--):t.push(o);return t}function E(e){return j(e,(function(e){var o="";return e>65535&&(o+=C((e-=65536)>>>10&1023|55296),e=56320|1023&e),o+=C(e)})).join("")}function F(e,o){return e+22+75*(e<26)-((0!=o)<<5)}function O(e,o,n){var t=0;for(e=n?y(e/d):e>>1,e+=y(e/o);e>b*l>>1;t+=f)e=y(e/b);return y(t+(b+1)*e/(e+s))}function S(e){var o,n,t,r,u,s,d,v,g,w,x,b=[],C=e.length,j=0,A=a,I=p;for((n=e.lastIndexOf(h))<0&&(n=0),t=0;t<n;++t)e.charCodeAt(t)>=128&&m("not-basic"),b.push(e.charCodeAt(t));for(r=n>0?n+1:0;r<C;){for(u=j,s=1,d=f;r>=C&&m("invalid-input"),((v=(x=e.charCodeAt(r++))-48<10?x-22:x-65<26?x-65:x-97<26?x-97:f)>=f||v>y((i-j)/s))&&m("overflow"),j+=v*s,!(v<(g=d<=I?c:d>=I+l?l:d-I));d+=f)s>y(i/(w=f-g))&&m("overflow"),s*=w;I=O(j-u,o=b.length+1,0==u),y(j/o)>i-A&&m("overflow"),A+=y(j/o),j%=o,b.splice(j++,0,A)}return E(b)}function T(e){var o,n,t,r,u,s,d,v,g,w,x,b,j,A,E,S=[];for(b=(e=I(e)).length,o=a,n=0,u=p,s=0;s<b;++s)(x=e[s])<128&&S.push(C(x));for(t=r=S.length,r&&S.push(h);t<b;){for(d=i,s=0;s<b;++s)(x=e[s])>=o&&x<d&&(d=x);for(d-o>y((i-n)/(j=t+1))&&m("overflow"),n+=(d-o)*j,o=d,s=0;s<b;++s)if((x=e[s])<o&&++n>i&&m("overflow"),x==o){for(v=n,g=f;!(v<(w=g<=u?c:g>=u+l?l:g-u));g+=f)E=v-w,A=f-w,S.push(C(F(w+E%A,0))),v=y(E/A);S.push(C(F(v,0))),u=O(n,j,t==r),n=0,++t}++n,++o}return S.join("")}if(r={version:"1.4.1",ucs2:{decode:I,encode:E},decode:S,encode:T,toASCII:function(e){return A(e,(function(e){return g.test(e)?"xn--"+T(e):e}))},toUnicode:function(e){return A(e,(function(e){return v.test(e)?S(e.slice(4).toLowerCase()):e}))}},"function"==typeof define&&"object"==typeof define.amd&&define.amd)define("punycode",(function(){return r}));else if(o&&n)if(module.exports==o)n.exports=r;else for(u in r)r.hasOwnProperty(u)&&(o[u]=r[u]);else e.punycode=r}(this);

}).call(this)}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})
},{}],111:[function(require,module,exports){
/** @license React v16.13.1
 * react-is.development.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
"use strict";"production"!=="production"&&function(){var e="function"==typeof Symbol&&Symbol.for,t=e?Symbol.for("react.element"):60103,o=e?Symbol.for("react.portal"):60106,r=e?Symbol.for("react.fragment"):60107,n=e?Symbol.for("react.strict_mode"):60108,s=e?Symbol.for("react.profiler"):60114,c=e?Symbol.for("react.provider"):60109,a=e?Symbol.for("react.context"):60110,f=e?Symbol.for("react.async_mode"):60111,p=e?Symbol.for("react.concurrent_mode"):60111,i=e?Symbol.for("react.forward_ref"):60112,u=e?Symbol.for("react.suspense"):60113,y=e?Symbol.for("react.suspense_list"):60120,l=e?Symbol.for("react.memo"):60115,m=e?Symbol.for("react.lazy"):60116,x=e?Symbol.for("react.block"):60121,d=e?Symbol.for("react.fundamental"):60117,b=e?Symbol.for("react.responder"):60118,S=e?Symbol.for("react.scope"):60119;function $(e){if("object"==typeof e&&null!==e){var y=e.$$typeof;switch(y){case t:var x=e.type;switch(x){case f:case p:case r:case s:case n:case u:return x;default:var d=x&&x.$$typeof;switch(d){case a:case i:case m:case l:case c:return d;default:return y}}case o:return y}}}var v=f,M=p,C=a,w=c,h=t,P=i,_=r,E=m,R=l,g=o,A=s,F=n,I=u,j=!1;function z(e){return $(e)===p}exports.AsyncMode=v,exports.ConcurrentMode=M,exports.ContextConsumer=C,exports.ContextProvider=w,exports.Element=h,exports.ForwardRef=P,exports.Fragment=_,exports.Lazy=E,exports.Memo=R,exports.Portal=g,exports.Profiler=A,exports.StrictMode=F,exports.Suspense=I,exports.isAsyncMode=function(e){return j||(j=!0,console.warn("The ReactIs.isAsyncMode() alias has been deprecated, and will be removed in React 17+. Update your code to use ReactIs.isConcurrentMode() instead. It has the exact same API.")),z(e)||$(e)===f},exports.isConcurrentMode=z,exports.isContextConsumer=function(e){return $(e)===a},exports.isContextProvider=function(e){return $(e)===c},exports.isElement=function(e){return"object"==typeof e&&null!==e&&e.$$typeof===t},exports.isForwardRef=function(e){return $(e)===i},exports.isFragment=function(e){return $(e)===r},exports.isLazy=function(e){return $(e)===m},exports.isMemo=function(e){return $(e)===l},exports.isPortal=function(e){return $(e)===o},exports.isProfiler=function(e){return $(e)===s},exports.isStrictMode=function(e){return $(e)===n},exports.isSuspense=function(e){return $(e)===u},exports.isValidElementType=function(e){return"string"==typeof e||"function"==typeof e||e===r||e===p||e===s||e===n||e===u||e===y||"object"==typeof e&&null!==e&&(e.$$typeof===m||e.$$typeof===l||e.$$typeof===c||e.$$typeof===a||e.$$typeof===i||e.$$typeof===d||e.$$typeof===b||e.$$typeof===S||e.$$typeof===x)},exports.typeOf=$}();

},{}],112:[function(require,module,exports){
/** @license React v16.13.1
 * react-is.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
"use strict";var b="function"==typeof Symbol&&Symbol.for,c=b?Symbol.for("react.element"):60103,d=b?Symbol.for("react.portal"):60106,e=b?Symbol.for("react.fragment"):60107,f=b?Symbol.for("react.strict_mode"):60108,g=b?Symbol.for("react.profiler"):60114,h=b?Symbol.for("react.provider"):60109,k=b?Symbol.for("react.context"):60110,l=b?Symbol.for("react.async_mode"):60111,m=b?Symbol.for("react.concurrent_mode"):60111,n=b?Symbol.for("react.forward_ref"):60112,p=b?Symbol.for("react.suspense"):60113,q=b?Symbol.for("react.suspense_list"):60120,r=b?Symbol.for("react.memo"):60115,t=b?Symbol.for("react.lazy"):60116,v=b?Symbol.for("react.block"):60121,w=b?Symbol.for("react.fundamental"):60117,x=b?Symbol.for("react.responder"):60118,y=b?Symbol.for("react.scope"):60119;function z(o){if("object"==typeof o&&null!==o){var s=o.$$typeof;switch(s){case c:switch(o=o.type){case l:case m:case e:case g:case f:case p:return o;default:switch(o=o&&o.$$typeof){case k:case n:case t:case r:case h:return o;default:return s}}case d:return s}}}function A(e){return z(e)===m}exports.AsyncMode=l,exports.ConcurrentMode=m,exports.ContextConsumer=k,exports.ContextProvider=h,exports.Element=c,exports.ForwardRef=n,exports.Fragment=e,exports.Lazy=t,exports.Memo=r,exports.Portal=d,exports.Profiler=g,exports.StrictMode=f,exports.Suspense=p,exports.isAsyncMode=function(e){return A(e)||z(e)===l},exports.isConcurrentMode=A,exports.isContextConsumer=function(e){return z(e)===k},exports.isContextProvider=function(e){return z(e)===h},exports.isElement=function(e){return"object"==typeof e&&null!==e&&e.$$typeof===c},exports.isForwardRef=function(e){return z(e)===n},exports.isFragment=function(r){return z(r)===e},exports.isLazy=function(e){return z(e)===t},exports.isMemo=function(e){return z(e)===r},exports.isPortal=function(e){return z(e)===d},exports.isProfiler=function(e){return z(e)===g},exports.isStrictMode=function(e){return z(e)===f},exports.isSuspense=function(e){return z(e)===p},exports.isValidElementType=function(o){return"string"==typeof o||"function"==typeof o||o===e||o===m||o===g||o===f||o===p||o===q||"object"==typeof o&&null!==o&&(o.$$typeof===t||o.$$typeof===r||o.$$typeof===h||o.$$typeof===k||o.$$typeof===n||o.$$typeof===w||o.$$typeof===x||o.$$typeof===y||o.$$typeof===v)},exports.typeOf=z;

},{}],117:[function(require,module,exports){
"use strict";function createInvalidArgFactory(e,r){return(t,n)=>{throw new Error(`Invalid value of type ${typeof e} for ${r} argument when connecting component ${n.wrappedComponentName}.`)}}exports.__esModule=!0,exports.createInvalidArgFactory=createInvalidArgFactory;

},{}],130:[function(require,module,exports){
"use strict";

},{}],132:[function(require,module,exports){
"use strict";function defaultNoopBatch(t){t()}exports.__esModule=!0,exports.getBatch=exports.setBatch=void 0;let batch=defaultNoopBatch;const setBatch=t=>batch=t;exports.setBatch=setBatch;const getBatch=()=>batch;exports.getBatch=getBatch;

},{}],133:[function(require,module,exports){
"use strict";function bindActionCreators(t,o){const n={};for(const e in t){const r=t[e];"function"==typeof r&&(n[e]=(...t)=>o(r(...t)))}return n}exports.__esModule=!0,exports.default=bindActionCreators;

},{}],134:[function(require,module,exports){
"use strict";function isPlainObject(t){if("object"!=typeof t||null===t)return!1;let e=Object.getPrototypeOf(t);if(null===e)return!0;let o=e;for(;null!==Object.getPrototypeOf(o);)o=Object.getPrototypeOf(o);return e===o}exports.__esModule=!0,exports.default=isPlainObject;

},{}],136:[function(require,module,exports){
"use strict";function is(t,e){return t===e?0!==t||0!==e||1/t==1/e:t!=t&&e!=e}function shallowEqual(t,e){if(is(t,e))return!0;if("object"!=typeof t||null===t||"object"!=typeof e||null===e)return!1;const r=Object.keys(t),l=Object.keys(e);if(r.length!==l.length)return!1;for(let l=0;l<r.length;l++)if(!Object.prototype.hasOwnProperty.call(e,r[l])||!is(t[r[l]],e[r[l]]))return!1;return!0}exports.__esModule=!0,exports.default=shallowEqual;

},{}],138:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.notInitialized=void 0;const notInitialized=()=>{throw new Error("uSES not initialized!")};exports.notInitialized=notInitialized;

},{}],140:[function(require,module,exports){
"use strict";function warning(o){"undefined"!=typeof console&&"function"==typeof console.error&&console.error(o);try{throw new Error(o)}catch(o){}}exports.__esModule=!0,exports.default=warning;

},{}],141:[function(require,module,exports){
/**
 * @license React
 * react-is.development.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
"use strict";"production"!=="production"&&function(){var e,r=Symbol.for("react.element"),t=Symbol.for("react.portal"),o=Symbol.for("react.fragment"),n=Symbol.for("react.strict_mode"),s=Symbol.for("react.profiler"),c=Symbol.for("react.provider"),a=Symbol.for("react.context"),f=Symbol.for("react.server_context"),i=Symbol.for("react.forward_ref"),p=Symbol.for("react.suspense"),u=Symbol.for("react.suspense_list"),l=Symbol.for("react.memo"),y=Symbol.for("react.lazy"),x=Symbol.for("react.offscreen");function m(e){if("object"==typeof e&&null!==e){var x=e.$$typeof;switch(x){case r:var m=e.type;switch(m){case o:case s:case n:case p:case u:return m;default:var d=m&&m.$$typeof;switch(d){case f:case a:case i:case y:case l:case c:return d;default:return x}}case t:return x}}}e=Symbol.for("react.module.reference");var d=a,b=c,S=r,$=i,v=o,w=y,M=l,C=t,h=s,P=n,R=p,g=u,E=!1,_=!1;exports.ContextConsumer=d,exports.ContextProvider=b,exports.Element=S,exports.ForwardRef=$,exports.Fragment=v,exports.Lazy=w,exports.Memo=M,exports.Portal=C,exports.Profiler=h,exports.StrictMode=P,exports.Suspense=R,exports.SuspenseList=g,exports.isAsyncMode=function(e){return E||(E=!0,console.warn("The ReactIs.isAsyncMode() alias has been deprecated, and will be removed in React 18+.")),!1},exports.isConcurrentMode=function(e){return _||(_=!0,console.warn("The ReactIs.isConcurrentMode() alias has been deprecated, and will be removed in React 18+.")),!1},exports.isContextConsumer=function(e){return m(e)===a},exports.isContextProvider=function(e){return m(e)===c},exports.isElement=function(e){return"object"==typeof e&&null!==e&&e.$$typeof===r},exports.isForwardRef=function(e){return m(e)===i},exports.isFragment=function(e){return m(e)===o},exports.isLazy=function(e){return m(e)===y},exports.isMemo=function(e){return m(e)===l},exports.isPortal=function(e){return m(e)===t},exports.isProfiler=function(e){return m(e)===s},exports.isStrictMode=function(e){return m(e)===n},exports.isSuspense=function(e){return m(e)===p},exports.isSuspenseList=function(e){return m(e)===u},exports.isValidElementType=function(r){return"string"==typeof r||"function"==typeof r||(r===o||r===s||r===n||r===p||r===u||r===x||"object"==typeof r&&null!==r&&(r.$$typeof===y||r.$$typeof===l||r.$$typeof===c||r.$$typeof===a||r.$$typeof===i||r.$$typeof===e||void 0!==r.getModuleId))},exports.typeOf=m}();

},{}],142:[function(require,module,exports){
/**
 * @license React
 * react-is.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
"use strict";var u,b=Symbol.for("react.element"),c=Symbol.for("react.portal"),d=Symbol.for("react.fragment"),e=Symbol.for("react.strict_mode"),f=Symbol.for("react.profiler"),g=Symbol.for("react.provider"),h=Symbol.for("react.context"),k=Symbol.for("react.server_context"),l=Symbol.for("react.forward_ref"),m=Symbol.for("react.suspense"),n=Symbol.for("react.suspense_list"),p=Symbol.for("react.memo"),q=Symbol.for("react.lazy"),t=Symbol.for("react.offscreen");function v(t){if("object"==typeof t&&null!==t){var r=t.$$typeof;switch(r){case b:switch(t=t.type){case d:case f:case e:case m:case n:return t;default:switch(t=t&&t.$$typeof){case k:case h:case l:case q:case p:case g:return t;default:return r}}case c:return r}}}u=Symbol.for("react.module.reference"),exports.ContextConsumer=h,exports.ContextProvider=g,exports.Element=b,exports.ForwardRef=l,exports.Fragment=d,exports.Lazy=q,exports.Memo=p,exports.Portal=c,exports.Profiler=f,exports.StrictMode=e,exports.Suspense=m,exports.SuspenseList=n,exports.isAsyncMode=function(){return!1},exports.isConcurrentMode=function(){return!1},exports.isContextConsumer=function(e){return v(e)===h},exports.isContextProvider=function(e){return v(e)===g},exports.isElement=function(e){return"object"==typeof e&&null!==e&&e.$$typeof===b},exports.isForwardRef=function(e){return v(e)===l},exports.isFragment=function(e){return v(e)===d},exports.isLazy=function(e){return v(e)===q},exports.isMemo=function(e){return v(e)===p},exports.isPortal=function(e){return v(e)===c},exports.isProfiler=function(e){return v(e)===f},exports.isStrictMode=function(t){return v(t)===e},exports.isSuspense=function(e){return v(e)===m},exports.isSuspenseList=function(e){return v(e)===n},exports.isValidElementType=function(r){return"string"==typeof r||"function"==typeof r||r===d||r===f||r===e||r===m||r===n||r===t||"object"==typeof r&&null!==r&&(r.$$typeof===q||r.$$typeof===p||r.$$typeof===g||r.$$typeof===h||r.$$typeof===l||r.$$typeof===u||void 0!==r.getModuleId)},exports.typeOf=v;

},{}],145:[function(require,module,exports){
/**
 * @license React
 * react.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
"use strict";var l=Symbol.for("react.element"),n=Symbol.for("react.portal"),p=Symbol.for("react.fragment"),q=Symbol.for("react.strict_mode"),r=Symbol.for("react.profiler"),t=Symbol.for("react.provider"),u=Symbol.for("react.context"),v=Symbol.for("react.forward_ref"),w=Symbol.for("react.suspense"),x=Symbol.for("react.memo"),y=Symbol.for("react.lazy"),z=Symbol.iterator;function A(e){return null===e||"object"!=typeof e?null:"function"==typeof(e=z&&e[z]||e["@@iterator"])?e:null}var B={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},C=Object.assign,D={};function E(e,t,r){this.props=e,this.context=t,this.refs=D,this.updater=r||B}function F(){}function G(e,t,r){this.props=e,this.context=t,this.refs=D,this.updater=r||B}E.prototype.isReactComponent={},E.prototype.setState=function(e,t){if("object"!=typeof e&&"function"!=typeof e&&null!=e)throw Error("setState(...): takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,e,t,"setState")},E.prototype.forceUpdate=function(e){this.updater.enqueueForceUpdate(this,e,"forceUpdate")},F.prototype=E.prototype;var H=G.prototype=new F;H.constructor=G,C(H,E.prototype),H.isPureReactComponent=!0;var I=Array.isArray,J=Object.prototype.hasOwnProperty,K={current:null},L={key:!0,ref:!0,__self:!0,__source:!0};function M(e,t,r){var n,o={},u=null,s=null;if(null!=t)for(n in void 0!==t.ref&&(s=t.ref),void 0!==t.key&&(u=""+t.key),t)J.call(t,n)&&!L.hasOwnProperty(n)&&(o[n]=t[n]);var a=arguments.length-2;if(1===a)o.children=r;else if(1<a){for(var c=Array(a),i=0;i<a;i++)c[i]=arguments[i+2];o.children=c}if(e&&e.defaultProps)for(n in a=e.defaultProps)void 0===o[n]&&(o[n]=a[n]);return{$$typeof:l,type:e,key:u,ref:s,props:o,_owner:K.current}}function N(e,t){return{$$typeof:l,type:e.type,key:t,ref:e.ref,props:e.props,_owner:e._owner}}function O(e){return"object"==typeof e&&null!==e&&e.$$typeof===l}function escape(e){var t={"=":"=0",":":"=2"};return"$"+e.replace(/[=:]/g,(function(e){return t[e]}))}var P=/\/+/g;function Q(e,t){return"object"==typeof e&&null!==e&&null!=e.key?escape(""+e.key):t.toString(36)}function R(e,t,r,o,u){var s=typeof e;"undefined"!==s&&"boolean"!==s||(e=null);var a=!1;if(null===e)a=!0;else switch(s){case"string":case"number":a=!0;break;case"object":switch(e.$$typeof){case l:case n:a=!0}}if(a)return u=u(a=e),e=""===o?"."+Q(a,0):o,I(u)?(r="",null!=e&&(r=e.replace(P,"$&/")+"/"),R(u,t,r,"",(function(e){return e}))):null!=u&&(O(u)&&(u=N(u,r+(!u.key||a&&a.key===u.key?"":(""+u.key).replace(P,"$&/")+"/")+e)),t.push(u)),1;if(a=0,o=""===o?".":o+":",I(e))for(var c=0;c<e.length;c++){var i=o+Q(s=e[c],c);a+=R(s,t,r,i,u)}else if("function"==typeof(i=A(e)))for(e=i.call(e),c=0;!(s=e.next()).done;)a+=R(s=s.value,t,r,i=o+Q(s,c++),u);else if("object"===s)throw t=String(e),Error("Objects are not valid as a React child (found: "+("[object Object]"===t?"object with keys {"+Object.keys(e).join(", ")+"}":t)+"). If you meant to render a collection of children, use an array instead.");return a}function S(e,t,r){if(null==e)return e;var n=[],o=0;return R(e,n,"","",(function(e){return t.call(r,e,o++)})),n}function T(e){if(-1===e._status){var t=e._result;(t=t()).then((function(t){0!==e._status&&-1!==e._status||(e._status=1,e._result=t)}),(function(t){0!==e._status&&-1!==e._status||(e._status=2,e._result=t)})),-1===e._status&&(e._status=0,e._result=t)}if(1===e._status)return e._result.default;throw e._result}var U={current:null},V={transition:null},W={ReactCurrentDispatcher:U,ReactCurrentBatchConfig:V,ReactCurrentOwner:K};exports.Children={map:S,forEach:function(e,t,r){S(e,(function(){t.apply(this,arguments)}),r)},count:function(e){var t=0;return S(e,(function(){t++})),t},toArray:function(e){return S(e,(function(e){return e}))||[]},only:function(e){if(!O(e))throw Error("React.Children.only expected to receive a single React element child.");return e}},exports.Component=E,exports.Fragment=p,exports.Profiler=r,exports.PureComponent=G,exports.StrictMode=q,exports.Suspense=w,exports.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED=W,exports.cloneElement=function(e,t,r){if(null==e)throw Error("React.cloneElement(...): The argument must be a React element, but you passed "+e+".");var n=C({},e.props),o=e.key,u=e.ref,s=e._owner;if(null!=t){if(void 0!==t.ref&&(u=t.ref,s=K.current),void 0!==t.key&&(o=""+t.key),e.type&&e.type.defaultProps)var a=e.type.defaultProps;for(c in t)J.call(t,c)&&!L.hasOwnProperty(c)&&(n[c]=void 0===t[c]&&void 0!==a?a[c]:t[c])}var c=arguments.length-2;if(1===c)n.children=r;else if(1<c){a=Array(c);for(var i=0;i<c;i++)a[i]=arguments[i+2];n.children=a}return{$$typeof:l,type:e.type,key:o,ref:u,props:n,_owner:s}},exports.createContext=function(e){return(e={$$typeof:u,_currentValue:e,_currentValue2:e,_threadCount:0,Provider:null,Consumer:null,_defaultValue:null,_globalName:null}).Provider={$$typeof:t,_context:e},e.Consumer=e},exports.createElement=M,exports.createFactory=function(e){var t=M.bind(null,e);return t.type=e,t},exports.createRef=function(){return{current:null}},exports.forwardRef=function(e){return{$$typeof:v,render:e}},exports.isValidElement=O,exports.lazy=function(e){return{$$typeof:y,_payload:{_status:-1,_result:e},_init:T}},exports.memo=function(e,t){return{$$typeof:x,type:e,compare:void 0===t?null:t}},exports.startTransition=function(e){var t=V.transition;V.transition={};try{e()}finally{V.transition=t}},exports.unstable_act=function(){throw Error("act(...) is not supported in production builds of React.")},exports.useCallback=function(e,t){return U.current.useCallback(e,t)},exports.useContext=function(e){return U.current.useContext(e)},exports.useDebugValue=function(){},exports.useDeferredValue=function(e){return U.current.useDeferredValue(e)},exports.useEffect=function(e,t){return U.current.useEffect(e,t)},exports.useId=function(){return U.current.useId()},exports.useImperativeHandle=function(e,t,r){return U.current.useImperativeHandle(e,t,r)},exports.useInsertionEffect=function(e,t){return U.current.useInsertionEffect(e,t)},exports.useLayoutEffect=function(e,t){return U.current.useLayoutEffect(e,t)},exports.useMemo=function(e,t){return U.current.useMemo(e,t)},exports.useReducer=function(e,t,r){return U.current.useReducer(e,t,r)},exports.useRef=function(e){return U.current.useRef(e)},exports.useState=function(e){return U.current.useState(e)},exports.useSyncExternalStore=function(e,t,r){return U.current.useSyncExternalStore(e,t,r)},exports.useTransition=function(){return U.current.useTransition()},exports.version="18.2.0";

},{}],148:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.DEFAULT_VERSION=exports.REGISTER=exports.PURGE=exports.PERSIST=exports.PAUSE=exports.REHYDRATE=exports.FLUSH=exports.KEY_PREFIX=void 0;var KEY_PREFIX="persist:";exports.KEY_PREFIX=KEY_PREFIX;var FLUSH="persist/FLUSH";exports.FLUSH=FLUSH;var REHYDRATE="persist/REHYDRATE";exports.REHYDRATE=REHYDRATE;var PAUSE="persist/PAUSE";exports.PAUSE=PAUSE;var PERSIST="persist/PERSIST";exports.PERSIST=PERSIST;var PURGE="persist/PURGE";exports.PURGE=PURGE;var REGISTER="persist/REGISTER";exports.REGISTER=REGISTER;var DEFAULT_VERSION=-1;exports.DEFAULT_VERSION=DEFAULT_VERSION;

},{}],151:[function(require,module,exports){
"use strict";function createTransform(n,t){var e=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},r=e.whitelist||null,u=e.blacklist||null;function i(n){return!(!r||-1!==r.indexOf(n))||!(!u||-1===u.indexOf(n))}return{in:function(t,e,r){return!i(e)&&n?n(t,e,r):t},out:function(n,e,r){return!i(e)&&t?t(n,e,r):n}}}exports.__esModule=!0,exports.default=createTransform;

},{}],159:[function(require,module,exports){
"use strict";function _typeof(e){return _typeof="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},_typeof(e)}function ownKeys(e,t){var o=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter((function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable}))),o.push.apply(o,r)}return o}function _objectSpread(e){for(var t=1;t<arguments.length;t++){var o=null!=arguments[t]?arguments[t]:{};t%2?ownKeys(o,!0).forEach((function(t){_defineProperty(e,t,o[t])})):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(o)):ownKeys(o).forEach((function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(o,t))}))}return e}function _defineProperty(e,t,o){return t in e?Object.defineProperty(e,t,{value:o,enumerable:!0,configurable:!0,writable:!0}):e[t]=o,e}function autoMergeLevel1(e,t,o,r){var n=r.debug,c=_objectSpread({},o);return e&&"object"===_typeof(e)&&Object.keys(e).forEach((function(r){"_persist"!==r&&(t[r]===o[r]?c[r]=e[r]:"production"!=="production"&&n&&console.log("redux-persist/stateReconciler: sub state for key `%s` modified, skipping.",r))})),"production"!=="production"&&n&&e&&"object"===_typeof(e)&&console.log("redux-persist/stateReconciler: rehydrated keys '".concat(Object.keys(e).join(", "),"'")),c}exports.__esModule=!0,exports.default=autoMergeLevel1;

},{}],160:[function(require,module,exports){
"use strict";function _typeof(e){return _typeof="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},_typeof(e)}function ownKeys(e,t){var o=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter((function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable}))),o.push.apply(o,r)}return o}function _objectSpread(e){for(var t=1;t<arguments.length;t++){var o=null!=arguments[t]?arguments[t]:{};t%2?ownKeys(o,!0).forEach((function(t){_defineProperty(e,t,o[t])})):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(o)):ownKeys(o).forEach((function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(o,t))}))}return e}function _defineProperty(e,t,o){return t in e?Object.defineProperty(e,t,{value:o,enumerable:!0,configurable:!0,writable:!0}):e[t]=o,e}function autoMergeLevel2(e,t,o,r){var n=r.debug,c=_objectSpread({},o);return e&&"object"===_typeof(e)&&Object.keys(e).forEach((function(r){"_persist"!==r&&(t[r]===o[r]?isPlainEnoughObject(o[r])?c[r]=_objectSpread({},c[r],{},e[r]):c[r]=e[r]:"production"!=="production"&&n&&console.log("redux-persist/stateReconciler: sub state for key `%s` modified, skipping.",r))})),"production"!=="production"&&n&&e&&"object"===_typeof(e)&&console.log("redux-persist/stateReconciler: rehydrated keys '".concat(Object.keys(e).join(", "),"'")),c}function isPlainEnoughObject(e){return null!==e&&!Array.isArray(e)&&"object"===_typeof(e)}exports.__esModule=!0,exports.default=autoMergeLevel2;

},{}],162:[function(require,module,exports){
"use strict";function _typeof(e){return _typeof="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},_typeof(e)}function noop(){}exports.__esModule=!0,exports.default=getStorage;var noopStorage={getItem:noop,setItem:noop,removeItem:noop};function hasStorage(e){if("object"!==("undefined"==typeof self?"undefined":_typeof(self))||!(e in self))return!1;try{var t=self[e],o="redux-persist ".concat(e," test");t.setItem(o,"test"),t.getItem(o),t.removeItem(o)}catch(t){return"production"!=="production"&&console.warn("redux-persist ".concat(e," test failed, persistence will be disabled.")),!1}return!0}function getStorage(e){var t="".concat(e,"Storage");return hasStorage(t)?self[t]:("production"!=="production"&&console.error("redux-persist failed to create sync storage. falling back to noop storage."),noopStorage)}

},{}],164:[function(require,module,exports){
"use strict";function createThunkMiddleware(e){return function(t){var r=t.dispatch,u=t.getState;return function(t){return function(n){return"function"==typeof n?n(r,u,e):t(n)}}}}Object.defineProperty(exports,"__esModule",{value:!0}),exports.default=void 0;var thunk=createThunkMiddleware();thunk.withExtraArgument=createThunkMiddleware;var _default=thunk;exports.default=_default;

},{}],166:[function(require,module,exports){
var characterMap={"À":"A","Á":"A","Â":"A","Ã":"A","Ä":"A","Å":"A","Ấ":"A","Ắ":"A","Ẳ":"A","Ẵ":"A","Ặ":"A","Æ":"AE","Ầ":"A","Ằ":"A","Ȃ":"A","Ç":"C","Ḉ":"C","È":"E","É":"E","Ê":"E","Ë":"E","Ế":"E","Ḗ":"E","Ề":"E","Ḕ":"E","Ḝ":"E","Ȇ":"E","Ì":"I","Í":"I","Î":"I","Ï":"I","Ḯ":"I","Ȋ":"I","Ð":"D","Ñ":"N","Ò":"O","Ó":"O","Ô":"O","Õ":"O","Ö":"O","Ø":"O","Ố":"O","Ṍ":"O","Ṓ":"O","Ȏ":"O","Ù":"U","Ú":"U","Û":"U","Ü":"U","Ý":"Y","à":"a","á":"a","â":"a","ã":"a","ä":"a","å":"a","ấ":"a","ắ":"a","ẳ":"a","ẵ":"a","ặ":"a","æ":"ae","ầ":"a","ằ":"a","ȃ":"a","ç":"c","ḉ":"c","è":"e","é":"e","ê":"e","ë":"e","ế":"e","ḗ":"e","ề":"e","ḕ":"e","ḝ":"e","ȇ":"e","ì":"i","í":"i","î":"i","ï":"i","ḯ":"i","ȋ":"i","ð":"d","ñ":"n","ò":"o","ó":"o","ô":"o","õ":"o","ö":"o","ø":"o","ố":"o","ṍ":"o","ṓ":"o","ȏ":"o","ù":"u","ú":"u","û":"u","ü":"u","ý":"y","ÿ":"y","Ā":"A","ā":"a","Ă":"A","ă":"a","Ą":"A","ą":"a","Ć":"C","ć":"c","Ĉ":"C","ĉ":"c","Ċ":"C","ċ":"c","Č":"C","č":"c","C̆":"C","c̆":"c","Ď":"D","ď":"d","Đ":"D","đ":"d","Ē":"E","ē":"e","Ĕ":"E","ĕ":"e","Ė":"E","ė":"e","Ę":"E","ę":"e","Ě":"E","ě":"e","Ĝ":"G","Ǵ":"G","ĝ":"g","ǵ":"g","Ğ":"G","ğ":"g","Ġ":"G","ġ":"g","Ģ":"G","ģ":"g","Ĥ":"H","ĥ":"h","Ħ":"H","ħ":"h","Ḫ":"H","ḫ":"h","Ĩ":"I","ĩ":"i","Ī":"I","ī":"i","Ĭ":"I","ĭ":"i","Į":"I","į":"i","İ":"I","ı":"i","Ĳ":"IJ","ĳ":"ij","Ĵ":"J","ĵ":"j","Ķ":"K","ķ":"k","Ḱ":"K","ḱ":"k","K̆":"K","k̆":"k","Ĺ":"L","ĺ":"l","Ļ":"L","ļ":"l","Ľ":"L","ľ":"l","Ŀ":"L","ŀ":"l","Ł":"l","ł":"l","Ḿ":"M","ḿ":"m","M̆":"M","m̆":"m","Ń":"N","ń":"n","Ņ":"N","ņ":"n","Ň":"N","ň":"n","ŉ":"n","N̆":"N","n̆":"n","Ō":"O","ō":"o","Ŏ":"O","ŏ":"o","Ő":"O","ő":"o","Œ":"OE","œ":"oe","P̆":"P","p̆":"p","Ŕ":"R","ŕ":"r","Ŗ":"R","ŗ":"r","Ř":"R","ř":"r","R̆":"R","r̆":"r","Ȓ":"R","ȓ":"r","Ś":"S","ś":"s","Ŝ":"S","ŝ":"s","Ş":"S","Ș":"S","ș":"s","ş":"s","Š":"S","š":"s","Ţ":"T","ţ":"t","ț":"t","Ț":"T","Ť":"T","ť":"t","Ŧ":"T","ŧ":"t","T̆":"T","t̆":"t","Ũ":"U","ũ":"u","Ū":"U","ū":"u","Ŭ":"U","ŭ":"u","Ů":"U","ů":"u","Ű":"U","ű":"u","Ų":"U","ų":"u","Ȗ":"U","ȗ":"u","V̆":"V","v̆":"v","Ŵ":"W","ŵ":"w","Ẃ":"W","ẃ":"w","X̆":"X","x̆":"x","Ŷ":"Y","ŷ":"y","Ÿ":"Y","Y̆":"Y","y̆":"y","Ź":"Z","ź":"z","Ż":"Z","ż":"z","Ž":"Z","ž":"z","ſ":"s","ƒ":"f","Ơ":"O","ơ":"o","Ư":"U","ư":"u","Ǎ":"A","ǎ":"a","Ǐ":"I","ǐ":"i","Ǒ":"O","ǒ":"o","Ǔ":"U","ǔ":"u","Ǖ":"U","ǖ":"u","Ǘ":"U","ǘ":"u","Ǚ":"U","ǚ":"u","Ǜ":"U","ǜ":"u","Ứ":"U","ứ":"u","Ṹ":"U","ṹ":"u","Ǻ":"A","ǻ":"a","Ǽ":"AE","ǽ":"ae","Ǿ":"O","ǿ":"o","Þ":"TH","þ":"th","Ṕ":"P","ṕ":"p","Ṥ":"S","ṥ":"s","X́":"X","x́":"x","Ѓ":"Г","ѓ":"г","Ќ":"К","ќ":"к","A̋":"A","a̋":"a","E̋":"E","e̋":"e","I̋":"I","i̋":"i","Ǹ":"N","ǹ":"n","Ồ":"O","ồ":"o","Ṑ":"O","ṑ":"o","Ừ":"U","ừ":"u","Ẁ":"W","ẁ":"w","Ỳ":"Y","ỳ":"y","Ȁ":"A","ȁ":"a","Ȅ":"E","ȅ":"e","Ȉ":"I","ȉ":"i","Ȍ":"O","ȍ":"o","Ȑ":"R","ȑ":"r","Ȕ":"U","ȕ":"u","B̌":"B","b̌":"b","Č̣":"C","č̣":"c","Ê̌":"E","ê̌":"e","F̌":"F","f̌":"f","Ǧ":"G","ǧ":"g","Ȟ":"H","ȟ":"h","J̌":"J","ǰ":"j","Ǩ":"K","ǩ":"k","M̌":"M","m̌":"m","P̌":"P","p̌":"p","Q̌":"Q","q̌":"q","Ř̩":"R","ř̩":"r","Ṧ":"S","ṧ":"s","V̌":"V","v̌":"v","W̌":"W","w̌":"w","X̌":"X","x̌":"x","Y̌":"Y","y̌":"y","A̧":"A","a̧":"a","B̧":"B","b̧":"b","Ḑ":"D","ḑ":"d","Ȩ":"E","ȩ":"e","Ɛ̧":"E","ɛ̧":"e","Ḩ":"H","ḩ":"h","I̧":"I","i̧":"i","Ɨ̧":"I","ɨ̧":"i","M̧":"M","m̧":"m","O̧":"O","o̧":"o","Q̧":"Q","q̧":"q","U̧":"U","u̧":"u","X̧":"X","x̧":"x","Z̧":"Z","z̧":"z"},chars=Object.keys(characterMap).join("|"),allAccents=new RegExp(chars,"g"),firstAccent=new RegExp(chars,""),removeAccents=function(e){return e.replace(allAccents,(function(e){return characterMap[e]}))},hasAccents=function(e){return!!e.match(firstAccent)};module.exports=removeAccents,module.exports.has=hasAccents,module.exports.remove=removeAccents;

},{}],167:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.createCacheKeyComparator=createCacheKeyComparator,exports.defaultEqualityCheck=void 0,exports.defaultMemoize=defaultMemoize;var NOT_FOUND="NOT_FOUND";function createSingletonCache(e){var t;return{get:function(r){return t&&e(t.key,r)?t.value:NOT_FOUND},put:function(e,r){t={key:e,value:r}},getEntries:function(){return t?[t]:[]},clear:function(){t=void 0}}}function createLruCache(e,t){var r=[];function n(e){var n=r.findIndex((function(r){return t(e,r.key)}));if(n>-1){var u=r[n];return n>0&&(r.splice(n,1),r.unshift(u)),u.value}return NOT_FOUND}return{get:n,put:function(t,u){n(t)===NOT_FOUND&&(r.unshift({key:t,value:u}),r.length>e&&r.pop())},getEntries:function(){return r},clear:function(){r=[]}}}var defaultEqualityCheck=function(e,t){return e===t};function createCacheKeyComparator(e){return function(t,r){if(null===t||null===r||t.length!==r.length)return!1;for(var n=t.length,u=0;u<n;u++)if(!e(t[u],r[u]))return!1;return!0}}function defaultMemoize(e,t){var r="object"==typeof t?t:{equalityCheck:t},n=r.equalityCheck,u=void 0===n?defaultEqualityCheck:n,a=r.maxSize,c=void 0===a?1:a,i=r.resultEqualityCheck,o=createCacheKeyComparator(u),l=1===c?createSingletonCache(o):createLruCache(c,o);function f(){var t=l.get(arguments);if(t===NOT_FOUND){if(t=e.apply(null,arguments),i){var r=l.getEntries().find((function(e){return i(e.value,t)}));r&&(t=r.value)}l.put(arguments,t)}return t}return f.clearCache=function(){return l.clear()},f}exports.defaultEqualityCheck=defaultEqualityCheck;

},{}],172:[function(require,module,exports){
module.exports={ROOT:0,GROUP:1,POSITION:2,SET:3,RANGE:4,REPETITION:5,REFERENCE:6,CHAR:7};

},{}],176:[function(require,module,exports){
"use strict";module.exports=function(e,l,t){let u=Object.create(null);if(null!=l)for(let e of l)u[e]=[];for(let[l,n]of e.entries()){let e=t(n,l);null!=e&&(null==u[e]&&(u[e]=[]),u[e].push(n))}return u};

},{}],179:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],180:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],181:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],182:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],183:[function(require,module,exports){
"use strict";var __extends=this&&this.__extends||function(){var t=function(e,r){return t=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(t,e){t.__proto__=e}||function(t,e){for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&(t[r]=e[r])},t(e,r)};return function(e,r){if("function"!=typeof r&&null!==r)throw new TypeError("Class extends value "+String(r)+" is not a constructor or null");function o(){this.constructor=e}t(e,r),e.prototype=null===r?Object.create(r):(o.prototype=r.prototype,new o)}}();Object.defineProperty(exports,"__esModule",{value:!0}),exports.TypeGuardError=void 0;var TypeGuardError=function(t){function e(e){var r=this.constructor,o=t.call(this,e.message||"Error on ".concat(e.method,"(): invalid type").concat(e.path?" on ".concat(e.path):"",", expect to be ").concat(e.expected))||this,n=r.prototype;return Object.setPrototypeOf?Object.setPrototypeOf(o,n):o.__proto__=n,o.method=e.method,o.path=e.path,o.expected=e.expected,o.value=e.value,o}return __extends(e,t),e}(Error);exports.TypeGuardError=TypeGuardError;

},{}],184:[function(require,module,exports){
"use strict";var $HeadersReader;Object.defineProperty(exports,"__esModule",{value:!0}),exports.$HeadersReader=void 0,function(e){e.boolean=function(e){return void 0!==e?"true"===e||"false"!==e&&e:void 0},e.bigint=function(e){return void 0!==e?toBigint(e):void 0},e.number=function(e){return void 0!==e?toNumber(e):void 0},e.string=function(e){return e}}($HeadersReader||(exports.$HeadersReader=$HeadersReader={}));var toNumber=function(e){var r=Number(e);return isNaN(r)?e:r},toBigint=function(e){try{return BigInt(e)}catch(r){return e}};

},{}],185:[function(require,module,exports){
"use strict";var $ParameterReader;Object.defineProperty(exports,"__esModule",{value:!0}),exports.$ParameterReader=void 0,function(e){e.boolean=function(e){return"null"!==e?"true"===e||"1"===e||"false"!==e&&"0"!==e&&e:null},e.bigint=function(e){return"null"!==e?toBigint(e):null},e.number=function(e){return"null"!==e?toNumber(e):null},e.string=function(e){return"null"!==e?e:null}}($ParameterReader||(exports.$ParameterReader=$ParameterReader={}));var toNumber=function(e){var r=Number(e);return isNaN(r)?e:r},toBigint=function(e){try{return BigInt(e)}catch(r){return e}};

},{}],186:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.$ProtobufReader=void 0;var $ProtobufReader=function(){function t(t){this.buf=t,this.ptr=0,this.view=new DataView(t.buffer)}return t.prototype.index=function(){return this.ptr},t.prototype.size=function(){return this.buf.length},t.prototype.uint32=function(){return this.varint32()},t.prototype.int32=function(){return this.varint32()},t.prototype.sint32=function(){var t=this.varint32();return t>>>1^-(1&t)},t.prototype.uint64=function(){return this.varint64()},t.prototype.int64=function(){return this.varint64()},t.prototype.sint64=function(){var t=this.varint64();return t>>N01^-(t&N01)},t.prototype.bool=function(){return 0!==this.varint32()},t.prototype.float=function(){var t=this.view.getFloat32(this.ptr,!0);return this.ptr+=4,t},t.prototype.double=function(){var t=this.view.getFloat64(this.ptr,!0);return this.ptr+=8,t},t.prototype.bytes=function(){var t=this.uint32(),i=this.ptr;return this.ptr+=t,this.buf.subarray(i,i+t)},t.prototype.string=function(){return utf8.decode(this.bytes())},t.prototype.skip=function(t){if(0===t)for(;128&this.u8(););else{if(this.index()+t>this.size())throw new Error("Error on typia.protobuf.decode(): buffer overflow.");this.ptr+=t}},t.prototype.skipType=function(t){switch(t){case 0:this.skip(0);break;case 1:this.skip(8);break;case 2:this.skip(this.uint32());break;case 3:for(;4!=(t=7&this.uint32());)this.skipType(t);break;case 5:this.skip(4);break;default:throw new Error("Invalid wire type ".concat(t," at offset ").concat(this.ptr,"."))}},t.prototype.varint32=function(){var t,i;return i=127&(t=this.u8()),t<128?i:(i|=(127&(t=this.u8()))<<7,t<128?i:(i|=(127&(t=this.u8()))<<14,t<128?i:(i|=(127&(t=this.u8()))<<21,t<128||(i|=(15&(t=this.u8()))<<28,t<128||this.u8()<128||this.u8()<128||this.u8()<128||this.u8()<128||this.u8()),i)))},t.prototype.varint64=function(){var t,i;return i=(t=this.u8n())&N7F,t<N80?i:(i|=((t=this.u8n())&N7F)<<BigInt(7),t<N80?i:(i|=((t=this.u8n())&N7F)<<BigInt(14),t<N80?i:(i|=((t=this.u8n())&N7F)<<BigInt(21),t<N80?i:(i|=((t=this.u8n())&N7F)<<BigInt(28),t<N80?i:(i|=((t=this.u8n())&N7F)<<BigInt(35),t<N80?i:(i|=((t=this.u8n())&N7F)<<BigInt(42),t<N80?i:(i|=((t=this.u8n())&N7F)<<BigInt(49),t<N80?i:(i|=((t=this.u8n())&N7F)<<BigInt(56),t<N80?i:(i|=(this.u8n()&N01)<<BigInt(63),BigInt.asIntN(64,i))))))))))},t.prototype.u8=function(){return this.view.getUint8(this.ptr++)},t.prototype.u8n=function(){return BigInt(this.u8())},t}();exports.$ProtobufReader=$ProtobufReader;var utf8=new TextDecoder,N01=BigInt(1),N7F=BigInt(127),N80=BigInt(128);

},{}],188:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.$ProtobufWriter=void 0;var $ProtobufWriter=function(){function t(t){this.sizer=t,this.buf=new Uint8Array(t.len),this.view=new DataView(this.buf.buffer),this.ptr=0,this.varlenidx=0}return t.prototype.buffer=function(){return this.buf},t.prototype.bool=function(t){this.byte(t?1:0)},t.prototype.byte=function(t){this.buf[this.ptr++]=255&t},t.prototype.int32=function(t){t<0?this.int64(t):this.variant32(t>>>0)},t.prototype.sint32=function(t){this.variant32(t<<1^t>>31)},t.prototype.uint32=function(t){this.variant32(t)},t.prototype.sint64=function(t){t=BigInt(t),this.variant64(t<<ND01^t>>ND63)},t.prototype.int64=function(t){this.variant64(BigInt(t))},t.prototype.uint64=function(t){this.variant64(BigInt(t))},t.prototype.float=function(t){this.view.setFloat32(this.ptr,t,!0),this.ptr+=4},t.prototype.double=function(t){this.view.setFloat64(this.ptr,t,!0),this.ptr+=8},t.prototype.bytes=function(t){this.uint32(t.byteLength);for(var i=0;i<t.byteLength;i++)this.buf[this.ptr++]=t[i]},t.prototype.string=function(t){var i=this.varlen();this.uint32(i);for(var n=utf8.encode(t),r=0;r<n.byteLength;r++)this.buf[this.ptr++]=n[r]},t.prototype.fork=function(){this.uint32(this.varlen())},t.prototype.ldelim=function(){},t.prototype.finish=function(){return this.buf},t.prototype.reset=function(){this.buf=new Uint8Array(this.sizer.len),this.view=new DataView(this.buf.buffer),this.ptr=0,this.varlenidx=0},t.prototype.variant32=function(t){for(;t>127;)this.buf[this.ptr++]=127&t|128,t>>>=7;this.buf[this.ptr++]=t},t.prototype.variant64=function(t){for(t=BigInt.asUintN(64,t);t>NX7F;)this.buf[this.ptr++]=Number(t&NX7F|NX80),t>>=ND07;this.buf[this.ptr++]=Number(t)},t.prototype.varlen=function(){return this.varlenidx>=this.sizer.varlen.length?0:this.sizer.varlen[this.varlenidx++]},t}();exports.$ProtobufWriter=$ProtobufWriter;var utf8=new TextEncoder,ND01=BigInt(1),ND07=BigInt(7),ND63=BigInt(63),NX7F=BigInt(127),NX80=BigInt(128);

},{}],189:[function(require,module,exports){
"use strict";var $QueryReader;Object.defineProperty(exports,"__esModule",{value:!0}),exports.$QueryReader=void 0,function(n){n.boolean=function(n){return null===n?void 0:"null"===n?null:0===n.length||("true"===n||"1"===n||"false"!==n&&"0"!==n&&n)},n.number=function(n){return(null==n?void 0:n.length)?"null"===n?null:toNumber(n):void 0},n.bigint=function(n){return(null==n?void 0:n.length)?"null"===n?null:toBigint(n):void 0},n.string=function(n){return null===n?void 0:"null"===n?null:n},n.params=function(n){if("string"==typeof n){var r=n.indexOf("?");return n=-1===r?"":n.substring(r+1),new URLSearchParams(n)}return n},n.array=function(n,r){return n.length?n:r}}($QueryReader||(exports.$QueryReader=$QueryReader={}));var toNumber=function(n){var r=Number(n);return isNaN(r)?n:r},toBigint=function(n){try{return BigInt(n)}catch(r){return n}};

},{}],191:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.$clone=void 0;var $clone=function(e){return JSON.parse(JSON.stringify(e))};exports.$clone=$clone;

},{}],192:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.$every=void 0;var $every=function(e,r){for(var t=null,l=0;l<e.length;++l)if(null!==(t=r(e[l],l)))return t;return null};exports.$every=$every;

},{}],194:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.$is_between=void 0;var $is_between=function(e,t,s){return t<=e&&e<=s};exports.$is_between=$is_between;

},{}],195:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.$join=void 0;var $join=function(e){return variable(e)?".".concat(e):"[".concat(JSON.stringify(e),"]")};exports.$join=$join;var variable=function(e){return!1===reserved(e)&&/^[a-zA-Z_$][a-zA-Z_$0-9]*$/g.test(e)},reserved=function(e){return RESERVED.has(e)},RESERVED=new Set(["break","case","catch","class","const","continue","debugger","default","delete","do","else","enum","export","extends","false","finally","for","function","if","import","in","instanceof","new","null","return","super","switch","this","throw","true","try","typeof","var","void","while","with"]);

},{}],197:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.$report=void 0;var $report=function(t){return function(r,e){return r&&function(r){if(0===t.length)return!0;var e=t[t.length-1].path;return r.length>e.length||e.substring(0,r.length)!==r}(e.path)&&t.push(e),!1}};exports.$report=$report;

},{}],198:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.$rest=void 0;var $rest=function(e){return 2===e.length?"":","+e.substring(1,e.length-1)};exports.$rest=$rest;

},{}],199:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.$string=void 0;var $string=function(r){if(!1===STR_ESCAPE.test(r))return'"'.concat(r,'"');var t=r.length;if(t>41)return JSON.stringify(r);for(var f="",u=-1,e=255,i=0;i<t;++i){if((e=r.charCodeAt(i))<32)return JSON.stringify(r);if(e>=55296&&e<=57343)return JSON.stringify(r);34!==e&&92!==e||(-1===u&&(u=0),f+=r.slice(u,i)+"\\",u=i)}return-1===u&&'"'+r+'"'||'"'+f+r.slice(u)+'"'};exports.$string=$string;var STR_ESCAPE=/[\u0000-\u001f\u0022\u005c\ud800-\udfff]|[\ud800-\udbff](?![\udc00-\udfff])|(?:[^\ud800-\udbff]|^)[\udc00-\udfff]/;

},{}],200:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.$strlen=void 0;var $strlen=function(e){var r,t,s;for(r=t=0;s=e.charCodeAt(t++);r+=s>>11?3:s>>7?2:1);return r};exports.$strlen=$strlen;

},{}],201:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.$tail=void 0;var $tail=function(t){return","===t[t.length-1]?t.substring(0,t.length-1):t};exports.$tail=$tail;

},{}],209:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],210:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],211:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],212:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],213:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],214:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],215:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],216:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],217:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],218:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],219:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],220:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],221:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],222:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],223:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],224:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],225:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});

},{}],235:[function(require,module,exports){
"use strict";function makeMatcher(e=pathToRegexp){let t={};return(r,n)=>{const{regexp:s,keys:u}=(r=>t[r]||(t[r]=e(r)))(r||""),x=s.exec(n);if(!x)return[!1,null];return[!0,u.reduce(((e,t,r)=>(e[t.name]=x[r+1],e)),{})]}}Object.defineProperty(exports,"__esModule",{value:!0});const escapeRx=e=>e.replace(/([.+*?=^!:${}()[\]|/\\])/g,"\\$1"),rxForSegment=(e,t,r)=>{let n=e?"((?:[^\\/]+?)(?:\\/(?:[^\\/]+?))*)":"([^\\/]+?)";return t&&r&&(n="(?:\\/"+n+")"),n+(t?"?":"")},pathToRegexp=e=>{const t=/:([A-Za-z0-9_]+)([?+*]?)/g;let r=null,n=0,s=[],u="";for(;null!==(r=t.exec(e));){const[x,a,c]=r,p="+"===c||"*"===c,l="?"===c||"*"===c,o=l&&"/"===e[r.index-1]?1:0,g=e.substring(n,r.index-o);s.push({name:a}),n=t.lastIndex,u+=escapeRx(g)+rxForSegment(p,l,o)}return u+=escapeRx(e.substring(n)),{keys:s,regexp:new RegExp("^"+u+"(?:\\/)?$","i")}};exports.default=makeMatcher;

},{}],285:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
Object.defineProperty(exports, "__esModule", { value: true });
function getFormMutations(form, { changedOnly }) {
    const updatedFields = [];
    const mutationData = [];
    Object.values(form).forEach((field) => {
        if (field.nosubmit) {
            // Completely ignore
            // this field.
            return;
        }
        if ("selectedValues" in field) {
            // FieldArrayInputHook.
            const selected = field.selectedValues();
            if (!changedOnly || selected.length > 0) {
                updatedFields.push(field);
                mutationData.push([field.name, selected]);
            }
        }
        else if (!changedOnly || field.hasChanged()) {
            updatedFields.push(field);
            mutationData.push([field.name, field.value]);
        }
    });
    return {
        updatedFields,
        mutationData: Object.fromEntries(mutationData),
    };
}
exports.default = getFormMutations;

},{}],305:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.listToKeyedObject = void 0;
/**
 * Map a list of items into an object.
 *
 * In the following example, a list of DomainPerms like the following:
 *
 * ```json
 * [
 *   {
 *     "domain": "example.org",
 *     "public_comment": "aaaaa!!"
 *   },
 *   {
 *     "domain": "another.domain",
 *     "public_comment": "they are poo"
 *   }
 * ]
 * ```
 *
 * Would be converted into an Object like the following:
 *
 * ```json
 * {
 *   "example.org": {
 *     "domain": "example.org",
 *     "public_comment": "aaaaa!!"
 *   },
 *   "another.domain": {
 *     "domain": "another.domain",
 *     "public_comment": "they are poo"
 *   },
 * }
 * ```
 *
 * If you pass a non-array type into this function it
 * will be converted into an array first, as a treat.
 *
 * @example
 * const extended = gtsApi.injectEndpoints({
 *   endpoints: (build) => ({
 *     getDomainBlocks: build.query<MappedDomainPerms, void>({
 *       query: () => ({
 *         url: `/api/v1/admin/domain_blocks`
 *       }),
 *     transformResponse: listToKeyedObject<DomainPerm>("domain"),
 *   }),
 * });
 */
function listToKeyedObject(key) {
    return (list) => {
        // Ensure we're actually
        // dealing with an array.
        if (!Array.isArray(list)) {
            list = [list];
        }
        const entries = list.map((entry) => [entry[key], entry]);
        return Object.fromEntries(entries);
    };
}
exports.listToKeyedObject = listToKeyedObject;

},{}],308:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.NoArg = void 0;
/**
 * Pass into a query when you don't
 * want to provide an argument to it.
 */
exports.NoArg = undefined;

},{}],6:[function(require,module,exports){
var _typeof=require("./typeof.js").default;function _toPrimitive(e,t){if("object"!==_typeof(e)||null===e)return e;var r=e[Symbol.toPrimitive];if(void 0!==r){var o=r.call(e,t||"default");if("object"!==_typeof(o))return o;throw new TypeError("@@toPrimitive must return a primitive value.")}return("string"===t?String:Number)(e)}module.exports=_toPrimitive,module.exports.__esModule=!0,module.exports.default=module.exports;

},{"./typeof.js":8}],10:[function(require,module,exports){
!function(t,e){"object"==typeof exports&&"undefined"!=typeof module?e(exports,require("@floating-ui/core")):"function"==typeof define&&define.amd?define(["exports","@floating-ui/core"],e):e((t="undefined"!=typeof globalThis?globalThis:t||self).FloatingUIDOM={},t.FloatingUICore)}(this,(function(t,e){"use strict";const n=Math.min,o=Math.max,i=Math.round,r=Math.floor,c=t=>({x:t,y:t});function l(t){return u(t)?(t.nodeName||"").toLowerCase():"#document"}function f(t){var e;return(null==t||null==(e=t.ownerDocument)?void 0:e.defaultView)||window}function s(t){var e;return null==(e=(u(t)?t.ownerDocument:t.document)||window.document)?void 0:e.documentElement}function u(t){return t instanceof Node||t instanceof f(t).Node}function a(t){return t instanceof Element||t instanceof f(t).Element}function d(t){return t instanceof HTMLElement||t instanceof f(t).HTMLElement}function h(t){return"undefined"!=typeof ShadowRoot&&(t instanceof ShadowRoot||t instanceof f(t).ShadowRoot)}function p(t){const{overflow:e,overflowX:n,overflowY:o,display:i}=b(t);return/auto|scroll|overlay|hidden|clip/.test(e+o+n)&&!["inline","contents"].includes(i)}function m(t){return["table","td","th"].includes(l(t))}function g(t){const e=y(),n=b(t);return"none"!==n.transform||"none"!==n.perspective||!!n.containerType&&"normal"!==n.containerType||!e&&!!n.backdropFilter&&"none"!==n.backdropFilter||!e&&!!n.filter&&"none"!==n.filter||["transform","perspective","filter"].some((t=>(n.willChange||"").includes(t)))||["paint","layout","strict","content"].some((t=>(n.contain||"").includes(t)))}function y(){return!("undefined"==typeof CSS||!CSS.supports)&&CSS.supports("-webkit-backdrop-filter","none")}function w(t){return["html","body","#document"].includes(l(t))}function b(t){return f(t).getComputedStyle(t)}function x(t){return a(t)?{scrollLeft:t.scrollLeft,scrollTop:t.scrollTop}:{scrollLeft:t.pageXOffset,scrollTop:t.pageYOffset}}function v(t){if("html"===l(t))return t;const e=t.assignedSlot||t.parentNode||h(t)&&t.host||s(t);return h(e)?e.host:e}function T(t){const e=v(t);return w(e)?t.ownerDocument?t.ownerDocument.body:t.body:d(e)&&p(e)?e:T(e)}function L(t,e,n){var o;void 0===e&&(e=[]),void 0===n&&(n=!0);const i=T(t),r=i===(null==(o=t.ownerDocument)?void 0:o.body),c=f(i);return r?e.concat(c,c.visualViewport||[],p(i)?i:[],c.frameElement&&n?L(c.frameElement):[]):e.concat(i,L(i))}function O(t){const e=b(t);let n=parseFloat(e.width)||0,o=parseFloat(e.height)||0;const r=d(t),c=r?t.offsetWidth:n,l=r?t.offsetHeight:o,f=i(n)!==c||i(o)!==l;return f&&(n=c,o=l),{width:n,height:o,$:f}}function R(t){return a(t)?t:t.contextElement}function E(t){const e=R(t);if(!d(e))return c(1);const n=e.getBoundingClientRect(),{width:o,height:r,$:l}=O(e);let f=(l?i(n.width):n.width)/o,s=(l?i(n.height):n.height)/r;return f&&Number.isFinite(f)||(f=1),s&&Number.isFinite(s)||(s=1),{x:f,y:s}}const P=c(0);function C(t){const e=f(t);return y()&&e.visualViewport?{x:e.visualViewport.offsetLeft,y:e.visualViewport.offsetTop}:P}function S(t,n,o,i){void 0===n&&(n=!1),void 0===o&&(o=!1);const r=t.getBoundingClientRect(),l=R(t);let s=c(1);n&&(i?a(i)&&(s=E(i)):s=E(t));const u=function(t,e,n){return void 0===e&&(e=!1),!(!n||e&&n!==f(t))&&e}(l,o,i)?C(l):c(0);let d=(r.left+u.x)/s.x,h=(r.top+u.y)/s.y,p=r.width/s.x,m=r.height/s.y;if(l){const t=f(l),e=i&&a(i)?f(i):i;let n=t.frameElement;for(;n&&i&&e!==t;){const t=E(n),e=n.getBoundingClientRect(),o=b(n),i=e.left+(n.clientLeft+parseFloat(o.paddingLeft))*t.x,r=e.top+(n.clientTop+parseFloat(o.paddingTop))*t.y;d*=t.x,h*=t.y,p*=t.x,m*=t.y,d+=i,h+=r,n=f(n).frameElement}}return e.rectToClientRect({width:p,height:m,x:d,y:h})}function F(t){return S(s(t)).left+x(t).scrollLeft}function j(t,n,i){let r;if("viewport"===n)r=function(t,e){const n=f(t),o=s(t),i=n.visualViewport;let r=o.clientWidth,c=o.clientHeight,l=0,u=0;if(i){r=i.width,c=i.height;const t=y();(!t||t&&"fixed"===e)&&(l=i.offsetLeft,u=i.offsetTop)}return{width:r,height:c,x:l,y:u}}(t,i);else if("document"===n)r=function(t){const e=s(t),n=x(t),i=t.ownerDocument.body,r=o(e.scrollWidth,e.clientWidth,i.scrollWidth,i.clientWidth),c=o(e.scrollHeight,e.clientHeight,i.scrollHeight,i.clientHeight);let l=-n.scrollLeft+F(t);const f=-n.scrollTop;return"rtl"===b(i).direction&&(l+=o(e.clientWidth,i.clientWidth)-r),{width:r,height:c,x:l,y:f}}(s(t));else if(a(n))r=function(t,e){const n=S(t,!0,"fixed"===e),o=n.top+t.clientTop,i=n.left+t.clientLeft,r=d(t)?E(t):c(1);return{width:t.clientWidth*r.x,height:t.clientHeight*r.y,x:i*r.x,y:o*r.y}}(n,i);else{const e=C(t);r={...n,x:n.x-e.x,y:n.y-e.y}}return e.rectToClientRect(r)}function D(t,e){const n=v(t);return!(n===e||!a(n)||w(n))&&("fixed"===b(n).position||D(n,e))}function H(t,e,n){const o=d(e),i=s(e),r="fixed"===n,f=S(t,!0,r,e);let u={scrollLeft:0,scrollTop:0};const a=c(0);if(o||!o&&!r)if(("body"!==l(e)||p(i))&&(u=x(e)),o){const t=S(e,!0,r,e);a.x=t.x+e.clientLeft,a.y=t.y+e.clientTop}else i&&(a.x=F(i));return{x:f.left+u.scrollLeft-a.x,y:f.top+u.scrollTop-a.y,width:f.width,height:f.height}}function W(t,e){return d(t)&&"fixed"!==b(t).position?e?e(t):t.offsetParent:null}function M(t,e){const n=f(t);if(!d(t))return n;let o=W(t,e);for(;o&&m(o)&&"static"===b(o).position;)o=W(o,e);return o&&("html"===l(o)||"body"===l(o)&&"static"===b(o).position&&!g(o))?n:o||function(t){let e=v(t);for(;d(e)&&!w(e);){if(g(e))return e;e=v(e)}return null}(t)||n}const z={convertOffsetParentRelativeRectToViewportRelativeRect:function(t){let{rect:e,offsetParent:n,strategy:o}=t;const i=d(n),r=s(n);if(n===r)return e;let f={scrollLeft:0,scrollTop:0},u=c(1);const a=c(0);if((i||!i&&"fixed"!==o)&&(("body"!==l(n)||p(r))&&(f=x(n)),d(n))){const t=S(n);u=E(n),a.x=t.x+n.clientLeft,a.y=t.y+n.clientTop}return{width:e.width*u.x,height:e.height*u.y,x:e.x*u.x-f.scrollLeft*u.x+a.x,y:e.y*u.y-f.scrollTop*u.y+a.y}},getDocumentElement:s,getClippingRect:function(t){let{element:e,boundary:i,rootBoundary:r,strategy:c}=t;const f=[..."clippingAncestors"===i?function(t,e){const n=e.get(t);if(n)return n;let o=L(t,[],!1).filter((t=>a(t)&&"body"!==l(t))),i=null;const r="fixed"===b(t).position;let c=r?v(t):t;for(;a(c)&&!w(c);){const e=b(c),n=g(c);n||"fixed"!==e.position||(i=null),(r?!n&&!i:!n&&"static"===e.position&&i&&["absolute","fixed"].includes(i.position)||p(c)&&!n&&D(t,c))?o=o.filter((t=>t!==c)):i=e,c=v(c)}return e.set(t,o),o}(e,this._c):[].concat(i),r],s=f[0],u=f.reduce(((t,i)=>{const r=j(e,i,c);return t.top=o(r.top,t.top),t.right=n(r.right,t.right),t.bottom=n(r.bottom,t.bottom),t.left=o(r.left,t.left),t}),j(e,s,c));return{width:u.right-u.left,height:u.bottom-u.top,x:u.left,y:u.top}},getOffsetParent:M,getElementRects:async function(t){let{reference:e,floating:n,strategy:o}=t;const i=this.getOffsetParent||M,r=this.getDimensions;return{reference:H(e,await i(n),o),floating:{x:0,y:0,...await r(n)}}},getClientRects:function(t){return Array.from(t.getClientRects())},getDimensions:function(t){return O(t)},getScale:E,isElement:a,isRTL:function(t){return"rtl"===b(t).direction}};Object.defineProperty(t,"arrow",{enumerable:!0,get:function(){return e.arrow}}),Object.defineProperty(t,"autoPlacement",{enumerable:!0,get:function(){return e.autoPlacement}}),Object.defineProperty(t,"detectOverflow",{enumerable:!0,get:function(){return e.detectOverflow}}),Object.defineProperty(t,"flip",{enumerable:!0,get:function(){return e.flip}}),Object.defineProperty(t,"hide",{enumerable:!0,get:function(){return e.hide}}),Object.defineProperty(t,"inline",{enumerable:!0,get:function(){return e.inline}}),Object.defineProperty(t,"limitShift",{enumerable:!0,get:function(){return e.limitShift}}),Object.defineProperty(t,"offset",{enumerable:!0,get:function(){return e.offset}}),Object.defineProperty(t,"shift",{enumerable:!0,get:function(){return e.shift}}),Object.defineProperty(t,"size",{enumerable:!0,get:function(){return e.size}}),t.autoUpdate=function(t,e,i,c){void 0===c&&(c={});const{ancestorScroll:l=!0,ancestorResize:f=!0,elementResize:u="function"==typeof ResizeObserver,layoutShift:a="function"==typeof IntersectionObserver,animationFrame:d=!1}=c,h=R(t),p=l||f?[...h?L(h):[],...L(e)]:[];p.forEach((t=>{l&&t.addEventListener("scroll",i,{passive:!0}),f&&t.addEventListener("resize",i)}));const m=h&&a?function(t,e){let i,c=null;const l=s(t);function f(){clearTimeout(i),c&&c.disconnect(),c=null}return function s(u,a){void 0===u&&(u=!1),void 0===a&&(a=1),f();const{left:d,top:h,width:p,height:m}=t.getBoundingClientRect();if(u||e(),!p||!m)return;const g={rootMargin:-r(h)+"px "+-r(l.clientWidth-(d+p))+"px "+-r(l.clientHeight-(h+m))+"px "+-r(d)+"px",threshold:o(0,n(1,a))||1};let y=!0;function w(t){const e=t[0].intersectionRatio;if(e!==a){if(!y)return s();e?s(!1,e):i=setTimeout((()=>{s(!1,1e-7)}),100)}y=!1}try{c=new IntersectionObserver(w,{...g,root:l.ownerDocument})}catch(t){c=new IntersectionObserver(w,g)}c.observe(t)}(!0),f}(h,i):null;let g,y=-1,w=null;u&&(w=new ResizeObserver((t=>{let[n]=t;n&&n.target===h&&w&&(w.unobserve(e),cancelAnimationFrame(y),y=requestAnimationFrame((()=>{w&&w.observe(e)}))),i()})),h&&!d&&w.observe(h),w.observe(e));let b=d?S(t):null;return d&&function e(){const n=S(t);!b||n.x===b.x&&n.y===b.y&&n.width===b.width&&n.height===b.height||i();b=n,g=requestAnimationFrame(e)}(),i(),()=>{p.forEach((t=>{l&&t.removeEventListener("scroll",i),f&&t.removeEventListener("resize",i)})),m&&m(),w&&w.disconnect(),w=null,d&&cancelAnimationFrame(g)}},t.computePosition=(t,n,o)=>{const i=new Map,r={platform:z,...o},c={...r.platform,_c:i};return e.computePosition(t,n,{...r,platform:c})},t.getOverflowAncestors=L,t.platform=z}));

},{"@floating-ui/core":9}],27:[function(require,module,exports){
"use strict";var dom=require("./dom.js");const selector="input:not([type='hidden']):not([disabled]), select:not([disabled]), textarea:not([disabled]), a[href], button:not([disabled]), [tabindex], iframe, object, embed, area[href], audio[controls], video[controls], [contenteditable]:not([contenteditable='false'])";function hasNegativeTabIndex(e){return parseInt(e.getAttribute("tabindex")||"0",10)<0}function isFocusable(e){return dom.matches(e,selector)&&dom.isVisible(e)}function isTabbable(e){return isFocusable(e)&&!hasNegativeTabIndex(e)}function getAllFocusableIn(e,t){const n=Array.from(e.querySelectorAll(selector));t&&n.unshift(e);const b=n.filter(isFocusable);return b.forEach(((e,t)=>{if(dom.isFrame(e)&&e.contentDocument){const n=e.contentDocument.body;b.splice(t,1,...getAllFocusableIn(n))}})),b}function getAllFocusable(e){return getAllFocusableIn(document.body,e)}function getFirstFocusableIn(e,t){const[n]=getAllFocusableIn(e,t);return n||null}function getFirstFocusable(e){return getFirstFocusableIn(document.body,e)}function getAllTabbableIn(e,t,n){const b=Array.from(e.querySelectorAll(selector)),o=b.filter(isTabbable);return t&&isTabbable(e)&&o.unshift(e),o.forEach(((e,t)=>{if(dom.isFrame(e)&&e.contentDocument){const b=getAllTabbableIn(e.contentDocument.body,!1,n);o.splice(t,1,...b)}})),!o.length&&n?b:o}function getAllTabbable(e){return getAllTabbableIn(document.body,!1,e)}function getFirstTabbableIn(e,t,n){const[b]=getAllTabbableIn(e,t,n);return b||null}function getFirstTabbable(e){return getFirstTabbableIn(document.body,!1,e)}function getLastTabbableIn(e,t,n){const b=getAllTabbableIn(e,t,n);return b[b.length-1]||null}function getLastTabbable(e){return getLastTabbableIn(document.body,!1,e)}function getNextTabbableIn(e,t,n,b){const o=dom.getActiveElement(e),a=getAllFocusableIn(e,t),s=a.indexOf(o),l=a.slice(s+1);return l.find(isTabbable)||(n?a.find(isTabbable):null)||(b?l[0]:null)||null}function getNextTabbable(e,t){return getNextTabbableIn(document.body,!1,e,t)}function getPreviousTabbableIn(e,t,n,b){const o=dom.getActiveElement(e),a=getAllFocusableIn(e,t).reverse(),s=a.indexOf(o),l=a.slice(s+1);return l.find(isTabbable)||(n?a.find(isTabbable):null)||(b?l[0]:null)||null}function getPreviousTabbable(e,t){return getPreviousTabbableIn(document.body,!1,e,t)}function getClosestFocusable(e){for(;e&&!isFocusable(e);)e=dom.closest(e,selector);return e||null}function hasFocus(e){const t=dom.getActiveElement(e);if(!t)return!1;if(t===e)return!0;const n=t.getAttribute("aria-activedescendant");return!!n&&n===e.id}function hasFocusWithin(e){const t=dom.getActiveElement(e);if(!t)return!1;if(dom.contains(e,t))return!0;const n=t.getAttribute("aria-activedescendant");return!!n&&("id"in e&&(n===e.id||!!e.querySelector(`#${CSS.escape(n)}`)))}function focusIfNeeded(e){!hasFocusWithin(e)&&isFocusable(e)&&e.focus()}function disableFocus(e){const t=e.getAttribute("tabindex")??"";e.setAttribute("data-tabindex",t),e.setAttribute("tabindex","-1")}function disableFocusIn(e,t){getAllTabbableIn(e,t).forEach(disableFocus)}function restoreFocusIn(e){const t=e.querySelectorAll("[data-tabindex]"),n=e=>{const t=e.getAttribute("data-tabindex");e.removeAttribute("data-tabindex"),t?e.setAttribute("tabindex",t):e.removeAttribute("tabindex")};e.hasAttribute("data-tabindex")&&n(e),t.forEach(n)}function focusIntoView(e,t){"scrollIntoView"in e?(e.focus({preventScroll:!0}),e.scrollIntoView({block:"nearest",inline:"nearest",...t})):e.focus()}exports.disableFocus=disableFocus,exports.disableFocusIn=disableFocusIn,exports.focusIfNeeded=focusIfNeeded,exports.focusIntoView=focusIntoView,exports.getAllFocusable=getAllFocusable,exports.getAllFocusableIn=getAllFocusableIn,exports.getAllTabbable=getAllTabbable,exports.getAllTabbableIn=getAllTabbableIn,exports.getClosestFocusable=getClosestFocusable,exports.getFirstFocusable=getFirstFocusable,exports.getFirstFocusableIn=getFirstFocusableIn,exports.getFirstTabbable=getFirstTabbable,exports.getFirstTabbableIn=getFirstTabbableIn,exports.getLastTabbable=getLastTabbable,exports.getLastTabbableIn=getLastTabbableIn,exports.getNextTabbable=getNextTabbable,exports.getNextTabbableIn=getNextTabbableIn,exports.getPreviousTabbable=getPreviousTabbable,exports.getPreviousTabbableIn=getPreviousTabbableIn,exports.hasFocus=hasFocus,exports.hasFocusWithin=hasFocusWithin,exports.isFocusable=isFocusable,exports.isTabbable=isTabbable,exports.restoreFocusIn=restoreFocusIn;

},{"./dom.js":25}],29:[function(require,module,exports){
"use strict";var dom=require("./dom.js");function isTouchDevice(){return dom.canUseDOM&&!!navigator.maxTouchPoints}function isApple(){return!!dom.canUseDOM&&/mac|iphone|ipad|ipod/i.test(navigator.platform)}function isSafari(){return dom.canUseDOM&&isApple()&&/apple/i.test(navigator.vendor)}function isFirefox(){return dom.canUseDOM&&/firefox\//i.test(navigator.userAgent)}function isMac(){return dom.canUseDOM&&navigator.platform.startsWith("Mac")&&!isTouchDevice()}exports.isApple=isApple,exports.isFirefox=isFirefox,exports.isMac=isMac,exports.isSafari=isSafari,exports.isTouchDevice=isTouchDevice;

},{"./dom.js":25}],81:[function(require,module,exports){
"use strict";module.exports=require("./lib");

},{"./lib":82}],89:[function(require,module,exports){
"use strict";"production"==="production"?module.exports=require("./immer.cjs.production.min.js"):module.exports=require("./immer.cjs.development.js");

},{"./immer.cjs.development.js":87,"./immer.cjs.production.min.js":88}],96:[function(require,module,exports){
var data=require("./data"),langs={all:allLanguages,has:hasLanguage,codes:getCodes,names:getNames,where:findBy};function allLanguages(){return data}function hasLanguage(a,n){return void 0!==findBy(a,n)}function getCodes(a){if(isValidType(a))return forAll(data,(function(n){return n[a]}))}function getNames(a){return forAll(data,(function(n){return a?n.local:n.name}))}function findBy(a,n){for(var e=0;e<data.length;e++)if(n===data[e][a])return data[e]}function forAll(a,n){var e,t=[];for(e=0;e<a.length;e++)t.push(n(a[e],e));return t}function isValidType(a){return-1!==[1,2,3,"1","2","2B","2T","3"].indexOf(a)}module.exports=langs;

},{"./data":95}],98:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.random=exports.nanoid=exports.customRandom=exports.customAlphabet=void 0,Object.defineProperty(exports,"urlAlphabet",{enumerable:!0,get:function(){return _index.urlAlphabet}});var _index=require("./url-alphabet/index.js");let random=t=>crypto.getRandomValues(new Uint8Array(t));exports.random=random;let customRandom=(t,e,o)=>{let n=(2<<Math.log(t.length-1)/Math.LN2)-1,r=-~(1.6*n*e/t.length);return function(){let a=arguments.length>0&&void 0!==arguments[0]?arguments[0]:e,l="";for(;;){let e=o(r),u=r;for(;u--;)if(l+=t[e[u]&n]||"",l.length===a)return l}}};exports.customRandom=customRandom;let customAlphabet=function(t){return customRandom(t,arguments.length>1&&void 0!==arguments[1]?arguments[1]:21,random)};exports.customAlphabet=customAlphabet;let nanoid=function(){let t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:21;return crypto.getRandomValues(new Uint8Array(t)).reduce(((t,e)=>t+=(e&=63)<36?e.toString(36):e<62?(e-26).toString(36).toUpperCase():e>62?"-":"_"),"")};exports.nanoid=nanoid;

},{"./url-alphabet/index.js":99}],178:[function(require,module,exports){
(function (setImmediate,clearImmediate){(function (){
var nextTick=require("process/browser.js").nextTick,apply=Function.prototype.apply,slice=Array.prototype.slice,immediateIds={},nextImmediateId=0;function Timeout(e,t){this._id=e,this._clearFn=t}exports.setTimeout=function(){return new Timeout(apply.call(setTimeout,window,arguments),clearTimeout)},exports.setInterval=function(){return new Timeout(apply.call(setInterval,window,arguments),clearInterval)},exports.clearTimeout=exports.clearInterval=function(e){e.close()},Timeout.prototype.unref=Timeout.prototype.ref=function(){},Timeout.prototype.close=function(){this._clearFn.call(window,this._id)},exports.enroll=function(e,t){clearTimeout(e._idleTimeoutId),e._idleTimeout=t},exports.unenroll=function(e){clearTimeout(e._idleTimeoutId),e._idleTimeout=-1},exports._unrefActive=exports.active=function(e){clearTimeout(e._idleTimeoutId);var t=e._idleTimeout;t>=0&&(e._idleTimeoutId=setTimeout((function(){e._onTimeout&&e._onTimeout()}),t))},exports.setImmediate="function"==typeof setImmediate?setImmediate:function(e){var t=nextImmediateId++,i=!(arguments.length<2)&&slice.call(arguments,1);return immediateIds[t]=!0,nextTick((function(){immediateIds[t]&&(i?e.apply(null,i):e.call(null),exports.clearImmediate(t))})),t},exports.clearImmediate="function"==typeof clearImmediate?clearImmediate:function(e){delete immediateIds[e]};

}).call(this)}).call(this,require("timers").setImmediate,require("timers").clearImmediate)
},{"process/browser.js":103,"timers":178}],93:[function(require,module,exports){
const punycode=require("punycode"),sldMap=require("./data/sldMap.json"),ccTldMap=require("./data/ccTldMap.json");module.exports=function(t,e){if("string"!=typeof t)return!1;if(e instanceof Object||(e={}),(t=t.toLowerCase()).endsWith(".")&&(t=t.slice(0,t.length-1)),e.allowUnicode&&(t=punycode.toASCII(t)),t.length>253)return!1;if(!/^([\u0E00-\u0E7Fa-z0-9-._*]+)$/g.test(t))return!1;if(e.topLevel&&ccTldMap[t.replace(/\.$/,"")])return!0;const n=t.match(/(.*)\.(([\u0E00-\u0E7Fa-z0-9]+)(\.[a-z0-9]+))/);let r=null,u=null;if(n&&n.length>2&&sldMap[n[2]]&&(r=n[2],u=n[1].split(".")),!u){if(u=t.split("."),u.length<=1)return!1;r=u.pop();if(!/^(?:xn--)?(?!^\d+$)[\u0E00-\u0E7Fa-z0-9]+$/gi.test(r))return!1}if(!1===e.subdomain&&u.length>1)return!1;return u.every((function(t,n){if(e.wildcard&&0===n&&"*"===t&&u.length>1)return!0;let r=/^([\u0E00-\u0E7Fa-zA-Z0-9-_]+)$/g;n===u.length-1&&(r=/^([\u0E00-\u0E7Fa-zA-Z0-9-]+)$/g);const l=(t.match(/--(--)?/g)||[]).length,i=(t.match(/xn--/g)||[]).length;if(n===u.length-1&&l!==i)return!1;return r.test(t)&&t.length<64&&!t.startsWith("-")&&!t.endsWith("-")}))};

},{"./data/ccTldMap.json":91,"./data/sldMap.json":92,"punycode":106}],105:[function(require,module,exports){
"use strict";var Punycode=require("punycode"),internals={};internals.rules=require("./data/rules.json").map((function(n){return{rule:n,suffix:n.replace(/^(\*\.|\!)/,""),punySuffix:-1,wildcard:"*"===n.charAt(0),exception:"!"===n.charAt(0)}})),internals.endsWith=function(n,e){return-1!==n.indexOf(e,n.length-e.length)},internals.findRule=function(n){var e=Punycode.toASCII(n);return internals.rules.reduce((function(n,t){return-1===t.punySuffix&&(t.punySuffix=Punycode.toASCII(t.suffix)),internals.endsWith(e,"."+t.punySuffix)||e===t.punySuffix?t:n}),null)},exports.errorCodes={DOMAIN_TOO_SHORT:"Domain name too short.",DOMAIN_TOO_LONG:"Domain name too long. It should be no more than 255 chars.",LABEL_STARTS_WITH_DASH:"Domain name label can not start with a dash.",LABEL_ENDS_WITH_DASH:"Domain name label can not end with a dash.",LABEL_TOO_LONG:"Domain name label should be at most 63 chars long.",LABEL_TOO_SHORT:"Domain name label should be at least 1 character long.",LABEL_INVALID_CHARS:"Domain name label can only contain alphanumeric characters or dashes."},internals.validate=function(n){var e=Punycode.toASCII(n);if(e.length<1)return"DOMAIN_TOO_SHORT";if(e.length>255)return"DOMAIN_TOO_LONG";for(var t,r=e.split("."),a=0;a<r.length;++a){if(!(t=r[a]).length)return"LABEL_TOO_SHORT";if(t.length>63)return"LABEL_TOO_LONG";if("-"===t.charAt(0))return"LABEL_STARTS_WITH_DASH";if("-"===t.charAt(t.length-1))return"LABEL_ENDS_WITH_DASH";if(!/^[a-z0-9\-]+$/.test(t))return"LABEL_INVALID_CHARS"}},exports.parse=function(n){if("string"!=typeof n)throw new TypeError("Domain name must be a string.");var e=n.slice(0).toLowerCase();"."===e.charAt(e.length-1)&&(e=e.slice(0,e.length-1));var t=internals.validate(e);if(t)return{input:n,error:{message:exports.errorCodes[t],code:t}};var r={input:n,tld:null,sld:null,domain:null,subdomain:null,listed:!1},a=e.split(".");if("local"===a[a.length-1])return r;var i=function(){return/xn--/.test(e)?(r.domain&&(r.domain=Punycode.toASCII(r.domain)),r.subdomain&&(r.subdomain=Punycode.toASCII(r.subdomain)),r):r},o=internals.findRule(e);if(!o)return a.length<2?r:(r.tld=a.pop(),r.sld=a.pop(),r.domain=[r.sld,r.tld].join("."),a.length&&(r.subdomain=a.pop()),i());r.listed=!0;var l=o.suffix.split("."),s=a.slice(0,a.length-l.length);return o.exception&&s.push(l.shift()),r.tld=l.join("."),s.length?(o.wildcard&&(l.unshift(s.pop()),r.tld=l.join(".")),s.length?(r.sld=s.pop(),r.domain=[r.sld,r.tld].join("."),s.length&&(r.subdomain=s.join(".")),i()):i()):i()},exports.get=function(n){return n&&exports.parse(n).domain||null},exports.isValid=function(n){var e=exports.parse(n);return Boolean(e.domain&&e.listed)};

},{"./data/rules.json":104,"punycode":106}],113:[function(require,module,exports){
"use strict";"production"==="production"?module.exports=require("./cjs/react-is.production.min.js"):module.exports=require("./cjs/react-is.development.js");

},{"./cjs/react-is.development.js":111,"./cjs/react-is.production.min.js":112}],131:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.createSubscription=createSubscription;var _batch=require("./batch");function createListenerCollection(){const e=(0,_batch.getBatch)();let t=null,n=null;return{clear(){t=null,n=null},notify(){e((()=>{let e=t;for(;e;)e.callback(),e=e.next}))},get(){let e=[],n=t;for(;n;)e.push(n),n=n.next;return e},subscribe(e){let r=!0,c=n={callback:e,next:null,prev:n};return c.prev?c.prev.next=c:t=c,function(){r&&null!==t&&(r=!1,c.next?c.next.prev=c.prev:n=c.prev,c.prev?c.prev.next=c.next:t=c.next)}}}}const nullListeners={notify(){},get:()=>[]};function createSubscription(e,t){let n,r=nullListeners,c=0,u=!1;function i(){o.onStateChange&&o.onStateChange()}function s(){c++,n||(n=t?t.addNestedSub(i):e.subscribe(i),r=createListenerCollection())}function l(){c--,n&&0===c&&(n(),n=void 0,r.clear(),r=nullListeners)}const o={addNestedSub:function(e){s();const t=r.subscribe(e);let n=!1;return()=>{n||(n=!0,t(),l())}},notifyNestedSubs:function(){r.notify()},handleChangeWrapper:i,isSubscribed:function(){return u},trySubscribe:function(){u||(u=!0,s())},tryUnsubscribe:function(){u&&(u=!1,l())},getListeners:()=>r};return o}

},{"./batch":132}],122:[function(require,module,exports){
"use strict";var _interopRequireDefault=require("@babel/runtime/helpers/interopRequireDefault");exports.__esModule=!0,exports.default=verifySubselectors;var _warning=_interopRequireDefault(require("../utils/warning"));function verify(e,r){if(!e)throw new Error(`Unexpected value for ${r} in connect.`);"mapStateToProps"!==r&&"mapDispatchToProps"!==r||Object.prototype.hasOwnProperty.call(e,"dependsOnOwnProps")||(0,_warning.default)(`The selector for ${r} of connect did not specify a value for dependsOnOwnProps.`)}function verifySubselectors(e,r,o){verify(e,"mapStateToProps"),verify(r,"mapDispatchToProps"),verify(o,"mergeProps")}

},{"../utils/warning":140,"@babel/runtime/helpers/interopRequireDefault":3}],139:[function(require,module,exports){
"use strict";var _interopRequireDefault=require("@babel/runtime/helpers/interopRequireDefault");exports.__esModule=!0,exports.default=verifyPlainObject;var _isPlainObject=_interopRequireDefault(require("./isPlainObject")),_warning=_interopRequireDefault(require("./warning"));function verifyPlainObject(e,i,r){(0,_isPlainObject.default)(e)||(0,_warning.default)(`${r}() in ${i} must return a plain object. Instead received ${e}.`)}

},{"./isPlainObject":134,"./warning":140,"@babel/runtime/helpers/interopRequireDefault":3}],143:[function(require,module,exports){
"use strict";"production"==="production"?module.exports=require("./cjs/react-is.production.min.js"):module.exports=require("./cjs/react-is.development.js");

},{"./cjs/react-is.development.js":141,"./cjs/react-is.production.min.js":142}],146:[function(require,module,exports){
"use strict";module.exports=require("./cjs/react.production.min.js");

},{"./cjs/react.production.min.js":145}],149:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.default=createMigrate;var _constants=require("./constants");function createMigrate(r,e){var o=(e||{}).debug;return function(e,s){if(!e)return"production"!=="production"&&o&&console.log("redux-persist: no inbound state, skipping migration"),Promise.resolve(void 0);var n=e._persist&&void 0!==e._persist.version?e._persist.version:_constants.DEFAULT_VERSION;if(n===s)return"production"!=="production"&&o&&console.log("redux-persist: versions match, noop migration"),Promise.resolve(e);if(n>s)return"production"!=="production"&&console.error("redux-persist: downgrading version is not supported"),Promise.resolve(e);var t=Object.keys(r).map((function(r){return parseInt(r)})).filter((function(r){return s>=r&&r>n})).sort((function(r,e){return r-e}));"production"!=="production"&&o&&console.log("redux-persist: migrationKeys",t);try{var i=t.reduce((function(e,s){return"production"!=="production"&&o&&console.log("redux-persist: running migration for versionKey",s),r[s](e)}),e);return Promise.resolve(i)}catch(r){return Promise.reject(r)}}}

},{"./constants":148}],150:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.default=createPersistoid;var _constants=require("./constants");function createPersistoid(e){var t,r=e.blacklist||null,n=e.whitelist||null,i=e.transforms||[],o=e.throttle||0,s="".concat(void 0!==e.keyPrefix?e.keyPrefix:_constants.KEY_PREFIX).concat(e.key),l=e.storage;t=!1===e.serialize?function(e){return e}:"function"==typeof e.serialize?e.serialize:defaultSerialize;var c=e.writeFailHandler||null,u={},a={},f=[],d=null,h=null;function v(){if(0===f.length)return d&&clearInterval(d),void(d=null);var e=f.shift(),r=i.reduce((function(t,r){return r.in(t,e,u)}),u[e]);if(void 0!==r)try{a[e]=t(r)}catch(e){console.error("redux-persist/createPersistoid: error serializing state",e)}else delete a[e];0===f.length&&(Object.keys(a).forEach((function(e){void 0===u[e]&&delete a[e]})),h=l.setItem(s,t(a)).catch(x))}function p(e){return(!n||-1!==n.indexOf(e)||"_persist"===e)&&(!r||-1===r.indexOf(e))}function x(e){c&&c(e),e&&"production"!=="production"&&console.error("Error storing data",e)}return{update:function(e){Object.keys(e).forEach((function(t){p(t)&&u[t]!==e[t]&&-1===f.indexOf(t)&&f.push(t)})),Object.keys(u).forEach((function(t){void 0===e[t]&&p(t)&&-1===f.indexOf(t)&&void 0!==u[t]&&f.push(t)})),null===d&&(d=setInterval(v,o)),u=e},flush:function(){for(;0!==f.length;)v();return h||Promise.resolve()}}}function defaultSerialize(e){return JSON.stringify(e)}

},{"./constants":148}],152:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.default=getStoredState;var _constants=require("./constants");function getStoredState(e){var t,r=e.transforms||[],n="".concat(void 0!==e.keyPrefix?e.keyPrefix:_constants.KEY_PREFIX).concat(e.key),o=e.storage,a=e.debug;return t=!1===e.deserialize?function(e){return e}:"function"==typeof e.deserialize?e.deserialize:defaultDeserialize,o.getItem(n).then((function(e){if(e)try{var n={},o=t(e);return Object.keys(o).forEach((function(e){n[e]=r.reduceRight((function(t,r){return r.out(t,e,o)}),t(o[e]))})),n}catch(t){throw"production"!=="production"&&a&&console.log("redux-persist/getStoredState: Error restoring data ".concat(e),t),t}}))}function defaultDeserialize(e){return JSON.parse(e)}

},{"./constants":148}],158:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.default=purgeStoredState;var _constants=require("./constants");function purgeStoredState(e){var r=e.storage,t="".concat(void 0!==e.keyPrefix?e.keyPrefix:_constants.KEY_PREFIX).concat(e.key);return r.removeItem(t,warnIfRemoveError)}function warnIfRemoveError(e){e&&"production"!=="production"&&console.error("redux-persist/purgeStoredState: Error purging data stored state",e)}

},{"./constants":148}],161:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.default=createWebStorage;var _getStorage=_interopRequireDefault(require("./getStorage"));function _interopRequireDefault(e){return e&&e.__esModule?e:{default:e}}function createWebStorage(e){var t=(0,_getStorage.default)(e);return{getItem:function(e){return new Promise((function(r,n){r(t.getItem(e))}))},setItem:function(e,r){return new Promise((function(n,o){n(t.setItem(e,r))}))},removeItem:function(e){return new Promise((function(r,n){r(t.removeItem(e))}))}}}

},{"./getStorage":162}],97:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});var _extends=require("@babel/runtime/helpers/extends"),removeAccents=require("remove-accents");function _interopDefaultLegacy(e){return e&&"object"==typeof e&&"default"in e?e:{default:e}}var _extends__default=_interopDefaultLegacy(_extends),removeAccents__default=_interopDefaultLegacy(removeAccents),rankings={CASE_SENSITIVE_EQUAL:7,EQUAL:6,STARTS_WITH:5,WORD_STARTS_WITH:4,CONTAINS:3,ACRONYM:2,MATCHES:1,NO_MATCH:0};matchSorter.rankings=rankings;var defaultBaseSortFn=function(e,n){return String(e.rankedValue).localeCompare(String(n.rankedValue))};function matchSorter(e,n,r){void 0===r&&(r={});var t=r,a=t.keys,u=t.threshold,i=void 0===u?rankings.MATCHES:u,s=t.baseSort,o=void 0===s?defaultBaseSortFn:s,l=t.sorter,c=void 0===l?function(e){return e.sort((function(e,n){return sortRankedValues(e,n,o)}))}:l;return c(e.reduce((function(e,t,u){var s=getHighestRanking(t,a,n,r),o=s.rank,l=s.keyThreshold;o>=(void 0===l?i:l)&&e.push(_extends__default.default({},s,{item:t,index:u}));return e}),[])).map((function(e){return e.item}))}function getHighestRanking(e,n,r,t){if(!n){return{rankedValue:e,rank:getMatchRanking(e,r,t),keyIndex:-1,keyThreshold:t.threshold}}return getAllValuesToRank(e,n).reduce((function(e,n,a){var u=e.rank,i=e.rankedValue,s=e.keyIndex,o=e.keyThreshold,l=n.itemValue,c=n.attributes,f=getMatchRanking(l,r,t),g=i,d=c.minRanking,k=c.maxRanking,h=c.threshold;return f<d&&f>=rankings.MATCHES?f=d:f>k&&(f=k),f>u&&(u=f,s=a,o=h,g=l),{rankedValue:g,rank:u,keyIndex:s,keyThreshold:o}}),{rankedValue:e,rank:rankings.NO_MATCH,keyIndex:-1,keyThreshold:t.threshold})}function getMatchRanking(e,n,r){return e=prepareValueForComparison(e,r),(n=prepareValueForComparison(n,r)).length>e.length?rankings.NO_MATCH:e===n?rankings.CASE_SENSITIVE_EQUAL:(e=e.toLowerCase())===(n=n.toLowerCase())?rankings.EQUAL:e.startsWith(n)?rankings.STARTS_WITH:e.includes(" "+n)?rankings.WORD_STARTS_WITH:e.includes(n)?rankings.CONTAINS:1===n.length?rankings.NO_MATCH:getAcronym(e).includes(n)?rankings.ACRONYM:getClosenessRanking(e,n)}function getAcronym(e){var n="";return e.split(" ").forEach((function(e){e.split("-").forEach((function(e){n+=e.substr(0,1)}))})),n}function getClosenessRanking(e,n){var r=0,t=0;function a(e,n,t){for(var a=t,u=n.length;a<u;a++){if(n[a]===e)return r+=1,a+1}return-1}var u=a(n[0],e,0);if(u<0)return rankings.NO_MATCH;t=u;for(var i=1,s=n.length;i<s;i++){if(!((t=a(n[i],e,t))>-1))return rankings.NO_MATCH}return function(e){var t=1/e,a=r/n.length;return rankings.MATCHES+a*t}(t-u)}function sortRankedValues(e,n,r){var t=e.rank,a=e.keyIndex,u=n.rank,i=n.keyIndex;return t===u?a===i?r(e,n):a<i?-1:1:t>u?-1:1}function prepareValueForComparison(e,n){return e=""+e,n.keepDiacritics||(e=removeAccents__default.default(e)),e}function getItemValues(e,n){var r;if("object"==typeof n&&(n=n.key),"function"==typeof n)r=n(e);else if(null==e)r=null;else if(Object.hasOwnProperty.call(e,n))r=e[n];else{if(n.includes("."))return getNestedValues(n,e);r=null}return null==r?[]:Array.isArray(r)?r:[String(r)]}function getNestedValues(e,n){for(var r=e.split("."),t=[n],a=0,u=r.length;a<u;a++){for(var i=r[a],s=[],o=0,l=t.length;o<l;o++){var c=t[o];if(null!=c)if(Object.hasOwnProperty.call(c,i)){var f=c[i];null!=f&&s.push(f)}else"*"===i&&(s=s.concat(c))}t=s}if(Array.isArray(t[0])){var g=[];return g.concat.apply(g,t)}return t}function getAllValuesToRank(e,n){for(var r=[],t=0,a=n.length;t<a;t++)for(var u=n[t],i=getKeyAttributes(u),s=getItemValues(e,u),o=0,l=s.length;o<l;o++)r.push({itemValue:s[o],attributes:i});return r}var defaultKeyAttributes={maxRanking:1/0,minRanking:-1/0};function getKeyAttributes(e){return"string"==typeof e?defaultKeyAttributes:_extends__default.default({},defaultKeyAttributes,e)}exports.defaultBaseSortFn=defaultBaseSortFn,exports.matchSorter=matchSorter,exports.rankings=rankings;

},{"@babel/runtime/helpers/extends":2,"remove-accents":166}],168:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.createSelector=void 0,exports.createSelectorCreator=createSelectorCreator,exports.createStructuredSelector=void 0,Object.defineProperty(exports,"defaultEqualityCheck",{enumerable:!0,get:function(){return _defaultMemoize.defaultEqualityCheck}}),Object.defineProperty(exports,"defaultMemoize",{enumerable:!0,get:function(){return _defaultMemoize.defaultMemoize}});var _defaultMemoize=require("./defaultMemoize");function getDependencies(e){var t=Array.isArray(e[0])?e[0]:e;if(!t.every((function(e){return"function"==typeof e}))){var r=t.map((function(e){return"function"==typeof e?"function "+(e.name||"unnamed")+"()":typeof e})).join(", ");throw new Error("createSelector expects all input-selectors to be functions, but received the following types: ["+r+"]")}return t}function createSelectorCreator(e){for(var t=arguments.length,r=new Array(t>1?t-1:0),o=1;o<t;o++)r[o-1]=arguments[o];return function(){for(var t=arguments.length,o=new Array(t),n=0;n<t;n++)o[n]=arguments[n];var c,u=0,a={memoizeOptions:void 0},i=o.pop();if("object"==typeof i&&(a=i,i=o.pop()),"function"!=typeof i)throw new Error("createSelector expects an output function after the inputs, but received: ["+typeof i+"]");var l=a.memoizeOptions,f=void 0===l?r:l,p=Array.isArray(f)?f:[f],s=getDependencies(o),d=e.apply(void 0,[function(){return u++,i.apply(null,arguments)}].concat(p)),y=e((function(){for(var e=[],t=s.length,r=0;r<t;r++)e.push(s[r].apply(null,arguments));return c=d.apply(null,e)}));return Object.assign(y,{resultFunc:i,memoizedResultFunc:d,dependencies:s,lastResult:function(){return c},recomputations:function(){return u},resetRecomputations:function(){return u=0}}),y}}var createSelector=createSelectorCreator(_defaultMemoize.defaultMemoize);exports.createSelector=createSelector;var createStructuredSelector=function(e,t){if(void 0===t&&(t=createSelector),"object"!=typeof e)throw new Error("createStructuredSelector expects first argument to be an object where each property is a selector, instead received a "+typeof e);var r=Object.keys(e),o=t(r.map((function(t){return e[t]})),(function(){for(var e=arguments.length,t=new Array(e),o=0;o<e;o++)t[o]=arguments[o];return t.reduce((function(e,t,o){return e[r[o]]=t,e}),{})}));return o};exports.createStructuredSelector=createStructuredSelector;

},{"./defaultMemoize":167}],170:[function(require,module,exports){
const types=require("./types");exports.wordBoundary=()=>({type:types.POSITION,value:"b"}),exports.nonWordBoundary=()=>({type:types.POSITION,value:"B"}),exports.begin=()=>({type:types.POSITION,value:"^"}),exports.end=()=>({type:types.POSITION,value:"$"});

},{"./types":172}],171:[function(require,module,exports){
const types=require("./types"),INTS=()=>[{type:types.RANGE,from:48,to:57}],WORDS=()=>[{type:types.CHAR,value:95},{type:types.RANGE,from:97,to:122},{type:types.RANGE,from:65,to:90}].concat(INTS()),WHITESPACE=()=>[{type:types.CHAR,value:9},{type:types.CHAR,value:10},{type:types.CHAR,value:11},{type:types.CHAR,value:12},{type:types.CHAR,value:13},{type:types.CHAR,value:32},{type:types.CHAR,value:160},{type:types.CHAR,value:5760},{type:types.RANGE,from:8192,to:8202},{type:types.CHAR,value:8232},{type:types.CHAR,value:8233},{type:types.CHAR,value:8239},{type:types.CHAR,value:8287},{type:types.CHAR,value:12288},{type:types.CHAR,value:65279}],NOTANYCHAR=()=>[{type:types.CHAR,value:10},{type:types.CHAR,value:13},{type:types.CHAR,value:8232},{type:types.CHAR,value:8233}];exports.words=()=>({type:types.SET,set:WORDS(),not:!1}),exports.notWords=()=>({type:types.SET,set:WORDS(),not:!0}),exports.ints=()=>({type:types.SET,set:INTS(),not:!1}),exports.notInts=()=>({type:types.SET,set:INTS(),not:!0}),exports.whitespace=()=>({type:types.SET,set:WHITESPACE(),not:!1}),exports.notWhitespace=()=>({type:types.SET,set:WHITESPACE(),not:!0}),exports.anyChar=()=>({type:types.SET,set:NOTANYCHAR(),not:!0});

},{"./types":172}],193:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.$guard=void 0;var TypeGuardError_1=require("../TypeGuardError"),$guard=function(r){return function(e,u){if(!0===e)throw new TypeGuardError_1.TypeGuardError({method:r,path:u.path,expected:u.expected,value:u.value});return!1}};exports.$guard=$guard;

},{"../TypeGuardError":183}],196:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.$number=void 0;var TypeGuardError_1=require("../TypeGuardError"),$number=function(r){if(!1===isFinite(r))throw new TypeGuardError_1.TypeGuardError({method:"typia.json.stringify",expected:"number",value:r,message:"Error on typia.json.stringify(): infinite or not a number."});return r};exports.$number=$number;

},{"../TypeGuardError":183}],190:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.$any=void 0;var _clone_1=require("./$clone"),$any=function(e){return void 0!==e?(0,_clone_1.$clone)(e):void 0};exports.$any=$any;

},{"./$clone":191}],187:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.$ProtobufSizer=void 0;var _strlen_1=require("./$strlen"),$ProtobufSizer=function(){function t(t){void 0===t&&(t=0),this.len=t,this.pos=[],this.varlen=[],this.varlenidx=[]}return t.prototype.bool=function(){this.len+=1},t.prototype.int32=function(t){t<0?this.len+=10:this.varint32(t)},t.prototype.sint32=function(t){this.varint32(t<<1^t>>31)},t.prototype.uint32=function(t){this.varint32(t)},t.prototype.int64=function(t){this.varint64("number"==typeof t?BigInt(t):t)},t.prototype.sint64=function(t){"number"==typeof t&&(t=BigInt(t)),this.varint64(t<<BigInt(1)^t>>BigInt(63))},t.prototype.uint64=function(t){this.varint64("number"==typeof t?BigInt(t):t)},t.prototype.float=function(t){this.len+=4},t.prototype.double=function(t){this.len+=8},t.prototype.bytes=function(t){this.uint32(t.byteLength),this.len+=t.byteLength},t.prototype.string=function(t){var n=(0,_strlen_1.$strlen)(t);this.varlen.push(n),this.uint32(n),this.len+=n},t.prototype.fork=function(){this.pos.push(this.len),this.varlenidx.push(this.varlen.length),this.varlen.push(0)},t.prototype.ldelim=function(){if(!this.pos.length||!this.varlenidx.length)throw new Error("Error on typia.protobuf.encode(): missing fork() before ldelim() call.");var t=this.len,n=this.pos.pop(),i=this.varlenidx.pop(),o=t-n;this.varlen[i]=o,this.uint32(o)},t.prototype.reset=function(){this.len=0,this.pos.length=0,this.varlen.length=0,this.varlenidx.length=0},t.prototype.varint32=function(t){this.len+=t<0?10:t<128?1:t<16384?2:t<2097152?3:t<268435456?4:5},t.prototype.varint64=function(t){for(t=BigInt.asUintN(64,t);t>NX7F;)++this.len,t>>=ND07;++this.len},t}();exports.$ProtobufSizer=$ProtobufSizer;var ND07=BigInt(7),NX7F=BigInt(127);

},{"./$strlen":200}],226:[function(require,module,exports){
"use strict";var __createBinding=this&&this.__createBinding||(Object.create?function(e,r,t,i){void 0===i&&(i=t);var o=Object.getOwnPropertyDescriptor(r,t);o&&!("get"in o?!r.__esModule:o.writable||o.configurable)||(o={enumerable:!0,get:function(){return r[t]}}),Object.defineProperty(e,i,o)}:function(e,r,t,i){void 0===i&&(i=t),e[i]=r[t]}),__exportStar=this&&this.__exportStar||function(e,r){for(var t in e)"default"===t||Object.prototype.hasOwnProperty.call(r,t)||__createBinding(r,e,t)};Object.defineProperty(exports,"__esModule",{value:!0}),__exportStar(require("./Default"),exports),__exportStar(require("./ExclusiveMaximum"),exports),__exportStar(require("./ExclusiveMinimum"),exports),__exportStar(require("./Format"),exports),__exportStar(require("./Maximum"),exports),__exportStar(require("./MaxItems"),exports),__exportStar(require("./MaxLength"),exports),__exportStar(require("./Minimum"),exports),__exportStar(require("./MinItems"),exports),__exportStar(require("./MinLength"),exports),__exportStar(require("./MultipleOf"),exports),__exportStar(require("./Pattern"),exports),__exportStar(require("./TagBase"),exports),__exportStar(require("./Type"),exports);

},{"./Default":212,"./ExclusiveMaximum":213,"./ExclusiveMinimum":214,"./Format":215,"./MaxItems":216,"./MaxLength":217,"./Maximum":218,"./MinItems":219,"./MinLength":220,"./Minimum":221,"./MultipleOf":222,"./Pattern":223,"./TagBase":224,"./Type":225}],7:[function(require,module,exports){
var _typeof=require("./typeof.js").default,toPrimitive=require("./toPrimitive.js");function _toPropertyKey(e){var t=toPrimitive(e,"string");return"symbol"===_typeof(t)?t:String(t)}module.exports=_toPropertyKey,module.exports.__esModule=!0,module.exports.default=module.exports;

},{"./toPrimitive.js":6,"./typeof.js":8}],26:[function(require,module,exports){
"use strict";var dom=require("./dom.js"),platform=require("./platform.js");function isPortalEvent(e){return Boolean(e.currentTarget&&!dom.contains(e.currentTarget,e.target))}function isSelfTarget(e){return e.target===e.currentTarget}function isOpeningInNewTab(e){const t=e.currentTarget;if(!t)return!1;const n=platform.isApple();if(n&&!e.metaKey)return!1;if(!n&&!e.ctrlKey)return!1;const r=t.tagName.toLowerCase();return"a"===r||("button"===r&&"submit"===t.type||"input"===r&&"submit"===t.type)}function isDownloading(e){const t=e.currentTarget;if(!t)return!1;const n=t.tagName.toLowerCase();return!!e.altKey&&("a"===n||("button"===n&&"submit"===t.type||"input"===n&&"submit"===t.type))}function fireEvent(e,t,n){const r=new Event(t,n);return e.dispatchEvent(r)}function fireBlurEvent(e,t){const n=new FocusEvent("blur",t),r=e.dispatchEvent(n),o={...t,bubbles:!0};return e.dispatchEvent(new FocusEvent("focusout",o)),r}function fireFocusEvent(e,t){const n=new FocusEvent("focus",t),r=e.dispatchEvent(n),o={...t,bubbles:!0};return e.dispatchEvent(new FocusEvent("focusin",o)),r}function fireKeyboardEvent(e,t,n){const r=new KeyboardEvent(t,n);return e.dispatchEvent(r)}function fireClickEvent(e,t){const n=new MouseEvent("click",t);return e.dispatchEvent(n)}function isFocusEventOutside(e,t){const n=t||e.currentTarget,r=e.relatedTarget;return!r||!dom.contains(n,r)}function queueBeforeEvent(e,t,n){const r=requestAnimationFrame((()=>{e.removeEventListener(t,o,!0),n()})),o=()=>{cancelAnimationFrame(r),n()};return e.addEventListener(t,o,{once:!0,capture:!0}),r}function addGlobalEventListener(e,t,n,r){void 0===r&&(r=window);try{r.document.addEventListener(e,t,n)}catch(e){}const o=[];for(let i=0;i<r.frames?.length;i+=1){const s=r.frames[i];s&&o.push(addGlobalEventListener(e,t,n,s))}return()=>{try{r.document.removeEventListener(e,t,n)}catch(e){}o.forEach((e=>e()))}}exports.addGlobalEventListener=addGlobalEventListener,exports.fireBlurEvent=fireBlurEvent,exports.fireClickEvent=fireClickEvent,exports.fireEvent=fireEvent,exports.fireFocusEvent=fireFocusEvent,exports.fireKeyboardEvent=fireKeyboardEvent,exports.isDownloading=isDownloading,exports.isFocusEventOutside=isFocusEventOutside,exports.isOpeningInNewTab=isOpeningInNewTab,exports.isPortalEvent=isPortalEvent,exports.isSelfTarget=isSelfTarget,exports.queueBeforeEvent=queueBeforeEvent;

},{"./dom.js":25,"./platform.js":29}],177:[function(require,module,exports){
"use strict";const assureArray=require("assure-array");module.exports=function(r,e){return assureArray(e).reduce(((r,e)=>e(r)),r)};

},{"assure-array":81}],313:[function(require,module,exports){
require("../node_modules/icssify/global-css-loader.js"); module.exports = {};
},{"../node_modules/icssify/global-css-loader.js":86}],174:[function(require,module,exports){
(function (setImmediate){(function (){
/**
 * @license React
 * scheduler.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
"use strict";function f(e,n){var t=e.length;e.push(n);e:for(;0<t;){var r=t-1>>>1,a=e[r];if(!(0<g(a,n)))break e;e[r]=n,e[t]=a,t=r}}function h(e){return 0===e.length?null:e[0]}function k(e){if(0===e.length)return null;var n=e[0],t=e.pop();if(t!==n){e[0]=t;e:for(var r=0,a=e.length,o=a>>>1;r<o;){var l=2*(r+1)-1,i=e[l],u=l+1,s=e[u];if(0>g(i,t))u<a&&0>g(s,i)?(e[r]=s,e[u]=t,r=u):(e[r]=i,e[l]=t,r=l);else{if(!(u<a&&0>g(s,t)))break e;e[r]=s,e[u]=t,r=u}}}return n}function g(e,n){var t=e.sortIndex-n.sortIndex;return 0!==t?t:e.id-n.id}if("object"==typeof performance&&"function"==typeof performance.now){var l=performance;exports.unstable_now=function(){return l.now()}}else{var p=Date,q=p.now();exports.unstable_now=function(){return p.now()-q}}var r=[],t=[],u=1,v=null,y=3,z=!1,A=!1,B=!1,D="function"==typeof setTimeout?setTimeout:null,E="function"==typeof clearTimeout?clearTimeout:null,F="undefined"!=typeof setImmediate?setImmediate:null;function G(e){for(var n=h(t);null!==n;){if(null===n.callback)k(t);else{if(!(n.startTime<=e))break;k(t),n.sortIndex=n.expirationTime,f(r,n)}n=h(t)}}function H(e){if(B=!1,G(e),!A)if(null!==h(r))A=!0,I(J);else{var n=h(t);null!==n&&K(H,n.startTime-e)}}function J(e,n){A=!1,B&&(B=!1,E(L),L=-1),z=!0;var a=y;try{for(G(n),v=h(r);null!==v&&(!(v.expirationTime>n)||e&&!M());){var o=v.callback;if("function"==typeof o){v.callback=null,y=v.priorityLevel;var l=o(v.expirationTime<=n);n=exports.unstable_now(),"function"==typeof l?v.callback=l:v===h(r)&&k(r),G(n)}else k(r);v=h(r)}if(null!==v)var i=!0;else{var u=h(t);null!==u&&K(H,u.startTime-n),i=!1}return i}finally{v=null,y=a,z=!1}}"undefined"!=typeof navigator&&void 0!==navigator.scheduling&&void 0!==navigator.scheduling.isInputPending&&navigator.scheduling.isInputPending.bind(navigator.scheduling);var S,N=!1,O=null,L=-1,P=5,Q=-1;function M(){return!(exports.unstable_now()-Q<P)}function R(){if(null!==O){var e=exports.unstable_now();Q=e;var n=!0;try{n=O(!0,e)}finally{n?S():(N=!1,O=null)}}else N=!1}if("function"==typeof F)S=function(){F(R)};else if("undefined"!=typeof MessageChannel){var T=new MessageChannel,U=T.port2;T.port1.onmessage=R,S=function(){U.postMessage(null)}}else S=function(){D(R,0)};function I(e){O=e,N||(N=!0,S())}function K(e,n){L=D((function(){e(exports.unstable_now())}),n)}exports.unstable_IdlePriority=5,exports.unstable_ImmediatePriority=1,exports.unstable_LowPriority=4,exports.unstable_NormalPriority=3,exports.unstable_Profiling=null,exports.unstable_UserBlockingPriority=2,exports.unstable_cancelCallback=function(e){e.callback=null},exports.unstable_continueExecution=function(){A||z||(A=!0,I(J))},exports.unstable_forceFrameRate=function(e){0>e||125<e?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):P=0<e?Math.floor(1e3/e):5},exports.unstable_getCurrentPriorityLevel=function(){return y},exports.unstable_getFirstCallbackNode=function(){return h(r)},exports.unstable_next=function(e){switch(y){case 1:case 2:case 3:var n=3;break;default:n=y}var t=y;y=n;try{return e()}finally{y=t}},exports.unstable_pauseExecution=function(){},exports.unstable_requestPaint=function(){},exports.unstable_runWithPriority=function(e,n){switch(e){case 1:case 2:case 3:case 4:case 5:break;default:e=3}var t=y;y=e;try{return n()}finally{y=t}},exports.unstable_scheduleCallback=function(e,n,a){var o=exports.unstable_now();switch("object"==typeof a&&null!==a?a="number"==typeof(a=a.delay)&&0<a?o+a:o:a=o,e){case 1:var l=-1;break;case 2:l=250;break;case 5:l=1073741823;break;case 4:l=1e4;break;default:l=5e3}return e={id:u++,callback:n,priorityLevel:e,startTime:a,expirationTime:l=a+l,sortIndex:-1},a>o?(e.sortIndex=a,f(t,e),null===h(r)&&e===h(t)&&(B?(E(L),L=-1):B=!0,K(H,a-o))):(e.sortIndex=l,f(r,e),A||z||(A=!0,I(J))),e},exports.unstable_shouldYield=M,exports.unstable_wrapCallback=function(e){var n=y;return function(){var t=y;y=n;try{return e.apply(this,arguments)}finally{y=t}}};

}).call(this)}).call(this,require("timers").setImmediate)
},{"timers":178}],309:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.hasBetterScope = exports.isValidDomainPermission = void 0;
const is_valid_domain_1 = __importDefault(require("is-valid-domain"));
const psl_1 = require("psl");
/**
 * Check the input string to ensure it's a valid
 * domain that doesn't include a wildcard ("*").
 * @param domain
 * @returns
 */
function isValidDomainPermission(domain) {
    return (0, is_valid_domain_1.default)(domain, {
        wildcard: false,
        allowUnicode: true
    });
}
exports.isValidDomainPermission = isValidDomainPermission;
/**
 * Checks a domain against the Public Suffix List <https://publicsuffix.org/> to see if we
 * should suggest removing subdomain(s), since they're likely owned/ran by the same party.
 * Eg., "social.example.com" suggests "example.com".
 * @param domain
 * @returns
 */
function hasBetterScope(domain) {
    const lookup = (0, psl_1.get)(domain);
    if (lookup && lookup != domain) {
        return lookup;
    }
}
exports.hasBetterScope = hasBetterScope;

},{"is-valid-domain":93,"psl":105}],85:[function(require,module,exports){
"use strict";var reactIs=require("react-is"),REACT_STATICS={childContextTypes:!0,contextType:!0,contextTypes:!0,defaultProps:!0,displayName:!0,getDefaultProps:!0,getDerivedStateFromError:!0,getDerivedStateFromProps:!0,mixins:!0,propTypes:!0,type:!0},KNOWN_STATICS={name:!0,length:!0,prototype:!0,caller:!0,callee:!0,arguments:!0,arity:!0},FORWARD_REF_STATICS={$$typeof:!0,render:!0,defaultProps:!0,displayName:!0,propTypes:!0},MEMO_STATICS={$$typeof:!0,compare:!0,defaultProps:!0,displayName:!0,propTypes:!0,type:!0},TYPE_STATICS={};function getStatics(t){return reactIs.isMemo(t)?MEMO_STATICS:TYPE_STATICS[t.$$typeof]||REACT_STATICS}TYPE_STATICS[reactIs.ForwardRef]=FORWARD_REF_STATICS,TYPE_STATICS[reactIs.Memo]=MEMO_STATICS;var defineProperty=Object.defineProperty,getOwnPropertyNames=Object.getOwnPropertyNames,getOwnPropertySymbols=Object.getOwnPropertySymbols,getOwnPropertyDescriptor=Object.getOwnPropertyDescriptor,getPrototypeOf=Object.getPrototypeOf,objectPrototype=Object.prototype;function hoistNonReactStatics(t,e,r){if("string"!=typeof e){if(objectPrototype){var o=getPrototypeOf(e);o&&o!==objectPrototype&&hoistNonReactStatics(t,o,r)}var p=getOwnPropertyNames(e);getOwnPropertySymbols&&(p=p.concat(getOwnPropertySymbols(e)));for(var a=getStatics(t),s=getStatics(e),y=0;y<p.length;++y){var c=p[y];if(!(KNOWN_STATICS[c]||r&&r[c]||s&&s[c]||a&&a[c])){var S=getOwnPropertyDescriptor(e,c);try{defineProperty(t,c,S)}catch(t){}}}}return t}module.exports=hoistNonReactStatics;

},{"react-is":113}],121:[function(require,module,exports){
"use strict";var _interopRequireDefault=require("@babel/runtime/helpers/interopRequireDefault");exports.__esModule=!0,exports.pureFinalPropsSelectorFactory=pureFinalPropsSelectorFactory,exports.default=finalPropsSelectorFactory;var _objectWithoutPropertiesLoose2=_interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose")),_verifySubselectors=_interopRequireDefault(require("./verifySubselectors"));const _excluded=["initMapStateToProps","initMapDispatchToProps","initMergeProps"];function pureFinalPropsSelectorFactory(e,r,t,o,{areStatesEqual:i,areOwnPropsEqual:n,areStatePropsEqual:s}){let p,u,a,c,l,P=!1;function f(P,f){const d=!n(f,u),S=!i(P,p,f,u);return p=P,u=f,d&&S?(a=e(p,u),r.dependsOnOwnProps&&(c=r(o,u)),l=t(a,c,u),l):d?(e.dependsOnOwnProps&&(a=e(p,u)),r.dependsOnOwnProps&&(c=r(o,u)),l=t(a,c,u),l):S?function(){const r=e(p,u),o=!s(r,a);return a=r,o&&(l=t(a,c,u)),l}():l}return function(i,n){return P?f(i,n):(p=i,u=n,a=e(p,u),c=r(o,u),l=t(a,c,u),P=!0,l)}}function finalPropsSelectorFactory(e,r){let{initMapStateToProps:t,initMapDispatchToProps:o,initMergeProps:i}=r,n=(0,_objectWithoutPropertiesLoose2.default)(r,_excluded);const s=t(e,n),p=o(e,n),u=i(e,n);return"production"!=="production"&&(0,_verifySubselectors.default)(s,p,u),pureFinalPropsSelectorFactory(s,p,u,e,n)}

},{"./verifySubselectors":122,"@babel/runtime/helpers/interopRequireDefault":3,"@babel/runtime/helpers/objectWithoutPropertiesLoose":5}],120:[function(require,module,exports){
"use strict";var _interopRequireDefault=require("@babel/runtime/helpers/interopRequireDefault");exports.__esModule=!0,exports.defaultMergeProps=defaultMergeProps,exports.wrapMergePropsFunc=wrapMergePropsFunc,exports.mergePropsFactory=mergePropsFactory;var _extends2=_interopRequireDefault(require("@babel/runtime/helpers/extends")),_verifyPlainObject=_interopRequireDefault(require("../utils/verifyPlainObject")),_invalidArgFactory=require("./invalidArgFactory");function defaultMergeProps(e,r,t){return(0,_extends2.default)({},t,e,r)}function wrapMergePropsFunc(e){return function(r,{displayName:t,areMergedPropsEqual:o}){let n,u=!1;return function(r,a,i){const p=e(r,a,i);return u?o(p,n)||(n=p):(u=!0,n=p,"production"!=="production"&&(0,_verifyPlainObject.default)(n,t,"mergeProps")),n}}}function mergePropsFactory(e){return e?"function"==typeof e?wrapMergePropsFunc(e):(0,_invalidArgFactory.createInvalidArgFactory)(e,"mergeProps"):()=>defaultMergeProps}

},{"../utils/verifyPlainObject":139,"./invalidArgFactory":117,"@babel/runtime/helpers/extends":2,"@babel/runtime/helpers/interopRequireDefault":3}],123:[function(require,module,exports){
"use strict";var _interopRequireDefault=require("@babel/runtime/helpers/interopRequireDefault");exports.__esModule=!0,exports.wrapMapToPropsConstant=wrapMapToPropsConstant,exports.getDependsOnOwnProps=getDependsOnOwnProps,exports.wrapMapToPropsFunc=wrapMapToPropsFunc;var _verifyPlainObject=_interopRequireDefault(require("../utils/verifyPlainObject"));function wrapMapToPropsConstant(n){return function(e){const r=n(e);function p(){return r}return p.dependsOnOwnProps=!1,p}}function getDependsOnOwnProps(n){return n.dependsOnOwnProps?Boolean(n.dependsOnOwnProps):1!==n.length}function wrapMapToPropsFunc(n,e){return function(r,{displayName:p}){const o=function(n,e){return o.dependsOnOwnProps?o.mapToProps(n,e):o.mapToProps(n,void 0)};return o.dependsOnOwnProps=!0,o.mapToProps=function(r,s){o.mapToProps=n,o.dependsOnOwnProps=getDependsOnOwnProps(n);let t=o(r,s);return"function"==typeof t&&(o.mapToProps=t,o.dependsOnOwnProps=getDependsOnOwnProps(t),t=o(r,s)),"production"!=="production"&&(0,_verifyPlainObject.default)(t,p,e),t},o}}

},{"../utils/verifyPlainObject":139,"@babel/runtime/helpers/interopRequireDefault":3}],31:[function(require,module,exports){
"use strict";var react=require("react");const PopoverContext=react.createContext(void 0);exports.PopoverContext=PopoverContext;

},{"react":146}],32:[function(require,module,exports){
"use strict";var react=require("react");const CollectionItemContext=react.createContext(void 0);exports.CollectionItemContext=CollectionItemContext;

},{"react":146}],34:[function(require,module,exports){
"use strict";var react=require("react");const GroupLabelContext=react.createContext(void 0);exports.GroupLabelContext=GroupLabelContext;

},{"react":146}],35:[function(require,module,exports){
"use strict";var react=require("react");const HeadingContext=react.createContext(0);exports.HeadingContext=HeadingContext;

},{"react":146}],61:[function(require,module,exports){
"use strict";var react=require("react");const DialogContext=react.createContext(void 0),DialogHeadingContext=react.createContext(void 0),DialogDescriptionContext=react.createContext(void 0);exports.DialogContext=DialogContext,exports.DialogDescriptionContext=DialogDescriptionContext,exports.DialogHeadingContext=DialogHeadingContext;

},{"react":146}],77:[function(require,module,exports){
"use strict";var react=require("react");const PortalContext=react.createContext(null);exports.PortalContext=PortalContext;

},{"react":146}],114:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.default=exports.ReactReduxContext=void 0;var React=_interopRequireWildcard(require("react"));function _getRequireWildcardCache(e){if("function"!=typeof WeakMap)return null;var t=new WeakMap,r=new WeakMap;return(_getRequireWildcardCache=function(e){return e?r:t})(e)}function _interopRequireWildcard(e,t){if(!t&&e&&e.__esModule)return e;if(null===e||"object"!=typeof e&&"function"!=typeof e)return{default:e};var r=_getRequireWildcardCache(t);if(r&&r.has(e))return r.get(e);var n={},o=Object.defineProperty&&Object.getOwnPropertyDescriptor;for(var a in e)if("default"!==a&&Object.prototype.hasOwnProperty.call(e,a)){var c=o?Object.getOwnPropertyDescriptor(e,a):null;c&&(c.get||c.set)?Object.defineProperty(n,a,c):n[a]=e[a]}return n.default=e,r&&r.set(e,n),n}const ContextKey=Symbol.for("react-redux-context"),gT="undefined"!=typeof globalThis?globalThis:{};function getContext(){var e;if(!React.createContext)return{};const t=null!=(e=gT[ContextKey])?e:gT[ContextKey]=new Map;let r=t.get(React.createContext);return r||(r=React.createContext(null),"production"!=="production"&&(r.displayName="ReactRedux"),t.set(React.createContext,r)),r}const ReactReduxContext=getContext();exports.ReactReduxContext=ReactReduxContext;var _default=ReactReduxContext;exports.default=_default;

},{"react":146}],137:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.useIsomorphicLayoutEffect=exports.canUseDOM=void 0;var React=_interopRequireWildcard(require("react"));function _getRequireWildcardCache(e){if("function"!=typeof WeakMap)return null;var t=new WeakMap,r=new WeakMap;return(_getRequireWildcardCache=function(e){return e?r:t})(e)}function _interopRequireWildcard(e,t){if(!t&&e&&e.__esModule)return e;if(null===e||"object"!=typeof e&&"function"!=typeof e)return{default:e};var r=_getRequireWildcardCache(t);if(r&&r.has(e))return r.get(e);var o={},c=Object.defineProperty&&Object.getOwnPropertyDescriptor;for(var n in e)if("default"!==n&&Object.prototype.hasOwnProperty.call(e,n)){var a=c?Object.getOwnPropertyDescriptor(e,n):null;a&&(a.get||a.set)?Object.defineProperty(o,n,a):o[n]=e[n]}return o.default=e,r&&r.set(e,o),o}const canUseDOM=!("undefined"==typeof window||void 0===window.document||void 0===window.document.createElement);exports.canUseDOM=canUseDOM;const useIsomorphicLayoutEffect=canUseDOM?React.useLayoutEffect:React.useEffect;exports.useIsomorphicLayoutEffect=useIsomorphicLayoutEffect;

},{"react":146}],144:[function(require,module,exports){
/**
 * @license React
 * react-jsx-runtime.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
"use strict";var f=require("react"),k=Symbol.for("react.element"),l=Symbol.for("react.fragment"),m=Object.prototype.hasOwnProperty,n=f.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED.ReactCurrentOwner,p={key:!0,ref:!0,__self:!0,__source:!0};function q(e,r,t){var o,f={},_=null,s=null;for(o in void 0!==t&&(_=""+t),void 0!==r.key&&(_=""+r.key),void 0!==r.ref&&(s=r.ref),r)m.call(r,o)&&!p.hasOwnProperty(o)&&(f[o]=r[o]);if(e&&e.defaultProps)for(o in r=e.defaultProps)void 0===f[o]&&(f[o]=r[o]);return{$$typeof:k,type:e,key:_,ref:s,props:f,_owner:n.current}}exports.Fragment=l,exports.jsx=q,exports.jsxs=q;

},{"react":146}],154:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.PersistGate=void 0;var _react=_interopRequireWildcard(require("react"));function _interopRequireWildcard(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var r in e)if(Object.prototype.hasOwnProperty.call(e,r)){var o=Object.defineProperty&&Object.getOwnPropertyDescriptor?Object.getOwnPropertyDescriptor(e,r):{};o.get||o.set?Object.defineProperty(t,r,o):t[r]=e[r]}return t.default=e,t}function _typeof(e){return _typeof="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},_typeof(e)}function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _defineProperties(e,t){for(var r=0;r<t.length;r++){var o=t[r];o.enumerable=o.enumerable||!1,o.configurable=!0,"value"in o&&(o.writable=!0),Object.defineProperty(e,o.key,o)}}function _createClass(e,t,r){return t&&_defineProperties(e.prototype,t),r&&_defineProperties(e,r),e}function _possibleConstructorReturn(e,t){return!t||"object"!==_typeof(t)&&"function"!=typeof t?_assertThisInitialized(e):t}function _getPrototypeOf(e){return _getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(e){return e.__proto__||Object.getPrototypeOf(e)},_getPrototypeOf(e)}function _assertThisInitialized(e){if(void 0===e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),t&&_setPrototypeOf(e,t)}function _setPrototypeOf(e,t){return _setPrototypeOf=Object.setPrototypeOf||function(e,t){return e.__proto__=t,e},_setPrototypeOf(e,t)}function _defineProperty(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var PersistGate=function(e){function t(){var e,r;_classCallCheck(this,t);for(var o=arguments.length,n=new Array(o),i=0;i<o;i++)n[i]=arguments[i];return _defineProperty(_assertThisInitialized(r=_possibleConstructorReturn(this,(e=_getPrototypeOf(t)).call.apply(e,[this].concat(n)))),"state",{bootstrapped:!1}),_defineProperty(_assertThisInitialized(r),"_unsubscribe",void 0),_defineProperty(_assertThisInitialized(r),"handlePersistorState",(function(){r.props.persistor.getState().bootstrapped&&(r.props.onBeforeLift?Promise.resolve(r.props.onBeforeLift()).finally((function(){return r.setState({bootstrapped:!0})})):r.setState({bootstrapped:!0}),r._unsubscribe&&r._unsubscribe())})),r}return _inherits(t,_react.PureComponent),_createClass(t,[{key:"componentDidMount",value:function(){this._unsubscribe=this.props.persistor.subscribe(this.handlePersistorState),this.handlePersistorState()}},{key:"componentWillUnmount",value:function(){this._unsubscribe&&this._unsubscribe()}},{key:"render",value:function(){return"production"!=="production"&&"function"==typeof this.props.children&&this.props.loading&&console.error("redux-persist: PersistGate expects either a function child or loading prop, but not both. The loading prop will be ignored."),"function"==typeof this.props.children?this.props.children(this.state.bootstrapped):this.state.bootstrapped?this.props.children:this.props.loading}}]),t}();exports.PersistGate=PersistGate,_defineProperty(PersistGate,"defaultProps",{children:null,loading:null});

},{"react":146}],228:[function(require,module,exports){
/**
 * @license React
 * use-sync-external-store-shim.development.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
"use strict";"production"!=="production"&&function(){"undefined"!=typeof __REACT_DEVTOOLS_GLOBAL_HOOK__&&"function"==typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.registerInternalModuleStart&&__REACT_DEVTOOLS_GLOBAL_HOOK__.registerInternalModuleStart(new Error);var e=require("react"),t=e.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED;function n(e){for(var n=arguments.length,r=new Array(n>1?n-1:0),o=1;o<n;o++)r[o-1]=arguments[o];!function(e,n,r){var o=t.ReactDebugCurrentFrame.getStackAddendum();""!==o&&(n+="%s",r=r.concat([o]));var a=r.map((function(e){return String(e)}));a.unshift("Warning: "+n),Function.prototype.apply.call(console[e],console,a)}("error",e,r)}var r="function"==typeof Object.is?Object.is:function(e,t){return e===t&&(0!==e||1/e==1/t)||e!=e&&t!=t},o=e.useState,a=e.useEffect,u=e.useLayoutEffect,_=e.useDebugValue,i=!1,c=!1;function s(e){var t=e.getSnapshot,n=e.value;try{var o=t();return!r(n,o)}catch(e){return!0}}var O=!!("undefined"==typeof window||void 0===window.document||void 0===window.document.createElement)?function(e,t,n){return t()}:function(t,O,f){i||void 0!==e.startTransition&&(i=!0,n("You are using an outdated, pre-release alpha of React 18 that does not support useSyncExternalStore. The use-sync-external-store shim will not work correctly. Upgrade to a newer pre-release."));var l=O();if(!c){var d=O();r(l,d)||(n("The result of getSnapshot should be cached to avoid an infinite loop"),c=!0)}var E=o({inst:{value:l,getSnapshot:O}}),S=E[0].inst,p=E[1];return u((function(){S.value=l,S.getSnapshot=O,s(S)&&p({inst:S})}),[t,l,O]),a((function(){s(S)&&p({inst:S});return t((function(){s(S)&&p({inst:S})}))}),[t]),_(l),l},f=void 0!==e.useSyncExternalStore?e.useSyncExternalStore:O;exports.useSyncExternalStore=f,"undefined"!=typeof __REACT_DEVTOOLS_GLOBAL_HOOK__&&"function"==typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.registerInternalModuleStop&&__REACT_DEVTOOLS_GLOBAL_HOOK__.registerInternalModuleStop(new Error)}();

},{"react":146}],229:[function(require,module,exports){
/**
 * @license React
 * use-sync-external-store-shim.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
"use strict";var e=require("react");function h(e,t){return e===t&&(0!==e||1/e==1/t)||e!=e&&t!=t}var k="function"==typeof Object.is?Object.is:h,l=e.useState,m=e.useEffect,n=e.useLayoutEffect,p=e.useDebugValue;function q(e,t){var u=t(),o=l({inst:{value:u,getSnapshot:t}}),i=o[0].inst,c=o[1];return n((function(){i.value=u,i.getSnapshot=t,r(i)&&c({inst:i})}),[e,u,t]),m((function(){return r(i)&&c({inst:i}),e((function(){r(i)&&c({inst:i})}))}),[e]),p(u),u}function r(e){var t=e.getSnapshot;e=e.value;try{var n=t();return!k(e,n)}catch(e){return!0}}function t(e,t){return t()}var u="undefined"==typeof window||void 0===window.document||void 0===window.document.createElement?t:q;exports.useSyncExternalStore=void 0!==e.useSyncExternalStore?e.useSyncExternalStore:u;

},{"react":146}],246:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
module.exports = function ExportFormatTable() {
  return React.createElement("div", {
    className: "export-format-table-wrapper without-border"
  }, React.createElement("table", {
    className: "export-format-table"
  }, React.createElement("thead", null, React.createElement("tr", null, React.createElement("th", {
    rowSpan: 2
  }), React.createElement("th", {
    colSpan: 2
  }, "Includes"), React.createElement("th", {
    colSpan: 2
  }, "Importable by")), React.createElement("tr", null, React.createElement("th", null, "Domain"), React.createElement("th", null, "Public comment"), React.createElement("th", null, "GoToSocial"), React.createElement("th", null, "Mastodon"))), React.createElement("tbody", null, React.createElement(Format, {
    name: "Text",
    info: [true, false, true, false]
  }), React.createElement(Format, {
    name: "JSON",
    info: [true, true, true, false]
  }), React.createElement(Format, {
    name: "CSV",
    info: [true, true, true, true]
  }))));
};
function Format(_ref) {
  let {
    name,
    info
  } = _ref;
  return React.createElement("tr", null, React.createElement("td", null, React.createElement("b", null, name)), info.map((b, key) => React.createElement("td", {
    key: key,
    className: "bool"
  }, bool(b))));
}
function bool(val) {
  return React.createElement(React.Fragment, null, React.createElement("i", {
    className: `fa fa-${val ? "check" : "times"}`,
    "aria-hidden": "true"
  }), React.createElement("span", {
    className: "sr-only"
  }, val ? "Yes" : "No"));
}

},{"react":146}],268:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_2 = require("react");
function CheckList({ field, header = "All", EntryComponent, getExtraProps }) {
    var _a;
    return (react_1.default.createElement("div", { className: "checkbox-list list" },
        react_1.default.createElement(CheckListHeader, { toggleAll: field.toggleAll },
            "\t",
            header),
        react_1.default.createElement(CheckListEntries, { entries: (_a = field.value) !== null && _a !== void 0 ? _a : {}, updateValue: field.onChange, EntryComponent: EntryComponent, getExtraProps: getExtraProps })));
}
exports.default = CheckList;
function CheckListHeader({ toggleAll, children }) {
    return (react_1.default.createElement("label", { className: "header entry" },
        react_1.default.createElement("input", { ref: toggleAll.ref, type: "checkbox", onChange: toggleAll.onChange }),
        " ",
        children));
}
const CheckListEntries = (0, react_2.memo)(function CheckListEntries({ entries, updateValue, EntryComponent, getExtraProps }) {
    const deferredEntries = (0, react_2.useDeferredValue)(entries);
    return Object.values(deferredEntries).map((entry) => (react_1.default.createElement(CheckListEntry, { key: entry.key, entry: entry, updateValue: updateValue, EntryComponent: EntryComponent, getExtraProps: getExtraProps })));
});
/*
    React.memo is a performance optimization that only re-renders a CheckListEntry
    when it's props actually change, instead of every time anything
    in the list (CheckListEntries) updates
*/
const CheckListEntry = (0, react_2.memo)(function CheckListEntry({ entry, updateValue, getExtraProps, EntryComponent }) {
    const onChange = (0, react_2.useCallback)((value) => updateValue(entry.key, value), [updateValue, entry.key]);
    const extraProps = (0, react_2.useMemo)(() => getExtraProps === null || getExtraProps === void 0 ? void 0 : getExtraProps(entry), [getExtraProps, entry]);
    return (react_1.default.createElement("label", { className: "entry" },
        react_1.default.createElement("input", { type: "checkbox", onChange: (e) => onChange({ checked: e.target.checked }), checked: entry.checked }),
        react_1.default.createElement(EntryComponent, { entry: entry, onChange: onChange, extraProps: extraProps })));
});

},{"react":146}],270:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
function ErrorFallback(_ref) {
  let {
    error,
    resetErrorBoundary
  } = _ref;
  return React.createElement("div", {
    className: "error"
  }, React.createElement("p", null, "An error occured, please report this on the ", React.createElement("a", {
    href: "https://github.com/superseriousbusiness/gotosocial/issues"
  }, "GoToSocial issue tracker"), " or ", React.createElement("a", {
    href: "https://matrix.to/#/#gotosocial-help:superseriousbusiness.org"
  }, "Matrix support room"), ".", React.createElement("br", null), "Include the details below:"), React.createElement("div", {
    className: "details"
  }, React.createElement("pre", null, error.name, ": ", error.message), React.createElement("pre", null, error.stack)), React.createElement("p", null, React.createElement("button", {
    onClick: resetErrorBoundary
  }, "Try again"), " or ", React.createElement("a", {
    href: ""
  }, "refresh the page")));
}
function Error(_ref2) {
  let {
    error
  } = _ref2;
  var _a;
  /* eslint-disable-next-line no-console */
  console.error("Rendering error:", error);
  let message;
  if (error.data != undefined) {
    // RTK Query error with data
    if (error.status) {
      message = React.createElement(React.Fragment, null, React.createElement("b", null, error.status, ":"), " ", error.data.error, error.data.error_description && React.createElement("p", null, error.data.error_description));
    } else {
      message = error.data.error;
    }
  } else if (error.name != undefined || error.type != undefined) {
    // JS error
    message = React.createElement(React.Fragment, null, React.createElement("b", null, error.type && error.name, ":"), " ", error.message);
  } else if (error.status && typeof error.error == "string") {
    message = React.createElement(React.Fragment, null, React.createElement("b", null, error.status, ":"), " ", error.error);
  } else {
    message = (_a = error.message) !== null && _a !== void 0 ? _a : error;
  }
  return React.createElement("div", {
    className: "error"
  }, message);
}
module.exports = {
  ErrorFallback,
  Error
};

},{"react":146}],271:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
module.exports = function FakeProfile(_ref) {
  let {
    avatar,
    header,
    display_name,
    username,
    role
  } = _ref;
  return (
    // Keep in sync with web/template/profile.tmpl
    React.createElement("div", {
      className: "profile"
    }, React.createElement("div", {
      className: "header"
    }, React.createElement("div", {
      className: "header-image"
    }, React.createElement("img", {
      src: header,
      alt: header ? `header image for ${username}` : "None set"
    })), React.createElement("div", {
      className: "basic-info",
      "aria-hidden": "true"
    }, React.createElement("a", {
      className: "avatar",
      href: avatar
    }, React.createElement("img", {
      src: avatar,
      alt: avatar ? `avatar image for ${username}` : "None set"
    })), React.createElement("span", {
      className: "displayname text-cutoff"
    }, display_name.trim().length > 0 ? display_name : username, React.createElement("span", {
      className: "sr-only"
    }, ".")), React.createElement("span", {
      className: "username text-cutoff"
    }, "@", username), role && role.name != "user" && React.createElement("div", {
      className: `role ${role.name}`
    }, React.createElement("span", {
      className: "sr-only"
    }, "Role: "), role.name))))
  );
};

},{"react":146}],273:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RadioGroup = exports.Select = exports.Checkbox = exports.FileInput = exports.TextArea = exports.TextInput = void 0;
const react_1 = __importDefault(require("react"));
function TextInput(_a) {
    var { label, field } = _a, props = __rest(_a, ["label", "field"]);
    const { onChange, value, ref } = field;
    return (react_1.default.createElement("div", { className: `form-field text${field.valid ? "" : " invalid"}` },
        react_1.default.createElement("label", null,
            label,
            react_1.default.createElement("input", Object.assign({ onChange: onChange, value: value, ref: ref }, props)))));
}
exports.TextInput = TextInput;
function TextArea(_a) {
    var { label, field } = _a, props = __rest(_a, ["label", "field"]);
    const { onChange, value, ref } = field;
    return (react_1.default.createElement("div", { className: "form-field textarea" },
        react_1.default.createElement("label", null,
            label,
            react_1.default.createElement("textarea", Object.assign({ onChange: onChange, value: value, ref: ref }, props)))));
}
exports.TextArea = TextArea;
function FileInput(_a) {
    var { label, field } = _a, props = __rest(_a, ["label", "field"]);
    const { onChange, ref, infoComponent } = field;
    return (react_1.default.createElement("div", { className: "form-field file" },
        react_1.default.createElement("label", null,
            react_1.default.createElement("div", { className: "label" }, label),
            react_1.default.createElement("div", { className: "file-input button" }, "Browse"),
            infoComponent,
            react_1.default.createElement("input", Object.assign({ type: "file", className: "hidden", onChange: onChange, ref: ref ? ref : undefined }, props)))));
}
exports.FileInput = FileInput;
function Checkbox(_a) {
    var { label, field } = _a, inputProps = __rest(_a, ["label", "field"]);
    const { onChange, value } = field;
    return (react_1.default.createElement("div", { className: "form-field checkbox" },
        react_1.default.createElement("label", null,
            react_1.default.createElement("input", Object.assign({ type: "checkbox", checked: value, onChange: onChange }, inputProps)),
            " ",
            label)));
}
exports.Checkbox = Checkbox;
function Select(_a) {
    var { label, field, children, options } = _a, props = __rest(_a, ["label", "field", "children", "options"]);
    const { onChange, value, ref } = field;
    return (react_1.default.createElement("div", { className: "form-field select" },
        react_1.default.createElement("label", null,
            label,
            children,
            react_1.default.createElement("select", Object.assign({ onChange: onChange, value: value, ref: ref }, props), options))));
}
exports.Select = Select;
function RadioGroup(_a) {
    var { label, field } = _a, props = __rest(_a, ["label", "field"]);
    return (react_1.default.createElement("div", { className: "form-field radio" },
        Object.entries(field.options).map(([value, radioLabel]) => (react_1.default.createElement("label", { key: value },
            react_1.default.createElement("input", Object.assign({ type: "radio", name: field.name, value: value, checked: field.value == value, onChange: field.onChange }, props)),
            radioLabel))),
        label));
}
exports.RadioGroup = RadioGroup;

},{"react":146}],275:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
const langs = require("langs");
const asElements = langs.all().map(l => {
  let code = l["1"].toUpperCase();
  let name = l.name;
  if (l.name != l.local) {
    name = `${name} - ${l.local}`;
  }
  return React.createElement("option", {
    key: code,
    value: code
  }, name);
});
module.exports = function Languages() {
  return asElements;
};

},{"langs":96,"react":146}],276:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
module.exports = function Loading() {
  return React.createElement("i", {
    className: "fa fa-spin fa-refresh loading-icon",
    "aria-label": "Loading",
    title: "Loading"
  });
};

},{"react":146}],278:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const _default = false;
function useBoolInput({ name, Name }, { initialValue = _default }) {
    const [value, setValue] = (0, react_1.useState)(initialValue);
    function onChange(e) {
        setValue(e.target.checked);
    }
    function reset() {
        setValue(initialValue);
    }
    // Array / Object hybrid, for easier access in different contexts
    return Object.assign([
        onChange,
        reset,
        {
            [name]: value,
            [`set${Name}`]: setValue
        }
    ], {
        name,
        Name: "",
        onChange,
        reset,
        value,
        setter: setValue,
        hasChanged: () => value != initialValue,
        _default
    });
}
exports.default = useBoolInput;

},{"react":146}],281:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
const FormContext = React.createContext({});
module.exports = {
  FormContext,
  useWithFormContext(index, form) {
    const formContainer = React.useContext(FormContext);
    formContainer[index] = form;
    return form;
  }
};

},{"react":146}],282:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const get_form_mutations_1 = __importDefault(require("./get-form-mutations"));
function parseFields(entries, length) {
    const fields = [];
    for (let i = 0; i < length; i++) {
        if (entries[i] != undefined) {
            fields[i] = Object.assign({}, entries[i]);
        }
        else {
            fields[i] = {};
        }
    }
    return fields;
}
function useArrayInput({ name }, { initialValue, length = 0, }) {
    const _default = Array(length);
    const fields = (0, react_1.useRef)(_default);
    const value = (0, react_1.useMemo)(() => parseFields(initialValue, length), [initialValue, length]);
    function hasUpdate() {
        return Object.values(fields.current).some((fieldSet) => {
            const { updatedFields } = (0, get_form_mutations_1.default)(fieldSet, { changedOnly: true });
            return updatedFields.length > 0;
        });
    }
    return {
        _default,
        name,
        Name: "",
        value,
        ctx: fields.current,
        maxLength: length,
        hasChanged: hasUpdate,
        selectedValues() {
            if (hasUpdate()) {
                return Object.values(fields.current).map((fieldSet) => {
                    return (0, get_form_mutations_1.default)(fieldSet, { changedOnly: false }).mutationData;
                });
            }
            else {
                return [];
            }
        }
    };
}
exports.default = useArrayInput;

},{"./get-form-mutations":285,"react":146}],283:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_2 = require("react");
const prettier_bytes_1 = __importDefault(require("prettier-bytes"));
const _default = undefined;
function useFileInput({ name }, { withPreview, maxSize, initialInfo = "no file selected" }) {
    const [file, setFile] = (0, react_2.useState)();
    const [imageURL, setImageURL] = (0, react_2.useState)();
    const [info, setInfo] = (0, react_2.useState)();
    function onChange(e) {
        const files = e.target.files;
        if (!files) {
            setInfo(undefined);
            return;
        }
        let file = files[0];
        setFile(file);
        if (imageURL) {
            URL.revokeObjectURL(imageURL);
        }
        if (withPreview) {
            setImageURL(URL.createObjectURL(file));
        }
        let size = (0, prettier_bytes_1.default)(file.size);
        if (maxSize && file.size > maxSize) {
            size = react_1.default.createElement("span", { className: "error-text" }, size);
        }
        setInfo(react_1.default.createElement(react_1.default.Fragment, null,
            file.name,
            " (",
            size,
            ")"));
    }
    function reset() {
        if (imageURL) {
            URL.revokeObjectURL(imageURL);
        }
        setImageURL(undefined);
        setFile(undefined);
        setInfo(undefined);
    }
    const infoComponent = (react_1.default.createElement("span", { className: "form-info" }, info
        ? info
        : initialInfo));
    // Array / Object hybrid, for easier access in different contexts
    return Object.assign([
        onChange,
        reset,
        {
            [name]: file,
            [`${name}URL`]: imageURL,
            [`${name}Info`]: infoComponent,
        }
    ], {
        onChange,
        reset,
        name,
        Name: "",
        value: file,
        previewValue: imageURL,
        hasChanged: () => file != undefined,
        infoComponent,
        _default,
    });
}
exports.default = useFileInput;

},{"prettier-bytes":102,"react":146}],287:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const _default = "";
function useRadioInput({ name, Name }, { initialValue = _default, options = {}, }) {
    const [value, setValue] = (0, react_1.useState)(initialValue);
    function onChange(e) {
        setValue(e.target.value);
    }
    function reset() {
        setValue(initialValue);
    }
    // Array / Object hybrid, for easier access in different contexts
    return Object.assign([
        onChange,
        reset,
        {
            [name]: value,
            [`set${Name}`]: setValue
        }
    ], {
        onChange,
        reset,
        name,
        Name: "",
        value,
        setter: setValue,
        options,
        hasChanged: () => value != initialValue,
        _default
    });
}
exports.default = useRadioInput;

},{"react":146}],288:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const get_form_mutations_1 = __importDefault(require("./get-form-mutations"));
const react_1 = require("react");
/**
 * Parse changed values from the hooked form into a request
 * body, and submit it using the given mutation trigger.
 *
 * This function basically wraps RTK Query's submit methods to
 * work with our hooked form interface.
 *
 * An `onFinish` callback function can be provided, which will
 * be executed on a **successful** run of the given MutationTrigger,
 * with the mutation result passed into it.
 *
 * If `changedOnly` is false, then **all** fields of the given HookedForm
 * will be submitted to the mutation endpoint, not just changed ones.
 *
 * The returned function and result can be triggered and read
 * from just like an RTK Query mutation hook result would be.
 *
 * See: https://redux-toolkit.js.org/rtk-query/usage/mutations#mutation-hook-behavior
 */
function useFormSubmit(form, mutationQuery, opts = { changedOnly: true }) {
    if (!Array.isArray(mutationQuery)) {
        throw "useFormSubmit: mutationQuery was not an Array. Is a valid useMutation RTK Query provided?";
    }
    const { changedOnly, onFinish } = opts;
    const [runMutation, mutationResult] = mutationQuery;
    const usedAction = (0, react_1.useRef)(undefined);
    const submitForm = (e) => __awaiter(this, void 0, void 0, function* () {
        let action;
        if (typeof e === "string") {
            if (e !== "") {
                // String action name was provided.
                action = e;
            }
            else {
                // Empty string action name was provided.
                action = undefined;
            }
        }
        else if (e) {
            // Submit event action was provided.
            e.preventDefault();
            if (e.nativeEvent.submitter) {
                // We want the name of the element that was invoked to submit this form,
                // which will be something that extends HTMLElement, though we don't know
                // what at this point. If it's an empty string, fall back to undefined.
                // 
                // See: https://developer.mozilla.org/en-US/docs/Web/API/SubmitEvent/submitter
                action = e.nativeEvent.submitter.name || undefined;
            }
            else {
                // No submitter defined. Fall back
                // to just use the FormSubmitEvent.
                action = e;
            }
        }
        else {
            // Void or null or something
            // else was provided.
            action = undefined;
        }
        usedAction.current = action;
        // Transform the hooked form into an object.
        const { mutationData, updatedFields, } = (0, get_form_mutations_1.default)(form, { changedOnly });
        // If there were no updated fields according to
        // the form parsing then there's nothing for us
        // to do, since remote and desired state match.
        if (updatedFields.length == 0) {
            return;
        }
        mutationData.action = action;
        try {
            const res = yield runMutation(mutationData);
            if (onFinish) {
                onFinish(res);
            }
        }
        catch (e) {
            // eslint-disable-next-line no-console
            console.error(`caught error running mutation: ${e}`);
        }
    });
    return [
        submitForm,
        Object.assign(Object.assign({}, mutationResult), { action: usedAction.current })
    ];
}
exports.default = useFormSubmit;

},{"./get-form-mutations":285,"react":146}],289:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const _default = "";
function useTextInput({ name, Name }, { initialValue = _default, dontReset = false, validator, showValidation = true, initValidation, nosubmit = false, }) {
    const [text, setText] = (0, react_1.useState)(initialValue);
    const textRef = (0, react_1.useRef)(null);
    const [validation, setValidation] = (0, react_1.useState)(initValidation !== null && initValidation !== void 0 ? initValidation : "");
    const [_isValidating, startValidation] = (0, react_1.useTransition)();
    const valid = validation == "";
    function onChange(e) {
        const input = e.target.value;
        setText(input);
        if (validator) {
            startValidation(() => {
                setValidation(validator(input));
            });
        }
    }
    function reset() {
        if (!dontReset) {
            setText(initialValue);
        }
    }
    (0, react_1.useEffect)(() => {
        if (validator && textRef.current) {
            if (showValidation) {
                textRef.current.setCustomValidity(validation);
            }
            else {
                textRef.current.setCustomValidity("");
            }
        }
    }, [validation, validator, showValidation]);
    // Array / Object hybrid, for easier access in different contexts
    return Object.assign([
        onChange,
        reset,
        {
            [name]: text,
            [`${name}Ref`]: textRef,
            [`set${Name}`]: setText,
            [`${name}Valid`]: valid,
        }
    ], {
        onChange,
        reset,
        name,
        Name: "",
        nosubmit,
        value: text,
        ref: textRef,
        setter: setText,
        valid,
        validate: () => setValidation(validator ? validator(text) : ""),
        hasChanged: () => text != initialValue,
        _default
    });
}
exports.default = useTextInput;

},{"react":146}],292:[function(require,module,exports){
"use strict";const React=require("react"),RoleContext=React.createContext([]),BaseUrlContext=React.createContext(null);function urlSafe(e){return e.toLowerCase().replace(/[\s/]+/g,"-")}function useHasPermission(e){return checkPermission(e,React.useContext(RoleContext))}function checkPermission(e,t){return!1===e||t.some((t=>e.includes(t)))}function useBaseUrl(){return React.useContext(BaseUrlContext)}module.exports={urlSafe:urlSafe,RoleContext:RoleContext,useHasPermission:useHasPermission,checkPermission:checkPermission,BaseUrlContext:BaseUrlContext,useBaseUrl:useBaseUrl};

},{"react":146}],156:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.default=persistReducer;var _constants=require("./constants"),_autoMergeLevel=_interopRequireDefault(require("./stateReconciler/autoMergeLevel1")),_createPersistoid=_interopRequireDefault(require("./createPersistoid")),_getStoredState=_interopRequireDefault(require("./getStoredState")),_purgeStoredState=_interopRequireDefault(require("./purgeStoredState"));function _interopRequireDefault(e){return e&&e.__esModule?e:{default:e}}function ownKeys(e,r){var t=Object.keys(e);if(Object.getOwnPropertySymbols){var o=Object.getOwnPropertySymbols(e);r&&(o=o.filter((function(r){return Object.getOwnPropertyDescriptor(e,r).enumerable}))),t.push.apply(t,o)}return t}function _objectSpread(e){for(var r=1;r<arguments.length;r++){var t=null!=arguments[r]?arguments[r]:{};r%2?ownKeys(t,!0).forEach((function(r){_defineProperty(e,r,t[r])})):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(t)):ownKeys(t).forEach((function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(t,r))}))}return e}function _defineProperty(e,r,t){return r in e?Object.defineProperty(e,r,{value:t,enumerable:!0,configurable:!0,writable:!0}):e[r]=t,e}function _objectWithoutProperties(e,r){if(null==e)return{};var t,o,i=_objectWithoutPropertiesLoose(e,r);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(e);for(o=0;o<n.length;o++)t=n[o],r.indexOf(t)>=0||Object.prototype.propertyIsEnumerable.call(e,t)&&(i[t]=e[t])}return i}function _objectWithoutPropertiesLoose(e,r){if(null==e)return{};var t,o,i={},n=Object.keys(e);for(o=0;o<n.length;o++)t=n[o],r.indexOf(t)>=0||(i[t]=e[t]);return i}var DEFAULT_TIMEOUT=5e3;function persistReducer(e,r){if("production"!=="production"){if(!e)throw new Error("config is required for persistReducer");if(!e.key)throw new Error("key is required in persistor config");if(!e.storage)throw new Error("redux-persist: config.storage is required. Try using one of the provided storage engines `import storage from 'redux-persist/lib/storage'`")}var t=void 0!==e.version?e.version:_constants.DEFAULT_VERSION,o=(e.debug,void 0===e.stateReconciler?_autoMergeLevel.default:e.stateReconciler),i=e.getStoredState||_getStoredState.default,n=void 0!==e.timeout?e.timeout:DEFAULT_TIMEOUT,s=null,u=!1,a=!0,c=function(e){return e._persist.rehydrated&&s&&!a&&s.update(e),e};return function(p,d){var f=p||{},l=f._persist,_=_objectWithoutProperties(f,["_persist"]);if(d.type===_constants.PERSIST){var y=!1,b=function(r,t){"production"!=="production"&&y&&console.error('redux-persist: rehydrate for "'.concat(e.key,'" called after timeout.'),r,t),y||(d.rehydrate(e.key,r,t),y=!0)};if(n&&setTimeout((function(){!y&&b(void 0,new Error('redux-persist: persist timed out for persist key "'.concat(e.key,'"')))}),n),a=!1,s||(s=(0,_createPersistoid.default)(e)),l)return _objectSpread({},r(_,d),{_persist:l});if("function"!=typeof d.rehydrate||"function"!=typeof d.register)throw new Error("redux-persist: either rehydrate or register is not a function on the PERSIST action. This can happen if the action is being replayed. This is an unexplored use case, please open an issue and we will figure out a resolution.");return d.register(e.key),i(e).then((function(r){(e.migrate||function(e,r){return Promise.resolve(e)})(r,t).then((function(e){b(e)}),(function(e){"production"!=="production"&&e&&console.error("redux-persist: migration error",e),b(void 0,e)}))}),(function(e){b(void 0,e)})),_objectSpread({},r(_,d),{_persist:{version:t,rehydrated:!1}})}if(d.type===_constants.PURGE)return u=!0,d.result((0,_purgeStoredState.default)(e)),_objectSpread({},r(_,d),{_persist:l});if(d.type===_constants.FLUSH)return d.result(s&&s.flush()),_objectSpread({},r(_,d),{_persist:l});if(d.type===_constants.PAUSE)a=!0;else if(d.type===_constants.REHYDRATE){if(u)return _objectSpread({},_,{_persist:_objectSpread({},l,{rehydrated:!0})});if(d.key===e.key){var g=r(_,d),S=d.payload,v=_objectSpread({},!1!==o&&void 0!==S?o(S,p,g,e):g,{_persist:_objectSpread({},l,{rehydrated:!0})});return c(v)}}if(!l)return r(p,d);var h=r(_,d);return h===_?p:c(_objectSpread({},h,{_persist:l}))}}

},{"./constants":148,"./createPersistoid":150,"./getStoredState":152,"./purgeStoredState":158,"./stateReconciler/autoMergeLevel1":159}],163:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.default=void 0;var _createWebStorage=_interopRequireDefault(require("./createWebStorage"));function _interopRequireDefault(e){return e&&e.__esModule?e:{default:e}}var _default=(0,_createWebStorage.default)("local");exports.default=_default;

},{"./createWebStorage":161}],173:[function(require,module,exports){
const types=require("./types"),sets=require("./sets"),CTRL="@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^ ?",SLSH={0:0,t:9,n:10,v:11,f:12,r:13};exports.strToChars=function(e){return e=e.replace(/(\[\\b\])|(\\)?\\(?:u([A-F0-9]{4})|x([A-F0-9]{2})|(0?[0-7]{2})|c([@A-Z[\\\]^?])|([0tnvfr]))/g,(function(e,s,r,t,n,o,p,a){if(r)return e;var i=s?8:t?parseInt(t,16):n?parseInt(n,16):o?parseInt(o,8):p?CTRL.indexOf(p):SLSH[a],u=String.fromCharCode(i);return/[[\]{}^$.|?*+()]/.test(u)&&(u="\\"+u),u}))},exports.tokenizeClass=(e,s)=>{for(var r,t,n=[],o=/\\(?:(w)|(d)|(s)|(W)|(D)|(S))|((?:(?:\\)(.)|([^\]\\]))-(?:\\)?([^\]]))|(\])|(?:\\)?([^])/g;null!=(r=o.exec(e));)if(r[1])n.push(sets.words());else if(r[2])n.push(sets.ints());else if(r[3])n.push(sets.whitespace());else if(r[4])n.push(sets.notWords());else if(r[5])n.push(sets.notInts());else if(r[6])n.push(sets.notWhitespace());else if(r[7])n.push({type:types.RANGE,from:(r[8]||r[9]).charCodeAt(0),to:r[10].charCodeAt(0)});else{if(!(t=r[12]))return[n,o.lastIndex];n.push({type:types.CHAR,value:t.charCodeAt(0)})}exports.error(s,"Unterminated character class")},exports.error=(e,s)=>{throw new SyntaxError("Invalid regular expression: /"+e+"/: "+s)};

},{"./sets":171,"./types":172}],1:[function(require,module,exports){
var toPropertyKey=require("./toPropertyKey.js");function _defineProperty(e,r,o){return(r=toPropertyKey(r))in e?Object.defineProperty(e,r,{value:o,enumerable:!0,configurable:!0,writable:!0}):e[r]=o,e}module.exports=_defineProperty,module.exports.__esModule=!0,module.exports.default=module.exports;

},{"./toPropertyKey.js":7}],20:[function(require,module,exports){
"use strict";var React=require("react"),dom=require("ariakit-utils/dom"),events=require("ariakit-utils/events"),misc$1=require("ariakit-utils/misc"),misc=require("./misc.js");function _interopNamespaceDefault(e){var t=Object.create(null);return e&&Object.keys(e).forEach((function(u){if("default"!==u){var n=Object.getOwnPropertyDescriptor(e,u);Object.defineProperty(t,u,n.get?n:{enumerable:!0,get:function(){return e[u]}})}})),t.default=e,Object.freeze(t)}var React__namespace=_interopNamespaceDefault(React);const useReactId=React__namespace.useId,useReactDeferredValue=React__namespace.useDeferredValue,useInsertionEffect=React__namespace.useInsertionEffect,useSafeLayoutEffect=dom.canUseDOM?React.useLayoutEffect:React.useEffect;function useInitialValue(e){const[t]=React.useState(e);return t}function useLazyValue(e){const t=React.useRef();return void 0===t.current&&(t.current=e()),t.current}function useLiveRef(e){const t=React.useRef(e);return useSafeLayoutEffect((()=>{t.current=e})),t}function usePreviousValue(e){const[t,u]=React.useState(e);return e!==t&&u(e),t}function useEvent(e){const t=React.useRef((()=>{throw new Error("Cannot call an event handler while rendering.")}));return useInsertionEffect?useInsertionEffect((()=>{t.current=e})):t.current=e,React.useCallback((function(){for(var e=arguments.length,u=new Array(e),n=0;n<e;n++)u[n]=arguments[n];return t.current?.(...u)}),[])}function useForkRef(){for(var e=arguments.length,t=new Array(e),u=0;u<e;u++)t[u]=arguments[u];return React.useMemo((()=>{if(t.some(Boolean))return e=>{t.forEach((t=>{misc.setRef(t,e)}))}}),t)}function useRefId(e,t){const[u,n]=React.useState(void 0);return useSafeLayoutEffect((()=>{n(e?.current?.id)}),t),u}function useId(e){if(useReactId){const t=useReactId();return e||t}const[t,u]=React.useState(e);return useSafeLayoutEffect((()=>{if(e||t)return;const n=Math.random().toString(36).substr(2,6);u(`id-${n}`)}),[e,t]),e||t}function useDeferredValue(e){if(useReactDeferredValue)return useReactDeferredValue(e);const[t,u]=React.useState(e);return React.useEffect((()=>{const t=requestAnimationFrame((()=>u(e)));return()=>cancelAnimationFrame(t)}),[e]),t}function useTagName(e,t){const[u,n]=React.useState((()=>stringOrUndefined(t)));return useSafeLayoutEffect((()=>{n(e?.current?.tagName.toLowerCase()||stringOrUndefined(t))}),[e,t]),u}function stringOrUndefined(e){if("string"==typeof e)return e}function useUpdateEffect(e,t){const u=React.useRef(!1);React.useEffect((()=>{if(u.current)return e();u.current=!0}),t),React.useEffect((()=>()=>{u.current=!1}),[])}function useUpdateLayoutEffect(e,t){const u=React.useRef(!1);useSafeLayoutEffect((()=>{if(u.current)return e();u.current=!0}),t),useSafeLayoutEffect((()=>()=>{u.current=!1}),[])}function useControlledState(e,t,u){const[n,r]=React.useState(e),s=void 0!==t?t:n,o=useLiveRef(t),a=useLiveRef(u),c=useLiveRef(s),f=React.useCallback((e=>{const t=a.current;if(t)if(isSetNextState(t))t(e);else{const u=misc$1.applyState(e,c.current);c.current=u,t(u)}void 0===o.current&&r(e)}),[]);return defineSetNextState(f),[s,f]}const SET_NEXT_STATE=Symbol("setNextState");function isSetNextState(e){return!0===e[SET_NEXT_STATE]}function defineSetNextState(e){isSetNextState(e)||Object.defineProperty(e,SET_NEXT_STATE,{value:!0})}function useForceUpdate(){return React.useReducer((()=>[]),[])}function useBooleanEvent(e){return useEvent("function"==typeof e?e:()=>e)}function useWrapElement(e,t,u){void 0===u&&(u=[]);const n=React.useCallback((u=>(e.wrapElement&&(u=e.wrapElement(u)),t(u))),[...u,e.wrapElement]);return{...e,wrapElement:n}}function usePortalRef(e,t){void 0===e&&(e=!1);const[u,n]=React.useState(null);return{portalRef:useForkRef(n,t),portalNode:u,domReady:!e||u}}function useIsMouseMoving(){React.useEffect((()=>{events.addGlobalEventListener("mousemove",setMouseMoving,!0),events.addGlobalEventListener("mousedown",resetMouseMoving,!0),events.addGlobalEventListener("mouseup",resetMouseMoving,!0),events.addGlobalEventListener("keydown",resetMouseMoving,!0),events.addGlobalEventListener("scroll",resetMouseMoving,!0)}),[]);return useEvent((()=>mouseMoving))}let mouseMoving=!1,previousScreenX=0,previousScreenY=0;function hasMouseMovement(e){const t=e.movementX||e.screenX-previousScreenX,u=e.movementY||e.screenY-previousScreenY;return previousScreenX=e.screenX,previousScreenY=e.screenY,t||u||"test"==="production"}function setMouseMoving(e){hasMouseMovement(e)&&(mouseMoving=!0)}function resetMouseMoving(){mouseMoving=!1}exports.useBooleanEvent=useBooleanEvent,exports.useControlledState=useControlledState,exports.useDeferredValue=useDeferredValue,exports.useEvent=useEvent,exports.useForceUpdate=useForceUpdate,exports.useForkRef=useForkRef,exports.useId=useId,exports.useInitialValue=useInitialValue,exports.useIsMouseMoving=useIsMouseMoving,exports.useLazyValue=useLazyValue,exports.useLiveRef=useLiveRef,exports.usePortalRef=usePortalRef,exports.usePreviousValue=usePreviousValue,exports.useRefId=useRefId,exports.useSafeLayoutEffect=useSafeLayoutEffect,exports.useTagName=useTagName,exports.useUpdateEffect=useUpdateEffect,exports.useUpdateLayoutEffect=useUpdateLayoutEffect,exports.useWrapElement=useWrapElement;

},{"./misc.js":21,"ariakit-utils/dom":25,"ariakit-utils/events":26,"ariakit-utils/misc":28,"react":146}],175:[function(require,module,exports){
"use strict";module.exports=require("./cjs/scheduler.production.min.js");

},{"./cjs/scheduler.production.min.js":174}],118:[function(require,module,exports){
"use strict";var _interopRequireDefault=require("@babel/runtime/helpers/interopRequireDefault");exports.__esModule=!0,exports.mapDispatchToPropsFactory=mapDispatchToPropsFactory;var _bindActionCreators=_interopRequireDefault(require("../utils/bindActionCreators")),_wrapMapToProps=require("./wrapMapToProps"),_invalidArgFactory=require("./invalidArgFactory");function mapDispatchToPropsFactory(r){return r&&"object"==typeof r?(0,_wrapMapToProps.wrapMapToPropsConstant)((o=>(0,_bindActionCreators.default)(r,o))):r?"function"==typeof r?(0,_wrapMapToProps.wrapMapToPropsFunc)(r,"mapDispatchToProps"):(0,_invalidArgFactory.createInvalidArgFactory)(r,"mapDispatchToProps"):(0,_wrapMapToProps.wrapMapToPropsConstant)((r=>({dispatch:r})))}

},{"../utils/bindActionCreators":133,"./invalidArgFactory":117,"./wrapMapToProps":123,"@babel/runtime/helpers/interopRequireDefault":3}],119:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.mapStateToPropsFactory=mapStateToPropsFactory;var _wrapMapToProps=require("./wrapMapToProps"),_invalidArgFactory=require("./invalidArgFactory");function mapStateToPropsFactory(r){return r?"function"==typeof r?(0,_wrapMapToProps.wrapMapToPropsFunc)(r,"mapStateToProps"):(0,_invalidArgFactory.createInvalidArgFactory)(r,"mapStateToProps"):(0,_wrapMapToProps.wrapMapToPropsConstant)((()=>({})))}

},{"./invalidArgFactory":117,"./wrapMapToProps":123}],126:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.createReduxContextHook=createReduxContextHook,exports.useReduxContext=void 0;var _react=require("react"),_Context=require("../components/Context");function createReduxContextHook(e=_Context.ReactReduxContext){return function(){const t=(0,_react.useContext)(e);if("production"!=="production"&&!t)throw new Error("could not find react-redux context value; please ensure the component is wrapped in a <Provider>");return t}}const useReduxContext=createReduxContextHook();exports.useReduxContext=useReduxContext;

},{"../components/Context":114,"react":146}],115:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.default=void 0;var React=_interopRequireWildcard(require("react")),_Context=require("./Context"),_Subscription=require("../utils/Subscription"),_useIsomorphicLayoutEffect=require("../utils/useIsomorphicLayoutEffect");function _getRequireWildcardCache(e){if("function"!=typeof WeakMap)return null;var t=new WeakMap,r=new WeakMap;return(_getRequireWildcardCache=function(e){return e?r:t})(e)}function _interopRequireWildcard(e,t){if(!t&&e&&e.__esModule)return e;if(null===e||"object"!=typeof e&&"function"!=typeof e)return{default:e};var r=_getRequireWildcardCache(t);if(r&&r.has(e))return r.get(e);var o={},i=Object.defineProperty&&Object.getOwnPropertyDescriptor;for(var n in e)if("default"!==n&&Object.prototype.hasOwnProperty.call(e,n)){var u=i?Object.getOwnPropertyDescriptor(e,n):null;u&&(u.get||u.set)?Object.defineProperty(o,n,u):o[n]=e[n]}return o.default=e,r&&r.set(e,o),o}function Provider({store:e,context:t,children:r,serverState:o,stabilityCheck:i="once",noopCheck:n="once"}){const u=React.useMemo((()=>{const t=(0,_Subscription.createSubscription)(e);return{store:e,subscription:t,getServerState:o?()=>o:void 0,stabilityCheck:i,noopCheck:n}}),[e,o,i,n]),c=React.useMemo((()=>e.getState()),[e]);(0,_useIsomorphicLayoutEffect.useIsomorphicLayoutEffect)((()=>{const{subscription:t}=u;return t.onStateChange=t.notifyNestedSubs,t.trySubscribe(),c!==e.getState()&&t.notifyNestedSubs(),()=>{t.tryUnsubscribe(),t.onStateChange=void 0}}),[u,c]);const a=t||_Context.ReactReduxContext;return React.createElement(a.Provider,{value:u},r)}var _default=Provider;exports.default=_default;

},{"../utils/Subscription":131,"../utils/useIsomorphicLayoutEffect":137,"./Context":114,"react":146}],147:[function(require,module,exports){
"use strict";module.exports=require("./cjs/react-jsx-runtime.production.min.js");

},{"./cjs/react-jsx-runtime.production.min.js":144}],232:[function(require,module,exports){
"use strict";"production"==="production"?module.exports=require("../cjs/use-sync-external-store-shim.production.min.js"):module.exports=require("../cjs/use-sync-external-store-shim.development.js");

},{"../cjs/use-sync-external-store-shim.development.js":228,"../cjs/use-sync-external-store-shim.production.min.js":229}],274:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __rest = void 0 && (void 0).__rest || function (s, e) {
  var t = {};
  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};
const React = require("react");
const {
  Error
} = require("../error");
module.exports = function MutationButton(_a) {
  var {
      label,
      result,
      disabled,
      showError = true,
      className = "",
      wrapperClassName = ""
    } = _a,
    inputProps = __rest(_a, ["label", "result", "disabled", "showError", "className", "wrapperClassName"]);
  let iconClass = "";
  const targetsThisButton = result.action == inputProps.name; // can also both be undefined, which is correct
  if (targetsThisButton) {
    if (result.isLoading) {
      iconClass = "fa-spin fa-refresh";
    } else if (result.isSuccess) {
      iconClass = "fa-check fadeout";
    }
  }
  return React.createElement("div", {
    className: wrapperClassName
  }, showError && targetsThisButton && result.error && React.createElement(Error, {
    error: result.error
  }), React.createElement("button", Object.assign({
    type: "submit",
    className: "with-icon " + className,
    disabled: result.isLoading || disabled
  }, inputProps), React.createElement("i", {
    className: `fa fa-fw ${iconClass}`,
    "aria-hidden": "true"
  }), targetsThisButton && result.isLoading ? "Processing..." : label));
};

},{"../error":270,"react":146}],284:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable no-unused-vars */
const react_1 = __importDefault(require("react"));
const error_1 = require("../../components/error");
const loading_1 = __importDefault(require("../../components/loading"));
const query_1 = require("../types/query");
/**
 * Wrap Form component inside component that fires the RTK Query call, so Form
 * will only be rendered when data is available to generate form-fields for.
 */
function FormWithData(_a) {
    var { dataQuery, DataForm, queryArg } = _a, props = __rest(_a, ["dataQuery", "DataForm", "queryArg"]);
    if (!queryArg) {
        queryArg = query_1.NoArg;
    }
    // Trigger provided query.
    const { data, isLoading, isError, error } = dataQuery(queryArg);
    if (isLoading) {
        return (react_1.default.createElement("div", null,
            react_1.default.createElement(loading_1.default, null)));
    }
    else if (isError) {
        return (react_1.default.createElement(error_1.Error, { error: error }));
    }
    else {
        return react_1.default.createElement(DataForm, Object.assign({ data: data }, props));
    }
}
exports.default = FormWithData;

},{"../../components/error":270,"../../components/loading":276,"../types/query":308,"react":146}],169:[function(require,module,exports){
const util=require("./util"),types=require("./types"),sets=require("./sets"),positions=require("./positions");module.exports=e=>{var s,t,a=0,p={type:types.ROOT,stack:[]},r=p,o=p.stack,u=[],n=s=>{util.error(e,"Nothing to repeat at column "+(s-1))},i=util.strToChars(e);for(s=i.length;a<s;)switch(t=i[a++]){case"\\":switch(t=i[a++]){case"b":o.push(positions.wordBoundary());break;case"B":o.push(positions.nonWordBoundary());break;case"w":o.push(sets.words());break;case"W":o.push(sets.notWords());break;case"d":o.push(sets.ints());break;case"D":o.push(sets.notInts());break;case"s":o.push(sets.whitespace());break;case"S":o.push(sets.notWhitespace());break;default:/\d/.test(t)?o.push({type:types.REFERENCE,value:parseInt(t,10)}):o.push({type:types.CHAR,value:t.charCodeAt(0)})}break;case"^":o.push(positions.begin());break;case"$":o.push(positions.end());break;case"[":var c;"^"===i[a]?(c=!0,a++):c=!1;var h=util.tokenizeClass(i.slice(a),e);a+=h[1],o.push({type:types.SET,set:h[0],not:c});break;case".":o.push(sets.anyChar());break;case"(":var l={type:types.GROUP,stack:[],remember:!0};"?"===(t=i[a])&&(t=i[a+1],a+=2,"="===t?l.followedBy=!0:"!"===t?l.notFollowedBy=!0:":"!==t&&util.error(e,`Invalid group, character '${t}' after '?' at column `+(a-1)),l.remember=!1),o.push(l),u.push(r),r=l,o=l.stack;break;case")":0===u.length&&util.error(e,"Unmatched ) at column "+(a-1)),o=(r=u.pop()).options?r.options[r.options.length-1]:r.stack;break;case"|":r.options||(r.options=[r.stack],delete r.stack);var y=[];r.options.push(y),o=y;break;case"{":var k,b,d=/^(\d+)(,(\d+)?)?\}/.exec(i.slice(a));null!==d?(0===o.length&&n(a),k=parseInt(d[1],10),b=d[2]?d[3]?parseInt(d[3],10):1/0:k,a+=d[0].length,o.push({type:types.REPETITION,min:k,max:b,value:o.pop()})):o.push({type:types.CHAR,value:123});break;case"?":0===o.length&&n(a),o.push({type:types.REPETITION,min:0,max:1,value:o.pop()});break;case"+":0===o.length&&n(a),o.push({type:types.REPETITION,min:1,max:1/0,value:o.pop()});break;case"*":0===o.length&&n(a),o.push({type:types.REPETITION,min:0,max:1/0,value:o.pop()});break;default:o.push({type:types.CHAR,value:t.charCodeAt(0)})}return 0!==u.length&&util.error(e,"Unterminated group"),p},module.exports.types=types;

},{"./positions":170,"./sets":171,"./types":172,"./util":173}],4:[function(require,module,exports){
var defineProperty=require("./defineProperty.js");function ownKeys(e,r){var t=Object.keys(e);if(Object.getOwnPropertySymbols){var o=Object.getOwnPropertySymbols(e);r&&(o=o.filter((function(r){return Object.getOwnPropertyDescriptor(e,r).enumerable}))),t.push.apply(t,o)}return t}function _objectSpread2(e){for(var r=1;r<arguments.length;r++){var t=null!=arguments[r]?arguments[r]:{};r%2?ownKeys(Object(t),!0).forEach((function(r){defineProperty(e,r,t[r])})):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(t)):ownKeys(Object(t)).forEach((function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(t,r))}))}return e}module.exports=_objectSpread2,module.exports.__esModule=!0,module.exports.default=module.exports;

},{"./defineProperty.js":1}],38:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),array=require("ariakit-utils/array"),dom=require("ariakit-utils/dom");function isElementPreceding(e,t){return Boolean(t.compareDocumentPosition(e)&Node.DOCUMENT_POSITION_PRECEDING)}function findDOMIndex(e,t){const r=t.ref.current;if(!r)return-1;let n=e.length;if(!n)return-1;for(;n--;){const t=e[n];if(t?.ref.current&&isElementPreceding(t.ref.current,r))return n+1}return 0}function sortBasedOnDOMPosition(e){const t=e.map(((e,t)=>[t,e]));let r=!1;return t.sort(((e,t)=>{let[n,o]=e,[s,i]=t;const u=o.ref.current,c=i.ref.current;return u===c?0:u&&c?isElementPreceding(u,c)?(n>s&&(r=!0),-1):(n<s&&(r=!0),1):0})),r?t.map((e=>{let[t,r]=e;return r})):e}function setItemsBasedOnDOMPosition(e,t){const r=sortBasedOnDOMPosition(e);e!==r&&t(r)}function getCommonParent(e){const t=e[0],r=e[e.length-1];let n=t?.ref.current?.parentElement;for(;n;){if(r&&n.contains(r.ref.current))return n;n=n.parentElement}return dom.getDocument(n).body}function useTimeoutObserver(e,t){react.useEffect((()=>{const r=setTimeout((()=>setItemsBasedOnDOMPosition(e,t)));return()=>clearTimeout(r)}))}function useSortBasedOnDOMPosition(e,t){if("function"!=typeof IntersectionObserver)return void useTimeoutObserver(e,t);const r=react.useRef([]);react.useEffect((()=>{const n=getCommonParent(e),o=new IntersectionObserver((()=>{const n=!!r.current.length;r.current=e,n&&setItemsBasedOnDOMPosition(e,t)}),{root:n});return e.forEach((e=>{e.ref.current&&o.observe(e.ref.current)})),()=>o.disconnect()}),[e,t])}function useCollectionState(e){void 0===e&&(e={});const[t,r]=hooks.useControlledState([],e.items,e.setItems);useSortBasedOnDOMPosition(t,r);const n=react.useCallback((e=>{r((t=>{const r=findDOMIndex(t,e);return array.addItemToArray(t,e,r)}));return()=>{r((t=>{const r=t.filter((t=>{let{ref:r}=t;return r!==e.ref}));return t.length===r.length?t:r}))}}),[]);return react.useMemo((()=>({items:t,setItems:r,registerItem:n})),[t,r,n])}exports.useCollectionState=useCollectionState;

},{"ariakit-react-utils/hooks":20,"ariakit-utils/array":24,"ariakit-utils/dom":25,"react":146}],66:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks");function useDisclosureState(e){let{animated:t=!1,...a}=void 0===e?{}:e;const s=react.useRef(null),[o,u]=hooks.useControlledState(a.defaultOpen??!1,a.open,a.setOpen),[r,n]=react.useState(null),[l,c]=react.useState(!!t&&o),i=hooks.usePreviousValue(o),k=o||l;t&&!l&&i!==o&&c(!0);const d=react.useCallback((()=>u(!0)),[u]),m=react.useCallback((()=>u(!1)),[u]),p=react.useCallback((()=>u((e=>!e))),[u]),h=react.useCallback((()=>c(!1)),[]);return react.useMemo((()=>({disclosureRef:s,open:o,mounted:k,animated:t,animating:l,contentElement:r,setContentElement:n,setOpen:u,show:d,hide:m,toggle:p,stopAnimation:h})),[o,k,t,l,r,n,u,d,m,p,h])}exports.useDisclosureState=useDisclosureState;

},{"ariakit-react-utils/hooks":20,"react":146}],108:[function(require,module,exports){
/**
 * @license React
 * react-dom.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
"use strict";var aa=require("react"),ca=require("scheduler");function p(e){for(var n="https://reactjs.org/docs/error-decoder.html?invariant="+e,t=1;t<arguments.length;t++)n+="&args[]="+encodeURIComponent(arguments[t]);return"Minified React error #"+e+"; visit "+n+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}var da=new Set,ea={};function fa(e,n){ha(e,n),ha(e+"Capture",n)}function ha(e,n){for(ea[e]=n,e=0;e<n.length;e++)da.add(n[e])}var ia=!("undefined"==typeof window||void 0===window.document||void 0===window.document.createElement),ja=Object.prototype.hasOwnProperty,ka=/^[:A-Z_a-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD][:A-Z_a-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\-.0-9\u00B7\u0300-\u036F\u203F-\u2040]*$/,la={},ma={};function oa(e){return!!ja.call(ma,e)||!ja.call(la,e)&&(ka.test(e)?ma[e]=!0:(la[e]=!0,!1))}function pa(e,n,t,r){if(null!==t&&0===t.type)return!1;switch(typeof n){case"function":case"symbol":return!0;case"boolean":return!r&&(null!==t?!t.acceptsBooleans:"data-"!==(e=e.toLowerCase().slice(0,5))&&"aria-"!==e);default:return!1}}function qa(e,n,t,r){if(null==n||pa(e,n,t,r))return!0;if(r)return!1;if(null!==t)switch(t.type){case 3:return!n;case 4:return!1===n;case 5:return isNaN(n);case 6:return isNaN(n)||1>n}return!1}function v(e,n,t,r,l,a,i){this.acceptsBooleans=2===n||3===n||4===n,this.attributeName=r,this.attributeNamespace=l,this.mustUseProperty=t,this.propertyName=e,this.type=n,this.sanitizeURL=a,this.removeEmptyString=i}var z={};"children dangerouslySetInnerHTML defaultValue defaultChecked innerHTML suppressContentEditableWarning suppressHydrationWarning style".split(" ").forEach((function(e){z[e]=new v(e,0,!1,e,null,!1,!1)})),[["acceptCharset","accept-charset"],["className","class"],["htmlFor","for"],["httpEquiv","http-equiv"]].forEach((function(e){var n=e[0];z[n]=new v(n,1,!1,e[1],null,!1,!1)})),["contentEditable","draggable","spellCheck","value"].forEach((function(e){z[e]=new v(e,2,!1,e.toLowerCase(),null,!1,!1)})),["autoReverse","externalResourcesRequired","focusable","preserveAlpha"].forEach((function(e){z[e]=new v(e,2,!1,e,null,!1,!1)})),"allowFullScreen async autoFocus autoPlay controls default defer disabled disablePictureInPicture disableRemotePlayback formNoValidate hidden loop noModule noValidate open playsInline readOnly required reversed scoped seamless itemScope".split(" ").forEach((function(e){z[e]=new v(e,3,!1,e.toLowerCase(),null,!1,!1)})),["checked","multiple","muted","selected"].forEach((function(e){z[e]=new v(e,3,!0,e,null,!1,!1)})),["capture","download"].forEach((function(e){z[e]=new v(e,4,!1,e,null,!1,!1)})),["cols","rows","size","span"].forEach((function(e){z[e]=new v(e,6,!1,e,null,!1,!1)})),["rowSpan","start"].forEach((function(e){z[e]=new v(e,5,!1,e.toLowerCase(),null,!1,!1)}));var ra=/[\-:]([a-z])/g;function sa(e){return e[1].toUpperCase()}function ta(e,n,t,r){var l=z.hasOwnProperty(n)?z[n]:null;(null!==l?0!==l.type:r||!(2<n.length)||"o"!==n[0]&&"O"!==n[0]||"n"!==n[1]&&"N"!==n[1])&&(qa(n,t,l,r)&&(t=null),r||null===l?oa(n)&&(null===t?e.removeAttribute(n):e.setAttribute(n,""+t)):l.mustUseProperty?e[l.propertyName]=null===t?3!==l.type&&"":t:(n=l.attributeName,r=l.attributeNamespace,null===t?e.removeAttribute(n):(t=3===(l=l.type)||4===l&&!0===t?"":""+t,r?e.setAttributeNS(r,n,t):e.setAttribute(n,t))))}"accent-height alignment-baseline arabic-form baseline-shift cap-height clip-path clip-rule color-interpolation color-interpolation-filters color-profile color-rendering dominant-baseline enable-background fill-opacity fill-rule flood-color flood-opacity font-family font-size font-size-adjust font-stretch font-style font-variant font-weight glyph-name glyph-orientation-horizontal glyph-orientation-vertical horiz-adv-x horiz-origin-x image-rendering letter-spacing lighting-color marker-end marker-mid marker-start overline-position overline-thickness paint-order panose-1 pointer-events rendering-intent shape-rendering stop-color stop-opacity strikethrough-position strikethrough-thickness stroke-dasharray stroke-dashoffset stroke-linecap stroke-linejoin stroke-miterlimit stroke-opacity stroke-width text-anchor text-decoration text-rendering underline-position underline-thickness unicode-bidi unicode-range units-per-em v-alphabetic v-hanging v-ideographic v-mathematical vector-effect vert-adv-y vert-origin-x vert-origin-y word-spacing writing-mode xmlns:xlink x-height".split(" ").forEach((function(e){var n=e.replace(ra,sa);z[n]=new v(n,1,!1,e,null,!1,!1)})),"xlink:actuate xlink:arcrole xlink:role xlink:show xlink:title xlink:type".split(" ").forEach((function(e){var n=e.replace(ra,sa);z[n]=new v(n,1,!1,e,"http://www.w3.org/1999/xlink",!1,!1)})),["xml:base","xml:lang","xml:space"].forEach((function(e){var n=e.replace(ra,sa);z[n]=new v(n,1,!1,e,"http://www.w3.org/XML/1998/namespace",!1,!1)})),["tabIndex","crossOrigin"].forEach((function(e){z[e]=new v(e,1,!1,e.toLowerCase(),null,!1,!1)})),z.xlinkHref=new v("xlinkHref",1,!1,"xlink:href","http://www.w3.org/1999/xlink",!0,!1),["src","href","action","formAction"].forEach((function(e){z[e]=new v(e,1,!1,e.toLowerCase(),null,!0,!0)}));var ua=aa.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED,va=Symbol.for("react.element"),wa=Symbol.for("react.portal"),ya=Symbol.for("react.fragment"),za=Symbol.for("react.strict_mode"),Aa=Symbol.for("react.profiler"),Ba=Symbol.for("react.provider"),Ca=Symbol.for("react.context"),Da=Symbol.for("react.forward_ref"),Ea=Symbol.for("react.suspense"),Fa=Symbol.for("react.suspense_list"),Ga=Symbol.for("react.memo"),Ha=Symbol.for("react.lazy");Symbol.for("react.scope"),Symbol.for("react.debug_trace_mode");var Ia=Symbol.for("react.offscreen");Symbol.for("react.legacy_hidden"),Symbol.for("react.cache"),Symbol.for("react.tracing_marker");var Ja=Symbol.iterator;function Ka(e){return null===e||"object"!=typeof e?null:"function"==typeof(e=Ja&&e[Ja]||e["@@iterator"])?e:null}var La,A=Object.assign;function Ma(e){if(void 0===La)try{throw Error()}catch(e){var n=e.stack.trim().match(/\n( *(at )?)/);La=n&&n[1]||""}return"\n"+La+e}var Na=!1;function Oa(e,n){if(!e||Na)return"";Na=!0;var t=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{if(n)if(n=function(){throw Error()},Object.defineProperty(n.prototype,"props",{set:function(){throw Error()}}),"object"==typeof Reflect&&Reflect.construct){try{Reflect.construct(n,[])}catch(e){var r=e}Reflect.construct(e,[],n)}else{try{n.call()}catch(e){r=e}e.call(n.prototype)}else{try{throw Error()}catch(e){r=e}e()}}catch(n){if(n&&r&&"string"==typeof n.stack){for(var l=n.stack.split("\n"),a=r.stack.split("\n"),i=l.length-1,u=a.length-1;1<=i&&0<=u&&l[i]!==a[u];)u--;for(;1<=i&&0<=u;i--,u--)if(l[i]!==a[u]){if(1!==i||1!==u)do{if(i--,0>--u||l[i]!==a[u]){var o="\n"+l[i].replace(" at new "," at ");return e.displayName&&o.includes("<anonymous>")&&(o=o.replace("<anonymous>",e.displayName)),o}}while(1<=i&&0<=u);break}}}finally{Na=!1,Error.prepareStackTrace=t}return(e=e?e.displayName||e.name:"")?Ma(e):""}function Pa(e){switch(e.tag){case 5:return Ma(e.type);case 16:return Ma("Lazy");case 13:return Ma("Suspense");case 19:return Ma("SuspenseList");case 0:case 2:case 15:return e=Oa(e.type,!1);case 11:return e=Oa(e.type.render,!1);case 1:return e=Oa(e.type,!0);default:return""}}function Qa(e){if(null==e)return null;if("function"==typeof e)return e.displayName||e.name||null;if("string"==typeof e)return e;switch(e){case ya:return"Fragment";case wa:return"Portal";case Aa:return"Profiler";case za:return"StrictMode";case Ea:return"Suspense";case Fa:return"SuspenseList"}if("object"==typeof e)switch(e.$$typeof){case Ca:return(e.displayName||"Context")+".Consumer";case Ba:return(e._context.displayName||"Context")+".Provider";case Da:var n=e.render;return(e=e.displayName)||(e=""!==(e=n.displayName||n.name||"")?"ForwardRef("+e+")":"ForwardRef"),e;case Ga:return null!==(n=e.displayName||null)?n:Qa(e.type)||"Memo";case Ha:n=e._payload,e=e._init;try{return Qa(e(n))}catch(e){}}return null}function Ra(e){var n=e.type;switch(e.tag){case 24:return"Cache";case 9:return(n.displayName||"Context")+".Consumer";case 10:return(n._context.displayName||"Context")+".Provider";case 18:return"DehydratedFragment";case 11:return e=(e=n.render).displayName||e.name||"",n.displayName||(""!==e?"ForwardRef("+e+")":"ForwardRef");case 7:return"Fragment";case 5:return n;case 4:return"Portal";case 3:return"Root";case 6:return"Text";case 16:return Qa(n);case 8:return n===za?"StrictMode":"Mode";case 22:return"Offscreen";case 12:return"Profiler";case 21:return"Scope";case 13:return"Suspense";case 19:return"SuspenseList";case 25:return"TracingMarker";case 1:case 0:case 17:case 2:case 14:case 15:if("function"==typeof n)return n.displayName||n.name||null;if("string"==typeof n)return n}return null}function Sa(e){switch(typeof e){case"boolean":case"number":case"string":case"undefined":case"object":return e;default:return""}}function Ta(e){var n=e.type;return(e=e.nodeName)&&"input"===e.toLowerCase()&&("checkbox"===n||"radio"===n)}function Ua(e){var n=Ta(e)?"checked":"value",t=Object.getOwnPropertyDescriptor(e.constructor.prototype,n),r=""+e[n];if(!e.hasOwnProperty(n)&&void 0!==t&&"function"==typeof t.get&&"function"==typeof t.set){var l=t.get,a=t.set;return Object.defineProperty(e,n,{configurable:!0,get:function(){return l.call(this)},set:function(e){r=""+e,a.call(this,e)}}),Object.defineProperty(e,n,{enumerable:t.enumerable}),{getValue:function(){return r},setValue:function(e){r=""+e},stopTracking:function(){e._valueTracker=null,delete e[n]}}}}function Va(e){e._valueTracker||(e._valueTracker=Ua(e))}function Wa(e){if(!e)return!1;var n=e._valueTracker;if(!n)return!0;var t=n.getValue(),r="";return e&&(r=Ta(e)?e.checked?"true":"false":e.value),(e=r)!==t&&(n.setValue(e),!0)}function Xa(e){if(void 0===(e=e||("undefined"!=typeof document?document:void 0)))return null;try{return e.activeElement||e.body}catch(n){return e.body}}function Ya(e,n){var t=n.checked;return A({},n,{defaultChecked:void 0,defaultValue:void 0,value:void 0,checked:null!=t?t:e._wrapperState.initialChecked})}function Za(e,n){var t=null==n.defaultValue?"":n.defaultValue,r=null!=n.checked?n.checked:n.defaultChecked;t=Sa(null!=n.value?n.value:t),e._wrapperState={initialChecked:r,initialValue:t,controlled:"checkbox"===n.type||"radio"===n.type?null!=n.checked:null!=n.value}}function ab(e,n){null!=(n=n.checked)&&ta(e,"checked",n,!1)}function bb(e,n){ab(e,n);var t=Sa(n.value),r=n.type;if(null!=t)"number"===r?(0===t&&""===e.value||e.value!=t)&&(e.value=""+t):e.value!==""+t&&(e.value=""+t);else if("submit"===r||"reset"===r)return void e.removeAttribute("value");n.hasOwnProperty("value")?cb(e,n.type,t):n.hasOwnProperty("defaultValue")&&cb(e,n.type,Sa(n.defaultValue)),null==n.checked&&null!=n.defaultChecked&&(e.defaultChecked=!!n.defaultChecked)}function db(e,n,t){if(n.hasOwnProperty("value")||n.hasOwnProperty("defaultValue")){var r=n.type;if(!("submit"!==r&&"reset"!==r||void 0!==n.value&&null!==n.value))return;n=""+e._wrapperState.initialValue,t||n===e.value||(e.value=n),e.defaultValue=n}""!==(t=e.name)&&(e.name=""),e.defaultChecked=!!e._wrapperState.initialChecked,""!==t&&(e.name=t)}function cb(e,n,t){"number"===n&&Xa(e.ownerDocument)===e||(null==t?e.defaultValue=""+e._wrapperState.initialValue:e.defaultValue!==""+t&&(e.defaultValue=""+t))}var eb=Array.isArray;function fb(e,n,t,r){if(e=e.options,n){n={};for(var l=0;l<t.length;l++)n["$"+t[l]]=!0;for(t=0;t<e.length;t++)l=n.hasOwnProperty("$"+e[t].value),e[t].selected!==l&&(e[t].selected=l),l&&r&&(e[t].defaultSelected=!0)}else{for(t=""+Sa(t),n=null,l=0;l<e.length;l++){if(e[l].value===t)return e[l].selected=!0,void(r&&(e[l].defaultSelected=!0));null!==n||e[l].disabled||(n=e[l])}null!==n&&(n.selected=!0)}}function gb(e,n){if(null!=n.dangerouslySetInnerHTML)throw Error(p(91));return A({},n,{value:void 0,defaultValue:void 0,children:""+e._wrapperState.initialValue})}function hb(e,n){var t=n.value;if(null==t){if(t=n.children,n=n.defaultValue,null!=t){if(null!=n)throw Error(p(92));if(eb(t)){if(1<t.length)throw Error(p(93));t=t[0]}n=t}null==n&&(n=""),t=n}e._wrapperState={initialValue:Sa(t)}}function ib(e,n){var t=Sa(n.value),r=Sa(n.defaultValue);null!=t&&((t=""+t)!==e.value&&(e.value=t),null==n.defaultValue&&e.defaultValue!==t&&(e.defaultValue=t)),null!=r&&(e.defaultValue=""+r)}function jb(e){var n=e.textContent;n===e._wrapperState.initialValue&&""!==n&&null!==n&&(e.value=n)}function kb(e){switch(e){case"svg":return"http://www.w3.org/2000/svg";case"math":return"http://www.w3.org/1998/Math/MathML";default:return"http://www.w3.org/1999/xhtml"}}function lb(e,n){return null==e||"http://www.w3.org/1999/xhtml"===e?kb(n):"http://www.w3.org/2000/svg"===e&&"foreignObject"===n?"http://www.w3.org/1999/xhtml":e}var mb,nb=function(e){return"undefined"!=typeof MSApp&&MSApp.execUnsafeLocalFunction?function(n,t,r,l){MSApp.execUnsafeLocalFunction((function(){return e(n,t)}))}:e}((function(e,n){if("http://www.w3.org/2000/svg"!==e.namespaceURI||"innerHTML"in e)e.innerHTML=n;else{for((mb=mb||document.createElement("div")).innerHTML="<svg>"+n.valueOf().toString()+"</svg>",n=mb.firstChild;e.firstChild;)e.removeChild(e.firstChild);for(;n.firstChild;)e.appendChild(n.firstChild)}}));function ob(e,n){if(n){var t=e.firstChild;if(t&&t===e.lastChild&&3===t.nodeType)return void(t.nodeValue=n)}e.textContent=n}var pb={animationIterationCount:!0,aspectRatio:!0,borderImageOutset:!0,borderImageSlice:!0,borderImageWidth:!0,boxFlex:!0,boxFlexGroup:!0,boxOrdinalGroup:!0,columnCount:!0,columns:!0,flex:!0,flexGrow:!0,flexPositive:!0,flexShrink:!0,flexNegative:!0,flexOrder:!0,gridArea:!0,gridRow:!0,gridRowEnd:!0,gridRowSpan:!0,gridRowStart:!0,gridColumn:!0,gridColumnEnd:!0,gridColumnSpan:!0,gridColumnStart:!0,fontWeight:!0,lineClamp:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,tabSize:!0,widows:!0,zIndex:!0,zoom:!0,fillOpacity:!0,floodOpacity:!0,stopOpacity:!0,strokeDasharray:!0,strokeDashoffset:!0,strokeMiterlimit:!0,strokeOpacity:!0,strokeWidth:!0},qb=["Webkit","ms","Moz","O"];function rb(e,n,t){return null==n||"boolean"==typeof n||""===n?"":t||"number"!=typeof n||0===n||pb.hasOwnProperty(e)&&pb[e]?(""+n).trim():n+"px"}function sb(e,n){for(var t in e=e.style,n)if(n.hasOwnProperty(t)){var r=0===t.indexOf("--"),l=rb(t,n[t],r);"float"===t&&(t="cssFloat"),r?e.setProperty(t,l):e[t]=l}}Object.keys(pb).forEach((function(e){qb.forEach((function(n){n=n+e.charAt(0).toUpperCase()+e.substring(1),pb[n]=pb[e]}))}));var tb=A({menuitem:!0},{area:!0,base:!0,br:!0,col:!0,embed:!0,hr:!0,img:!0,input:!0,keygen:!0,link:!0,meta:!0,param:!0,source:!0,track:!0,wbr:!0});function ub(e,n){if(n){if(tb[e]&&(null!=n.children||null!=n.dangerouslySetInnerHTML))throw Error(p(137,e));if(null!=n.dangerouslySetInnerHTML){if(null!=n.children)throw Error(p(60));if("object"!=typeof n.dangerouslySetInnerHTML||!("__html"in n.dangerouslySetInnerHTML))throw Error(p(61))}if(null!=n.style&&"object"!=typeof n.style)throw Error(p(62))}}function vb(e,n){if(-1===e.indexOf("-"))return"string"==typeof n.is;switch(e){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var wb=null;function xb(e){return(e=e.target||e.srcElement||window).correspondingUseElement&&(e=e.correspondingUseElement),3===e.nodeType?e.parentNode:e}var yb=null,zb=null,Ab=null;function Bb(e){if(e=Cb(e)){if("function"!=typeof yb)throw Error(p(280));var n=e.stateNode;n&&(n=Db(n),yb(e.stateNode,e.type,n))}}function Eb(e){zb?Ab?Ab.push(e):Ab=[e]:zb=e}function Fb(){if(zb){var e=zb,n=Ab;if(Ab=zb=null,Bb(e),n)for(e=0;e<n.length;e++)Bb(n[e])}}function Gb(e,n){return e(n)}function Hb(){}var Ib=!1;function Jb(e,n,t){if(Ib)return e(n,t);Ib=!0;try{return Gb(e,n,t)}finally{Ib=!1,(null!==zb||null!==Ab)&&(Hb(),Fb())}}function Kb(e,n){var t=e.stateNode;if(null===t)return null;var r=Db(t);if(null===r)return null;t=r[n];e:switch(n){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(r=!r.disabled)||(r=!("button"===(e=e.type)||"input"===e||"select"===e||"textarea"===e)),e=!r;break e;default:e=!1}if(e)return null;if(t&&"function"!=typeof t)throw Error(p(231,n,typeof t));return t}var Lb=!1;if(ia)try{var Mb={};Object.defineProperty(Mb,"passive",{get:function(){Lb=!0}}),window.addEventListener("test",Mb,Mb),window.removeEventListener("test",Mb,Mb)}catch(e){Lb=!1}function Nb(e,n,t,r,l,a,i,u,o){var c=Array.prototype.slice.call(arguments,3);try{n.apply(t,c)}catch(e){this.onError(e)}}var Ob=!1,Pb=null,Qb=!1,Rb=null,Sb={onError:function(e){Ob=!0,Pb=e}};function Tb(e,n,t,r,l,a,i,u,o){Ob=!1,Pb=null,Nb.apply(Sb,arguments)}function Ub(e,n,t,r,l,a,i,u,o){if(Tb.apply(this,arguments),Ob){if(!Ob)throw Error(p(198));var c=Pb;Ob=!1,Pb=null,Qb||(Qb=!0,Rb=c)}}function Vb(e){var n=e,t=e;if(e.alternate)for(;n.return;)n=n.return;else{e=n;do{0!=(4098&(n=e).flags)&&(t=n.return),e=n.return}while(e)}return 3===n.tag?t:null}function Wb(e){if(13===e.tag){var n=e.memoizedState;if(null===n&&(null!==(e=e.alternate)&&(n=e.memoizedState)),null!==n)return n.dehydrated}return null}function Xb(e){if(Vb(e)!==e)throw Error(p(188))}function Yb(e){var n=e.alternate;if(!n){if(null===(n=Vb(e)))throw Error(p(188));return n!==e?null:e}for(var t=e,r=n;;){var l=t.return;if(null===l)break;var a=l.alternate;if(null===a){if(null!==(r=l.return)){t=r;continue}break}if(l.child===a.child){for(a=l.child;a;){if(a===t)return Xb(l),e;if(a===r)return Xb(l),n;a=a.sibling}throw Error(p(188))}if(t.return!==r.return)t=l,r=a;else{for(var i=!1,u=l.child;u;){if(u===t){i=!0,t=l,r=a;break}if(u===r){i=!0,r=l,t=a;break}u=u.sibling}if(!i){for(u=a.child;u;){if(u===t){i=!0,t=a,r=l;break}if(u===r){i=!0,r=a,t=l;break}u=u.sibling}if(!i)throw Error(p(189))}}if(t.alternate!==r)throw Error(p(190))}if(3!==t.tag)throw Error(p(188));return t.stateNode.current===t?e:n}function Zb(e){return null!==(e=Yb(e))?$b(e):null}function $b(e){if(5===e.tag||6===e.tag)return e;for(e=e.child;null!==e;){var n=$b(e);if(null!==n)return n;e=e.sibling}return null}var ac=ca.unstable_scheduleCallback,bc=ca.unstable_cancelCallback,cc=ca.unstable_shouldYield,dc=ca.unstable_requestPaint,B=ca.unstable_now,ec=ca.unstable_getCurrentPriorityLevel,fc=ca.unstable_ImmediatePriority,gc=ca.unstable_UserBlockingPriority,hc=ca.unstable_NormalPriority,ic=ca.unstable_LowPriority,jc=ca.unstable_IdlePriority,kc=null,lc=null;function mc(e){if(lc&&"function"==typeof lc.onCommitFiberRoot)try{lc.onCommitFiberRoot(kc,e,void 0,128==(128&e.current.flags))}catch(e){}}var oc=Math.clz32?Math.clz32:nc,pc=Math.log,qc=Math.LN2;function nc(e){return 0===(e>>>=0)?32:31-(pc(e)/qc|0)|0}var rc=64,sc=4194304;function tc(e){switch(e&-e){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return 4194240&e;case 4194304:case 8388608:case 16777216:case 33554432:case 67108864:return 130023424&e;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 1073741824;default:return e}}function uc(e,n){var t=e.pendingLanes;if(0===t)return 0;var r=0,l=e.suspendedLanes,a=e.pingedLanes,i=268435455&t;if(0!==i){var u=i&~l;0!==u?r=tc(u):0!==(a&=i)&&(r=tc(a))}else 0!==(i=t&~l)?r=tc(i):0!==a&&(r=tc(a));if(0===r)return 0;if(0!==n&&n!==r&&0==(n&l)&&((l=r&-r)>=(a=n&-n)||16===l&&0!=(4194240&a)))return n;if(0!=(4&r)&&(r|=16&t),0!==(n=e.entangledLanes))for(e=e.entanglements,n&=r;0<n;)l=1<<(t=31-oc(n)),r|=e[t],n&=~l;return r}function vc(e,n){switch(e){case 1:case 2:case 4:return n+250;case 8:case 16:case 32:case 64:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return n+5e3;default:return-1}}function wc(e,n){for(var t=e.suspendedLanes,r=e.pingedLanes,l=e.expirationTimes,a=e.pendingLanes;0<a;){var i=31-oc(a),u=1<<i,o=l[i];-1===o?0!=(u&t)&&0==(u&r)||(l[i]=vc(u,n)):o<=n&&(e.expiredLanes|=u),a&=~u}}function xc(e){return 0!==(e=-1073741825&e.pendingLanes)?e:1073741824&e?1073741824:0}function yc(){var e=rc;return 0==(4194240&(rc<<=1))&&(rc=64),e}function zc(e){for(var n=[],t=0;31>t;t++)n.push(e);return n}function Ac(e,n,t){e.pendingLanes|=n,536870912!==n&&(e.suspendedLanes=0,e.pingedLanes=0),(e=e.eventTimes)[n=31-oc(n)]=t}function Bc(e,n){var t=e.pendingLanes&~n;e.pendingLanes=n,e.suspendedLanes=0,e.pingedLanes=0,e.expiredLanes&=n,e.mutableReadLanes&=n,e.entangledLanes&=n,n=e.entanglements;var r=e.eventTimes;for(e=e.expirationTimes;0<t;){var l=31-oc(t),a=1<<l;n[l]=0,r[l]=-1,e[l]=-1,t&=~a}}function Cc(e,n){var t=e.entangledLanes|=n;for(e=e.entanglements;t;){var r=31-oc(t),l=1<<r;l&n|e[r]&n&&(e[r]|=n),t&=~l}}var C=0;function Dc(e){return 1<(e&=-e)?4<e?0!=(268435455&e)?16:536870912:4:1}var Ec,Fc,Gc,Hc,Ic,Jc=!1,Kc=[],Lc=null,Mc=null,Nc=null,Oc=new Map,Pc=new Map,Qc=[],Rc="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset submit".split(" ");function Sc(e,n){switch(e){case"focusin":case"focusout":Lc=null;break;case"dragenter":case"dragleave":Mc=null;break;case"mouseover":case"mouseout":Nc=null;break;case"pointerover":case"pointerout":Oc.delete(n.pointerId);break;case"gotpointercapture":case"lostpointercapture":Pc.delete(n.pointerId)}}function Tc(e,n,t,r,l,a){return null===e||e.nativeEvent!==a?(e={blockedOn:n,domEventName:t,eventSystemFlags:r,nativeEvent:a,targetContainers:[l]},null!==n&&(null!==(n=Cb(n))&&Fc(n)),e):(e.eventSystemFlags|=r,n=e.targetContainers,null!==l&&-1===n.indexOf(l)&&n.push(l),e)}function Uc(e,n,t,r,l){switch(n){case"focusin":return Lc=Tc(Lc,e,n,t,r,l),!0;case"dragenter":return Mc=Tc(Mc,e,n,t,r,l),!0;case"mouseover":return Nc=Tc(Nc,e,n,t,r,l),!0;case"pointerover":var a=l.pointerId;return Oc.set(a,Tc(Oc.get(a)||null,e,n,t,r,l)),!0;case"gotpointercapture":return a=l.pointerId,Pc.set(a,Tc(Pc.get(a)||null,e,n,t,r,l)),!0}return!1}function Vc(e){var n=Wc(e.target);if(null!==n){var t=Vb(n);if(null!==t)if(13===(n=t.tag)){if(null!==(n=Wb(t)))return e.blockedOn=n,void Ic(e.priority,(function(){Gc(t)}))}else if(3===n&&t.stateNode.current.memoizedState.isDehydrated)return void(e.blockedOn=3===t.tag?t.stateNode.containerInfo:null)}e.blockedOn=null}function Xc(e){if(null!==e.blockedOn)return!1;for(var n=e.targetContainers;0<n.length;){var t=Yc(e.domEventName,e.eventSystemFlags,n[0],e.nativeEvent);if(null!==t)return null!==(n=Cb(t))&&Fc(n),e.blockedOn=t,!1;var r=new(t=e.nativeEvent).constructor(t.type,t);wb=r,t.target.dispatchEvent(r),wb=null,n.shift()}return!0}function Zc(e,n,t){Xc(e)&&t.delete(n)}function $c(){Jc=!1,null!==Lc&&Xc(Lc)&&(Lc=null),null!==Mc&&Xc(Mc)&&(Mc=null),null!==Nc&&Xc(Nc)&&(Nc=null),Oc.forEach(Zc),Pc.forEach(Zc)}function ad(e,n){e.blockedOn===n&&(e.blockedOn=null,Jc||(Jc=!0,ca.unstable_scheduleCallback(ca.unstable_NormalPriority,$c)))}function bd(e){function n(n){return ad(n,e)}if(0<Kc.length){ad(Kc[0],e);for(var t=1;t<Kc.length;t++){var r=Kc[t];r.blockedOn===e&&(r.blockedOn=null)}}for(null!==Lc&&ad(Lc,e),null!==Mc&&ad(Mc,e),null!==Nc&&ad(Nc,e),Oc.forEach(n),Pc.forEach(n),t=0;t<Qc.length;t++)(r=Qc[t]).blockedOn===e&&(r.blockedOn=null);for(;0<Qc.length&&null===(t=Qc[0]).blockedOn;)Vc(t),null===t.blockedOn&&Qc.shift()}var cd=ua.ReactCurrentBatchConfig,dd=!0;function ed(e,n,t,r){var l=C,a=cd.transition;cd.transition=null;try{C=1,fd(e,n,t,r)}finally{C=l,cd.transition=a}}function gd(e,n,t,r){var l=C,a=cd.transition;cd.transition=null;try{C=4,fd(e,n,t,r)}finally{C=l,cd.transition=a}}function fd(e,n,t,r){if(dd){var l=Yc(e,n,t,r);if(null===l)hd(e,n,r,id,t),Sc(e,r);else if(Uc(l,e,n,t,r))r.stopPropagation();else if(Sc(e,r),4&n&&-1<Rc.indexOf(e)){for(;null!==l;){var a=Cb(l);if(null!==a&&Ec(a),null===(a=Yc(e,n,t,r))&&hd(e,n,r,id,t),a===l)break;l=a}null!==l&&r.stopPropagation()}else hd(e,n,r,null,t)}}var id=null;function Yc(e,n,t,r){if(id=null,null!==(e=Wc(e=xb(r))))if(null===(n=Vb(e)))e=null;else if(13===(t=n.tag)){if(null!==(e=Wb(n)))return e;e=null}else if(3===t){if(n.stateNode.current.memoizedState.isDehydrated)return 3===n.tag?n.stateNode.containerInfo:null;e=null}else n!==e&&(e=null);return id=e,null}function jd(e){switch(e){case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 1;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"toggle":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 4;case"message":switch(ec()){case fc:return 1;case gc:return 4;case hc:case ic:return 16;case jc:return 536870912;default:return 16}default:return 16}}var kd=null,ld=null,md=null;function nd(){if(md)return md;var e,n,t=ld,r=t.length,l="value"in kd?kd.value:kd.textContent,a=l.length;for(e=0;e<r&&t[e]===l[e];e++);var i=r-e;for(n=1;n<=i&&t[r-n]===l[a-n];n++);return md=l.slice(e,1<n?1-n:void 0)}function od(e){var n=e.keyCode;return"charCode"in e?0===(e=e.charCode)&&13===n&&(e=13):e=n,10===e&&(e=13),32<=e||13===e?e:0}function pd(){return!0}function qd(){return!1}function rd(e){function n(n,t,r,l,a){for(var i in this._reactName=n,this._targetInst=r,this.type=t,this.nativeEvent=l,this.target=a,this.currentTarget=null,e)e.hasOwnProperty(i)&&(n=e[i],this[i]=n?n(l):l[i]);return this.isDefaultPrevented=(null!=l.defaultPrevented?l.defaultPrevented:!1===l.returnValue)?pd:qd,this.isPropagationStopped=qd,this}return A(n.prototype,{preventDefault:function(){this.defaultPrevented=!0;var e=this.nativeEvent;e&&(e.preventDefault?e.preventDefault():"unknown"!=typeof e.returnValue&&(e.returnValue=!1),this.isDefaultPrevented=pd)},stopPropagation:function(){var e=this.nativeEvent;e&&(e.stopPropagation?e.stopPropagation():"unknown"!=typeof e.cancelBubble&&(e.cancelBubble=!0),this.isPropagationStopped=pd)},persist:function(){},isPersistent:pd}),n}var wd,xd,yd,sd={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(e){return e.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},td=rd(sd),ud=A({},sd,{view:0,detail:0}),vd=rd(ud),Ad=A({},ud,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:zd,button:0,buttons:0,relatedTarget:function(e){return void 0===e.relatedTarget?e.fromElement===e.srcElement?e.toElement:e.fromElement:e.relatedTarget},movementX:function(e){return"movementX"in e?e.movementX:(e!==yd&&(yd&&"mousemove"===e.type?(wd=e.screenX-yd.screenX,xd=e.screenY-yd.screenY):xd=wd=0,yd=e),wd)},movementY:function(e){return"movementY"in e?e.movementY:xd}}),Bd=rd(Ad),Cd=A({},Ad,{dataTransfer:0}),Dd=rd(Cd),Ed=A({},ud,{relatedTarget:0}),Fd=rd(Ed),Gd=A({},sd,{animationName:0,elapsedTime:0,pseudoElement:0}),Hd=rd(Gd),Id=A({},sd,{clipboardData:function(e){return"clipboardData"in e?e.clipboardData:window.clipboardData}}),Jd=rd(Id),Kd=A({},sd,{data:0}),Ld=rd(Kd),Md={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},Nd={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},Od={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function Pd(e){var n=this.nativeEvent;return n.getModifierState?n.getModifierState(e):!!(e=Od[e])&&!!n[e]}function zd(){return Pd}var Qd=A({},ud,{key:function(e){if(e.key){var n=Md[e.key]||e.key;if("Unidentified"!==n)return n}return"keypress"===e.type?13===(e=od(e))?"Enter":String.fromCharCode(e):"keydown"===e.type||"keyup"===e.type?Nd[e.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:zd,charCode:function(e){return"keypress"===e.type?od(e):0},keyCode:function(e){return"keydown"===e.type||"keyup"===e.type?e.keyCode:0},which:function(e){return"keypress"===e.type?od(e):"keydown"===e.type||"keyup"===e.type?e.keyCode:0}}),Rd=rd(Qd),Sd=A({},Ad,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),Td=rd(Sd),Ud=A({},ud,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:zd}),Vd=rd(Ud),Wd=A({},sd,{propertyName:0,elapsedTime:0,pseudoElement:0}),Xd=rd(Wd),Yd=A({},Ad,{deltaX:function(e){return"deltaX"in e?e.deltaX:"wheelDeltaX"in e?-e.wheelDeltaX:0},deltaY:function(e){return"deltaY"in e?e.deltaY:"wheelDeltaY"in e?-e.wheelDeltaY:"wheelDelta"in e?-e.wheelDelta:0},deltaZ:0,deltaMode:0}),Zd=rd(Yd),$d=[9,13,27,32],ae=ia&&"CompositionEvent"in window,be=null;ia&&"documentMode"in document&&(be=document.documentMode);var ce=ia&&"TextEvent"in window&&!be,de=ia&&(!ae||be&&8<be&&11>=be),ee=String.fromCharCode(32),fe=!1;function ge(e,n){switch(e){case"keyup":return-1!==$d.indexOf(n.keyCode);case"keydown":return 229!==n.keyCode;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function he(e){return"object"==typeof(e=e.detail)&&"data"in e?e.data:null}var ie=!1;function je(e,n){switch(e){case"compositionend":return he(n);case"keypress":return 32!==n.which?null:(fe=!0,ee);case"textInput":return(e=n.data)===ee&&fe?null:e;default:return null}}function ke(e,n){if(ie)return"compositionend"===e||!ae&&ge(e,n)?(e=nd(),md=ld=kd=null,ie=!1,e):null;switch(e){case"paste":default:return null;case"keypress":if(!(n.ctrlKey||n.altKey||n.metaKey)||n.ctrlKey&&n.altKey){if(n.char&&1<n.char.length)return n.char;if(n.which)return String.fromCharCode(n.which)}return null;case"compositionend":return de&&"ko"!==n.locale?null:n.data}}var le={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function me(e){var n=e&&e.nodeName&&e.nodeName.toLowerCase();return"input"===n?!!le[e.type]:"textarea"===n}function ne(e,n,t,r){Eb(r),0<(n=oe(n,"onChange")).length&&(t=new td("onChange","change",null,t,r),e.push({event:t,listeners:n}))}var pe=null,qe=null;function re(e){se(e,0)}function te(e){if(Wa(ue(e)))return e}function ve(e,n){if("change"===e)return n}var we=!1;if(ia){var xe;if(ia){var ye="oninput"in document;if(!ye){var ze=document.createElement("div");ze.setAttribute("oninput","return;"),ye="function"==typeof ze.oninput}xe=ye}else xe=!1;we=xe&&(!document.documentMode||9<document.documentMode)}function Ae(){pe&&(pe.detachEvent("onpropertychange",Be),qe=pe=null)}function Be(e){if("value"===e.propertyName&&te(qe)){var n=[];ne(n,qe,e,xb(e)),Jb(re,n)}}function Ce(e,n,t){"focusin"===e?(Ae(),qe=t,(pe=n).attachEvent("onpropertychange",Be)):"focusout"===e&&Ae()}function De(e){if("selectionchange"===e||"keyup"===e||"keydown"===e)return te(qe)}function Ee(e,n){if("click"===e)return te(n)}function Fe(e,n){if("input"===e||"change"===e)return te(n)}function Ge(e,n){return e===n&&(0!==e||1/e==1/n)||e!=e&&n!=n}var He="function"==typeof Object.is?Object.is:Ge;function Ie(e,n){if(He(e,n))return!0;if("object"!=typeof e||null===e||"object"!=typeof n||null===n)return!1;var t=Object.keys(e),r=Object.keys(n);if(t.length!==r.length)return!1;for(r=0;r<t.length;r++){var l=t[r];if(!ja.call(n,l)||!He(e[l],n[l]))return!1}return!0}function Je(e){for(;e&&e.firstChild;)e=e.firstChild;return e}function Ke(e,n){var t,r=Je(e);for(e=0;r;){if(3===r.nodeType){if(t=e+r.textContent.length,e<=n&&t>=n)return{node:r,offset:n-e};e=t}e:{for(;r;){if(r.nextSibling){r=r.nextSibling;break e}r=r.parentNode}r=void 0}r=Je(r)}}function Le(e,n){return!(!e||!n)&&(e===n||(!e||3!==e.nodeType)&&(n&&3===n.nodeType?Le(e,n.parentNode):"contains"in e?e.contains(n):!!e.compareDocumentPosition&&!!(16&e.compareDocumentPosition(n))))}function Me(){for(var e=window,n=Xa();n instanceof e.HTMLIFrameElement;){try{var t="string"==typeof n.contentWindow.location.href}catch(e){t=!1}if(!t)break;n=Xa((e=n.contentWindow).document)}return n}function Ne(e){var n=e&&e.nodeName&&e.nodeName.toLowerCase();return n&&("input"===n&&("text"===e.type||"search"===e.type||"tel"===e.type||"url"===e.type||"password"===e.type)||"textarea"===n||"true"===e.contentEditable)}function Oe(e){var n=Me(),t=e.focusedElem,r=e.selectionRange;if(n!==t&&t&&t.ownerDocument&&Le(t.ownerDocument.documentElement,t)){if(null!==r&&Ne(t))if(n=r.start,void 0===(e=r.end)&&(e=n),"selectionStart"in t)t.selectionStart=n,t.selectionEnd=Math.min(e,t.value.length);else if((e=(n=t.ownerDocument||document)&&n.defaultView||window).getSelection){e=e.getSelection();var l=t.textContent.length,a=Math.min(r.start,l);r=void 0===r.end?a:Math.min(r.end,l),!e.extend&&a>r&&(l=r,r=a,a=l),l=Ke(t,a);var i=Ke(t,r);l&&i&&(1!==e.rangeCount||e.anchorNode!==l.node||e.anchorOffset!==l.offset||e.focusNode!==i.node||e.focusOffset!==i.offset)&&((n=n.createRange()).setStart(l.node,l.offset),e.removeAllRanges(),a>r?(e.addRange(n),e.extend(i.node,i.offset)):(n.setEnd(i.node,i.offset),e.addRange(n)))}for(n=[],e=t;e=e.parentNode;)1===e.nodeType&&n.push({element:e,left:e.scrollLeft,top:e.scrollTop});for("function"==typeof t.focus&&t.focus(),t=0;t<n.length;t++)(e=n[t]).element.scrollLeft=e.left,e.element.scrollTop=e.top}}var Pe=ia&&"documentMode"in document&&11>=document.documentMode,Qe=null,Re=null,Se=null,Te=!1;function Ue(e,n,t){var r=t.window===t?t.document:9===t.nodeType?t:t.ownerDocument;Te||null==Qe||Qe!==Xa(r)||("selectionStart"in(r=Qe)&&Ne(r)?r={start:r.selectionStart,end:r.selectionEnd}:r={anchorNode:(r=(r.ownerDocument&&r.ownerDocument.defaultView||window).getSelection()).anchorNode,anchorOffset:r.anchorOffset,focusNode:r.focusNode,focusOffset:r.focusOffset},Se&&Ie(Se,r)||(Se=r,0<(r=oe(Re,"onSelect")).length&&(n=new td("onSelect","select",null,n,t),e.push({event:n,listeners:r}),n.target=Qe)))}function Ve(e,n){var t={};return t[e.toLowerCase()]=n.toLowerCase(),t["Webkit"+e]="webkit"+n,t["Moz"+e]="moz"+n,t}var We={animationend:Ve("Animation","AnimationEnd"),animationiteration:Ve("Animation","AnimationIteration"),animationstart:Ve("Animation","AnimationStart"),transitionend:Ve("Transition","TransitionEnd")},Xe={},Ye={};function Ze(e){if(Xe[e])return Xe[e];if(!We[e])return e;var n,t=We[e];for(n in t)if(t.hasOwnProperty(n)&&n in Ye)return Xe[e]=t[n];return e}ia&&(Ye=document.createElement("div").style,"AnimationEvent"in window||(delete We.animationend.animation,delete We.animationiteration.animation,delete We.animationstart.animation),"TransitionEvent"in window||delete We.transitionend.transition);var $e=Ze("animationend"),af=Ze("animationiteration"),bf=Ze("animationstart"),cf=Ze("transitionend"),df=new Map,ef="abort auxClick cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");function ff(e,n){df.set(e,n),fa(n,[e])}for(var gf=0;gf<ef.length;gf++){var hf=ef[gf],jf=hf.toLowerCase(),kf=hf[0].toUpperCase()+hf.slice(1);ff(jf,"on"+kf)}ff($e,"onAnimationEnd"),ff(af,"onAnimationIteration"),ff(bf,"onAnimationStart"),ff("dblclick","onDoubleClick"),ff("focusin","onFocus"),ff("focusout","onBlur"),ff(cf,"onTransitionEnd"),ha("onMouseEnter",["mouseout","mouseover"]),ha("onMouseLeave",["mouseout","mouseover"]),ha("onPointerEnter",["pointerout","pointerover"]),ha("onPointerLeave",["pointerout","pointerover"]),fa("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),fa("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),fa("onBeforeInput",["compositionend","keypress","textInput","paste"]),fa("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),fa("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),fa("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var lf="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),mf=new Set("cancel close invalid load scroll toggle".split(" ").concat(lf));function nf(e,n,t){var r=e.type||"unknown-event";e.currentTarget=t,Ub(r,n,void 0,e),e.currentTarget=null}function se(e,n){n=0!=(4&n);for(var t=0;t<e.length;t++){var r=e[t],l=r.event;r=r.listeners;e:{var a=void 0;if(n)for(var i=r.length-1;0<=i;i--){var u=r[i],o=u.instance,c=u.currentTarget;if(u=u.listener,o!==a&&l.isPropagationStopped())break e;nf(l,u,c),a=o}else for(i=0;i<r.length;i++){if(o=(u=r[i]).instance,c=u.currentTarget,u=u.listener,o!==a&&l.isPropagationStopped())break e;nf(l,u,c),a=o}}}if(Qb)throw e=Rb,Qb=!1,Rb=null,e}function D(e,n){var t=n[of];void 0===t&&(t=n[of]=new Set);var r=e+"__bubble";t.has(r)||(pf(n,e,2,!1),t.add(r))}function qf(e,n,t){var r=0;n&&(r|=4),pf(t,e,r,n)}var rf="_reactListening"+Math.random().toString(36).slice(2);function sf(e){if(!e[rf]){e[rf]=!0,da.forEach((function(n){"selectionchange"!==n&&(mf.has(n)||qf(n,!1,e),qf(n,!0,e))}));var n=9===e.nodeType?e:e.ownerDocument;null===n||n[rf]||(n[rf]=!0,qf("selectionchange",!1,n))}}function pf(e,n,t,r){switch(jd(n)){case 1:var l=ed;break;case 4:l=gd;break;default:l=fd}t=l.bind(null,n,t,e),l=void 0,!Lb||"touchstart"!==n&&"touchmove"!==n&&"wheel"!==n||(l=!0),r?void 0!==l?e.addEventListener(n,t,{capture:!0,passive:l}):e.addEventListener(n,t,!0):void 0!==l?e.addEventListener(n,t,{passive:l}):e.addEventListener(n,t,!1)}function hd(e,n,t,r,l){var a=r;if(0==(1&n)&&0==(2&n)&&null!==r)e:for(;;){if(null===r)return;var i=r.tag;if(3===i||4===i){var u=r.stateNode.containerInfo;if(u===l||8===u.nodeType&&u.parentNode===l)break;if(4===i)for(i=r.return;null!==i;){var o=i.tag;if((3===o||4===o)&&((o=i.stateNode.containerInfo)===l||8===o.nodeType&&o.parentNode===l))return;i=i.return}for(;null!==u;){if(null===(i=Wc(u)))return;if(5===(o=i.tag)||6===o){r=a=i;continue e}u=u.parentNode}}r=r.return}Jb((function(){var r=a,l=xb(t),i=[];e:{var u=df.get(e);if(void 0!==u){var o=td,c=e;switch(e){case"keypress":if(0===od(t))break e;case"keydown":case"keyup":o=Rd;break;case"focusin":c="focus",o=Fd;break;case"focusout":c="blur",o=Fd;break;case"beforeblur":case"afterblur":o=Fd;break;case"click":if(2===t.button)break e;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":o=Bd;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":o=Dd;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":o=Vd;break;case $e:case af:case bf:o=Hd;break;case cf:o=Xd;break;case"scroll":o=vd;break;case"wheel":o=Zd;break;case"copy":case"cut":case"paste":o=Jd;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":o=Td}var s=0!=(4&n),f=!s&&"scroll"===e,d=s?null!==u?u+"Capture":null:u;s=[];for(var p,h=r;null!==h;){var g=(p=h).stateNode;if(5===p.tag&&null!==g&&(p=g,null!==d&&(null!=(g=Kb(h,d))&&s.push(tf(h,g,p)))),f)break;h=h.return}0<s.length&&(u=new o(u,c,null,t,l),i.push({event:u,listeners:s}))}}if(0==(7&n)){if(o="mouseout"===e||"pointerout"===e,(!(u="mouseover"===e||"pointerover"===e)||t===wb||!(c=t.relatedTarget||t.fromElement)||!Wc(c)&&!c[uf])&&(o||u)&&(u=l.window===l?l:(u=l.ownerDocument)?u.defaultView||u.parentWindow:window,o?(o=r,null!==(c=(c=t.relatedTarget||t.toElement)?Wc(c):null)&&(c!==(f=Vb(c))||5!==c.tag&&6!==c.tag)&&(c=null)):(o=null,c=r),o!==c)){if(s=Bd,g="onMouseLeave",d="onMouseEnter",h="mouse","pointerout"!==e&&"pointerover"!==e||(s=Td,g="onPointerLeave",d="onPointerEnter",h="pointer"),f=null==o?u:ue(o),p=null==c?u:ue(c),(u=new s(g,h+"leave",o,t,l)).target=f,u.relatedTarget=p,g=null,Wc(l)===r&&((s=new s(d,h+"enter",c,t,l)).target=p,s.relatedTarget=f,g=s),f=g,o&&c)e:{for(d=c,h=0,p=s=o;p;p=vf(p))h++;for(p=0,g=d;g;g=vf(g))p++;for(;0<h-p;)s=vf(s),h--;for(;0<p-h;)d=vf(d),p--;for(;h--;){if(s===d||null!==d&&s===d.alternate)break e;s=vf(s),d=vf(d)}s=null}else s=null;null!==o&&wf(i,u,o,s,!1),null!==c&&null!==f&&wf(i,f,c,s,!0)}if("select"===(o=(u=r?ue(r):window).nodeName&&u.nodeName.toLowerCase())||"input"===o&&"file"===u.type)var m=ve;else if(me(u))if(we)m=Fe;else{m=De;var v=Ce}else(o=u.nodeName)&&"input"===o.toLowerCase()&&("checkbox"===u.type||"radio"===u.type)&&(m=Ee);switch(m&&(m=m(e,r))?ne(i,m,t,l):(v&&v(e,u,r),"focusout"===e&&(v=u._wrapperState)&&v.controlled&&"number"===u.type&&cb(u,"number",u.value)),v=r?ue(r):window,e){case"focusin":(me(v)||"true"===v.contentEditable)&&(Qe=v,Re=r,Se=null);break;case"focusout":Se=Re=Qe=null;break;case"mousedown":Te=!0;break;case"contextmenu":case"mouseup":case"dragend":Te=!1,Ue(i,t,l);break;case"selectionchange":if(Pe)break;case"keydown":case"keyup":Ue(i,t,l)}var b;if(ae)e:{switch(e){case"compositionstart":var y="onCompositionStart";break e;case"compositionend":y="onCompositionEnd";break e;case"compositionupdate":y="onCompositionUpdate";break e}y=void 0}else ie?ge(e,t)&&(y="onCompositionEnd"):"keydown"===e&&229===t.keyCode&&(y="onCompositionStart");y&&(de&&"ko"!==t.locale&&(ie||"onCompositionStart"!==y?"onCompositionEnd"===y&&ie&&(b=nd()):(ld="value"in(kd=l)?kd.value:kd.textContent,ie=!0)),0<(v=oe(r,y)).length&&(y=new Ld(y,e,null,t,l),i.push({event:y,listeners:v}),b?y.data=b:null!==(b=he(t))&&(y.data=b))),(b=ce?je(e,t):ke(e,t))&&(0<(r=oe(r,"onBeforeInput")).length&&(l=new Ld("onBeforeInput","beforeinput",null,t,l),i.push({event:l,listeners:r}),l.data=b))}se(i,n)}))}function tf(e,n,t){return{instance:e,listener:n,currentTarget:t}}function oe(e,n){for(var t=n+"Capture",r=[];null!==e;){var l=e,a=l.stateNode;5===l.tag&&null!==a&&(l=a,null!=(a=Kb(e,t))&&r.unshift(tf(e,a,l)),null!=(a=Kb(e,n))&&r.push(tf(e,a,l))),e=e.return}return r}function vf(e){if(null===e)return null;do{e=e.return}while(e&&5!==e.tag);return e||null}function wf(e,n,t,r,l){for(var a=n._reactName,i=[];null!==t&&t!==r;){var u=t,o=u.alternate,c=u.stateNode;if(null!==o&&o===r)break;5===u.tag&&null!==c&&(u=c,l?null!=(o=Kb(t,a))&&i.unshift(tf(t,o,u)):l||null!=(o=Kb(t,a))&&i.push(tf(t,o,u))),t=t.return}0!==i.length&&e.push({event:n,listeners:i})}var xf=/\r\n?/g,yf=/\u0000|\uFFFD/g;function zf(e){return("string"==typeof e?e:""+e).replace(xf,"\n").replace(yf,"")}function Af(e,n,t){if(n=zf(n),zf(e)!==n&&t)throw Error(p(425))}function Bf(){}var Cf=null,Df=null;function Ef(e,n){return"textarea"===e||"noscript"===e||"string"==typeof n.children||"number"==typeof n.children||"object"==typeof n.dangerouslySetInnerHTML&&null!==n.dangerouslySetInnerHTML&&null!=n.dangerouslySetInnerHTML.__html}var Ff="function"==typeof setTimeout?setTimeout:void 0,Gf="function"==typeof clearTimeout?clearTimeout:void 0,Hf="function"==typeof Promise?Promise:void 0,Jf="function"==typeof queueMicrotask?queueMicrotask:void 0!==Hf?function(e){return Hf.resolve(null).then(e).catch(If)}:Ff;function If(e){setTimeout((function(){throw e}))}function Kf(e,n){var t=n,r=0;do{var l=t.nextSibling;if(e.removeChild(t),l&&8===l.nodeType)if("/$"===(t=l.data)){if(0===r)return e.removeChild(l),void bd(n);r--}else"$"!==t&&"$?"!==t&&"$!"!==t||r++;t=l}while(t);bd(n)}function Lf(e){for(;null!=e;e=e.nextSibling){var n=e.nodeType;if(1===n||3===n)break;if(8===n){if("$"===(n=e.data)||"$!"===n||"$?"===n)break;if("/$"===n)return null}}return e}function Mf(e){e=e.previousSibling;for(var n=0;e;){if(8===e.nodeType){var t=e.data;if("$"===t||"$!"===t||"$?"===t){if(0===n)return e;n--}else"/$"===t&&n++}e=e.previousSibling}return null}var Nf=Math.random().toString(36).slice(2),Of="__reactFiber$"+Nf,Pf="__reactProps$"+Nf,uf="__reactContainer$"+Nf,of="__reactEvents$"+Nf,Qf="__reactListeners$"+Nf,Rf="__reactHandles$"+Nf;function Wc(e){var n=e[Of];if(n)return n;for(var t=e.parentNode;t;){if(n=t[uf]||t[Of]){if(t=n.alternate,null!==n.child||null!==t&&null!==t.child)for(e=Mf(e);null!==e;){if(t=e[Of])return t;e=Mf(e)}return n}t=(e=t).parentNode}return null}function Cb(e){return!(e=e[Of]||e[uf])||5!==e.tag&&6!==e.tag&&13!==e.tag&&3!==e.tag?null:e}function ue(e){if(5===e.tag||6===e.tag)return e.stateNode;throw Error(p(33))}function Db(e){return e[Pf]||null}var Sf=[],Tf=-1;function Uf(e){return{current:e}}function E(e){0>Tf||(e.current=Sf[Tf],Sf[Tf]=null,Tf--)}function G(e,n){Tf++,Sf[Tf]=e.current,e.current=n}var Vf={},H=Uf(Vf),Wf=Uf(!1),Xf=Vf;function Yf(e,n){var t=e.type.contextTypes;if(!t)return Vf;var r=e.stateNode;if(r&&r.__reactInternalMemoizedUnmaskedChildContext===n)return r.__reactInternalMemoizedMaskedChildContext;var l,a={};for(l in t)a[l]=n[l];return r&&((e=e.stateNode).__reactInternalMemoizedUnmaskedChildContext=n,e.__reactInternalMemoizedMaskedChildContext=a),a}function Zf(e){return null!=(e=e.childContextTypes)}function $f(){E(Wf),E(H)}function ag(e,n,t){if(H.current!==Vf)throw Error(p(168));G(H,n),G(Wf,t)}function bg(e,n,t){var r=e.stateNode;if(n=n.childContextTypes,"function"!=typeof r.getChildContext)return t;for(var l in r=r.getChildContext())if(!(l in n))throw Error(p(108,Ra(e)||"Unknown",l));return A({},t,r)}function cg(e){return e=(e=e.stateNode)&&e.__reactInternalMemoizedMergedChildContext||Vf,Xf=H.current,G(H,e),G(Wf,Wf.current),!0}function dg(e,n,t){var r=e.stateNode;if(!r)throw Error(p(169));t?(e=bg(e,n,Xf),r.__reactInternalMemoizedMergedChildContext=e,E(Wf),E(H),G(H,e)):E(Wf),G(Wf,t)}var eg=null,fg=!1,gg=!1;function hg(e){null===eg?eg=[e]:eg.push(e)}function ig(e){fg=!0,hg(e)}function jg(){if(!gg&&null!==eg){gg=!0;var e=0,n=C;try{var t=eg;for(C=1;e<t.length;e++){var r=t[e];do{r=r(!0)}while(null!==r)}eg=null,fg=!1}catch(n){throw null!==eg&&(eg=eg.slice(e+1)),ac(fc,jg),n}finally{C=n,gg=!1}}return null}var kg=[],lg=0,mg=null,ng=0,og=[],pg=0,qg=null,rg=1,sg="";function tg(e,n){kg[lg++]=ng,kg[lg++]=mg,mg=e,ng=n}function ug(e,n,t){og[pg++]=rg,og[pg++]=sg,og[pg++]=qg,qg=e;var r=rg;e=sg;var l=32-oc(r)-1;r&=~(1<<l),t+=1;var a=32-oc(n)+l;if(30<a){var i=l-l%5;a=(r&(1<<i)-1).toString(32),r>>=i,l-=i,rg=1<<32-oc(n)+l|t<<l|r,sg=a+e}else rg=1<<a|t<<l|r,sg=e}function vg(e){null!==e.return&&(tg(e,1),ug(e,1,0))}function wg(e){for(;e===mg;)mg=kg[--lg],kg[lg]=null,ng=kg[--lg],kg[lg]=null;for(;e===qg;)qg=og[--pg],og[pg]=null,sg=og[--pg],og[pg]=null,rg=og[--pg],og[pg]=null}var xg=null,yg=null,I=!1,zg=null;function Ag(e,n){var t=Bg(5,null,null,0);t.elementType="DELETED",t.stateNode=n,t.return=e,null===(n=e.deletions)?(e.deletions=[t],e.flags|=16):n.push(t)}function Cg(e,n){switch(e.tag){case 5:var t=e.type;return null!==(n=1!==n.nodeType||t.toLowerCase()!==n.nodeName.toLowerCase()?null:n)&&(e.stateNode=n,xg=e,yg=Lf(n.firstChild),!0);case 6:return null!==(n=""===e.pendingProps||3!==n.nodeType?null:n)&&(e.stateNode=n,xg=e,yg=null,!0);case 13:return null!==(n=8!==n.nodeType?null:n)&&(t=null!==qg?{id:rg,overflow:sg}:null,e.memoizedState={dehydrated:n,treeContext:t,retryLane:1073741824},(t=Bg(18,null,null,0)).stateNode=n,t.return=e,e.child=t,xg=e,yg=null,!0);default:return!1}}function Dg(e){return 0!=(1&e.mode)&&0==(128&e.flags)}function Eg(e){if(I){var n=yg;if(n){var t=n;if(!Cg(e,n)){if(Dg(e))throw Error(p(418));n=Lf(t.nextSibling);var r=xg;n&&Cg(e,n)?Ag(r,t):(e.flags=-4097&e.flags|2,I=!1,xg=e)}}else{if(Dg(e))throw Error(p(418));e.flags=-4097&e.flags|2,I=!1,xg=e}}}function Fg(e){for(e=e.return;null!==e&&5!==e.tag&&3!==e.tag&&13!==e.tag;)e=e.return;xg=e}function Gg(e){if(e!==xg)return!1;if(!I)return Fg(e),I=!0,!1;var n;if((n=3!==e.tag)&&!(n=5!==e.tag)&&(n="head"!==(n=e.type)&&"body"!==n&&!Ef(e.type,e.memoizedProps)),n&&(n=yg)){if(Dg(e))throw Hg(),Error(p(418));for(;n;)Ag(e,n),n=Lf(n.nextSibling)}if(Fg(e),13===e.tag){if(!(e=null!==(e=e.memoizedState)?e.dehydrated:null))throw Error(p(317));e:{for(e=e.nextSibling,n=0;e;){if(8===e.nodeType){var t=e.data;if("/$"===t){if(0===n){yg=Lf(e.nextSibling);break e}n--}else"$"!==t&&"$!"!==t&&"$?"!==t||n++}e=e.nextSibling}yg=null}}else yg=xg?Lf(e.stateNode.nextSibling):null;return!0}function Hg(){for(var e=yg;e;)e=Lf(e.nextSibling)}function Ig(){yg=xg=null,I=!1}function Jg(e){null===zg?zg=[e]:zg.push(e)}var Kg=ua.ReactCurrentBatchConfig;function Lg(e,n){if(e&&e.defaultProps){for(var t in n=A({},n),e=e.defaultProps)void 0===n[t]&&(n[t]=e[t]);return n}return n}var Mg=Uf(null),Ng=null,Og=null,Pg=null;function Qg(){Pg=Og=Ng=null}function Rg(e){var n=Mg.current;E(Mg),e._currentValue=n}function Sg(e,n,t){for(;null!==e;){var r=e.alternate;if((e.childLanes&n)!==n?(e.childLanes|=n,null!==r&&(r.childLanes|=n)):null!==r&&(r.childLanes&n)!==n&&(r.childLanes|=n),e===t)break;e=e.return}}function Tg(e,n){Ng=e,Pg=Og=null,null!==(e=e.dependencies)&&null!==e.firstContext&&(0!=(e.lanes&n)&&(Ug=!0),e.firstContext=null)}function Vg(e){var n=e._currentValue;if(Pg!==e)if(e={context:e,memoizedValue:n,next:null},null===Og){if(null===Ng)throw Error(p(308));Og=e,Ng.dependencies={lanes:0,firstContext:e}}else Og=Og.next=e;return n}var Wg=null;function Xg(e){null===Wg?Wg=[e]:Wg.push(e)}function Yg(e,n,t,r){var l=n.interleaved;return null===l?(t.next=t,Xg(n)):(t.next=l.next,l.next=t),n.interleaved=t,Zg(e,r)}function Zg(e,n){e.lanes|=n;var t=e.alternate;for(null!==t&&(t.lanes|=n),t=e,e=e.return;null!==e;)e.childLanes|=n,null!==(t=e.alternate)&&(t.childLanes|=n),t=e,e=e.return;return 3===t.tag?t.stateNode:null}var $g=!1;function ah(e){e.updateQueue={baseState:e.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,interleaved:null,lanes:0},effects:null}}function bh(e,n){e=e.updateQueue,n.updateQueue===e&&(n.updateQueue={baseState:e.baseState,firstBaseUpdate:e.firstBaseUpdate,lastBaseUpdate:e.lastBaseUpdate,shared:e.shared,effects:e.effects})}function ch(e,n){return{eventTime:e,lane:n,tag:0,payload:null,callback:null,next:null}}function dh(e,n,t){var r=e.updateQueue;if(null===r)return null;if(r=r.shared,0!=(2&K)){var l=r.pending;return null===l?n.next=n:(n.next=l.next,l.next=n),r.pending=n,Zg(e,t)}return null===(l=r.interleaved)?(n.next=n,Xg(r)):(n.next=l.next,l.next=n),r.interleaved=n,Zg(e,t)}function eh(e,n,t){if(null!==(n=n.updateQueue)&&(n=n.shared,0!=(4194240&t))){var r=n.lanes;t|=r&=e.pendingLanes,n.lanes=t,Cc(e,t)}}function fh(e,n){var t=e.updateQueue,r=e.alternate;if(null!==r&&t===(r=r.updateQueue)){var l=null,a=null;if(null!==(t=t.firstBaseUpdate)){do{var i={eventTime:t.eventTime,lane:t.lane,tag:t.tag,payload:t.payload,callback:t.callback,next:null};null===a?l=a=i:a=a.next=i,t=t.next}while(null!==t);null===a?l=a=n:a=a.next=n}else l=a=n;return t={baseState:r.baseState,firstBaseUpdate:l,lastBaseUpdate:a,shared:r.shared,effects:r.effects},void(e.updateQueue=t)}null===(e=t.lastBaseUpdate)?t.firstBaseUpdate=n:e.next=n,t.lastBaseUpdate=n}function gh(e,n,t,r){var l=e.updateQueue;$g=!1;var a=l.firstBaseUpdate,i=l.lastBaseUpdate,u=l.shared.pending;if(null!==u){l.shared.pending=null;var o=u,c=o.next;o.next=null,null===i?a=c:i.next=c,i=o;var s=e.alternate;null!==s&&((u=(s=s.updateQueue).lastBaseUpdate)!==i&&(null===u?s.firstBaseUpdate=c:u.next=c,s.lastBaseUpdate=o))}if(null!==a){var f=l.baseState;for(i=0,s=c=o=null,u=a;;){var d=u.lane,p=u.eventTime;if((r&d)===d){null!==s&&(s=s.next={eventTime:p,lane:0,tag:u.tag,payload:u.payload,callback:u.callback,next:null});e:{var h=e,g=u;switch(d=n,p=t,g.tag){case 1:if("function"==typeof(h=g.payload)){f=h.call(p,f,d);break e}f=h;break e;case 3:h.flags=-65537&h.flags|128;case 0:if(null==(d="function"==typeof(h=g.payload)?h.call(p,f,d):h))break e;f=A({},f,d);break e;case 2:$g=!0}}null!==u.callback&&0!==u.lane&&(e.flags|=64,null===(d=l.effects)?l.effects=[u]:d.push(u))}else p={eventTime:p,lane:d,tag:u.tag,payload:u.payload,callback:u.callback,next:null},null===s?(c=s=p,o=f):s=s.next=p,i|=d;if(null===(u=u.next)){if(null===(u=l.shared.pending))break;u=(d=u).next,d.next=null,l.lastBaseUpdate=d,l.shared.pending=null}}if(null===s&&(o=f),l.baseState=o,l.firstBaseUpdate=c,l.lastBaseUpdate=s,null!==(n=l.shared.interleaved)){l=n;do{i|=l.lane,l=l.next}while(l!==n)}else null===a&&(l.shared.lanes=0);hh|=i,e.lanes=i,e.memoizedState=f}}function ih(e,n,t){if(e=n.effects,n.effects=null,null!==e)for(n=0;n<e.length;n++){var r=e[n],l=r.callback;if(null!==l){if(r.callback=null,r=t,"function"!=typeof l)throw Error(p(191,l));l.call(r)}}}var jh=(new aa.Component).refs;function kh(e,n,t,r){t=null==(t=t(r,n=e.memoizedState))?n:A({},n,t),e.memoizedState=t,0===e.lanes&&(e.updateQueue.baseState=t)}var nh={isMounted:function(e){return!!(e=e._reactInternals)&&Vb(e)===e},enqueueSetState:function(e,n,t){e=e._reactInternals;var r=L(),l=lh(e),a=ch(r,l);a.payload=n,null!=t&&(a.callback=t),null!==(n=dh(e,a,l))&&(mh(n,e,l,r),eh(n,e,l))},enqueueReplaceState:function(e,n,t){e=e._reactInternals;var r=L(),l=lh(e),a=ch(r,l);a.tag=1,a.payload=n,null!=t&&(a.callback=t),null!==(n=dh(e,a,l))&&(mh(n,e,l,r),eh(n,e,l))},enqueueForceUpdate:function(e,n){e=e._reactInternals;var t=L(),r=lh(e),l=ch(t,r);l.tag=2,null!=n&&(l.callback=n),null!==(n=dh(e,l,r))&&(mh(n,e,r,t),eh(n,e,r))}};function oh(e,n,t,r,l,a,i){return"function"==typeof(e=e.stateNode).shouldComponentUpdate?e.shouldComponentUpdate(r,a,i):!n.prototype||!n.prototype.isPureReactComponent||(!Ie(t,r)||!Ie(l,a))}function ph(e,n,t){var r=!1,l=Vf,a=n.contextType;return"object"==typeof a&&null!==a?a=Vg(a):(l=Zf(n)?Xf:H.current,a=(r=null!=(r=n.contextTypes))?Yf(e,l):Vf),n=new n(t,a),e.memoizedState=null!==n.state&&void 0!==n.state?n.state:null,n.updater=nh,e.stateNode=n,n._reactInternals=e,r&&((e=e.stateNode).__reactInternalMemoizedUnmaskedChildContext=l,e.__reactInternalMemoizedMaskedChildContext=a),n}function qh(e,n,t,r){e=n.state,"function"==typeof n.componentWillReceiveProps&&n.componentWillReceiveProps(t,r),"function"==typeof n.UNSAFE_componentWillReceiveProps&&n.UNSAFE_componentWillReceiveProps(t,r),n.state!==e&&nh.enqueueReplaceState(n,n.state,null)}function rh(e,n,t,r){var l=e.stateNode;l.props=t,l.state=e.memoizedState,l.refs=jh,ah(e);var a=n.contextType;"object"==typeof a&&null!==a?l.context=Vg(a):(a=Zf(n)?Xf:H.current,l.context=Yf(e,a)),l.state=e.memoizedState,"function"==typeof(a=n.getDerivedStateFromProps)&&(kh(e,n,a,t),l.state=e.memoizedState),"function"==typeof n.getDerivedStateFromProps||"function"==typeof l.getSnapshotBeforeUpdate||"function"!=typeof l.UNSAFE_componentWillMount&&"function"!=typeof l.componentWillMount||(n=l.state,"function"==typeof l.componentWillMount&&l.componentWillMount(),"function"==typeof l.UNSAFE_componentWillMount&&l.UNSAFE_componentWillMount(),n!==l.state&&nh.enqueueReplaceState(l,l.state,null),gh(e,t,l,r),l.state=e.memoizedState),"function"==typeof l.componentDidMount&&(e.flags|=4194308)}function sh(e,n,t){if(null!==(e=t.ref)&&"function"!=typeof e&&"object"!=typeof e){if(t._owner){if(t=t._owner){if(1!==t.tag)throw Error(p(309));var r=t.stateNode}if(!r)throw Error(p(147,e));var l=r,a=""+e;return null!==n&&null!==n.ref&&"function"==typeof n.ref&&n.ref._stringRef===a?n.ref:(n=function(e){var n=l.refs;n===jh&&(n=l.refs={}),null===e?delete n[a]:n[a]=e},n._stringRef=a,n)}if("string"!=typeof e)throw Error(p(284));if(!t._owner)throw Error(p(290,e))}return e}function th(e,n){throw e=Object.prototype.toString.call(n),Error(p(31,"[object Object]"===e?"object with keys {"+Object.keys(n).join(", ")+"}":e))}function uh(e){return(0,e._init)(e._payload)}function vh(e){function n(n,t){if(e){var r=n.deletions;null===r?(n.deletions=[t],n.flags|=16):r.push(t)}}function t(t,r){if(!e)return null;for(;null!==r;)n(t,r),r=r.sibling;return null}function r(e,n){for(e=new Map;null!==n;)null!==n.key?e.set(n.key,n):e.set(n.index,n),n=n.sibling;return e}function l(e,n){return(e=wh(e,n)).index=0,e.sibling=null,e}function a(n,t,r){return n.index=r,e?null!==(r=n.alternate)?(r=r.index)<t?(n.flags|=2,t):r:(n.flags|=2,t):(n.flags|=1048576,t)}function i(n){return e&&null===n.alternate&&(n.flags|=2),n}function u(e,n,t,r){return null===n||6!==n.tag?((n=xh(t,e.mode,r)).return=e,n):((n=l(n,t)).return=e,n)}function o(e,n,t,r){var a=t.type;return a===ya?s(e,n,t.props.children,r,t.key):null!==n&&(n.elementType===a||"object"==typeof a&&null!==a&&a.$$typeof===Ha&&uh(a)===n.type)?((r=l(n,t.props)).ref=sh(e,n,t),r.return=e,r):((r=yh(t.type,t.key,t.props,null,e.mode,r)).ref=sh(e,n,t),r.return=e,r)}function c(e,n,t,r){return null===n||4!==n.tag||n.stateNode.containerInfo!==t.containerInfo||n.stateNode.implementation!==t.implementation?((n=zh(t,e.mode,r)).return=e,n):((n=l(n,t.children||[])).return=e,n)}function s(e,n,t,r,a){return null===n||7!==n.tag?((n=Ah(t,e.mode,r,a)).return=e,n):((n=l(n,t)).return=e,n)}function f(e,n,t){if("string"==typeof n&&""!==n||"number"==typeof n)return(n=xh(""+n,e.mode,t)).return=e,n;if("object"==typeof n&&null!==n){switch(n.$$typeof){case va:return(t=yh(n.type,n.key,n.props,null,e.mode,t)).ref=sh(e,null,n),t.return=e,t;case wa:return(n=zh(n,e.mode,t)).return=e,n;case Ha:return f(e,(0,n._init)(n._payload),t)}if(eb(n)||Ka(n))return(n=Ah(n,e.mode,t,null)).return=e,n;th(e,n)}return null}function d(e,n,t,r){var l=null!==n?n.key:null;if("string"==typeof t&&""!==t||"number"==typeof t)return null!==l?null:u(e,n,""+t,r);if("object"==typeof t&&null!==t){switch(t.$$typeof){case va:return t.key===l?o(e,n,t,r):null;case wa:return t.key===l?c(e,n,t,r):null;case Ha:return d(e,n,(l=t._init)(t._payload),r)}if(eb(t)||Ka(t))return null!==l?null:s(e,n,t,r,null);th(e,t)}return null}function h(e,n,t,r,l){if("string"==typeof r&&""!==r||"number"==typeof r)return u(n,e=e.get(t)||null,""+r,l);if("object"==typeof r&&null!==r){switch(r.$$typeof){case va:return o(n,e=e.get(null===r.key?t:r.key)||null,r,l);case wa:return c(n,e=e.get(null===r.key?t:r.key)||null,r,l);case Ha:return h(e,n,t,(0,r._init)(r._payload),l)}if(eb(r)||Ka(r))return s(n,e=e.get(t)||null,r,l,null);th(n,r)}return null}function g(l,i,u,o){for(var c=null,s=null,p=i,g=i=0,m=null;null!==p&&g<u.length;g++){p.index>g?(m=p,p=null):m=p.sibling;var v=d(l,p,u[g],o);if(null===v){null===p&&(p=m);break}e&&p&&null===v.alternate&&n(l,p),i=a(v,i,g),null===s?c=v:s.sibling=v,s=v,p=m}if(g===u.length)return t(l,p),I&&tg(l,g),c;if(null===p){for(;g<u.length;g++)null!==(p=f(l,u[g],o))&&(i=a(p,i,g),null===s?c=p:s.sibling=p,s=p);return I&&tg(l,g),c}for(p=r(l,p);g<u.length;g++)null!==(m=h(p,l,g,u[g],o))&&(e&&null!==m.alternate&&p.delete(null===m.key?g:m.key),i=a(m,i,g),null===s?c=m:s.sibling=m,s=m);return e&&p.forEach((function(e){return n(l,e)})),I&&tg(l,g),c}function m(l,i,u,o){var c=Ka(u);if("function"!=typeof c)throw Error(p(150));if(null==(u=c.call(u)))throw Error(p(151));for(var s=c=null,g=i,m=i=0,v=null,b=u.next();null!==g&&!b.done;m++,b=u.next()){g.index>m?(v=g,g=null):v=g.sibling;var y=d(l,g,b.value,o);if(null===y){null===g&&(g=v);break}e&&g&&null===y.alternate&&n(l,g),i=a(y,i,m),null===s?c=y:s.sibling=y,s=y,g=v}if(b.done)return t(l,g),I&&tg(l,m),c;if(null===g){for(;!b.done;m++,b=u.next())null!==(b=f(l,b.value,o))&&(i=a(b,i,m),null===s?c=b:s.sibling=b,s=b);return I&&tg(l,m),c}for(g=r(l,g);!b.done;m++,b=u.next())null!==(b=h(g,l,m,b.value,o))&&(e&&null!==b.alternate&&g.delete(null===b.key?m:b.key),i=a(b,i,m),null===s?c=b:s.sibling=b,s=b);return e&&g.forEach((function(e){return n(l,e)})),I&&tg(l,m),c}return function e(r,a,u,o){if("object"==typeof u&&null!==u&&u.type===ya&&null===u.key&&(u=u.props.children),"object"==typeof u&&null!==u){switch(u.$$typeof){case va:e:{for(var c=u.key,s=a;null!==s;){if(s.key===c){if((c=u.type)===ya){if(7===s.tag){t(r,s.sibling),(a=l(s,u.props.children)).return=r,r=a;break e}}else if(s.elementType===c||"object"==typeof c&&null!==c&&c.$$typeof===Ha&&uh(c)===s.type){t(r,s.sibling),(a=l(s,u.props)).ref=sh(r,s,u),a.return=r,r=a;break e}t(r,s);break}n(r,s),s=s.sibling}u.type===ya?((a=Ah(u.props.children,r.mode,o,u.key)).return=r,r=a):((o=yh(u.type,u.key,u.props,null,r.mode,o)).ref=sh(r,a,u),o.return=r,r=o)}return i(r);case wa:e:{for(s=u.key;null!==a;){if(a.key===s){if(4===a.tag&&a.stateNode.containerInfo===u.containerInfo&&a.stateNode.implementation===u.implementation){t(r,a.sibling),(a=l(a,u.children||[])).return=r,r=a;break e}t(r,a);break}n(r,a),a=a.sibling}(a=zh(u,r.mode,o)).return=r,r=a}return i(r);case Ha:return e(r,a,(s=u._init)(u._payload),o)}if(eb(u))return g(r,a,u,o);if(Ka(u))return m(r,a,u,o);th(r,u)}return"string"==typeof u&&""!==u||"number"==typeof u?(u=""+u,null!==a&&6===a.tag?(t(r,a.sibling),(a=l(a,u)).return=r,r=a):(t(r,a),(a=xh(u,r.mode,o)).return=r,r=a),i(r)):t(r,a)}}var Bh=vh(!0),Ch=vh(!1),Dh={},Eh=Uf(Dh),Fh=Uf(Dh),Gh=Uf(Dh);function Hh(e){if(e===Dh)throw Error(p(174));return e}function Ih(e,n){switch(G(Gh,n),G(Fh,e),G(Eh,Dh),e=n.nodeType){case 9:case 11:n=(n=n.documentElement)?n.namespaceURI:lb(null,"");break;default:n=lb(n=(e=8===e?n.parentNode:n).namespaceURI||null,e=e.tagName)}E(Eh),G(Eh,n)}function Jh(){E(Eh),E(Fh),E(Gh)}function Kh(e){Hh(Gh.current);var n=Hh(Eh.current),t=lb(n,e.type);n!==t&&(G(Fh,e),G(Eh,t))}function Lh(e){Fh.current===e&&(E(Eh),E(Fh))}var M=Uf(0);function Mh(e){for(var n=e;null!==n;){if(13===n.tag){var t=n.memoizedState;if(null!==t&&(null===(t=t.dehydrated)||"$?"===t.data||"$!"===t.data))return n}else if(19===n.tag&&void 0!==n.memoizedProps.revealOrder){if(0!=(128&n.flags))return n}else if(null!==n.child){n.child.return=n,n=n.child;continue}if(n===e)break;for(;null===n.sibling;){if(null===n.return||n.return===e)return null;n=n.return}n.sibling.return=n.return,n=n.sibling}return null}var Nh=[];function Oh(){for(var e=0;e<Nh.length;e++)Nh[e]._workInProgressVersionPrimary=null;Nh.length=0}var Ph=ua.ReactCurrentDispatcher,Qh=ua.ReactCurrentBatchConfig,Rh=0,N=null,O=null,P=null,Sh=!1,Th=!1,Uh=0,Vh=0;function Q(){throw Error(p(321))}function Wh(e,n){if(null===n)return!1;for(var t=0;t<n.length&&t<e.length;t++)if(!He(e[t],n[t]))return!1;return!0}function Xh(e,n,t,r,l,a){if(Rh=a,N=n,n.memoizedState=null,n.updateQueue=null,n.lanes=0,Ph.current=null===e||null===e.memoizedState?Yh:Zh,e=t(r,l),Th){a=0;do{if(Th=!1,Uh=0,25<=a)throw Error(p(301));a+=1,P=O=null,n.updateQueue=null,Ph.current=$h,e=t(r,l)}while(Th)}if(Ph.current=ai,n=null!==O&&null!==O.next,Rh=0,P=O=N=null,Sh=!1,n)throw Error(p(300));return e}function bi(){var e=0!==Uh;return Uh=0,e}function ci(){var e={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return null===P?N.memoizedState=P=e:P=P.next=e,P}function di(){if(null===O){var e=N.alternate;e=null!==e?e.memoizedState:null}else e=O.next;var n=null===P?N.memoizedState:P.next;if(null!==n)P=n,O=e;else{if(null===e)throw Error(p(310));e={memoizedState:(O=e).memoizedState,baseState:O.baseState,baseQueue:O.baseQueue,queue:O.queue,next:null},null===P?N.memoizedState=P=e:P=P.next=e}return P}function ei(e,n){return"function"==typeof n?n(e):n}function fi(e){var n=di(),t=n.queue;if(null===t)throw Error(p(311));t.lastRenderedReducer=e;var r=O,l=r.baseQueue,a=t.pending;if(null!==a){if(null!==l){var i=l.next;l.next=a.next,a.next=i}r.baseQueue=l=a,t.pending=null}if(null!==l){a=l.next,r=r.baseState;var u=i=null,o=null,c=a;do{var s=c.lane;if((Rh&s)===s)null!==o&&(o=o.next={lane:0,action:c.action,hasEagerState:c.hasEagerState,eagerState:c.eagerState,next:null}),r=c.hasEagerState?c.eagerState:e(r,c.action);else{var f={lane:s,action:c.action,hasEagerState:c.hasEagerState,eagerState:c.eagerState,next:null};null===o?(u=o=f,i=r):o=o.next=f,N.lanes|=s,hh|=s}c=c.next}while(null!==c&&c!==a);null===o?i=r:o.next=u,He(r,n.memoizedState)||(Ug=!0),n.memoizedState=r,n.baseState=i,n.baseQueue=o,t.lastRenderedState=r}if(null!==(e=t.interleaved)){l=e;do{a=l.lane,N.lanes|=a,hh|=a,l=l.next}while(l!==e)}else null===l&&(t.lanes=0);return[n.memoizedState,t.dispatch]}function gi(e){var n=di(),t=n.queue;if(null===t)throw Error(p(311));t.lastRenderedReducer=e;var r=t.dispatch,l=t.pending,a=n.memoizedState;if(null!==l){t.pending=null;var i=l=l.next;do{a=e(a,i.action),i=i.next}while(i!==l);He(a,n.memoizedState)||(Ug=!0),n.memoizedState=a,null===n.baseQueue&&(n.baseState=a),t.lastRenderedState=a}return[a,r]}function hi(){}function ii(e,n){var t=N,r=di(),l=n(),a=!He(r.memoizedState,l);if(a&&(r.memoizedState=l,Ug=!0),r=r.queue,ji(ki.bind(null,t,r,e),[e]),r.getSnapshot!==n||a||null!==P&&1&P.memoizedState.tag){if(t.flags|=2048,li(9,mi.bind(null,t,r,l,n),void 0,null),null===R)throw Error(p(349));0!=(30&Rh)||ni(t,n,l)}return l}function ni(e,n,t){e.flags|=16384,e={getSnapshot:n,value:t},null===(n=N.updateQueue)?(n={lastEffect:null,stores:null},N.updateQueue=n,n.stores=[e]):null===(t=n.stores)?n.stores=[e]:t.push(e)}function mi(e,n,t,r){n.value=t,n.getSnapshot=r,oi(n)&&pi(e)}function ki(e,n,t){return t((function(){oi(n)&&pi(e)}))}function oi(e){var n=e.getSnapshot;e=e.value;try{var t=n();return!He(e,t)}catch(e){return!0}}function pi(e){var n=Zg(e,1);null!==n&&mh(n,e,1,-1)}function qi(e){var n=ci();return"function"==typeof e&&(e=e()),n.memoizedState=n.baseState=e,e={pending:null,interleaved:null,lanes:0,dispatch:null,lastRenderedReducer:ei,lastRenderedState:e},n.queue=e,e=e.dispatch=ri.bind(null,N,e),[n.memoizedState,e]}function li(e,n,t,r){return e={tag:e,create:n,destroy:t,deps:r,next:null},null===(n=N.updateQueue)?(n={lastEffect:null,stores:null},N.updateQueue=n,n.lastEffect=e.next=e):null===(t=n.lastEffect)?n.lastEffect=e.next=e:(r=t.next,t.next=e,e.next=r,n.lastEffect=e),e}function si(){return di().memoizedState}function ti(e,n,t,r){var l=ci();N.flags|=e,l.memoizedState=li(1|n,t,void 0,void 0===r?null:r)}function ui(e,n,t,r){var l=di();r=void 0===r?null:r;var a=void 0;if(null!==O){var i=O.memoizedState;if(a=i.destroy,null!==r&&Wh(r,i.deps))return void(l.memoizedState=li(n,t,a,r))}N.flags|=e,l.memoizedState=li(1|n,t,a,r)}function vi(e,n){return ti(8390656,8,e,n)}function ji(e,n){return ui(2048,8,e,n)}function wi(e,n){return ui(4,2,e,n)}function xi(e,n){return ui(4,4,e,n)}function yi(e,n){return"function"==typeof n?(e=e(),n(e),function(){n(null)}):null!=n?(e=e(),n.current=e,function(){n.current=null}):void 0}function zi(e,n,t){return t=null!=t?t.concat([e]):null,ui(4,4,yi.bind(null,n,e),t)}function Ai(){}function Bi(e,n){var t=di();n=void 0===n?null:n;var r=t.memoizedState;return null!==r&&null!==n&&Wh(n,r[1])?r[0]:(t.memoizedState=[e,n],e)}function Ci(e,n){var t=di();n=void 0===n?null:n;var r=t.memoizedState;return null!==r&&null!==n&&Wh(n,r[1])?r[0]:(e=e(),t.memoizedState=[e,n],e)}function Di(e,n,t){return 0==(21&Rh)?(e.baseState&&(e.baseState=!1,Ug=!0),e.memoizedState=t):(He(t,n)||(t=yc(),N.lanes|=t,hh|=t,e.baseState=!0),n)}function Ei(e,n){var t=C;C=0!==t&&4>t?t:4,e(!0);var r=Qh.transition;Qh.transition={};try{e(!1),n()}finally{C=t,Qh.transition=r}}function Fi(){return di().memoizedState}function Gi(e,n,t){var r=lh(e);if(t={lane:r,action:t,hasEagerState:!1,eagerState:null,next:null},Hi(e))Ii(n,t);else if(null!==(t=Yg(e,n,t,r))){mh(t,e,r,L()),Ji(t,n,r)}}function ri(e,n,t){var r=lh(e),l={lane:r,action:t,hasEagerState:!1,eagerState:null,next:null};if(Hi(e))Ii(n,l);else{var a=e.alternate;if(0===e.lanes&&(null===a||0===a.lanes)&&null!==(a=n.lastRenderedReducer))try{var i=n.lastRenderedState,u=a(i,t);if(l.hasEagerState=!0,l.eagerState=u,He(u,i)){var o=n.interleaved;return null===o?(l.next=l,Xg(n)):(l.next=o.next,o.next=l),void(n.interleaved=l)}}catch(e){}null!==(t=Yg(e,n,l,r))&&(mh(t,e,r,l=L()),Ji(t,n,r))}}function Hi(e){var n=e.alternate;return e===N||null!==n&&n===N}function Ii(e,n){Th=Sh=!0;var t=e.pending;null===t?n.next=n:(n.next=t.next,t.next=n),e.pending=n}function Ji(e,n,t){if(0!=(4194240&t)){var r=n.lanes;t|=r&=e.pendingLanes,n.lanes=t,Cc(e,t)}}var ai={readContext:Vg,useCallback:Q,useContext:Q,useEffect:Q,useImperativeHandle:Q,useInsertionEffect:Q,useLayoutEffect:Q,useMemo:Q,useReducer:Q,useRef:Q,useState:Q,useDebugValue:Q,useDeferredValue:Q,useTransition:Q,useMutableSource:Q,useSyncExternalStore:Q,useId:Q,unstable_isNewReconciler:!1},Yh={readContext:Vg,useCallback:function(e,n){return ci().memoizedState=[e,void 0===n?null:n],e},useContext:Vg,useEffect:vi,useImperativeHandle:function(e,n,t){return t=null!=t?t.concat([e]):null,ti(4194308,4,yi.bind(null,n,e),t)},useLayoutEffect:function(e,n){return ti(4194308,4,e,n)},useInsertionEffect:function(e,n){return ti(4,2,e,n)},useMemo:function(e,n){var t=ci();return n=void 0===n?null:n,e=e(),t.memoizedState=[e,n],e},useReducer:function(e,n,t){var r=ci();return n=void 0!==t?t(n):n,r.memoizedState=r.baseState=n,e={pending:null,interleaved:null,lanes:0,dispatch:null,lastRenderedReducer:e,lastRenderedState:n},r.queue=e,e=e.dispatch=Gi.bind(null,N,e),[r.memoizedState,e]},useRef:function(e){return e={current:e},ci().memoizedState=e},useState:qi,useDebugValue:Ai,useDeferredValue:function(e){return ci().memoizedState=e},useTransition:function(){var e=qi(!1),n=e[0];return e=Ei.bind(null,e[1]),ci().memoizedState=e,[n,e]},useMutableSource:function(){},useSyncExternalStore:function(e,n,t){var r=N,l=ci();if(I){if(void 0===t)throw Error(p(407));t=t()}else{if(t=n(),null===R)throw Error(p(349));0!=(30&Rh)||ni(r,n,t)}l.memoizedState=t;var a={value:t,getSnapshot:n};return l.queue=a,vi(ki.bind(null,r,a,e),[e]),r.flags|=2048,li(9,mi.bind(null,r,a,t,n),void 0,null),t},useId:function(){var e=ci(),n=R.identifierPrefix;if(I){var t=sg;n=":"+n+"R"+(t=(rg&~(1<<32-oc(rg)-1)).toString(32)+t),0<(t=Uh++)&&(n+="H"+t.toString(32)),n+=":"}else n=":"+n+"r"+(t=Vh++).toString(32)+":";return e.memoizedState=n},unstable_isNewReconciler:!1},Zh={readContext:Vg,useCallback:Bi,useContext:Vg,useEffect:ji,useImperativeHandle:zi,useInsertionEffect:wi,useLayoutEffect:xi,useMemo:Ci,useReducer:fi,useRef:si,useState:function(){return fi(ei)},useDebugValue:Ai,useDeferredValue:function(e){return Di(di(),O.memoizedState,e)},useTransition:function(){return[fi(ei)[0],di().memoizedState]},useMutableSource:hi,useSyncExternalStore:ii,useId:Fi,unstable_isNewReconciler:!1},$h={readContext:Vg,useCallback:Bi,useContext:Vg,useEffect:ji,useImperativeHandle:zi,useInsertionEffect:wi,useLayoutEffect:xi,useMemo:Ci,useReducer:gi,useRef:si,useState:function(){return gi(ei)},useDebugValue:Ai,useDeferredValue:function(e){var n=di();return null===O?n.memoizedState=e:Di(n,O.memoizedState,e)},useTransition:function(){return[gi(ei)[0],di().memoizedState]},useMutableSource:hi,useSyncExternalStore:ii,useId:Fi,unstable_isNewReconciler:!1};function Ki(e,n){try{var t="",r=n;do{t+=Pa(r),r=r.return}while(r);var l=t}catch(e){l="\nError generating stack: "+e.message+"\n"+e.stack}return{value:e,source:n,stack:l,digest:null}}function Li(e,n,t){return{value:e,source:null,stack:null!=t?t:null,digest:null!=n?n:null}}function Mi(e,n){try{console.error(n.value)}catch(e){setTimeout((function(){throw e}))}}var Ni="function"==typeof WeakMap?WeakMap:Map;function Oi(e,n,t){(t=ch(-1,t)).tag=3,t.payload={element:null};var r=n.value;return t.callback=function(){Pi||(Pi=!0,Qi=r),Mi(e,n)},t}function Ri(e,n,t){(t=ch(-1,t)).tag=3;var r=e.type.getDerivedStateFromError;if("function"==typeof r){var l=n.value;t.payload=function(){return r(l)},t.callback=function(){Mi(e,n)}}var a=e.stateNode;return null!==a&&"function"==typeof a.componentDidCatch&&(t.callback=function(){Mi(e,n),"function"!=typeof r&&(null===Si?Si=new Set([this]):Si.add(this));var t=n.stack;this.componentDidCatch(n.value,{componentStack:null!==t?t:""})}),t}function Ti(e,n,t){var r=e.pingCache;if(null===r){r=e.pingCache=new Ni;var l=new Set;r.set(n,l)}else void 0===(l=r.get(n))&&(l=new Set,r.set(n,l));l.has(t)||(l.add(t),e=Ui.bind(null,e,n,t),n.then(e,e))}function Vi(e){do{var n;if((n=13===e.tag)&&(n=null===(n=e.memoizedState)||null!==n.dehydrated),n)return e;e=e.return}while(null!==e);return null}function Wi(e,n,t,r,l){return 0==(1&e.mode)?(e===n?e.flags|=65536:(e.flags|=128,t.flags|=131072,t.flags&=-52805,1===t.tag&&(null===t.alternate?t.tag=17:((n=ch(-1,1)).tag=2,dh(t,n,1))),t.lanes|=1),e):(e.flags|=65536,e.lanes=l,e)}var Xi=ua.ReactCurrentOwner,Ug=!1;function Yi(e,n,t,r){n.child=null===e?Ch(n,null,t,r):Bh(n,e.child,t,r)}function Zi(e,n,t,r,l){t=t.render;var a=n.ref;return Tg(n,l),r=Xh(e,n,t,r,a,l),t=bi(),null===e||Ug?(I&&t&&vg(n),n.flags|=1,Yi(e,n,r,l),n.child):(n.updateQueue=e.updateQueue,n.flags&=-2053,e.lanes&=~l,$i(e,n,l))}function aj(e,n,t,r,l){if(null===e){var a=t.type;return"function"!=typeof a||bj(a)||void 0!==a.defaultProps||null!==t.compare||void 0!==t.defaultProps?((e=yh(t.type,null,r,n,n.mode,l)).ref=n.ref,e.return=n,n.child=e):(n.tag=15,n.type=a,cj(e,n,a,r,l))}if(a=e.child,0==(e.lanes&l)){var i=a.memoizedProps;if((t=null!==(t=t.compare)?t:Ie)(i,r)&&e.ref===n.ref)return $i(e,n,l)}return n.flags|=1,(e=wh(a,r)).ref=n.ref,e.return=n,n.child=e}function cj(e,n,t,r,l){if(null!==e){var a=e.memoizedProps;if(Ie(a,r)&&e.ref===n.ref){if(Ug=!1,n.pendingProps=r=a,0==(e.lanes&l))return n.lanes=e.lanes,$i(e,n,l);0!=(131072&e.flags)&&(Ug=!0)}}return dj(e,n,t,r,l)}function ej(e,n,t){var r=n.pendingProps,l=r.children,a=null!==e?e.memoizedState:null;if("hidden"===r.mode)if(0==(1&n.mode))n.memoizedState={baseLanes:0,cachePool:null,transitions:null},G(fj,gj),gj|=t;else{if(0==(1073741824&t))return e=null!==a?a.baseLanes|t:t,n.lanes=n.childLanes=1073741824,n.memoizedState={baseLanes:e,cachePool:null,transitions:null},n.updateQueue=null,G(fj,gj),gj|=e,null;n.memoizedState={baseLanes:0,cachePool:null,transitions:null},r=null!==a?a.baseLanes:t,G(fj,gj),gj|=r}else null!==a?(r=a.baseLanes|t,n.memoizedState=null):r=t,G(fj,gj),gj|=r;return Yi(e,n,l,t),n.child}function hj(e,n){var t=n.ref;(null===e&&null!==t||null!==e&&e.ref!==t)&&(n.flags|=512,n.flags|=2097152)}function dj(e,n,t,r,l){var a=Zf(t)?Xf:H.current;return a=Yf(n,a),Tg(n,l),t=Xh(e,n,t,r,a,l),r=bi(),null===e||Ug?(I&&r&&vg(n),n.flags|=1,Yi(e,n,t,l),n.child):(n.updateQueue=e.updateQueue,n.flags&=-2053,e.lanes&=~l,$i(e,n,l))}function ij(e,n,t,r,l){if(Zf(t)){var a=!0;cg(n)}else a=!1;if(Tg(n,l),null===n.stateNode)jj(e,n),ph(n,t,r),rh(n,t,r,l),r=!0;else if(null===e){var i=n.stateNode,u=n.memoizedProps;i.props=u;var o=i.context,c=t.contextType;"object"==typeof c&&null!==c?c=Vg(c):c=Yf(n,c=Zf(t)?Xf:H.current);var s=t.getDerivedStateFromProps,f="function"==typeof s||"function"==typeof i.getSnapshotBeforeUpdate;f||"function"!=typeof i.UNSAFE_componentWillReceiveProps&&"function"!=typeof i.componentWillReceiveProps||(u!==r||o!==c)&&qh(n,i,r,c),$g=!1;var d=n.memoizedState;i.state=d,gh(n,r,i,l),o=n.memoizedState,u!==r||d!==o||Wf.current||$g?("function"==typeof s&&(kh(n,t,s,r),o=n.memoizedState),(u=$g||oh(n,t,u,r,d,o,c))?(f||"function"!=typeof i.UNSAFE_componentWillMount&&"function"!=typeof i.componentWillMount||("function"==typeof i.componentWillMount&&i.componentWillMount(),"function"==typeof i.UNSAFE_componentWillMount&&i.UNSAFE_componentWillMount()),"function"==typeof i.componentDidMount&&(n.flags|=4194308)):("function"==typeof i.componentDidMount&&(n.flags|=4194308),n.memoizedProps=r,n.memoizedState=o),i.props=r,i.state=o,i.context=c,r=u):("function"==typeof i.componentDidMount&&(n.flags|=4194308),r=!1)}else{i=n.stateNode,bh(e,n),u=n.memoizedProps,c=n.type===n.elementType?u:Lg(n.type,u),i.props=c,f=n.pendingProps,d=i.context,"object"==typeof(o=t.contextType)&&null!==o?o=Vg(o):o=Yf(n,o=Zf(t)?Xf:H.current);var p=t.getDerivedStateFromProps;(s="function"==typeof p||"function"==typeof i.getSnapshotBeforeUpdate)||"function"!=typeof i.UNSAFE_componentWillReceiveProps&&"function"!=typeof i.componentWillReceiveProps||(u!==f||d!==o)&&qh(n,i,r,o),$g=!1,d=n.memoizedState,i.state=d,gh(n,r,i,l);var h=n.memoizedState;u!==f||d!==h||Wf.current||$g?("function"==typeof p&&(kh(n,t,p,r),h=n.memoizedState),(c=$g||oh(n,t,c,r,d,h,o)||!1)?(s||"function"!=typeof i.UNSAFE_componentWillUpdate&&"function"!=typeof i.componentWillUpdate||("function"==typeof i.componentWillUpdate&&i.componentWillUpdate(r,h,o),"function"==typeof i.UNSAFE_componentWillUpdate&&i.UNSAFE_componentWillUpdate(r,h,o)),"function"==typeof i.componentDidUpdate&&(n.flags|=4),"function"==typeof i.getSnapshotBeforeUpdate&&(n.flags|=1024)):("function"!=typeof i.componentDidUpdate||u===e.memoizedProps&&d===e.memoizedState||(n.flags|=4),"function"!=typeof i.getSnapshotBeforeUpdate||u===e.memoizedProps&&d===e.memoizedState||(n.flags|=1024),n.memoizedProps=r,n.memoizedState=h),i.props=r,i.state=h,i.context=o,r=c):("function"!=typeof i.componentDidUpdate||u===e.memoizedProps&&d===e.memoizedState||(n.flags|=4),"function"!=typeof i.getSnapshotBeforeUpdate||u===e.memoizedProps&&d===e.memoizedState||(n.flags|=1024),r=!1)}return kj(e,n,t,r,a,l)}function kj(e,n,t,r,l,a){hj(e,n);var i=0!=(128&n.flags);if(!r&&!i)return l&&dg(n,t,!1),$i(e,n,a);r=n.stateNode,Xi.current=n;var u=i&&"function"!=typeof t.getDerivedStateFromError?null:r.render();return n.flags|=1,null!==e&&i?(n.child=Bh(n,e.child,null,a),n.child=Bh(n,null,u,a)):Yi(e,n,u,a),n.memoizedState=r.state,l&&dg(n,t,!0),n.child}function lj(e){var n=e.stateNode;n.pendingContext?ag(e,n.pendingContext,n.pendingContext!==n.context):n.context&&ag(e,n.context,!1),Ih(e,n.containerInfo)}function mj(e,n,t,r,l){return Ig(),Jg(l),n.flags|=256,Yi(e,n,t,r),n.child}var Aj,Bj,Cj,Dj,nj={dehydrated:null,treeContext:null,retryLane:0};function oj(e){return{baseLanes:e,cachePool:null,transitions:null}}function pj(e,n,t){var r,l=n.pendingProps,a=M.current,i=!1,u=0!=(128&n.flags);if((r=u)||(r=(null===e||null!==e.memoizedState)&&0!=(2&a)),r?(i=!0,n.flags&=-129):null!==e&&null===e.memoizedState||(a|=1),G(M,1&a),null===e)return Eg(n),null!==(e=n.memoizedState)&&null!==(e=e.dehydrated)?(0==(1&n.mode)?n.lanes=1:"$!"===e.data?n.lanes=8:n.lanes=1073741824,null):(u=l.children,e=l.fallback,i?(l=n.mode,i=n.child,u={mode:"hidden",children:u},0==(1&l)&&null!==i?(i.childLanes=0,i.pendingProps=u):i=qj(u,l,0,null),e=Ah(e,l,t,null),i.return=n,e.return=n,i.sibling=e,n.child=i,n.child.memoizedState=oj(t),n.memoizedState=nj,e):rj(n,u));if(null!==(a=e.memoizedState)&&null!==(r=a.dehydrated))return sj(e,n,u,l,r,a,t);if(i){i=l.fallback,u=n.mode,r=(a=e.child).sibling;var o={mode:"hidden",children:l.children};return 0==(1&u)&&n.child!==a?((l=n.child).childLanes=0,l.pendingProps=o,n.deletions=null):(l=wh(a,o)).subtreeFlags=14680064&a.subtreeFlags,null!==r?i=wh(r,i):(i=Ah(i,u,t,null)).flags|=2,i.return=n,l.return=n,l.sibling=i,n.child=l,l=i,i=n.child,u=null===(u=e.child.memoizedState)?oj(t):{baseLanes:u.baseLanes|t,cachePool:null,transitions:u.transitions},i.memoizedState=u,i.childLanes=e.childLanes&~t,n.memoizedState=nj,l}return e=(i=e.child).sibling,l=wh(i,{mode:"visible",children:l.children}),0==(1&n.mode)&&(l.lanes=t),l.return=n,l.sibling=null,null!==e&&(null===(t=n.deletions)?(n.deletions=[e],n.flags|=16):t.push(e)),n.child=l,n.memoizedState=null,l}function rj(e,n){return(n=qj({mode:"visible",children:n},e.mode,0,null)).return=e,e.child=n}function tj(e,n,t,r){return null!==r&&Jg(r),Bh(n,e.child,null,t),(e=rj(n,n.pendingProps.children)).flags|=2,n.memoizedState=null,e}function sj(e,n,t,r,l,a,i){if(t)return 256&n.flags?(n.flags&=-257,tj(e,n,i,r=Li(Error(p(422))))):null!==n.memoizedState?(n.child=e.child,n.flags|=128,null):(a=r.fallback,l=n.mode,r=qj({mode:"visible",children:r.children},l,0,null),(a=Ah(a,l,i,null)).flags|=2,r.return=n,a.return=n,r.sibling=a,n.child=r,0!=(1&n.mode)&&Bh(n,e.child,null,i),n.child.memoizedState=oj(i),n.memoizedState=nj,a);if(0==(1&n.mode))return tj(e,n,i,null);if("$!"===l.data){if(r=l.nextSibling&&l.nextSibling.dataset)var u=r.dgst;return r=u,tj(e,n,i,r=Li(a=Error(p(419)),r,void 0))}if(u=0!=(i&e.childLanes),Ug||u){if(null!==(r=R)){switch(i&-i){case 4:l=2;break;case 16:l=8;break;case 64:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:case 67108864:l=32;break;case 536870912:l=268435456;break;default:l=0}0!==(l=0!=(l&(r.suspendedLanes|i))?0:l)&&l!==a.retryLane&&(a.retryLane=l,Zg(e,l),mh(r,e,l,-1))}return uj(),tj(e,n,i,r=Li(Error(p(421))))}return"$?"===l.data?(n.flags|=128,n.child=e.child,n=vj.bind(null,e),l._reactRetry=n,null):(e=a.treeContext,yg=Lf(l.nextSibling),xg=n,I=!0,zg=null,null!==e&&(og[pg++]=rg,og[pg++]=sg,og[pg++]=qg,rg=e.id,sg=e.overflow,qg=n),(n=rj(n,r.children)).flags|=4096,n)}function wj(e,n,t){e.lanes|=n;var r=e.alternate;null!==r&&(r.lanes|=n),Sg(e.return,n,t)}function xj(e,n,t,r,l){var a=e.memoizedState;null===a?e.memoizedState={isBackwards:n,rendering:null,renderingStartTime:0,last:r,tail:t,tailMode:l}:(a.isBackwards=n,a.rendering=null,a.renderingStartTime=0,a.last=r,a.tail=t,a.tailMode=l)}function yj(e,n,t){var r=n.pendingProps,l=r.revealOrder,a=r.tail;if(Yi(e,n,r.children,t),0!=(2&(r=M.current)))r=1&r|2,n.flags|=128;else{if(null!==e&&0!=(128&e.flags))e:for(e=n.child;null!==e;){if(13===e.tag)null!==e.memoizedState&&wj(e,t,n);else if(19===e.tag)wj(e,t,n);else if(null!==e.child){e.child.return=e,e=e.child;continue}if(e===n)break e;for(;null===e.sibling;){if(null===e.return||e.return===n)break e;e=e.return}e.sibling.return=e.return,e=e.sibling}r&=1}if(G(M,r),0==(1&n.mode))n.memoizedState=null;else switch(l){case"forwards":for(t=n.child,l=null;null!==t;)null!==(e=t.alternate)&&null===Mh(e)&&(l=t),t=t.sibling;null===(t=l)?(l=n.child,n.child=null):(l=t.sibling,t.sibling=null),xj(n,!1,l,t,a);break;case"backwards":for(t=null,l=n.child,n.child=null;null!==l;){if(null!==(e=l.alternate)&&null===Mh(e)){n.child=l;break}e=l.sibling,l.sibling=t,t=l,l=e}xj(n,!0,t,null,a);break;case"together":xj(n,!1,null,null,void 0);break;default:n.memoizedState=null}return n.child}function jj(e,n){0==(1&n.mode)&&null!==e&&(e.alternate=null,n.alternate=null,n.flags|=2)}function $i(e,n,t){if(null!==e&&(n.dependencies=e.dependencies),hh|=n.lanes,0==(t&n.childLanes))return null;if(null!==e&&n.child!==e.child)throw Error(p(153));if(null!==n.child){for(t=wh(e=n.child,e.pendingProps),n.child=t,t.return=n;null!==e.sibling;)e=e.sibling,(t=t.sibling=wh(e,e.pendingProps)).return=n;t.sibling=null}return n.child}function zj(e,n,t){switch(n.tag){case 3:lj(n),Ig();break;case 5:Kh(n);break;case 1:Zf(n.type)&&cg(n);break;case 4:Ih(n,n.stateNode.containerInfo);break;case 10:var r=n.type._context,l=n.memoizedProps.value;G(Mg,r._currentValue),r._currentValue=l;break;case 13:if(null!==(r=n.memoizedState))return null!==r.dehydrated?(G(M,1&M.current),n.flags|=128,null):0!=(t&n.child.childLanes)?pj(e,n,t):(G(M,1&M.current),null!==(e=$i(e,n,t))?e.sibling:null);G(M,1&M.current);break;case 19:if(r=0!=(t&n.childLanes),0!=(128&e.flags)){if(r)return yj(e,n,t);n.flags|=128}if(null!==(l=n.memoizedState)&&(l.rendering=null,l.tail=null,l.lastEffect=null),G(M,M.current),r)break;return null;case 22:case 23:return n.lanes=0,ej(e,n,t)}return $i(e,n,t)}function Ej(e,n){if(!I)switch(e.tailMode){case"hidden":n=e.tail;for(var t=null;null!==n;)null!==n.alternate&&(t=n),n=n.sibling;null===t?e.tail=null:t.sibling=null;break;case"collapsed":t=e.tail;for(var r=null;null!==t;)null!==t.alternate&&(r=t),t=t.sibling;null===r?n||null===e.tail?e.tail=null:e.tail.sibling=null:r.sibling=null}}function S(e){var n=null!==e.alternate&&e.alternate.child===e.child,t=0,r=0;if(n)for(var l=e.child;null!==l;)t|=l.lanes|l.childLanes,r|=14680064&l.subtreeFlags,r|=14680064&l.flags,l.return=e,l=l.sibling;else for(l=e.child;null!==l;)t|=l.lanes|l.childLanes,r|=l.subtreeFlags,r|=l.flags,l.return=e,l=l.sibling;return e.subtreeFlags|=r,e.childLanes=t,n}function Fj(e,n,t){var r=n.pendingProps;switch(wg(n),n.tag){case 2:case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return S(n),null;case 1:case 17:return Zf(n.type)&&$f(),S(n),null;case 3:return r=n.stateNode,Jh(),E(Wf),E(H),Oh(),r.pendingContext&&(r.context=r.pendingContext,r.pendingContext=null),null!==e&&null!==e.child||(Gg(n)?n.flags|=4:null===e||e.memoizedState.isDehydrated&&0==(256&n.flags)||(n.flags|=1024,null!==zg&&(Gj(zg),zg=null))),Bj(e,n),S(n),null;case 5:Lh(n);var l=Hh(Gh.current);if(t=n.type,null!==e&&null!=n.stateNode)Cj(e,n,t,r,l),e.ref!==n.ref&&(n.flags|=512,n.flags|=2097152);else{if(!r){if(null===n.stateNode)throw Error(p(166));return S(n),null}if(e=Hh(Eh.current),Gg(n)){r=n.stateNode,t=n.type;var a=n.memoizedProps;switch(r[Of]=n,r[Pf]=a,e=0!=(1&n.mode),t){case"dialog":D("cancel",r),D("close",r);break;case"iframe":case"object":case"embed":D("load",r);break;case"video":case"audio":for(l=0;l<lf.length;l++)D(lf[l],r);break;case"source":D("error",r);break;case"img":case"image":case"link":D("error",r),D("load",r);break;case"details":D("toggle",r);break;case"input":Za(r,a),D("invalid",r);break;case"select":r._wrapperState={wasMultiple:!!a.multiple},D("invalid",r);break;case"textarea":hb(r,a),D("invalid",r)}for(var i in ub(t,a),l=null,a)if(a.hasOwnProperty(i)){var u=a[i];"children"===i?"string"==typeof u?r.textContent!==u&&(!0!==a.suppressHydrationWarning&&Af(r.textContent,u,e),l=["children",u]):"number"==typeof u&&r.textContent!==""+u&&(!0!==a.suppressHydrationWarning&&Af(r.textContent,u,e),l=["children",""+u]):ea.hasOwnProperty(i)&&null!=u&&"onScroll"===i&&D("scroll",r)}switch(t){case"input":Va(r),db(r,a,!0);break;case"textarea":Va(r),jb(r);break;case"select":case"option":break;default:"function"==typeof a.onClick&&(r.onclick=Bf)}r=l,n.updateQueue=r,null!==r&&(n.flags|=4)}else{i=9===l.nodeType?l:l.ownerDocument,"http://www.w3.org/1999/xhtml"===e&&(e=kb(t)),"http://www.w3.org/1999/xhtml"===e?"script"===t?((e=i.createElement("div")).innerHTML="<script><\/script>",e=e.removeChild(e.firstChild)):"string"==typeof r.is?e=i.createElement(t,{is:r.is}):(e=i.createElement(t),"select"===t&&(i=e,r.multiple?i.multiple=!0:r.size&&(i.size=r.size))):e=i.createElementNS(e,t),e[Of]=n,e[Pf]=r,Aj(e,n,!1,!1),n.stateNode=e;e:{switch(i=vb(t,r),t){case"dialog":D("cancel",e),D("close",e),l=r;break;case"iframe":case"object":case"embed":D("load",e),l=r;break;case"video":case"audio":for(l=0;l<lf.length;l++)D(lf[l],e);l=r;break;case"source":D("error",e),l=r;break;case"img":case"image":case"link":D("error",e),D("load",e),l=r;break;case"details":D("toggle",e),l=r;break;case"input":Za(e,r),l=Ya(e,r),D("invalid",e);break;case"option":default:l=r;break;case"select":e._wrapperState={wasMultiple:!!r.multiple},l=A({},r,{value:void 0}),D("invalid",e);break;case"textarea":hb(e,r),l=gb(e,r),D("invalid",e)}for(a in ub(t,l),u=l)if(u.hasOwnProperty(a)){var o=u[a];"style"===a?sb(e,o):"dangerouslySetInnerHTML"===a?null!=(o=o?o.__html:void 0)&&nb(e,o):"children"===a?"string"==typeof o?("textarea"!==t||""!==o)&&ob(e,o):"number"==typeof o&&ob(e,""+o):"suppressContentEditableWarning"!==a&&"suppressHydrationWarning"!==a&&"autoFocus"!==a&&(ea.hasOwnProperty(a)?null!=o&&"onScroll"===a&&D("scroll",e):null!=o&&ta(e,a,o,i))}switch(t){case"input":Va(e),db(e,r,!1);break;case"textarea":Va(e),jb(e);break;case"option":null!=r.value&&e.setAttribute("value",""+Sa(r.value));break;case"select":e.multiple=!!r.multiple,null!=(a=r.value)?fb(e,!!r.multiple,a,!1):null!=r.defaultValue&&fb(e,!!r.multiple,r.defaultValue,!0);break;default:"function"==typeof l.onClick&&(e.onclick=Bf)}switch(t){case"button":case"input":case"select":case"textarea":r=!!r.autoFocus;break e;case"img":r=!0;break e;default:r=!1}}r&&(n.flags|=4)}null!==n.ref&&(n.flags|=512,n.flags|=2097152)}return S(n),null;case 6:if(e&&null!=n.stateNode)Dj(e,n,e.memoizedProps,r);else{if("string"!=typeof r&&null===n.stateNode)throw Error(p(166));if(t=Hh(Gh.current),Hh(Eh.current),Gg(n)){if(r=n.stateNode,t=n.memoizedProps,r[Of]=n,(a=r.nodeValue!==t)&&null!==(e=xg))switch(e.tag){case 3:Af(r.nodeValue,t,0!=(1&e.mode));break;case 5:!0!==e.memoizedProps.suppressHydrationWarning&&Af(r.nodeValue,t,0!=(1&e.mode))}a&&(n.flags|=4)}else(r=(9===t.nodeType?t:t.ownerDocument).createTextNode(r))[Of]=n,n.stateNode=r}return S(n),null;case 13:if(E(M),r=n.memoizedState,null===e||null!==e.memoizedState&&null!==e.memoizedState.dehydrated){if(I&&null!==yg&&0!=(1&n.mode)&&0==(128&n.flags))Hg(),Ig(),n.flags|=98560,a=!1;else if(a=Gg(n),null!==r&&null!==r.dehydrated){if(null===e){if(!a)throw Error(p(318));if(!(a=null!==(a=n.memoizedState)?a.dehydrated:null))throw Error(p(317));a[Of]=n}else Ig(),0==(128&n.flags)&&(n.memoizedState=null),n.flags|=4;S(n),a=!1}else null!==zg&&(Gj(zg),zg=null),a=!0;if(!a)return 65536&n.flags?n:null}return 0!=(128&n.flags)?(n.lanes=t,n):((r=null!==r)!==(null!==e&&null!==e.memoizedState)&&r&&(n.child.flags|=8192,0!=(1&n.mode)&&(null===e||0!=(1&M.current)?0===T&&(T=3):uj())),null!==n.updateQueue&&(n.flags|=4),S(n),null);case 4:return Jh(),Bj(e,n),null===e&&sf(n.stateNode.containerInfo),S(n),null;case 10:return Rg(n.type._context),S(n),null;case 19:if(E(M),null===(a=n.memoizedState))return S(n),null;if(r=0!=(128&n.flags),null===(i=a.rendering))if(r)Ej(a,!1);else{if(0!==T||null!==e&&0!=(128&e.flags))for(e=n.child;null!==e;){if(null!==(i=Mh(e))){for(n.flags|=128,Ej(a,!1),null!==(r=i.updateQueue)&&(n.updateQueue=r,n.flags|=4),n.subtreeFlags=0,r=t,t=n.child;null!==t;)e=r,(a=t).flags&=14680066,null===(i=a.alternate)?(a.childLanes=0,a.lanes=e,a.child=null,a.subtreeFlags=0,a.memoizedProps=null,a.memoizedState=null,a.updateQueue=null,a.dependencies=null,a.stateNode=null):(a.childLanes=i.childLanes,a.lanes=i.lanes,a.child=i.child,a.subtreeFlags=0,a.deletions=null,a.memoizedProps=i.memoizedProps,a.memoizedState=i.memoizedState,a.updateQueue=i.updateQueue,a.type=i.type,e=i.dependencies,a.dependencies=null===e?null:{lanes:e.lanes,firstContext:e.firstContext}),t=t.sibling;return G(M,1&M.current|2),n.child}e=e.sibling}null!==a.tail&&B()>Hj&&(n.flags|=128,r=!0,Ej(a,!1),n.lanes=4194304)}else{if(!r)if(null!==(e=Mh(i))){if(n.flags|=128,r=!0,null!==(t=e.updateQueue)&&(n.updateQueue=t,n.flags|=4),Ej(a,!0),null===a.tail&&"hidden"===a.tailMode&&!i.alternate&&!I)return S(n),null}else 2*B()-a.renderingStartTime>Hj&&1073741824!==t&&(n.flags|=128,r=!0,Ej(a,!1),n.lanes=4194304);a.isBackwards?(i.sibling=n.child,n.child=i):(null!==(t=a.last)?t.sibling=i:n.child=i,a.last=i)}return null!==a.tail?(n=a.tail,a.rendering=n,a.tail=n.sibling,a.renderingStartTime=B(),n.sibling=null,t=M.current,G(M,r?1&t|2:1&t),n):(S(n),null);case 22:case 23:return Ij(),r=null!==n.memoizedState,null!==e&&null!==e.memoizedState!==r&&(n.flags|=8192),r&&0!=(1&n.mode)?0!=(1073741824&gj)&&(S(n),6&n.subtreeFlags&&(n.flags|=8192)):S(n),null;case 24:case 25:return null}throw Error(p(156,n.tag))}function Jj(e,n){switch(wg(n),n.tag){case 1:return Zf(n.type)&&$f(),65536&(e=n.flags)?(n.flags=-65537&e|128,n):null;case 3:return Jh(),E(Wf),E(H),Oh(),0!=(65536&(e=n.flags))&&0==(128&e)?(n.flags=-65537&e|128,n):null;case 5:return Lh(n),null;case 13:if(E(M),null!==(e=n.memoizedState)&&null!==e.dehydrated){if(null===n.alternate)throw Error(p(340));Ig()}return 65536&(e=n.flags)?(n.flags=-65537&e|128,n):null;case 19:return E(M),null;case 4:return Jh(),null;case 10:return Rg(n.type._context),null;case 22:case 23:return Ij(),null;default:return null}}Aj=function(e,n){for(var t=n.child;null!==t;){if(5===t.tag||6===t.tag)e.appendChild(t.stateNode);else if(4!==t.tag&&null!==t.child){t.child.return=t,t=t.child;continue}if(t===n)break;for(;null===t.sibling;){if(null===t.return||t.return===n)return;t=t.return}t.sibling.return=t.return,t=t.sibling}},Bj=function(){},Cj=function(e,n,t,r){var l=e.memoizedProps;if(l!==r){e=n.stateNode,Hh(Eh.current);var a,i=null;switch(t){case"input":l=Ya(e,l),r=Ya(e,r),i=[];break;case"select":l=A({},l,{value:void 0}),r=A({},r,{value:void 0}),i=[];break;case"textarea":l=gb(e,l),r=gb(e,r),i=[];break;default:"function"!=typeof l.onClick&&"function"==typeof r.onClick&&(e.onclick=Bf)}for(c in ub(t,r),t=null,l)if(!r.hasOwnProperty(c)&&l.hasOwnProperty(c)&&null!=l[c])if("style"===c){var u=l[c];for(a in u)u.hasOwnProperty(a)&&(t||(t={}),t[a]="")}else"dangerouslySetInnerHTML"!==c&&"children"!==c&&"suppressContentEditableWarning"!==c&&"suppressHydrationWarning"!==c&&"autoFocus"!==c&&(ea.hasOwnProperty(c)?i||(i=[]):(i=i||[]).push(c,null));for(c in r){var o=r[c];if(u=null!=l?l[c]:void 0,r.hasOwnProperty(c)&&o!==u&&(null!=o||null!=u))if("style"===c)if(u){for(a in u)!u.hasOwnProperty(a)||o&&o.hasOwnProperty(a)||(t||(t={}),t[a]="");for(a in o)o.hasOwnProperty(a)&&u[a]!==o[a]&&(t||(t={}),t[a]=o[a])}else t||(i||(i=[]),i.push(c,t)),t=o;else"dangerouslySetInnerHTML"===c?(o=o?o.__html:void 0,u=u?u.__html:void 0,null!=o&&u!==o&&(i=i||[]).push(c,o)):"children"===c?"string"!=typeof o&&"number"!=typeof o||(i=i||[]).push(c,""+o):"suppressContentEditableWarning"!==c&&"suppressHydrationWarning"!==c&&(ea.hasOwnProperty(c)?(null!=o&&"onScroll"===c&&D("scroll",e),i||u===o||(i=[])):(i=i||[]).push(c,o))}t&&(i=i||[]).push("style",t);var c=i;(n.updateQueue=c)&&(n.flags|=4)}},Dj=function(e,n,t,r){t!==r&&(n.flags|=4)};var Kj=!1,U=!1,Lj="function"==typeof WeakSet?WeakSet:Set,V=null;function Mj(e,n){var t=e.ref;if(null!==t)if("function"==typeof t)try{t(null)}catch(t){W(e,n,t)}else t.current=null}function Nj(e,n,t){try{t()}catch(t){W(e,n,t)}}var Oj=!1;function Pj(e,n){if(Cf=dd,Ne(e=Me())){if("selectionStart"in e)var t={start:e.selectionStart,end:e.selectionEnd};else e:{var r=(t=(t=e.ownerDocument)&&t.defaultView||window).getSelection&&t.getSelection();if(r&&0!==r.rangeCount){t=r.anchorNode;var l=r.anchorOffset,a=r.focusNode;r=r.focusOffset;try{t.nodeType,a.nodeType}catch(e){t=null;break e}var i=0,u=-1,o=-1,c=0,s=0,f=e,d=null;n:for(;;){for(var h;f!==t||0!==l&&3!==f.nodeType||(u=i+l),f!==a||0!==r&&3!==f.nodeType||(o=i+r),3===f.nodeType&&(i+=f.nodeValue.length),null!==(h=f.firstChild);)d=f,f=h;for(;;){if(f===e)break n;if(d===t&&++c===l&&(u=i),d===a&&++s===r&&(o=i),null!==(h=f.nextSibling))break;d=(f=d).parentNode}f=h}t=-1===u||-1===o?null:{start:u,end:o}}else t=null}t=t||{start:0,end:0}}else t=null;for(Df={focusedElem:e,selectionRange:t},dd=!1,V=n;null!==V;)if(e=(n=V).child,0!=(1028&n.subtreeFlags)&&null!==e)e.return=n,V=e;else for(;null!==V;){n=V;try{var g=n.alternate;if(0!=(1024&n.flags))switch(n.tag){case 0:case 11:case 15:case 5:case 6:case 4:case 17:break;case 1:if(null!==g){var m=g.memoizedProps,v=g.memoizedState,b=n.stateNode,y=b.getSnapshotBeforeUpdate(n.elementType===n.type?m:Lg(n.type,m),v);b.__reactInternalSnapshotBeforeUpdate=y}break;case 3:var k=n.stateNode.containerInfo;1===k.nodeType?k.textContent="":9===k.nodeType&&k.documentElement&&k.removeChild(k.documentElement);break;default:throw Error(p(163))}}catch(e){W(n,n.return,e)}if(null!==(e=n.sibling)){e.return=n.return,V=e;break}V=n.return}return g=Oj,Oj=!1,g}function Qj(e,n,t){var r=n.updateQueue;if(null!==(r=null!==r?r.lastEffect:null)){var l=r=r.next;do{if((l.tag&e)===e){var a=l.destroy;l.destroy=void 0,void 0!==a&&Nj(n,t,a)}l=l.next}while(l!==r)}}function Rj(e,n){if(null!==(n=null!==(n=n.updateQueue)?n.lastEffect:null)){var t=n=n.next;do{if((t.tag&e)===e){var r=t.create;t.destroy=r()}t=t.next}while(t!==n)}}function Sj(e){var n=e.ref;if(null!==n){var t=e.stateNode;e.tag,e=t,"function"==typeof n?n(e):n.current=e}}function Tj(e){var n=e.alternate;null!==n&&(e.alternate=null,Tj(n)),e.child=null,e.deletions=null,e.sibling=null,5===e.tag&&(null!==(n=e.stateNode)&&(delete n[Of],delete n[Pf],delete n[of],delete n[Qf],delete n[Rf])),e.stateNode=null,e.return=null,e.dependencies=null,e.memoizedProps=null,e.memoizedState=null,e.pendingProps=null,e.stateNode=null,e.updateQueue=null}function Uj(e){return 5===e.tag||3===e.tag||4===e.tag}function Vj(e){e:for(;;){for(;null===e.sibling;){if(null===e.return||Uj(e.return))return null;e=e.return}for(e.sibling.return=e.return,e=e.sibling;5!==e.tag&&6!==e.tag&&18!==e.tag;){if(2&e.flags)continue e;if(null===e.child||4===e.tag)continue e;e.child.return=e,e=e.child}if(!(2&e.flags))return e.stateNode}}function Wj(e,n,t){var r=e.tag;if(5===r||6===r)e=e.stateNode,n?8===t.nodeType?t.parentNode.insertBefore(e,n):t.insertBefore(e,n):(8===t.nodeType?(n=t.parentNode).insertBefore(e,t):(n=t).appendChild(e),null!=(t=t._reactRootContainer)||null!==n.onclick||(n.onclick=Bf));else if(4!==r&&null!==(e=e.child))for(Wj(e,n,t),e=e.sibling;null!==e;)Wj(e,n,t),e=e.sibling}function Xj(e,n,t){var r=e.tag;if(5===r||6===r)e=e.stateNode,n?t.insertBefore(e,n):t.appendChild(e);else if(4!==r&&null!==(e=e.child))for(Xj(e,n,t),e=e.sibling;null!==e;)Xj(e,n,t),e=e.sibling}var X=null,Yj=!1;function Zj(e,n,t){for(t=t.child;null!==t;)ak(e,n,t),t=t.sibling}function ak(e,n,t){if(lc&&"function"==typeof lc.onCommitFiberUnmount)try{lc.onCommitFiberUnmount(kc,t)}catch(e){}switch(t.tag){case 5:U||Mj(t,n);case 6:var r=X,l=Yj;X=null,Zj(e,n,t),Yj=l,null!==(X=r)&&(Yj?(e=X,t=t.stateNode,8===e.nodeType?e.parentNode.removeChild(t):e.removeChild(t)):X.removeChild(t.stateNode));break;case 18:null!==X&&(Yj?(e=X,t=t.stateNode,8===e.nodeType?Kf(e.parentNode,t):1===e.nodeType&&Kf(e,t),bd(e)):Kf(X,t.stateNode));break;case 4:r=X,l=Yj,X=t.stateNode.containerInfo,Yj=!0,Zj(e,n,t),X=r,Yj=l;break;case 0:case 11:case 14:case 15:if(!U&&(null!==(r=t.updateQueue)&&null!==(r=r.lastEffect))){l=r=r.next;do{var a=l,i=a.destroy;a=a.tag,void 0!==i&&(0!=(2&a)||0!=(4&a))&&Nj(t,n,i),l=l.next}while(l!==r)}Zj(e,n,t);break;case 1:if(!U&&(Mj(t,n),"function"==typeof(r=t.stateNode).componentWillUnmount))try{r.props=t.memoizedProps,r.state=t.memoizedState,r.componentWillUnmount()}catch(e){W(t,n,e)}Zj(e,n,t);break;case 21:Zj(e,n,t);break;case 22:1&t.mode?(U=(r=U)||null!==t.memoizedState,Zj(e,n,t),U=r):Zj(e,n,t);break;default:Zj(e,n,t)}}function bk(e){var n=e.updateQueue;if(null!==n){e.updateQueue=null;var t=e.stateNode;null===t&&(t=e.stateNode=new Lj),n.forEach((function(n){var r=ck.bind(null,e,n);t.has(n)||(t.add(n),n.then(r,r))}))}}function dk(e,n){var t=n.deletions;if(null!==t)for(var r=0;r<t.length;r++){var l=t[r];try{var a=e,i=n,u=i;e:for(;null!==u;){switch(u.tag){case 5:X=u.stateNode,Yj=!1;break e;case 3:case 4:X=u.stateNode.containerInfo,Yj=!0;break e}u=u.return}if(null===X)throw Error(p(160));ak(a,i,l),X=null,Yj=!1;var o=l.alternate;null!==o&&(o.return=null),l.return=null}catch(e){W(l,n,e)}}if(12854&n.subtreeFlags)for(n=n.child;null!==n;)ek(n,e),n=n.sibling}function ek(e,n){var t=e.alternate,r=e.flags;switch(e.tag){case 0:case 11:case 14:case 15:if(dk(n,e),fk(e),4&r){try{Qj(3,e,e.return),Rj(3,e)}catch(n){W(e,e.return,n)}try{Qj(5,e,e.return)}catch(n){W(e,e.return,n)}}break;case 1:dk(n,e),fk(e),512&r&&null!==t&&Mj(t,t.return);break;case 5:if(dk(n,e),fk(e),512&r&&null!==t&&Mj(t,t.return),32&e.flags){var l=e.stateNode;try{ob(l,"")}catch(n){W(e,e.return,n)}}if(4&r&&null!=(l=e.stateNode)){var a=e.memoizedProps,i=null!==t?t.memoizedProps:a,u=e.type,o=e.updateQueue;if(e.updateQueue=null,null!==o)try{"input"===u&&"radio"===a.type&&null!=a.name&&ab(l,a),vb(u,i);var c=vb(u,a);for(i=0;i<o.length;i+=2){var s=o[i],f=o[i+1];"style"===s?sb(l,f):"dangerouslySetInnerHTML"===s?nb(l,f):"children"===s?ob(l,f):ta(l,s,f,c)}switch(u){case"input":bb(l,a);break;case"textarea":ib(l,a);break;case"select":var d=l._wrapperState.wasMultiple;l._wrapperState.wasMultiple=!!a.multiple;var h=a.value;null!=h?fb(l,!!a.multiple,h,!1):d!==!!a.multiple&&(null!=a.defaultValue?fb(l,!!a.multiple,a.defaultValue,!0):fb(l,!!a.multiple,a.multiple?[]:"",!1))}l[Pf]=a}catch(n){W(e,e.return,n)}}break;case 6:if(dk(n,e),fk(e),4&r){if(null===e.stateNode)throw Error(p(162));l=e.stateNode,a=e.memoizedProps;try{l.nodeValue=a}catch(n){W(e,e.return,n)}}break;case 3:if(dk(n,e),fk(e),4&r&&null!==t&&t.memoizedState.isDehydrated)try{bd(n.containerInfo)}catch(n){W(e,e.return,n)}break;case 4:default:dk(n,e),fk(e);break;case 13:dk(n,e),fk(e),8192&(l=e.child).flags&&(a=null!==l.memoizedState,l.stateNode.isHidden=a,!a||null!==l.alternate&&null!==l.alternate.memoizedState||(gk=B())),4&r&&bk(e);break;case 22:if(s=null!==t&&null!==t.memoizedState,1&e.mode?(U=(c=U)||s,dk(n,e),U=c):dk(n,e),fk(e),8192&r){if(c=null!==e.memoizedState,(e.stateNode.isHidden=c)&&!s&&0!=(1&e.mode))for(V=e,s=e.child;null!==s;){for(f=V=s;null!==V;){switch(h=(d=V).child,d.tag){case 0:case 11:case 14:case 15:Qj(4,d,d.return);break;case 1:Mj(d,d.return);var g=d.stateNode;if("function"==typeof g.componentWillUnmount){r=d,t=d.return;try{n=r,g.props=n.memoizedProps,g.state=n.memoizedState,g.componentWillUnmount()}catch(e){W(r,t,e)}}break;case 5:Mj(d,d.return);break;case 22:if(null!==d.memoizedState){hk(f);continue}}null!==h?(h.return=d,V=h):hk(f)}s=s.sibling}e:for(s=null,f=e;;){if(5===f.tag){if(null===s){s=f;try{l=f.stateNode,c?"function"==typeof(a=l.style).setProperty?a.setProperty("display","none","important"):a.display="none":(u=f.stateNode,i=null!=(o=f.memoizedProps.style)&&o.hasOwnProperty("display")?o.display:null,u.style.display=rb("display",i))}catch(n){W(e,e.return,n)}}}else if(6===f.tag){if(null===s)try{f.stateNode.nodeValue=c?"":f.memoizedProps}catch(n){W(e,e.return,n)}}else if((22!==f.tag&&23!==f.tag||null===f.memoizedState||f===e)&&null!==f.child){f.child.return=f,f=f.child;continue}if(f===e)break e;for(;null===f.sibling;){if(null===f.return||f.return===e)break e;s===f&&(s=null),f=f.return}s===f&&(s=null),f.sibling.return=f.return,f=f.sibling}}break;case 19:dk(n,e),fk(e),4&r&&bk(e);case 21:}}function fk(e){var n=e.flags;if(2&n){try{e:{for(var t=e.return;null!==t;){if(Uj(t)){var r=t;break e}t=t.return}throw Error(p(160))}switch(r.tag){case 5:var l=r.stateNode;32&r.flags&&(ob(l,""),r.flags&=-33),Xj(e,Vj(e),l);break;case 3:case 4:var a=r.stateNode.containerInfo;Wj(e,Vj(e),a);break;default:throw Error(p(161))}}catch(n){W(e,e.return,n)}e.flags&=-3}4096&n&&(e.flags&=-4097)}function ik(e,n,t){V=e,jk(e,n,t)}function jk(e,n,t){for(var r=0!=(1&e.mode);null!==V;){var l=V,a=l.child;if(22===l.tag&&r){var i=null!==l.memoizedState||Kj;if(!i){var u=l.alternate,o=null!==u&&null!==u.memoizedState||U;u=Kj;var c=U;if(Kj=i,(U=o)&&!c)for(V=l;null!==V;)o=(i=V).child,22===i.tag&&null!==i.memoizedState?kk(l):null!==o?(o.return=i,V=o):kk(l);for(;null!==a;)V=a,jk(a,n,t),a=a.sibling;V=l,Kj=u,U=c}lk(e,n,t)}else 0!=(8772&l.subtreeFlags)&&null!==a?(a.return=l,V=a):lk(e,n,t)}}function lk(e){for(;null!==V;){var n=V;if(0!=(8772&n.flags)){var t=n.alternate;try{if(0!=(8772&n.flags))switch(n.tag){case 0:case 11:case 15:U||Rj(5,n);break;case 1:var r=n.stateNode;if(4&n.flags&&!U)if(null===t)r.componentDidMount();else{var l=n.elementType===n.type?t.memoizedProps:Lg(n.type,t.memoizedProps);r.componentDidUpdate(l,t.memoizedState,r.__reactInternalSnapshotBeforeUpdate)}var a=n.updateQueue;null!==a&&ih(n,a,r);break;case 3:var i=n.updateQueue;if(null!==i){if(t=null,null!==n.child)switch(n.child.tag){case 5:case 1:t=n.child.stateNode}ih(n,i,t)}break;case 5:var u=n.stateNode;if(null===t&&4&n.flags){t=u;var o=n.memoizedProps;switch(n.type){case"button":case"input":case"select":case"textarea":o.autoFocus&&t.focus();break;case"img":o.src&&(t.src=o.src)}}break;case 6:case 4:case 12:case 19:case 17:case 21:case 22:case 23:case 25:break;case 13:if(null===n.memoizedState){var c=n.alternate;if(null!==c){var s=c.memoizedState;if(null!==s){var f=s.dehydrated;null!==f&&bd(f)}}}break;default:throw Error(p(163))}U||512&n.flags&&Sj(n)}catch(e){W(n,n.return,e)}}if(n===e){V=null;break}if(null!==(t=n.sibling)){t.return=n.return,V=t;break}V=n.return}}function hk(e){for(;null!==V;){var n=V;if(n===e){V=null;break}var t=n.sibling;if(null!==t){t.return=n.return,V=t;break}V=n.return}}function kk(e){for(;null!==V;){var n=V;try{switch(n.tag){case 0:case 11:case 15:var t=n.return;try{Rj(4,n)}catch(e){W(n,t,e)}break;case 1:var r=n.stateNode;if("function"==typeof r.componentDidMount){var l=n.return;try{r.componentDidMount()}catch(e){W(n,l,e)}}var a=n.return;try{Sj(n)}catch(e){W(n,a,e)}break;case 5:var i=n.return;try{Sj(n)}catch(e){W(n,i,e)}}}catch(e){W(n,n.return,e)}if(n===e){V=null;break}var u=n.sibling;if(null!==u){u.return=n.return,V=u;break}V=n.return}}var Wk,mk=Math.ceil,nk=ua.ReactCurrentDispatcher,ok=ua.ReactCurrentOwner,pk=ua.ReactCurrentBatchConfig,K=0,R=null,Y=null,Z=0,gj=0,fj=Uf(0),T=0,qk=null,hh=0,rk=0,sk=0,tk=null,uk=null,gk=0,Hj=1/0,vk=null,Pi=!1,Qi=null,Si=null,wk=!1,xk=null,yk=0,zk=0,Ak=null,Bk=-1,Ck=0;function L(){return 0!=(6&K)?B():-1!==Bk?Bk:Bk=B()}function lh(e){return 0==(1&e.mode)?1:0!=(2&K)&&0!==Z?Z&-Z:null!==Kg.transition?(0===Ck&&(Ck=yc()),Ck):0!==(e=C)?e:e=void 0===(e=window.event)?16:jd(e.type)}function mh(e,n,t,r){if(50<zk)throw zk=0,Ak=null,Error(p(185));Ac(e,t,r),0!=(2&K)&&e===R||(e===R&&(0==(2&K)&&(rk|=t),4===T&&Dk(e,Z)),Ek(e,r),1===t&&0===K&&0==(1&n.mode)&&(Hj=B()+500,fg&&jg()))}function Ek(e,n){var t=e.callbackNode;wc(e,n);var r=uc(e,e===R?Z:0);if(0===r)null!==t&&bc(t),e.callbackNode=null,e.callbackPriority=0;else if(n=r&-r,e.callbackPriority!==n){if(null!=t&&bc(t),1===n)0===e.tag?ig(Fk.bind(null,e)):hg(Fk.bind(null,e)),Jf((function(){0==(6&K)&&jg()})),t=null;else{switch(Dc(r)){case 1:t=fc;break;case 4:t=gc;break;case 16:default:t=hc;break;case 536870912:t=jc}t=Gk(t,Hk.bind(null,e))}e.callbackPriority=n,e.callbackNode=t}}function Hk(e,n){if(Bk=-1,Ck=0,0!=(6&K))throw Error(p(327));var t=e.callbackNode;if(Ik()&&e.callbackNode!==t)return null;var r=uc(e,e===R?Z:0);if(0===r)return null;if(0!=(30&r)||0!=(r&e.expiredLanes)||n)n=Jk(e,r);else{n=r;var l=K;K|=2;var a=Kk();for(R===e&&Z===n||(vk=null,Hj=B()+500,Lk(e,n));;)try{Mk();break}catch(n){Nk(e,n)}Qg(),nk.current=a,K=l,null!==Y?n=0:(R=null,Z=0,n=T)}if(0!==n){if(2===n&&(0!==(l=xc(e))&&(r=l,n=Ok(e,l))),1===n)throw t=qk,Lk(e,0),Dk(e,r),Ek(e,B()),t;if(6===n)Dk(e,r);else{if(l=e.current.alternate,0==(30&r)&&!Pk(l)&&(2===(n=Jk(e,r))&&(0!==(a=xc(e))&&(r=a,n=Ok(e,a))),1===n))throw t=qk,Lk(e,0),Dk(e,r),Ek(e,B()),t;switch(e.finishedWork=l,e.finishedLanes=r,n){case 0:case 1:throw Error(p(345));case 2:case 5:Qk(e,uk,vk);break;case 3:if(Dk(e,r),(130023424&r)===r&&10<(n=gk+500-B())){if(0!==uc(e,0))break;if(((l=e.suspendedLanes)&r)!==r){L(),e.pingedLanes|=e.suspendedLanes&l;break}e.timeoutHandle=Ff(Qk.bind(null,e,uk,vk),n);break}Qk(e,uk,vk);break;case 4:if(Dk(e,r),(4194240&r)===r)break;for(n=e.eventTimes,l=-1;0<r;){var i=31-oc(r);a=1<<i,(i=n[i])>l&&(l=i),r&=~a}if(r=l,10<(r=(120>(r=B()-r)?120:480>r?480:1080>r?1080:1920>r?1920:3e3>r?3e3:4320>r?4320:1960*mk(r/1960))-r)){e.timeoutHandle=Ff(Qk.bind(null,e,uk,vk),r);break}Qk(e,uk,vk);break;default:throw Error(p(329))}}}return Ek(e,B()),e.callbackNode===t?Hk.bind(null,e):null}function Ok(e,n){var t=tk;return e.current.memoizedState.isDehydrated&&(Lk(e,n).flags|=256),2!==(e=Jk(e,n))&&(n=uk,uk=t,null!==n&&Gj(n)),e}function Gj(e){null===uk?uk=e:uk.push.apply(uk,e)}function Pk(e){for(var n=e;;){if(16384&n.flags){var t=n.updateQueue;if(null!==t&&null!==(t=t.stores))for(var r=0;r<t.length;r++){var l=t[r],a=l.getSnapshot;l=l.value;try{if(!He(a(),l))return!1}catch(e){return!1}}}if(t=n.child,16384&n.subtreeFlags&&null!==t)t.return=n,n=t;else{if(n===e)break;for(;null===n.sibling;){if(null===n.return||n.return===e)return!0;n=n.return}n.sibling.return=n.return,n=n.sibling}}return!0}function Dk(e,n){for(n&=~sk,n&=~rk,e.suspendedLanes|=n,e.pingedLanes&=~n,e=e.expirationTimes;0<n;){var t=31-oc(n),r=1<<t;e[t]=-1,n&=~r}}function Fk(e){if(0!=(6&K))throw Error(p(327));Ik();var n=uc(e,0);if(0==(1&n))return Ek(e,B()),null;var t=Jk(e,n);if(0!==e.tag&&2===t){var r=xc(e);0!==r&&(n=r,t=Ok(e,r))}if(1===t)throw t=qk,Lk(e,0),Dk(e,n),Ek(e,B()),t;if(6===t)throw Error(p(345));return e.finishedWork=e.current.alternate,e.finishedLanes=n,Qk(e,uk,vk),Ek(e,B()),null}function Rk(e,n){var t=K;K|=1;try{return e(n)}finally{0===(K=t)&&(Hj=B()+500,fg&&jg())}}function Sk(e){null!==xk&&0===xk.tag&&0==(6&K)&&Ik();var n=K;K|=1;var t=pk.transition,r=C;try{if(pk.transition=null,C=1,e)return e()}finally{C=r,pk.transition=t,0==(6&(K=n))&&jg()}}function Ij(){gj=fj.current,E(fj)}function Lk(e,n){e.finishedWork=null,e.finishedLanes=0;var t=e.timeoutHandle;if(-1!==t&&(e.timeoutHandle=-1,Gf(t)),null!==Y)for(t=Y.return;null!==t;){var r=t;switch(wg(r),r.tag){case 1:null!=(r=r.type.childContextTypes)&&$f();break;case 3:Jh(),E(Wf),E(H),Oh();break;case 5:Lh(r);break;case 4:Jh();break;case 13:case 19:E(M);break;case 10:Rg(r.type._context);break;case 22:case 23:Ij()}t=t.return}if(R=e,Y=e=wh(e.current,null),Z=gj=n,T=0,qk=null,sk=rk=hh=0,uk=tk=null,null!==Wg){for(n=0;n<Wg.length;n++)if(null!==(r=(t=Wg[n]).interleaved)){t.interleaved=null;var l=r.next,a=t.pending;if(null!==a){var i=a.next;a.next=l,r.next=i}t.pending=r}Wg=null}return e}function Nk(e,n){for(;;){var t=Y;try{if(Qg(),Ph.current=ai,Sh){for(var r=N.memoizedState;null!==r;){var l=r.queue;null!==l&&(l.pending=null),r=r.next}Sh=!1}if(Rh=0,P=O=N=null,Th=!1,Uh=0,ok.current=null,null===t||null===t.return){T=1,qk=n,Y=null;break}e:{var a=e,i=t.return,u=t,o=n;if(n=Z,u.flags|=32768,null!==o&&"object"==typeof o&&"function"==typeof o.then){var c=o,s=u,f=s.tag;if(0==(1&s.mode)&&(0===f||11===f||15===f)){var d=s.alternate;d?(s.updateQueue=d.updateQueue,s.memoizedState=d.memoizedState,s.lanes=d.lanes):(s.updateQueue=null,s.memoizedState=null)}var h=Vi(i);if(null!==h){h.flags&=-257,Wi(h,i,u,a,n),1&h.mode&&Ti(a,c,n),o=c;var g=(n=h).updateQueue;if(null===g){var m=new Set;m.add(o),n.updateQueue=m}else g.add(o);break e}if(0==(1&n)){Ti(a,c,n),uj();break e}o=Error(p(426))}else if(I&&1&u.mode){var v=Vi(i);if(null!==v){0==(65536&v.flags)&&(v.flags|=256),Wi(v,i,u,a,n),Jg(Ki(o,u));break e}}a=o=Ki(o,u),4!==T&&(T=2),null===tk?tk=[a]:tk.push(a),a=i;do{switch(a.tag){case 3:a.flags|=65536,n&=-n,a.lanes|=n,fh(a,Oi(a,o,n));break e;case 1:u=o;var b=a.type,y=a.stateNode;if(0==(128&a.flags)&&("function"==typeof b.getDerivedStateFromError||null!==y&&"function"==typeof y.componentDidCatch&&(null===Si||!Si.has(y)))){a.flags|=65536,n&=-n,a.lanes|=n,fh(a,Ri(a,u,n));break e}}a=a.return}while(null!==a)}Tk(t)}catch(e){n=e,Y===t&&null!==t&&(Y=t=t.return);continue}break}}function Kk(){var e=nk.current;return nk.current=ai,null===e?ai:e}function uj(){0!==T&&3!==T&&2!==T||(T=4),null===R||0==(268435455&hh)&&0==(268435455&rk)||Dk(R,Z)}function Jk(e,n){var t=K;K|=2;var r=Kk();for(R===e&&Z===n||(vk=null,Lk(e,n));;)try{Uk();break}catch(n){Nk(e,n)}if(Qg(),K=t,nk.current=r,null!==Y)throw Error(p(261));return R=null,Z=0,T}function Uk(){for(;null!==Y;)Vk(Y)}function Mk(){for(;null!==Y&&!cc();)Vk(Y)}function Vk(e){var n=Wk(e.alternate,e,gj);e.memoizedProps=e.pendingProps,null===n?Tk(e):Y=n,ok.current=null}function Tk(e){var n=e;do{var t=n.alternate;if(e=n.return,0==(32768&n.flags)){if(null!==(t=Fj(t,n,gj)))return void(Y=t)}else{if(null!==(t=Jj(t,n)))return t.flags&=32767,void(Y=t);if(null===e)return T=6,void(Y=null);e.flags|=32768,e.subtreeFlags=0,e.deletions=null}if(null!==(n=n.sibling))return void(Y=n);Y=n=e}while(null!==n);0===T&&(T=5)}function Qk(e,n,t){var r=C,l=pk.transition;try{pk.transition=null,C=1,Xk(e,n,t,r)}finally{pk.transition=l,C=r}return null}function Xk(e,n,t,r){do{Ik()}while(null!==xk);if(0!=(6&K))throw Error(p(327));t=e.finishedWork;var l=e.finishedLanes;if(null===t)return null;if(e.finishedWork=null,e.finishedLanes=0,t===e.current)throw Error(p(177));e.callbackNode=null,e.callbackPriority=0;var a=t.lanes|t.childLanes;if(Bc(e,a),e===R&&(Y=R=null,Z=0),0==(2064&t.subtreeFlags)&&0==(2064&t.flags)||wk||(wk=!0,Gk(hc,(function(){return Ik(),null}))),a=0!=(15990&t.flags),0!=(15990&t.subtreeFlags)||a){a=pk.transition,pk.transition=null;var i=C;C=1;var u=K;K|=4,ok.current=null,Pj(e,t),ek(t,e),Oe(Df),dd=!!Cf,Df=Cf=null,e.current=t,ik(t,e,l),dc(),K=u,C=i,pk.transition=a}else e.current=t;if(wk&&(wk=!1,xk=e,yk=l),0===(a=e.pendingLanes)&&(Si=null),mc(t.stateNode,r),Ek(e,B()),null!==n)for(r=e.onRecoverableError,t=0;t<n.length;t++)r((l=n[t]).value,{componentStack:l.stack,digest:l.digest});if(Pi)throw Pi=!1,e=Qi,Qi=null,e;return 0!=(1&yk)&&0!==e.tag&&Ik(),0!=(1&(a=e.pendingLanes))?e===Ak?zk++:(zk=0,Ak=e):zk=0,jg(),null}function Ik(){if(null!==xk){var e=Dc(yk),n=pk.transition,t=C;try{if(pk.transition=null,C=16>e?16:e,null===xk)var r=!1;else{if(e=xk,xk=null,yk=0,0!=(6&K))throw Error(p(331));var l=K;for(K|=4,V=e.current;null!==V;){var a=V,i=a.child;if(0!=(16&V.flags)){var u=a.deletions;if(null!==u){for(var o=0;o<u.length;o++){var c=u[o];for(V=c;null!==V;){var s=V;switch(s.tag){case 0:case 11:case 15:Qj(8,s,a)}var f=s.child;if(null!==f)f.return=s,V=f;else for(;null!==V;){var d=(s=V).sibling,h=s.return;if(Tj(s),s===c){V=null;break}if(null!==d){d.return=h,V=d;break}V=h}}}var g=a.alternate;if(null!==g){var m=g.child;if(null!==m){g.child=null;do{var v=m.sibling;m.sibling=null,m=v}while(null!==m)}}V=a}}if(0!=(2064&a.subtreeFlags)&&null!==i)i.return=a,V=i;else e:for(;null!==V;){if(0!=(2048&(a=V).flags))switch(a.tag){case 0:case 11:case 15:Qj(9,a,a.return)}var b=a.sibling;if(null!==b){b.return=a.return,V=b;break e}V=a.return}}var y=e.current;for(V=y;null!==V;){var k=(i=V).child;if(0!=(2064&i.subtreeFlags)&&null!==k)k.return=i,V=k;else e:for(i=y;null!==V;){if(0!=(2048&(u=V).flags))try{switch(u.tag){case 0:case 11:case 15:Rj(9,u)}}catch(e){W(u,u.return,e)}if(u===i){V=null;break e}var w=u.sibling;if(null!==w){w.return=u.return,V=w;break e}V=u.return}}if(K=l,jg(),lc&&"function"==typeof lc.onPostCommitFiberRoot)try{lc.onPostCommitFiberRoot(kc,e)}catch(e){}r=!0}return r}finally{C=t,pk.transition=n}}return!1}function Yk(e,n,t){e=dh(e,n=Oi(e,n=Ki(t,n),1),1),n=L(),null!==e&&(Ac(e,1,n),Ek(e,n))}function W(e,n,t){if(3===e.tag)Yk(e,e,t);else for(;null!==n;){if(3===n.tag){Yk(n,e,t);break}if(1===n.tag){var r=n.stateNode;if("function"==typeof n.type.getDerivedStateFromError||"function"==typeof r.componentDidCatch&&(null===Si||!Si.has(r))){n=dh(n,e=Ri(n,e=Ki(t,e),1),1),e=L(),null!==n&&(Ac(n,1,e),Ek(n,e));break}}n=n.return}}function Ui(e,n,t){var r=e.pingCache;null!==r&&r.delete(n),n=L(),e.pingedLanes|=e.suspendedLanes&t,R===e&&(Z&t)===t&&(4===T||3===T&&(130023424&Z)===Z&&500>B()-gk?Lk(e,0):sk|=t),Ek(e,n)}function Zk(e,n){0===n&&(0==(1&e.mode)?n=1:(n=sc,0==(130023424&(sc<<=1))&&(sc=4194304)));var t=L();null!==(e=Zg(e,n))&&(Ac(e,n,t),Ek(e,t))}function vj(e){var n=e.memoizedState,t=0;null!==n&&(t=n.retryLane),Zk(e,t)}function ck(e,n){var t=0;switch(e.tag){case 13:var r=e.stateNode,l=e.memoizedState;null!==l&&(t=l.retryLane);break;case 19:r=e.stateNode;break;default:throw Error(p(314))}null!==r&&r.delete(n),Zk(e,t)}function Gk(e,n){return ac(e,n)}function al(e,n,t,r){this.tag=e,this.key=t,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.ref=null,this.pendingProps=n,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=r,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function Bg(e,n,t,r){return new al(e,n,t,r)}function bj(e){return!(!(e=e.prototype)||!e.isReactComponent)}function $k(e){if("function"==typeof e)return bj(e)?1:0;if(null!=e){if((e=e.$$typeof)===Da)return 11;if(e===Ga)return 14}return 2}function wh(e,n){var t=e.alternate;return null===t?((t=Bg(e.tag,n,e.key,e.mode)).elementType=e.elementType,t.type=e.type,t.stateNode=e.stateNode,t.alternate=e,e.alternate=t):(t.pendingProps=n,t.type=e.type,t.flags=0,t.subtreeFlags=0,t.deletions=null),t.flags=14680064&e.flags,t.childLanes=e.childLanes,t.lanes=e.lanes,t.child=e.child,t.memoizedProps=e.memoizedProps,t.memoizedState=e.memoizedState,t.updateQueue=e.updateQueue,n=e.dependencies,t.dependencies=null===n?null:{lanes:n.lanes,firstContext:n.firstContext},t.sibling=e.sibling,t.index=e.index,t.ref=e.ref,t}function yh(e,n,t,r,l,a){var i=2;if(r=e,"function"==typeof e)bj(e)&&(i=1);else if("string"==typeof e)i=5;else e:switch(e){case ya:return Ah(t.children,l,a,n);case za:i=8,l|=8;break;case Aa:return(e=Bg(12,t,n,2|l)).elementType=Aa,e.lanes=a,e;case Ea:return(e=Bg(13,t,n,l)).elementType=Ea,e.lanes=a,e;case Fa:return(e=Bg(19,t,n,l)).elementType=Fa,e.lanes=a,e;case Ia:return qj(t,l,a,n);default:if("object"==typeof e&&null!==e)switch(e.$$typeof){case Ba:i=10;break e;case Ca:i=9;break e;case Da:i=11;break e;case Ga:i=14;break e;case Ha:i=16,r=null;break e}throw Error(p(130,null==e?e:typeof e,""))}return(n=Bg(i,t,n,l)).elementType=e,n.type=r,n.lanes=a,n}function Ah(e,n,t,r){return(e=Bg(7,e,r,n)).lanes=t,e}function qj(e,n,t,r){return(e=Bg(22,e,r,n)).elementType=Ia,e.lanes=t,e.stateNode={isHidden:!1},e}function xh(e,n,t){return(e=Bg(6,e,null,n)).lanes=t,e}function zh(e,n,t){return(n=Bg(4,null!==e.children?e.children:[],e.key,n)).lanes=t,n.stateNode={containerInfo:e.containerInfo,pendingChildren:null,implementation:e.implementation},n}function bl(e,n,t,r,l){this.tag=n,this.containerInfo=e,this.finishedWork=this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.pendingContext=this.context=null,this.callbackPriority=0,this.eventTimes=zc(0),this.expirationTimes=zc(-1),this.entangledLanes=this.finishedLanes=this.mutableReadLanes=this.expiredLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=zc(0),this.identifierPrefix=r,this.onRecoverableError=l,this.mutableSourceEagerHydrationData=null}function cl(e,n,t,r,l,a,i,u,o){return e=new bl(e,n,t,u,o),1===n?(n=1,!0===a&&(n|=8)):n=0,a=Bg(3,null,null,n),e.current=a,a.stateNode=e,a.memoizedState={element:r,isDehydrated:t,cache:null,transitions:null,pendingSuspenseBoundaries:null},ah(a),e}function dl(e,n,t){var r=3<arguments.length&&void 0!==arguments[3]?arguments[3]:null;return{$$typeof:wa,key:null==r?null:""+r,children:e,containerInfo:n,implementation:t}}function el(e){if(!e)return Vf;e:{if(Vb(e=e._reactInternals)!==e||1!==e.tag)throw Error(p(170));var n=e;do{switch(n.tag){case 3:n=n.stateNode.context;break e;case 1:if(Zf(n.type)){n=n.stateNode.__reactInternalMemoizedMergedChildContext;break e}}n=n.return}while(null!==n);throw Error(p(171))}if(1===e.tag){var t=e.type;if(Zf(t))return bg(e,t,n)}return n}function fl(e,n,t,r,l,a,i,u,o){return(e=cl(t,r,!0,e,l,a,i,u,o)).context=el(null),t=e.current,(a=ch(r=L(),l=lh(t))).callback=null!=n?n:null,dh(t,a,l),e.current.lanes=l,Ac(e,l,r),Ek(e,r),e}function gl(e,n,t,r){var l=n.current,a=L(),i=lh(l);return t=el(t),null===n.context?n.context=t:n.pendingContext=t,(n=ch(a,i)).payload={element:e},null!==(r=void 0===r?null:r)&&(n.callback=r),null!==(e=dh(l,n,i))&&(mh(e,l,i,a),eh(e,l,i)),i}function hl(e){return(e=e.current).child?(e.child.tag,e.child.stateNode):null}function il(e,n){if(null!==(e=e.memoizedState)&&null!==e.dehydrated){var t=e.retryLane;e.retryLane=0!==t&&t<n?t:n}}function jl(e,n){il(e,n),(e=e.alternate)&&il(e,n)}function kl(){return null}Wk=function(e,n,t){if(null!==e)if(e.memoizedProps!==n.pendingProps||Wf.current)Ug=!0;else{if(0==(e.lanes&t)&&0==(128&n.flags))return Ug=!1,zj(e,n,t);Ug=0!=(131072&e.flags)}else Ug=!1,I&&0!=(1048576&n.flags)&&ug(n,ng,n.index);switch(n.lanes=0,n.tag){case 2:var r=n.type;jj(e,n),e=n.pendingProps;var l=Yf(n,H.current);Tg(n,t),l=Xh(null,n,r,e,l,t);var a=bi();return n.flags|=1,"object"==typeof l&&null!==l&&"function"==typeof l.render&&void 0===l.$$typeof?(n.tag=1,n.memoizedState=null,n.updateQueue=null,Zf(r)?(a=!0,cg(n)):a=!1,n.memoizedState=null!==l.state&&void 0!==l.state?l.state:null,ah(n),l.updater=nh,n.stateNode=l,l._reactInternals=n,rh(n,r,e,t),n=kj(null,n,r,!0,a,t)):(n.tag=0,I&&a&&vg(n),Yi(null,n,l,t),n=n.child),n;case 16:r=n.elementType;e:{switch(jj(e,n),e=n.pendingProps,r=(l=r._init)(r._payload),n.type=r,l=n.tag=$k(r),e=Lg(r,e),l){case 0:n=dj(null,n,r,e,t);break e;case 1:n=ij(null,n,r,e,t);break e;case 11:n=Zi(null,n,r,e,t);break e;case 14:n=aj(null,n,r,Lg(r.type,e),t);break e}throw Error(p(306,r,""))}return n;case 0:return r=n.type,l=n.pendingProps,dj(e,n,r,l=n.elementType===r?l:Lg(r,l),t);case 1:return r=n.type,l=n.pendingProps,ij(e,n,r,l=n.elementType===r?l:Lg(r,l),t);case 3:e:{if(lj(n),null===e)throw Error(p(387));r=n.pendingProps,l=(a=n.memoizedState).element,bh(e,n),gh(n,r,null,t);var i=n.memoizedState;if(r=i.element,a.isDehydrated){if(a={element:r,isDehydrated:!1,cache:i.cache,pendingSuspenseBoundaries:i.pendingSuspenseBoundaries,transitions:i.transitions},n.updateQueue.baseState=a,n.memoizedState=a,256&n.flags){n=mj(e,n,r,t,l=Ki(Error(p(423)),n));break e}if(r!==l){n=mj(e,n,r,t,l=Ki(Error(p(424)),n));break e}for(yg=Lf(n.stateNode.containerInfo.firstChild),xg=n,I=!0,zg=null,t=Ch(n,null,r,t),n.child=t;t;)t.flags=-3&t.flags|4096,t=t.sibling}else{if(Ig(),r===l){n=$i(e,n,t);break e}Yi(e,n,r,t)}n=n.child}return n;case 5:return Kh(n),null===e&&Eg(n),r=n.type,l=n.pendingProps,a=null!==e?e.memoizedProps:null,i=l.children,Ef(r,l)?i=null:null!==a&&Ef(r,a)&&(n.flags|=32),hj(e,n),Yi(e,n,i,t),n.child;case 6:return null===e&&Eg(n),null;case 13:return pj(e,n,t);case 4:return Ih(n,n.stateNode.containerInfo),r=n.pendingProps,null===e?n.child=Bh(n,null,r,t):Yi(e,n,r,t),n.child;case 11:return r=n.type,l=n.pendingProps,Zi(e,n,r,l=n.elementType===r?l:Lg(r,l),t);case 7:return Yi(e,n,n.pendingProps,t),n.child;case 8:case 12:return Yi(e,n,n.pendingProps.children,t),n.child;case 10:e:{if(r=n.type._context,l=n.pendingProps,a=n.memoizedProps,i=l.value,G(Mg,r._currentValue),r._currentValue=i,null!==a)if(He(a.value,i)){if(a.children===l.children&&!Wf.current){n=$i(e,n,t);break e}}else for(null!==(a=n.child)&&(a.return=n);null!==a;){var u=a.dependencies;if(null!==u){i=a.child;for(var o=u.firstContext;null!==o;){if(o.context===r){if(1===a.tag){(o=ch(-1,t&-t)).tag=2;var c=a.updateQueue;if(null!==c){var s=(c=c.shared).pending;null===s?o.next=o:(o.next=s.next,s.next=o),c.pending=o}}a.lanes|=t,null!==(o=a.alternate)&&(o.lanes|=t),Sg(a.return,t,n),u.lanes|=t;break}o=o.next}}else if(10===a.tag)i=a.type===n.type?null:a.child;else if(18===a.tag){if(null===(i=a.return))throw Error(p(341));i.lanes|=t,null!==(u=i.alternate)&&(u.lanes|=t),Sg(i,t,n),i=a.sibling}else i=a.child;if(null!==i)i.return=a;else for(i=a;null!==i;){if(i===n){i=null;break}if(null!==(a=i.sibling)){a.return=i.return,i=a;break}i=i.return}a=i}Yi(e,n,l.children,t),n=n.child}return n;case 9:return l=n.type,r=n.pendingProps.children,Tg(n,t),r=r(l=Vg(l)),n.flags|=1,Yi(e,n,r,t),n.child;case 14:return l=Lg(r=n.type,n.pendingProps),aj(e,n,r,l=Lg(r.type,l),t);case 15:return cj(e,n,n.type,n.pendingProps,t);case 17:return r=n.type,l=n.pendingProps,l=n.elementType===r?l:Lg(r,l),jj(e,n),n.tag=1,Zf(r)?(e=!0,cg(n)):e=!1,Tg(n,t),ph(n,r,l),rh(n,r,l,t),kj(null,n,r,!0,e,t);case 19:return yj(e,n,t);case 22:return ej(e,n,t)}throw Error(p(156,n.tag))};var ll="function"==typeof reportError?reportError:function(e){console.error(e)};function ml(e){this._internalRoot=e}function nl(e){this._internalRoot=e}function ol(e){return!(!e||1!==e.nodeType&&9!==e.nodeType&&11!==e.nodeType)}function pl(e){return!(!e||1!==e.nodeType&&9!==e.nodeType&&11!==e.nodeType&&(8!==e.nodeType||" react-mount-point-unstable "!==e.nodeValue))}function ql(){}function rl(e,n,t,r,l){if(l){if("function"==typeof r){var a=r;r=function(){var e=hl(i);a.call(e)}}var i=fl(n,r,e,0,null,!1,!1,"",ql);return e._reactRootContainer=i,e[uf]=i.current,sf(8===e.nodeType?e.parentNode:e),Sk(),i}for(;l=e.lastChild;)e.removeChild(l);if("function"==typeof r){var u=r;r=function(){var e=hl(o);u.call(e)}}var o=cl(e,0,!1,null,null,!1,!1,"",ql);return e._reactRootContainer=o,e[uf]=o.current,sf(8===e.nodeType?e.parentNode:e),Sk((function(){gl(n,o,t,r)})),o}function sl(e,n,t,r,l){var a=t._reactRootContainer;if(a){var i=a;if("function"==typeof l){var u=l;l=function(){var e=hl(i);u.call(e)}}gl(n,i,e,l)}else i=rl(t,n,e,l,r);return hl(i)}nl.prototype.render=ml.prototype.render=function(e){var n=this._internalRoot;if(null===n)throw Error(p(409));gl(e,n,null,null)},nl.prototype.unmount=ml.prototype.unmount=function(){var e=this._internalRoot;if(null!==e){this._internalRoot=null;var n=e.containerInfo;Sk((function(){gl(null,e,null,null)})),n[uf]=null}},nl.prototype.unstable_scheduleHydration=function(e){if(e){var n=Hc();e={blockedOn:null,target:e,priority:n};for(var t=0;t<Qc.length&&0!==n&&n<Qc[t].priority;t++);Qc.splice(t,0,e),0===t&&Vc(e)}},Ec=function(e){switch(e.tag){case 3:var n=e.stateNode;if(n.current.memoizedState.isDehydrated){var t=tc(n.pendingLanes);0!==t&&(Cc(n,1|t),Ek(n,B()),0==(6&K)&&(Hj=B()+500,jg()))}break;case 13:Sk((function(){var n=Zg(e,1);if(null!==n){var t=L();mh(n,e,1,t)}})),jl(e,1)}},Fc=function(e){if(13===e.tag){var n=Zg(e,134217728);if(null!==n)mh(n,e,134217728,L());jl(e,134217728)}},Gc=function(e){if(13===e.tag){var n=lh(e),t=Zg(e,n);if(null!==t)mh(t,e,n,L());jl(e,n)}},Hc=function(){return C},Ic=function(e,n){var t=C;try{return C=e,n()}finally{C=t}},yb=function(e,n,t){switch(n){case"input":if(bb(e,t),n=t.name,"radio"===t.type&&null!=n){for(t=e;t.parentNode;)t=t.parentNode;for(t=t.querySelectorAll("input[name="+JSON.stringify(""+n)+'][type="radio"]'),n=0;n<t.length;n++){var r=t[n];if(r!==e&&r.form===e.form){var l=Db(r);if(!l)throw Error(p(90));Wa(r),bb(r,l)}}}break;case"textarea":ib(e,t);break;case"select":null!=(n=t.value)&&fb(e,!!t.multiple,n,!1)}},Gb=Rk,Hb=Sk;var tl={usingClientEntryPoint:!1,Events:[Cb,ue,Db,Eb,Fb,Rk]},ul={findFiberByHostInstance:Wc,bundleType:0,version:"18.2.0",rendererPackageName:"react-dom"},vl={bundleType:ul.bundleType,version:ul.version,rendererPackageName:ul.rendererPackageName,rendererConfig:ul.rendererConfig,overrideHookState:null,overrideHookStateDeletePath:null,overrideHookStateRenamePath:null,overrideProps:null,overridePropsDeletePath:null,overridePropsRenamePath:null,setErrorHandler:null,setSuspenseHandler:null,scheduleUpdate:null,currentDispatcherRef:ua.ReactCurrentDispatcher,findHostInstanceByFiber:function(e){return null===(e=Zb(e))?null:e.stateNode},findFiberByHostInstance:ul.findFiberByHostInstance||kl,findHostInstancesForRefresh:null,scheduleRefresh:null,scheduleRoot:null,setRefreshHandler:null,getCurrentFiber:null,reconcilerVersion:"18.2.0-next-9e3b772b8-20220608"};if("undefined"!=typeof __REACT_DEVTOOLS_GLOBAL_HOOK__){var wl=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!wl.isDisabled&&wl.supportsFiber)try{kc=wl.inject(vl),lc=wl}catch(e){}}exports.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED=tl,exports.createPortal=function(e,n){var t=2<arguments.length&&void 0!==arguments[2]?arguments[2]:null;if(!ol(n))throw Error(p(200));return dl(e,n,null,t)},exports.createRoot=function(e,n){if(!ol(e))throw Error(p(299));var t=!1,r="",l=ll;return null!=n&&(!0===n.unstable_strictMode&&(t=!0),void 0!==n.identifierPrefix&&(r=n.identifierPrefix),void 0!==n.onRecoverableError&&(l=n.onRecoverableError)),n=cl(e,1,!1,null,null,t,!1,r,l),e[uf]=n.current,sf(8===e.nodeType?e.parentNode:e),new ml(n)},exports.findDOMNode=function(e){if(null==e)return null;if(1===e.nodeType)return e;var n=e._reactInternals;if(void 0===n){if("function"==typeof e.render)throw Error(p(188));throw e=Object.keys(e).join(","),Error(p(268,e))}return e=null===(e=Zb(n))?null:e.stateNode},exports.flushSync=function(e){return Sk(e)},exports.hydrate=function(e,n,t){if(!pl(n))throw Error(p(200));return sl(null,e,n,!0,t)},exports.hydrateRoot=function(e,n,t){if(!ol(e))throw Error(p(405));var r=null!=t&&t.hydratedSources||null,l=!1,a="",i=ll;if(null!=t&&(!0===t.unstable_strictMode&&(l=!0),void 0!==t.identifierPrefix&&(a=t.identifierPrefix),void 0!==t.onRecoverableError&&(i=t.onRecoverableError)),n=fl(n,null,e,1,null!=t?t:null,l,!1,a,i),e[uf]=n.current,sf(e),r)for(e=0;e<r.length;e++)l=(l=(t=r[e])._getVersion)(t._source),null==n.mutableSourceEagerHydrationData?n.mutableSourceEagerHydrationData=[t,l]:n.mutableSourceEagerHydrationData.push(t,l);return new nl(n)},exports.render=function(e,n,t){if(!pl(n))throw Error(p(200));return sl(null,e,n,!1,t)},exports.unmountComponentAtNode=function(e){if(!pl(e))throw Error(p(40));return!!e._reactRootContainer&&(Sk((function(){sl(null,null,e,!1,(function(){e._reactRootContainer=null,e[uf]=null}))})),!0)},exports.unstable_batchedUpdates=Rk,exports.unstable_renderSubtreeIntoContainer=function(e,n,t,r){if(!pl(t))throw Error(p(200));if(null==e||void 0===e._reactInternals)throw Error(p(38));return sl(e,n,t,!1,r)},exports.version="18.2.0-next-9e3b772b8-20220608";

},{"react":146,"scheduler":175}],116:[function(require,module,exports){
"use strict";var _interopRequireDefault=require("@babel/runtime/helpers/interopRequireDefault");exports.__esModule=!0,exports.default=exports.initializeConnect=void 0;var _extends2=_interopRequireDefault(require("@babel/runtime/helpers/extends")),_objectWithoutPropertiesLoose2=_interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose")),_hoistNonReactStatics=_interopRequireDefault(require("hoist-non-react-statics")),React=_interopRequireWildcard(require("react")),_reactIs=require("react-is"),_selectorFactory=_interopRequireDefault(require("../connect/selectorFactory")),_mapDispatchToProps=require("../connect/mapDispatchToProps"),_mapStateToProps=require("../connect/mapStateToProps"),_mergeProps=require("../connect/mergeProps"),_Subscription=require("../utils/Subscription"),_useIsomorphicLayoutEffect=require("../utils/useIsomorphicLayoutEffect"),_shallowEqual=_interopRequireDefault(require("../utils/shallowEqual")),_warning=_interopRequireDefault(require("../utils/warning")),_Context=require("./Context"),_useSyncExternalStore=require("../utils/useSyncExternalStore");const _excluded=["reactReduxForwardedRef"];function _getRequireWildcardCache(e){if("function"!=typeof WeakMap)return null;var t=new WeakMap,r=new WeakMap;return(_getRequireWildcardCache=function(e){return e?r:t})(e)}function _interopRequireWildcard(e,t){if(!t&&e&&e.__esModule)return e;if(null===e||"object"!=typeof e&&"function"!=typeof e)return{default:e};var r=_getRequireWildcardCache(t);if(r&&r.has(e))return r.get(e);var o={},n=Object.defineProperty&&Object.getOwnPropertyDescriptor;for(var a in e)if("default"!==a&&Object.prototype.hasOwnProperty.call(e,a)){var u=n?Object.getOwnPropertyDescriptor(e,a):null;u&&(u.get||u.set)?Object.defineProperty(o,a,u):o[a]=e[a]}return o.default=e,r&&r.set(e,o),o}let useSyncExternalStore=_useSyncExternalStore.notInitialized;const initializeConnect=e=>{useSyncExternalStore=e};exports.initializeConnect=initializeConnect;const EMPTY_ARRAY=[null,0],NO_SUBSCRIPTION_ARRAY=[null,null],stringifyComponent=e=>{try{return JSON.stringify(e)}catch(t){return String(e)}};function useIsomorphicLayoutEffectWithArgs(e,t,r){(0,_useIsomorphicLayoutEffect.useIsomorphicLayoutEffect)((()=>e(...t)),r)}function captureWrapperProps(e,t,r,o,n,a){e.current=o,r.current=!1,n.current&&(n.current=null,a())}function subscribeUpdates(e,t,r,o,n,a,u,c,s,i,p){if(!e)return()=>{};let l=!1,d=null;const f=()=>{if(l||!c.current)return;const e=t.getState();let r,f;try{r=o(e,n.current)}catch(e){f=e,d=e}f||(d=null),r===a.current?u.current||i():(a.current=r,s.current=r,u.current=!0,p())};r.onStateChange=f,r.trySubscribe(),f();return()=>{if(l=!0,r.tryUnsubscribe(),r.onStateChange=null,d)throw d}}const initStateUpdates=()=>EMPTY_ARRAY;function strictEqual(e,t){return e===t}let hasWarnedAboutDeprecatedPureOption=!1;function connect(e,t,r,{pure:o,areStatesEqual:n=strictEqual,areOwnPropsEqual:a=_shallowEqual.default,areStatePropsEqual:u=_shallowEqual.default,areMergedPropsEqual:c=_shallowEqual.default,forwardRef:s=!1,context:i=_Context.ReactReduxContext}={}){"production"!=="production"&&(void 0===o||hasWarnedAboutDeprecatedPureOption||(hasWarnedAboutDeprecatedPureOption=!0,(0,_warning.default)('The `pure` option has been removed. `connect` is now always a "pure/memoized" component')));const p=i,l=(0,_mapStateToProps.mapStateToPropsFactory)(e),d=(0,_mapDispatchToProps.mapDispatchToPropsFactory)(t),f=(0,_mergeProps.mergePropsFactory)(r),m=Boolean(e);return e=>{if("production"!=="production"&&!(0,_reactIs.isValidElementType)(e))throw new Error(`You must pass a component to the function returned by connect. Instead received ${stringifyComponent(e)}`);const t=e.displayName||e.name||"Component",r=`Connect(${t})`,o={shouldHandleStateChanges:m,displayName:r,wrappedComponentName:t,WrappedComponent:e,initMapStateToProps:l,initMapDispatchToProps:d,initMergeProps:f,areStatesEqual:n,areStatePropsEqual:u,areOwnPropsEqual:a,areMergedPropsEqual:c};function i(t){const[n,a,u]=React.useMemo((()=>{const{reactReduxForwardedRef:e}=t,r=(0,_objectWithoutPropertiesLoose2.default)(t,_excluded);return[t.context,e,r]}),[t]),c=React.useMemo((()=>n&&n.Consumer&&(0,_reactIs.isContextConsumer)(React.createElement(n.Consumer,null))?n:p),[n,p]),s=React.useContext(c),i=Boolean(t.store)&&Boolean(t.store.getState)&&Boolean(t.store.dispatch),l=Boolean(s)&&Boolean(s.store);if("production"!=="production"&&!i&&!l)throw new Error(`Could not find "store" in the context of "${r}". Either wrap the root component in a <Provider>, or pass a custom React context provider to <Provider> and the corresponding React context consumer to ${r} in connect options.`);const d=i?t.store:s.store,f=l?s.getServerState:d.getState,R=React.useMemo((()=>(0,_selectorFactory.default)(d.dispatch,o)),[d]),[_,h]=React.useMemo((()=>{if(!m)return NO_SUBSCRIPTION_ARRAY;const e=(0,_Subscription.createSubscription)(d,i?void 0:s.subscription),t=e.notifyNestedSubs.bind(e);return[e,t]}),[d,i,s]),y=React.useMemo((()=>i?s:(0,_extends2.default)({},s,{subscription:_})),[i,s,_]),E=React.useRef(),S=React.useRef(u),q=React.useRef(),P=React.useRef(!1),b=(React.useRef(!1),React.useRef(!1)),g=React.useRef();(0,_useIsomorphicLayoutEffect.useIsomorphicLayoutEffect)((()=>(b.current=!0,()=>{b.current=!1})),[]);const x=React.useMemo((()=>()=>q.current&&u===S.current?q.current:R(d.getState(),u)),[d,u]),w=React.useMemo((()=>e=>_?subscribeUpdates(m,d,_,R,S,E,P,b,q,h,e):()=>{}),[_]);let C;useIsomorphicLayoutEffectWithArgs(captureWrapperProps,[S,E,P,u,q,h]);try{C=useSyncExternalStore(w,x,f?()=>R(f(),u):x)}catch(e){throw g.current&&(e.message+=`\nThe error may be correlated with this previous error:\n${g.current.stack}\n\n`),e}(0,_useIsomorphicLayoutEffect.useIsomorphicLayoutEffect)((()=>{g.current=void 0,q.current=void 0,E.current=C}));const v=React.useMemo((()=>React.createElement(e,(0,_extends2.default)({},C,{ref:a}))),[a,e,C]);return React.useMemo((()=>m?React.createElement(c.Provider,{value:y},v):v),[c,v,y])}const R=React.memo(i);if(R.WrappedComponent=e,R.displayName=i.displayName=r,s){const t=React.forwardRef((function(e,t){return React.createElement(R,(0,_extends2.default)({},e,{reactReduxForwardedRef:t}))}));return t.displayName=r,t.WrappedComponent=e,(0,_hoistNonReactStatics.default)(t,e)}return(0,_hoistNonReactStatics.default)(R,e)}}var _default=connect;exports.default=_default;

},{"../connect/mapDispatchToProps":118,"../connect/mapStateToProps":119,"../connect/mergeProps":120,"../connect/selectorFactory":121,"../utils/Subscription":131,"../utils/shallowEqual":136,"../utils/useIsomorphicLayoutEffect":137,"../utils/useSyncExternalStore":138,"../utils/warning":140,"./Context":114,"@babel/runtime/helpers/extends":2,"@babel/runtime/helpers/interopRequireDefault":3,"@babel/runtime/helpers/objectWithoutPropertiesLoose":5,"hoist-non-react-statics":85,"react":146,"react-is":143}],127:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.createSelectorHook=createSelectorHook,exports.useSelector=exports.initializeUseSelector=void 0;var _react=require("react"),_useReduxContext=require("./useReduxContext"),_Context=require("../components/Context"),_useSyncExternalStore=require("../utils/useSyncExternalStore");let useSyncExternalStoreWithSelector=_useSyncExternalStore.notInitialized;const initializeUseSelector=e=>{useSyncExternalStoreWithSelector=e};exports.initializeUseSelector=initializeUseSelector;const refEquality=(e,t)=>e===t;function createSelectorHook(e=_Context.ReactReduxContext){const t=e===_Context.ReactReduxContext?_useReduxContext.useReduxContext:(0,_useReduxContext.createReduxContextHook)(e);return function(e,r={}){const{equalityFn:o=refEquality,stabilityCheck:n,noopCheck:s}="function"==typeof r?{equalityFn:r}:r;if("production"!=="production"){if(!e)throw new Error("You must pass a selector to useSelector");if("function"!=typeof e)throw new Error("You must pass a function as a selector to useSelector");if("function"!=typeof o)throw new Error("You must pass a function as an equality function to useSelector")}const{store:c,subscription:a,getServerState:u,stabilityCheck:i,noopCheck:l}=t(),S=(0,_react.useRef)(!0),d=(0,_react.useCallback)({[e.name](t){const r=e(t);if("production"!=="production"){const c=void 0===n?i:n;if("always"===c||"once"===c&&S.current){const n=e(t);if(!o(r,n)){let o;try{throw new Error}catch(e){({stack:o}=e)}console.warn("Selector "+(e.name||"unknown")+" returned a different result when called with the same parameters. This can lead to unnecessary rerenders.\nSelectors that return a new reference (such as an object or an array) should be memoized: https://redux.js.org/usage/deriving-data-selectors#optimizing-selectors-with-memoization",{state:t,selected:r,selected2:n,stack:o})}}const a=void 0===s?l:s;if(("always"===a||"once"===a&&S.current)&&r===t){let t;try{throw new Error}catch(e){({stack:t}=e)}console.warn("Selector "+(e.name||"unknown")+" returned the root state when called. This can lead to unnecessary rerenders.\nSelectors that return the entire state are almost certainly a mistake, as they will cause a rerender whenever *anything* in state changes.",{stack:t})}S.current&&(S.current=!1)}return r}}[e.name],[e,i,n]),x=useSyncExternalStoreWithSelector(a.addNestedSub,c.getState,u||c.getState,d,o);return(0,_react.useDebugValue)(x),x}}const useSelector=createSelectorHook();exports.useSelector=useSelector;

},{"../components/Context":114,"../utils/useSyncExternalStore":138,"./useReduxContext":126,"react":146}],128:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.createStoreHook=createStoreHook,exports.useStore=void 0;var _Context=require("../components/Context"),_useReduxContext=require("./useReduxContext");function createStoreHook(e=_Context.ReactReduxContext){const t=e===_Context.ReactReduxContext?_useReduxContext.useReduxContext:(0,_useReduxContext.createReduxContextHook)(e);return function(){const{store:e}=t();return e}}const useStore=createStoreHook();exports.useStore=useStore;

},{"../components/Context":114,"./useReduxContext":126}],23:[function(require,module,exports){
"use strict";var React=require("react"),misc=require("ariakit-utils/misc"),jsxRuntime=require("react/jsx-runtime");function isRenderProp(e){return"function"==typeof e}function createComponent(e){const t=(t,r)=>e({ref:r,...t});return React.forwardRef(t)}function createElement(e,t){const{as:r,wrapElement:n,...o}=t;let i;if(r&&"string"!=typeof r)i=jsxRuntime.jsx(r,{...o});else if(isRenderProp(t.children)){const{children:e,...r}=o;i=t.children(r)}else i=r?jsxRuntime.jsx(r,{...o}):jsxRuntime.jsx(e,{...o});return n?n(i):i}function createHook(e){return function(t){void 0===t&&(t={});const r=e(t),n={};for(const e in r)misc.hasOwnProperty(r,e)&&void 0!==r[e]&&(n[e]=r[e]);return n}}exports.createComponent=createComponent,exports.createElement=createElement,exports.createHook=createHook;

},{"ariakit-utils/misc":28,"react":146,"react/jsx-runtime":147}],73:[function(require,module,exports){
"use strict";var react=require("react"),__utils=require("../__utils-90f519da.js"),jsxRuntime=require("react/jsx-runtime");function HeadingLevel(e){let{level:t,children:i}=e;const r=react.useContext(__utils.HeadingContext),n=Math.max(Math.min(t||r+1,6),1);return jsxRuntime.jsx(__utils.HeadingContext.Provider,{value:n,children:i})}exports.HeadingLevel=HeadingLevel;

},{"../__utils-90f519da.js":35,"react":146,"react/jsx-runtime":147}],230:[function(require,module,exports){
/**
 * @license React
 * use-sync-external-store-shim/with-selector.development.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
"use strict";"production"!=="production"&&function(){"undefined"!=typeof __REACT_DEVTOOLS_GLOBAL_HOOK__&&"function"==typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.registerInternalModuleStart&&__REACT_DEVTOOLS_GLOBAL_HOOK__.registerInternalModuleStart(new Error);var e=require("react"),r=require("use-sync-external-store/shim");var n="function"==typeof Object.is?Object.is:function(e,r){return e===r&&(0!==e||1/e==1/r)||e!=e&&r!=r},t=r.useSyncExternalStore,u=e.useRef,_=e.useEffect,o=e.useMemo,i=e.useDebugValue;exports.useSyncExternalStoreWithSelector=function(e,r,O,a,l){var c,f=u(null);null===f.current?(c={hasValue:!1,value:null},f.current=c):c=f.current;var s=o((function(){var e,t,u=!1,_=function(r){if(!u){u=!0,e=r;var _=a(r);if(void 0!==l&&c.hasValue){var o=c.value;if(l(o,_))return t=o,o}return t=_,_}var i=t;if(n(e,r))return i;var O=a(r);return void 0!==l&&l(i,O)?i:(e=r,t=O,O)},o=void 0===O?null:O;return[function(){return _(r())},null===o?void 0:function(){return _(o())}]}),[r,O,a,l]),E=s[0],L=s[1],v=t(e,E,L);return _((function(){c.hasValue=!0,c.value=v}),[v]),i(v),v},"undefined"!=typeof __REACT_DEVTOOLS_GLOBAL_HOOK__&&"function"==typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.registerInternalModuleStop&&__REACT_DEVTOOLS_GLOBAL_HOOK__.registerInternalModuleStop(new Error)}();

},{"react":146,"use-sync-external-store/shim":232}],231:[function(require,module,exports){
/**
 * @license React
 * use-sync-external-store-shim/with-selector.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
"use strict";var h=require("react"),n=require("use-sync-external-store/shim");function p(e,r){return e===r&&(0!==e||1/e==1/r)||e!=e&&r!=r}var q="function"==typeof Object.is?Object.is:p,r=n.useSyncExternalStore,t=h.useRef,u=h.useEffect,v=h.useMemo,w=h.useDebugValue;exports.useSyncExternalStoreWithSelector=function(e,n,i,a,l){var c=t(null);if(null===c.current){var o={hasValue:!1,value:null};c.current=o}else o=c.current;c=v((function(){function e(e){if(!t){if(t=!0,r=e,e=a(e),void 0!==l&&o.hasValue){var n=o.value;if(l(n,e))return u=n}return u=e}if(n=u,q(r,e))return n;var i=a(e);return void 0!==l&&l(n,i)?n:(r=e,u=i)}var r,u,t=!1,c=void 0===i?null:i;return[function(){return e(n())},null===c?void 0:function(){return e(c())}]}),[n,i,a,l]);var s=r(e,c[0],c[1]);return u((function(){o.hasValue=!0,o.value=s}),[s]),w(s),s};

},{"react":146,"use-sync-external-store/shim":232}],238:[function(require,module,exports){
"use strict";var index_js=require("use-sync-external-store/shim/index.js");Object.defineProperty(exports,"useSyncExternalStore",{enumerable:!0,get:function(){return index_js.useSyncExternalStore}});

},{"use-sync-external-store/shim/index.js":232}],107:[function(require,module,exports){
const ret=require("ret"),DRange=require("drange"),types=ret.types;module.exports=class e{constructor(e,t){if(this._setDefaults(e),e instanceof RegExp)this.ignoreCase=e.ignoreCase,this.multiline=e.multiline,e=e.source;else{if("string"!=typeof e)throw new Error("Expected a regexp or string");this.ignoreCase=t&&-1!==t.indexOf("i"),this.multiline=t&&-1!==t.indexOf("m")}this.tokens=ret(e)}_setDefaults(t){this.max=null!=t.max?t.max:null!=e.prototype.max?e.prototype.max:100,this.defaultRange=t.defaultRange?t.defaultRange:this.defaultRange.clone(),t.randInt&&(this.randInt=t.randInt)}gen(){return this._gen(this.tokens,[])}_gen(e,t){var n,r,a,s,i;switch(e.type){case types.ROOT:case types.GROUP:if(e.followedBy||e.notFollowedBy)return"";for(e.remember&&void 0===e.groupNumber&&(e.groupNumber=t.push(null)-1),r="",s=0,i=(n=e.options?this._randSelect(e.options):e.stack).length;s<i;s++)r+=this._gen(n[s],t);return e.remember&&(t[e.groupNumber]=r),r;case types.POSITION:return"";case types.SET:var o=this._expand(e);return o.length?String.fromCharCode(this._randSelect(o)):"";case types.REPETITION:for(a=this.randInt(e.min,e.max===1/0?e.min+this.max:e.max),r="",s=0;s<a;s++)r+=this._gen(e.value,t);return r;case types.REFERENCE:return t[e.value-1]||"";case types.CHAR:var l=this.ignoreCase&&this._randBool()?this._toOtherCase(e.value):e.value;return String.fromCharCode(l)}}_toOtherCase(e){return e+(97<=e&&e<=122?-32:65<=e&&e<=90?32:0)}_randBool(){return!this.randInt(0,1)}_randSelect(e){return e instanceof DRange?e.index(this.randInt(0,e.length-1)):e[this.randInt(0,e.length-1)]}_expand(e){if(e.type===ret.types.CHAR)return new DRange(e.value);if(e.type===ret.types.RANGE)return new DRange(e.from,e.to);{let t=new DRange;for(let n=0;n<e.set.length;n++){let r=this._expand(e.set[n]);if(t.add(r),this.ignoreCase)for(let e=0;e<r.length;e++){let n=r.index(e),a=this._toOtherCase(n);n!==a&&t.add(a)}}return e.not?this.defaultRange.clone().subtract(t):this.defaultRange.clone().intersect(t)}}randInt(e,t){return e+Math.floor(Math.random()*(1+t-e))}get defaultRange(){return this._range=this._range||new DRange(32,126)}set defaultRange(e){this._range=e}static randexp(t,n){var r;return"string"==typeof t&&(t=new RegExp(t,n)),void 0===t._randexp?(r=new e(t,n),t._randexp=r):(r=t._randexp)._setDefaults(t),r.gen()}static sugar(){RegExp.prototype.gen=function(){return e.randexp(this)}}};

},{"drange":83,"ret":169}],165:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});var _objectSpread=require("@babel/runtime/helpers/objectSpread2");function _interopDefaultLegacy(e){return e&&"object"==typeof e&&"default"in e?e:{default:e}}var _objectSpread__default=_interopDefaultLegacy(_objectSpread);function formatProdErrorMessage(e){return"Minified Redux error #"+e+"; visit https://redux.js.org/Errors?code="+e+" for the full message or use the non-minified dev environment for full errors. "}var $$observable="function"==typeof Symbol&&Symbol.observable||"@@observable",randomString=function(){return Math.random().toString(36).substring(7).split("").join(".")},ActionTypes={INIT:"@@redux/INIT"+randomString(),REPLACE:"@@redux/REPLACE"+randomString(),PROBE_UNKNOWN_ACTION:function(){return"@@redux/PROBE_UNKNOWN_ACTION"+randomString()}};function isPlainObject(e){if("object"!=typeof e||null===e)return!1;for(var r=e;null!==Object.getPrototypeOf(r);)r=Object.getPrototypeOf(r);return Object.getPrototypeOf(e)===r}function miniKindOf(e){if(void 0===e)return"undefined";if(null===e)return"null";var r=typeof e;switch(r){case"boolean":case"string":case"number":case"symbol":case"function":return r}if(Array.isArray(e))return"array";if(isDate(e))return"date";if(isError(e))return"error";var t=ctorName(e);switch(t){case"Symbol":case"Promise":case"WeakMap":case"WeakSet":case"Map":case"Set":return t}return r.slice(8,-1).toLowerCase().replace(/\s/g,"")}function ctorName(e){return"function"==typeof e.constructor?e.constructor.name:null}function isError(e){return e instanceof Error||"string"==typeof e.message&&e.constructor&&"number"==typeof e.constructor.stackTraceLimit}function isDate(e){return e instanceof Date||"function"==typeof e.toDateString&&"function"==typeof e.getDate&&"function"==typeof e.setDate}function kindOf(e){var r=typeof e;return"production"!=="production"&&(r=miniKindOf(e)),r}function createStore(e,r,t){var o;if("function"==typeof r&&"function"==typeof t||"function"==typeof t&&"function"==typeof arguments[3])throw new Error("production"==="production"?formatProdErrorMessage(0):"It looks like you are passing several store enhancers to createStore(). This is not supported. Instead, compose them together to a single function. See https://redux.js.org/tutorials/fundamentals/part-4-store#creating-a-store-with-enhancers for an example.");if("function"==typeof r&&void 0===t&&(t=r,r=void 0),void 0!==t){if("function"!=typeof t)throw new Error("production"==="production"?formatProdErrorMessage(1):"Expected the enhancer to be a function. Instead, received: '"+kindOf(t)+"'");return t(createStore)(e,r)}if("function"!=typeof e)throw new Error("production"==="production"?formatProdErrorMessage(2):"Expected the root reducer to be a function. Instead, received: '"+kindOf(e)+"'");var n=e,i=r,a=[],s=a,c=!1;function u(){s===a&&(s=a.slice())}function d(){if(c)throw new Error("production"==="production"?formatProdErrorMessage(3):"You may not call store.getState() while the reducer is executing. The reducer has already received the state as an argument. Pass it down from the top reducer instead of reading it from the store.");return i}function f(e){if("function"!=typeof e)throw new Error("production"==="production"?formatProdErrorMessage(4):"Expected the listener to be a function. Instead, received: '"+kindOf(e)+"'");if(c)throw new Error("production"==="production"?formatProdErrorMessage(5):"You may not call store.subscribe() while the reducer is executing. If you would like to be notified after the store has been updated, subscribe from a component and invoke store.getState() in the callback to access the latest state. See https://redux.js.org/api/store#subscribelistener for more details.");var r=!0;return u(),s.push(e),function(){if(r){if(c)throw new Error("production"==="production"?formatProdErrorMessage(6):"You may not unsubscribe from a store listener while the reducer is executing. See https://redux.js.org/api/store#subscribelistener for more details.");r=!1,u();var t=s.indexOf(e);s.splice(t,1),a=null}}}function p(e){if(!isPlainObject(e))throw new Error("production"==="production"?formatProdErrorMessage(7):"Actions must be plain objects. Instead, the actual type was: '"+kindOf(e)+"'. You may need to add middleware to your store setup to handle dispatching other values, such as 'redux-thunk' to handle dispatching functions. See https://redux.js.org/tutorials/fundamentals/part-4-store#middleware and https://redux.js.org/tutorials/fundamentals/part-6-async-logic#using-the-redux-thunk-middleware for examples.");if(void 0===e.type)throw new Error("production"==="production"?formatProdErrorMessage(8):'Actions may not have an undefined "type" property. You may have misspelled an action type string constant.');if(c)throw new Error("production"==="production"?formatProdErrorMessage(9):"Reducers may not dispatch actions.");try{c=!0,i=n(i,e)}finally{c=!1}for(var r=a=s,t=0;t<r.length;t++){(0,r[t])()}return e}return p({type:ActionTypes.INIT}),(o={dispatch:p,subscribe:f,getState:d,replaceReducer:function(e){if("function"!=typeof e)throw new Error("production"==="production"?formatProdErrorMessage(10):"Expected the nextReducer to be a function. Instead, received: '"+kindOf(e));n=e,p({type:ActionTypes.REPLACE})}})[$$observable]=function(){var e,r=f;return(e={subscribe:function(e){if("object"!=typeof e||null===e)throw new Error("production"==="production"?formatProdErrorMessage(11):"Expected the observer to be an object. Instead, received: '"+kindOf(e)+"'");function t(){e.next&&e.next(d())}return t(),{unsubscribe:r(t)}}})[$$observable]=function(){return this},e},o}var legacy_createStore=createStore;function warning(e){"undefined"!=typeof console&&"function"==typeof console.error&&console.error(e);try{throw new Error(e)}catch(e){}}function getUnexpectedStateShapeWarningMessage(e,r,t,o){var n=Object.keys(r),i=t&&t.type===ActionTypes.INIT?"preloadedState argument passed to createStore":"previous state received by the reducer";if(0===n.length)return"Store does not have a valid reducer. Make sure the argument passed to combineReducers is an object whose values are reducers.";if(!isPlainObject(e))return"The "+i+' has unexpected type of "'+kindOf(e)+'". Expected argument to be an object with the following keys: "'+n.join('", "')+'"';var a=Object.keys(e).filter((function(e){return!r.hasOwnProperty(e)&&!o[e]}));return a.forEach((function(e){o[e]=!0})),t&&t.type===ActionTypes.REPLACE?void 0:a.length>0?"Unexpected "+(a.length>1?"keys":"key")+' "'+a.join('", "')+'" found in '+i+'. Expected to find one of the known reducer keys instead: "'+n.join('", "')+'". Unexpected keys will be ignored.':void 0}function assertReducerShape(e){Object.keys(e).forEach((function(r){var t=e[r];if(void 0===t(void 0,{type:ActionTypes.INIT}))throw new Error("production"==="production"?formatProdErrorMessage(12):'The slice reducer for key "'+r+"\" returned undefined during initialization. If the state passed to the reducer is undefined, you must explicitly return the initial state. The initial state may not be undefined. If you don't want to set a value for this reducer, you can use null instead of undefined.");if(void 0===t(void 0,{type:ActionTypes.PROBE_UNKNOWN_ACTION()}))throw new Error("production"==="production"?formatProdErrorMessage(13):'The slice reducer for key "'+r+"\" returned undefined when probed with a random type. Don't try to handle '"+ActionTypes.INIT+'\' or other actions in "redux/*" namespace. They are considered private. Instead, you must return the current state for any unknown actions, unless it is undefined, in which case you must return the initial state, regardless of the action type. The initial state may not be undefined, but can be null.')}))}function combineReducers(e){for(var r=Object.keys(e),t={},o=0;o<r.length;o++){var n=r[o];"production"!=="production"&&void 0===e[n]&&warning('No reducer provided for key "'+n+'"'),"function"==typeof e[n]&&(t[n]=e[n])}var i,a,s=Object.keys(t);"production"!=="production"&&(i={});try{assertReducerShape(t)}catch(e){a=e}return function(e,r){if(void 0===e&&(e={}),a)throw a;if("production"!=="production"){var o=getUnexpectedStateShapeWarningMessage(e,t,r,i);o&&warning(o)}for(var n=!1,c={},u=0;u<s.length;u++){var d=s[u],f=t[d],p=e[d],l=f(p,r);if(void 0===l){var h=r&&r.type;throw new Error("production"==="production"?formatProdErrorMessage(14):"When called with an action of type "+(h?'"'+String(h)+'"':"(unknown type)")+', the slice reducer for key "'+d+'" returned undefined. To ignore an action, you must explicitly return the previous state. If you want this reducer to hold no value, you can return null instead of undefined.')}c[d]=l,n=n||l!==p}return(n=n||s.length!==Object.keys(e).length)?c:e}}function bindActionCreator(e,r){return function(){return r(e.apply(this,arguments))}}function bindActionCreators(e,r){if("function"==typeof e)return bindActionCreator(e,r);if("object"!=typeof e||null===e)throw new Error("production"==="production"?formatProdErrorMessage(16):"bindActionCreators expected an object or a function, but instead received: '"+kindOf(e)+'\'. Did you write "import ActionCreators from" instead of "import * as ActionCreators from"?');var t={};for(var o in e){var n=e[o];"function"==typeof n&&(t[o]=bindActionCreator(n,r))}return t}function compose(){for(var e=arguments.length,r=new Array(e),t=0;t<e;t++)r[t]=arguments[t];return 0===r.length?function(e){return e}:1===r.length?r[0]:r.reduce((function(e,r){return function(){return e(r.apply(void 0,arguments))}}))}function applyMiddleware(){for(var e=arguments.length,r=new Array(e),t=0;t<e;t++)r[t]=arguments[t];return function(e){return function(){var t=e.apply(void 0,arguments),o=function(){throw new Error("production"==="production"?formatProdErrorMessage(15):"Dispatching while constructing your middleware is not allowed. Other middleware would not be applied to this dispatch.")},n={getState:t.getState,dispatch:function(){return o.apply(void 0,arguments)}},i=r.map((function(e){return e(n)}));return o=compose.apply(void 0,i)(t.dispatch),_objectSpread__default.default(_objectSpread__default.default({},t),{},{dispatch:o})}}}exports.__DO_NOT_USE__ActionTypes=ActionTypes,exports.applyMiddleware=applyMiddleware,exports.bindActionCreators=bindActionCreators,exports.combineReducers=combineReducers,exports.compose=compose,exports.createStore=createStore,exports.legacy_createStore=legacy_createStore;

},{"@babel/runtime/helpers/objectSpread2":4}],63:[function(require,module,exports){
"use strict";var disclosure_disclosureState=require("../disclosure/disclosure-state.js");function useDialogState(e){void 0===e&&(e={});return disclosure_disclosureState.useDisclosureState(e)}exports.useDialogState=useDialogState;

},{"../disclosure/disclosure-state.js":66}],110:[function(require,module,exports){
"use strict";function checkDCE(){if("undefined"!=typeof __REACT_DEVTOOLS_GLOBAL_HOOK__&&"function"==typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE){0;try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(checkDCE)}catch(_){console.error(_)}}}checkDCE(),module.exports=require("./cjs/react-dom.production.min.js");

},{"./cjs/react-dom.production.min.js":108}],125:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.createDispatchHook=createDispatchHook,exports.useDispatch=void 0;var _Context=require("../components/Context"),_useStore=require("./useStore");function createDispatchHook(e=_Context.ReactReduxContext){const t=e===_Context.ReactReduxContext?_useStore.useStore:(0,_useStore.createStoreHook)(e);return function(){return t().dispatch}}const useDispatch=createDispatchHook();exports.useDispatch=useDispatch;

},{"../components/Context":114,"./useStore":128}],22:[function(require,module,exports){
"use strict";var React=require("react"),array=require("ariakit-utils/array"),misc=require("ariakit-utils/misc"),hooks=require("./hooks.js"),system=require("./system.js"),jsxRuntime=require("react/jsx-runtime");const GET_STATE=Symbol("getState"),SUBSCRIBE=Symbol("subscribe"),TIMESTAMP=Symbol("timestamp"),INITIAL_CONTEXT=Symbol("initialContext");function getState(e){if(!e)return e;const t=e[GET_STATE];return t?t():e}function hasSubscribe(e){return!!e&&!!e[SUBSCRIBE]}function getSubscribe(e){if(e)return e[SUBSCRIBE]}function getLatest(e,t){return t?e?TIMESTAMP in t?TIMESTAMP in e&&e[TIMESTAMP]>=t[TIMESTAMP]?e:t:e:t:e}function defineGetState(e,t){void 0===t&&(t=e),Object.defineProperty(e,GET_STATE,{value:()=>t,writable:!0})}function defineSubscribe(e,t){SUBSCRIBE in e||Object.defineProperty(e,SUBSCRIBE,{value:t})}function defineTimestamp(e){TIMESTAMP in e||Object.defineProperty(e,TIMESTAMP,{value:Date.now(),writable:!0})}function patchState(e){Object.defineProperty(e,TIMESTAMP,{value:Date.now(),writable:!0})}function defineInitialContext(e){const t=React.createContext(void 0);return Object.defineProperty(e,INITIAL_CONTEXT,{value:t}),t}function hasInitialContext(e){return e&&INITIAL_CONTEXT in e}function getInitialContext(e){if(!hasInitialContext(e))return;return e[INITIAL_CONTEXT]}function createStoreContext(){const e=React.createContext(void 0);return defineInitialContext(e),e}function createMemoComponent(e,t){void 0===t&&(t=misc.shallowEqual);const n=system.createComponent(e);return React.memo(n,((e,n)=>{const{state:r,...o}=e,{state:i,...s}=n;return i&&hasSubscribe(i)?t(o,s):t(e,n)}))}function useStoreProvider(e,t){let{state:n,...r}=e;const o=hooks.useInitialValue(n),i=n&&hasSubscribe(n)?o:n;defineGetState(i,n);const s=getInitialContext(t);return hooks.useWrapElement(r,(e=>(i&&s&&(e=jsxRuntime.jsx(s.Provider,{value:i,children:e})),n&&(e=jsxRuntime.jsx(t.Provider,{value:n,children:e})),e)),[i,s,n,t])}function useStorePublisher(e){const t=hooks.useLazyValue((()=>new Set));hooks.useSafeLayoutEffect((()=>{patchState(e);for(const n of t)n(e)}),[e]);const n=React.useCallback((e=>(t.add(e),()=>t.delete(e))),[]);return defineSubscribe(e,n),defineGetState(e),defineTimestamp(e),e}function useStore(e,t){const n=React.useContext(getContext(e,t)),r=hasInitialContext(e)?n:e,[o,i]=React.useState((()=>getState(r))),s=hasSubscribe(r)&&hasSubscribe(o)?getLatest(o,r):r,a=getSubscribe(r),u=React.useRef(null),c=array.toArray(t),S=!t;return hooks.useSafeLayoutEffect((()=>{if(a&&i){if(S)return a(i);if(c.length)return a((e=>{const t=u.current;u.current=e;c.some((n=>{if("function"==typeof n){const r=n(e);return"boolean"==typeof r?r||t&&n(t):t?r!==n(t):r}const r=n;return t?.[r]!==e[r]}))&&i(e)}))}}),[a,i,S,...c]),s}const EmptyContext=React.createContext(void 0);function getContext(e,t){return hasInitialContext(e)?t?getInitialContext(e):e:EmptyContext}exports.createMemoComponent=createMemoComponent,exports.createStoreContext=createStoreContext,exports.useStore=useStore,exports.useStoreProvider=useStoreProvider,exports.useStorePublisher=useStorePublisher;

},{"./hooks.js":20,"./system.js":23,"ariakit-utils/array":24,"ariakit-utils/misc":28,"react":146,"react/jsx-runtime":147}],70:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),system=require("ariakit-react-utils/system"),dom=require("ariakit-utils/dom"),events=require("ariakit-utils/events"),focus=require("ariakit-utils/focus"),misc=require("ariakit-utils/misc"),platform=require("ariakit-utils/platform");const isSafariBrowser=platform.isSafari(),alwaysFocusVisibleInputTypes=["text","search","url","tel","email","password","number","date","month","week","time","datetime","datetime-local"];function isAlwaysFocusVisible(e){const{tagName:t,readOnly:s,type:r}=e;return"TEXTAREA"===t&&!s||("SELECT"===t&&!s||("INPUT"!==t||s?!!e.isContentEditable:alwaysFocusVisibleInputTypes.includes(r)))}function isAlwaysFocusVisibleDelayed(e){return"combobox"===e.getAttribute("role")}function getLabels(e){return"labels"in e?e.labels:null}function isNativeCheckboxOrRadio(e){return!("input"!==e.tagName.toLowerCase()||!e.type)&&("radio"===e.type||"checkbox"===e.type)}function isNativeTabbable(e){return!e||("button"===e||"input"===e||"select"===e||"textarea"===e||"a"===e)}function supportsDisabledAttribute(e){return!e||("button"===e||"input"===e||"select"===e||"textarea"===e)}function getTabIndex(e,t,s,r,o){return e?t?s&&!r?-1:void 0:s?o:o||0:o}function useDisableEvent(e,t){return hooks.useEvent((s=>{e?.(s),s.defaultPrevented||t&&(s.stopPropagation(),s.preventDefault())}))}let isKeyboardModality=!0;function onGlobalMouseDown(e){const t=e.target;t&&"hasAttribute"in t&&(t.hasAttribute("data-focus-visible")||(isKeyboardModality=!1))}function onGlobalKeyDown(e){e.metaKey||e.ctrlKey||(isKeyboardModality=!0)}const useFocusable=system.createHook((e=>{let{focusable:t=!0,accessibleWhenDisabled:s,autoFocus:r,onFocusVisible:o,...n}=e;const u=react.useRef(null);react.useEffect((()=>{t&&(events.addGlobalEventListener("mousedown",onGlobalMouseDown,!0),events.addGlobalEventListener("keydown",onGlobalKeyDown,!0))}),[t]),isSafariBrowser&&react.useEffect((()=>{if(!t)return;const e=u.current;if(!e)return;if(!isNativeCheckboxOrRadio(e))return;const s=getLabels(e);if(!s)return;const r=()=>misc.queueMicrotask((()=>e.focus()));return s.forEach((e=>e.addEventListener("mouseup",r))),()=>{s.forEach((e=>e.removeEventListener("mouseup",r)))}}),[t]);const a=t&&n.disabled,i=!!a&&!s,[c,l]=react.useState(!1);react.useEffect((()=>{t&&i&&c&&l(!1)}),[t,i,c]),react.useEffect((()=>{if(!t)return;if(!c)return;const e=u.current;if(!e)return;if("undefined"==typeof IntersectionObserver)return;const s=new IntersectionObserver((()=>{focus.isFocusable(e)||l(!1)}));return s.observe(e),()=>s.disconnect()}),[t,c]);const f=useDisableEvent(n.onKeyPressCapture,a),d=useDisableEvent(n.onMouseDownCapture,a),b=useDisableEvent(n.onClickCapture,a),v=n.onMouseDown,y=hooks.useEvent((e=>{if(v?.(e),e.defaultPrevented)return;if(!t)return;const s=e.currentTarget;if(!isSafariBrowser)return;if(events.isPortalEvent(e))return;if(!dom.isButton(s)&&!isNativeCheckboxOrRadio(s))return;let r=!1;const o=()=>{r=!0};s.addEventListener("focusin",o,{capture:!0,once:!0}),events.queueBeforeEvent(s,"mouseup",(()=>{s.removeEventListener("focusin",o,!0),r||focus.focusIfNeeded(s)}))})),p=(e,s)=>{if(s&&(e.currentTarget=s),o?.(e),e.defaultPrevented)return;if(!t)return;const r=e.currentTarget;r&&focus.hasFocus(r)&&l(!0)},m=n.onKeyDownCapture,E=hooks.useEvent((e=>{if(m?.(e),e.defaultPrevented)return;if(!t)return;if(c)return;if(e.metaKey)return;if(e.altKey)return;if(e.ctrlKey)return;if(!events.isSelfTarget(e))return;const s=e.currentTarget;misc.queueMicrotask((()=>p(e,s)))})),k=n.onFocusCapture,w=hooks.useEvent((e=>{if(k?.(e),e.defaultPrevented)return;if(!t)return;if(!events.isSelfTarget(e))return void l(!1);const s=e.currentTarget,r=()=>p(e,s);isKeyboardModality||isAlwaysFocusVisible(e.target)?misc.queueMicrotask(r):isAlwaysFocusVisibleDelayed(e.target)?events.queueBeforeEvent(e.target,"focusout",r):l(!1)})),F=n.onBlur,h=hooks.useEvent((e=>{F?.(e),t&&events.isFocusEventOutside(e)&&l(!1)}));hooks.useSafeLayoutEffect((()=>{t&&r&&u.current?.focus()}),[t,r]);const D=hooks.useTagName(u,n.as),g=t&&isNativeTabbable(D),C=t&&supportsDisabledAttribute(D),T=i?{pointerEvents:"none",...n.style}:n.style;return n={"data-focus-visible":t&&c?"":void 0,"aria-disabled":!!a||void 0,...n,ref:hooks.useForkRef(u,n.ref),style:T,tabIndex:getTabIndex(t,i,g,C,n.tabIndex),disabled:!(!C||!i)||void 0,contentEditable:a?void 0:n.contentEditable,onKeyPressCapture:f,onClickCapture:b,onMouseDownCapture:d,onMouseDown:y,onKeyDownCapture:E,onFocusCapture:w,onBlur:h},n})),Focusable=system.createComponent((e=>(e=useFocusable(e),system.createElement("div",e))));"production"!=="production"&&(Focusable.displayName="Focusable"),exports.Focusable=Focusable,exports.useFocusable=useFocusable;

},{"ariakit-react-utils/hooks":20,"ariakit-react-utils/system":23,"ariakit-utils/dom":25,"ariakit-utils/events":26,"ariakit-utils/focus":27,"ariakit-utils/misc":28,"ariakit-utils/platform":29,"react":146}],71:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),system=require("ariakit-react-utils/system"),__utils=require("../__utils-44d337e0.js");const useGroupLabel=system.createHook((e=>{const r=react.useContext(__utils.GroupLabelContext),t=hooks.useId(e.id);return hooks.useSafeLayoutEffect((()=>(r?.(t),()=>r?.(void 0))),[r,t]),e={id:t,"aria-hidden":!0,...e}})),GroupLabel=system.createComponent((e=>{const r=useGroupLabel(e);return system.createElement("div",r)}));"production"!=="production"&&(GroupLabel.displayName="GroupLabel"),exports.GroupLabel=GroupLabel,exports.useGroupLabel=useGroupLabel;

},{"../__utils-44d337e0.js":34,"ariakit-react-utils/hooks":20,"ariakit-react-utils/system":23,"react":146}],72:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),system=require("ariakit-react-utils/system"),__utils=require("../__utils-44d337e0.js"),jsxRuntime=require("react/jsx-runtime");const useGroup=system.createHook((e=>{const[r,t]=react.useState();return e=hooks.useWrapElement(e,(e=>jsxRuntime.jsx(__utils.GroupLabelContext.Provider,{value:t,children:e})),[]),e={role:"group","aria-labelledby":r,...e}})),Group=system.createComponent((e=>{const r=useGroup(e);return system.createElement("div",r)}));"production"!=="production"&&(Group.displayName="Group"),exports.Group=Group,exports.useGroup=useGroup;

},{"../__utils-44d337e0.js":34,"ariakit-react-utils/hooks":20,"ariakit-react-utils/system":23,"react":146,"react/jsx-runtime":147}],74:[function(require,module,exports){
"use strict";var hooks=require("ariakit-react-utils/hooks"),system=require("ariakit-react-utils/system");const usePopoverAnchor=system.createHook((e=>{let{state:o,...r}=e;return r={...r,ref:hooks.useForkRef(o.anchorRef,r.ref)},r})),PopoverAnchor=system.createComponent((e=>{const o=usePopoverAnchor(e);return system.createElement("div",o)}));"production"!=="production"&&(PopoverAnchor.displayName="PopoverAnchor"),exports.PopoverAnchor=PopoverAnchor,exports.usePopoverAnchor=usePopoverAnchor;

},{"ariakit-react-utils/hooks":20,"ariakit-react-utils/system":23}],79:[function(require,module,exports){
"use strict";var system=require("ariakit-react-utils/system");const useSeparator=system.createHook((e=>{let{orientation:r="horizontal",...t}=e;return t={role:"separator","aria-orientation":r,...t},t})),Separator=system.createComponent((e=>{const r=useSeparator(e);return system.createElement("hr",r)}));"production"!=="production"&&(Separator.displayName="Separator"),exports.Separator=Separator,exports.useSeparator=useSeparator;

},{"ariakit-react-utils/system":23}],80:[function(require,module,exports){
"use strict";var system=require("ariakit-react-utils/system");const useVisuallyHidden=system.createHook((e=>e={...e,style:{border:0,clip:"rect(0 0 0 0)",height:"1px",margin:"-1px",overflow:"hidden",padding:0,position:"absolute",whiteSpace:"nowrap",width:"1px",...e.style}})),VisuallyHidden=system.createComponent((e=>{const s=useVisuallyHidden(e);return system.createElement("span",s)}));"production"!=="production"&&(VisuallyHidden.displayName="VisuallyHidden"),exports.VisuallyHidden=VisuallyHidden,exports.useVisuallyHidden=useVisuallyHidden;

},{"ariakit-react-utils/system":23}],233:[function(require,module,exports){
"use strict";"production"==="production"?module.exports=require("../cjs/use-sync-external-store-shim/with-selector.production.min.js"):module.exports=require("../cjs/use-sync-external-store-shim/with-selector.development.js");

},{"../cjs/use-sync-external-store-shim/with-selector.development.js":230,"../cjs/use-sync-external-store-shim/with-selector.production.min.js":231}],236:[function(require,module,exports){
"use strict";var React=require("react"),useSyncExternalStore=require("./use-sync-external-store");function _interopNamespaceDefault(e){var t=Object.create(null);return e&&Object.keys(e).forEach((function(r){if("default"!==r){var n=Object.getOwnPropertyDescriptor(e,r);Object.defineProperty(t,r,n.get?n:{enumerable:!0,get:function(){return e[r]}})}})),t.default=e,Object.freeze(t)}var React__namespace=_interopNamespaceDefault(React);const{useEffect:useEffect,useLayoutEffect:useLayoutEffect,useRef:useRef,useInsertionEffect:useBuiltinInsertionEffect}=React__namespace,canUseDOM=!("undefined"==typeof window||void 0===window.document||void 0===window.document.createElement),useIsomorphicLayoutEffect=canUseDOM?useLayoutEffect:useEffect,useInsertionEffect=useBuiltinInsertionEffect||useIsomorphicLayoutEffect,useEvent=e=>{const t=useRef([e,(...e)=>t[0](...e)]).current;return useInsertionEffect((()=>{t[0]=e})),t[1]};Object.defineProperty(exports,"Fragment",{enumerable:!0,get:function(){return React.Fragment}}),Object.defineProperty(exports,"cloneElement",{enumerable:!0,get:function(){return React.cloneElement}}),Object.defineProperty(exports,"createContext",{enumerable:!0,get:function(){return React.createContext}}),Object.defineProperty(exports,"createElement",{enumerable:!0,get:function(){return React.createElement}}),Object.defineProperty(exports,"forwardRef",{enumerable:!0,get:function(){return React.forwardRef}}),Object.defineProperty(exports,"isValidElement",{enumerable:!0,get:function(){return React.isValidElement}}),Object.defineProperty(exports,"useContext",{enumerable:!0,get:function(){return React.useContext}}),Object.defineProperty(exports,"useState",{enumerable:!0,get:function(){return React.useState}}),Object.defineProperty(exports,"useSyncExternalStore",{enumerable:!0,get:function(){return useSyncExternalStore.useSyncExternalStore}}),exports.useEvent=useEvent,exports.useInsertionEffect=useInsertionEffect,exports.useIsomorphicLayoutEffect=useIsomorphicLayoutEffect;

},{"./use-sync-external-store":238,"react":146}],227:[function(require,module,exports){
"use strict";var __importDefault=this&&this.__importDefault||function(n){return n&&n.__esModule?n:{default:n}};Object.defineProperty(exports,"__esModule",{value:!0}),exports.RandomGenerator=void 0;var RandomGenerator,randexp_1=__importDefault(require("randexp"));!function(n){var t="abcdefghijklmnopqrstuvwxyz";n.boolean=function(){return Math.random()<.5},n.integer=function(n,t){return null!=n||(n=0),null!=t||(t=100),Math.floor(Math.random()*(t-n+1))+n},n.bigint=function(t,r){return null!=t||(t=BigInt(0)),null!=r||(r=BigInt(100)),BigInt(n.integer(Number(t),Number(r)))},n.number=function(n,t){return null!=n||(n=0),null!=t||(t=100),Math.random()*(t-n)+n},n.string=function(r){return new Array(null!=r?r:n.integer(5,10)).fill(0).map((function(){return t[n.integer(0,25)]})).join("")},n.array=function(t,r){return new Array(null!=r?r:n.length()).fill(0).map((function(n,r){return t(r)}))},n.pick=function(t){return t[n.integer(0,t.length-1)]},n.length=function(){return n.integer(0,3)},n.uuid=function(){return"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,(function(n){var t=16*Math.random()|0;return("x"===n?t:3&t|8).toString(16)}))},n.email=function(){return"".concat(n.string(10),"@").concat(n.string(10),".").concat(n.string(3))},n.url=function(){return"https://".concat(n.string(10),".").concat(n.string(3))},n.ipv4=function(){return n.array((function(){return n.integer(0,255)}),4).join(".")},n.ipv6=function(){return n.array((function(){return n.integer(0,65535).toString(16)}),8).join(":")},n.pattern=function(n){return new randexp_1.default(n).gen()},n.date=function(t,r){return null!=t||(t=0),null!=r||(r=2*Date.now()),new Date(n.number(t,r)).toISOString().substring(0,10)},n.datetime=function(t,r){return null!=t||(t=Date.now()-30*DAY),null!=r||(r=Date.now()+7*DAY),new Date(n.number(t,r)).toISOString()}}(RandomGenerator||(exports.RandomGenerator=RandomGenerator={}));var DAY=864e5;

},{"randexp":107}],18:[function(require,module,exports){
(function (process,global){(function (){
var __extends=this&&this.__extends||function(){var e=function(t,r){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var r in t)Object.prototype.hasOwnProperty.call(t,r)&&(e[r]=t[r])},e(t,r)};return function(t,r){if("function"!=typeof r&&null!==r)throw new TypeError("Class extends value "+String(r)+" is not a constructor or null");function n(){this.constructor=t}e(t,r),t.prototype=null===r?Object.create(r):(n.prototype=r.prototype,new n)}}(),__generator=this&&this.__generator||function(e,t){var r,n,i,a,o={label:0,sent:function(){if(1&i[0])throw i[1];return i[1]},trys:[],ops:[]};return a={next:u(0),throw:u(1),return:u(2)},"function"==typeof Symbol&&(a[Symbol.iterator]=function(){return this}),a;function u(a){return function(u){return function(a){if(r)throw new TypeError("Generator is already executing.");for(;o;)try{if(r=1,n&&(i=2&a[0]?n.return:a[0]?n.throw||((i=n.return)&&i.call(n),0):n.next)&&!(i=i.call(n,a[1])).done)return i;switch(n=0,i&&(a=[2&a[0],i.value]),a[0]){case 0:case 1:i=a;break;case 4:return o.label++,{value:a[1],done:!1};case 5:o.label++,n=a[1],a=[0];continue;case 7:a=o.ops.pop(),o.trys.pop();continue;default:if(!(i=o.trys,(i=i.length>0&&i[i.length-1])||6!==a[0]&&2!==a[0])){o=0;continue}if(3===a[0]&&(!i||a[1]>i[0]&&a[1]<i[3])){o.label=a[1];break}if(6===a[0]&&o.label<i[1]){o.label=i[1],i=a;break}if(i&&o.label<i[2]){o.label=i[2],o.ops.push(a);break}i[2]&&o.ops.pop(),o.trys.pop();continue}a=t.call(e,o)}catch(e){a=[6,e],n=0}finally{r=i=0}if(5&a[0])throw a[1];return{value:a[0]?a[1]:void 0,done:!0}}([a,u])}}},__spreadArray=this&&this.__spreadArray||function(e,t){for(var r=0,n=t.length,i=e.length;r<n;r++,i++)e[i]=t[r];return e},__create=Object.create,__defProp=Object.defineProperty,__defProps=Object.defineProperties,__getOwnPropDesc=Object.getOwnPropertyDescriptor,__getOwnPropDescs=Object.getOwnPropertyDescriptors,__getOwnPropNames=Object.getOwnPropertyNames,__getOwnPropSymbols=Object.getOwnPropertySymbols,__getProtoOf=Object.getPrototypeOf,__hasOwnProp=Object.prototype.hasOwnProperty,__propIsEnum=Object.prototype.propertyIsEnumerable,__defNormalProp=function(e,t,r){return t in e?__defProp(e,t,{enumerable:!0,configurable:!0,writable:!0,value:r}):e[t]=r},__spreadValues=function(e,t){for(var r in t||(t={}))__hasOwnProp.call(t,r)&&__defNormalProp(e,r,t[r]);if(__getOwnPropSymbols)for(var n=0,i=__getOwnPropSymbols(t);n<i.length;n++){r=i[n];__propIsEnum.call(t,r)&&__defNormalProp(e,r,t[r])}return e},__spreadProps=function(e,t){return __defProps(e,__getOwnPropDescs(t))},__markAsModule=function(e){return __defProp(e,"__esModule",{value:!0})},__export=function(e,t){for(var r in t)__defProp(e,r,{get:t[r],enumerable:!0})},__reExport=function(e,t,r){if(t&&"object"==typeof t||"function"==typeof t)for(var n=function(n){__hasOwnProp.call(e,n)||"default"===n||__defProp(e,n,{get:function(){return t[n]},enumerable:!(r=__getOwnPropDesc(t,n))||r.enumerable})},i=0,a=__getOwnPropNames(t);i<a.length;i++){n(a[i])}return e},__toModule=function(e){return __reExport(__markAsModule(__defProp(null!=e?__create(__getProtoOf(e)):{},"default",e&&e.__esModule&&"default"in e?{get:function(){return e.default},enumerable:!0}:{value:e,enumerable:!0})),e)},__async=function(e,t,r){return new Promise((function(n,i){var a=function(e){try{u(r.next(e))}catch(e){i(e)}},o=function(e){try{u(r.throw(e))}catch(e){i(e)}},u=function(e){return e.done?n(e.value):Promise.resolve(e.value).then(a,o)};u((r=r.apply(e,t)).next())}))};__markAsModule(exports),__export(exports,{EnhancerArray:function(){return EnhancerArray},MiddlewareArray:function(){return MiddlewareArray},SHOULD_AUTOBATCH:function(){return SHOULD_AUTOBATCH},TaskAbortError:function(){return TaskAbortError},addListener:function(){return addListener},autoBatchEnhancer:function(){return autoBatchEnhancer},clearAllListeners:function(){return clearAllListeners},configureStore:function(){return configureStore},createAction:function(){return createAction},createActionCreatorInvariantMiddleware:function(){return createActionCreatorInvariantMiddleware},createAsyncThunk:function(){return createAsyncThunk},createDraftSafeSelector:function(){return createDraftSafeSelector},createEntityAdapter:function(){return createEntityAdapter},createImmutableStateInvariantMiddleware:function(){return createImmutableStateInvariantMiddleware},createListenerMiddleware:function(){return createListenerMiddleware},createNextState:function(){return import_immer6.default},createReducer:function(){return createReducer},createSelector:function(){return import_reselect2.createSelector},createSerializableStateInvariantMiddleware:function(){return createSerializableStateInvariantMiddleware},createSlice:function(){return createSlice},current:function(){return import_immer6.current},findNonSerializableValue:function(){return findNonSerializableValue},freeze:function(){return import_immer6.freeze},getDefaultMiddleware:function(){return getDefaultMiddleware},getType:function(){return getType},isAction:function(){return isAction},isActionCreator:function(){return isActionCreator},isAllOf:function(){return isAllOf},isAnyOf:function(){return isAnyOf},isAsyncThunkAction:function(){return isAsyncThunkAction},isDraft:function(){return import_immer6.isDraft},isFluxStandardAction:function(){return isFSA},isFulfilled:function(){return isFulfilled},isImmutableDefault:function(){return isImmutableDefault},isPending:function(){return isPending},isPlain:function(){return isPlain},isPlainObject:function(){return isPlainObject},isRejected:function(){return isRejected},isRejectedWithValue:function(){return isRejectedWithValue},miniSerializeError:function(){return miniSerializeError},nanoid:function(){return nanoid},original:function(){return import_immer6.original},prepareAutoBatched:function(){return prepareAutoBatched},removeListener:function(){return removeListener},unwrapResult:function(){return unwrapResult}});var import_immer5=__toModule(require("immer"));__reExport(exports,__toModule(require("redux")));var import_immer6=__toModule(require("immer")),import_reselect2=__toModule(require("reselect")),import_immer=__toModule(require("immer")),import_reselect=__toModule(require("reselect")),createDraftSafeSelector=function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];var r=import_reselect.createSelector.apply(void 0,e);return function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];return r.apply(void 0,__spreadArray([(0,import_immer.isDraft)(e)?(0,import_immer.current)(e):e],t))}},import_redux2=__toModule(require("redux")),import_redux=__toModule(require("redux")),composeWithDevTools="undefined"!=typeof window&&window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__?window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__:function(){if(0!==arguments.length)return"object"==typeof arguments[0]?import_redux.compose:import_redux.compose.apply(null,arguments)},devToolsEnhancer="undefined"!=typeof window&&window.__REDUX_DEVTOOLS_EXTENSION__?window.__REDUX_DEVTOOLS_EXTENSION__:function(){return function(e){return e}};function isPlainObject(e){if("object"!=typeof e||null===e)return!1;var t=Object.getPrototypeOf(e);if(null===t)return!0;for(var r=t;null!==Object.getPrototypeOf(r);)r=Object.getPrototypeOf(r);return t===r}var import_redux_thunk=__toModule(require("redux-thunk")),hasMatchFunction=function(e){return e&&"function"==typeof e.match};function createAction(e,t){function r(){for(var r=[],n=0;n<arguments.length;n++)r[n]=arguments[n];if(t){var i=t.apply(void 0,r);if(!i)throw new Error("prepareAction did not return an object");return __spreadValues(__spreadValues({type:e,payload:i.payload},"meta"in i&&{meta:i.meta}),"error"in i&&{error:i.error})}return{type:e,payload:r[0]}}return r.toString=function(){return""+e},r.type=e,r.match=function(t){return t.type===e},r}function isAction(e){return isPlainObject(e)&&"type"in e}function isActionCreator(e){return"function"==typeof e&&"type"in e&&hasMatchFunction(e)}function isFSA(e){return isAction(e)&&"string"==typeof e.type&&Object.keys(e).every(isValidKey)}function isValidKey(e){return["type","payload","error","meta"].indexOf(e)>-1}function getType(e){return""+e}function getMessage(e){var t=e?(""+e).split("/"):[],r=t[t.length-1]||"actionCreator";return'Detected an action creator with type "'+(e||"unknown")+"\" being dispatched. \nMake sure you're calling the action creator before dispatching, i.e. `dispatch("+r+"())` instead of `dispatch("+r+")`. This is necessary even if the action has no payload."}function createActionCreatorInvariantMiddleware(e){void 0===e&&(e={});var t=e.isActionCreator,r=void 0===t?isActionCreator:t;return function(){return function(e){return function(t){return r(t)&&console.warn(getMessage(t.type)),e(t)}}}}var import_immer2=__toModule(require("immer"));function getTimeMeasureUtils(e,t){var r=0;return{measureTime:function(e){var t=Date.now();try{return e()}finally{var n=Date.now();r+=n-t}},warnIfExceeded:function(){r>e&&console.warn(t+" took "+r+"ms, which is more than the warning threshold of "+e+"ms. \nIf your state or actions are very large, you may want to disable the middleware as it might cause too much of a slowdown in development mode. See https://redux-toolkit.js.org/api/getDefaultMiddleware for instructions.\nIt is disabled in production builds, so you don't need to worry about that.")}}}var MiddlewareArray=function(e){function t(){for(var r=[],n=0;n<arguments.length;n++)r[n]=arguments[n];var i=e.apply(this,r)||this;return Object.setPrototypeOf(i,t.prototype),i}return __extends(t,e),Object.defineProperty(t,Symbol.species,{get:function(){return t},enumerable:!1,configurable:!0}),t.prototype.concat=function(){for(var t=[],r=0;r<arguments.length;r++)t[r]=arguments[r];return e.prototype.concat.apply(this,t)},t.prototype.prepend=function(){for(var e=[],r=0;r<arguments.length;r++)e[r]=arguments[r];return 1===e.length&&Array.isArray(e[0])?new(t.bind.apply(t,__spreadArray([void 0],e[0].concat(this)))):new(t.bind.apply(t,__spreadArray([void 0],e.concat(this))))},t}(Array),EnhancerArray=function(e){function t(){for(var r=[],n=0;n<arguments.length;n++)r[n]=arguments[n];var i=e.apply(this,r)||this;return Object.setPrototypeOf(i,t.prototype),i}return __extends(t,e),Object.defineProperty(t,Symbol.species,{get:function(){return t},enumerable:!1,configurable:!0}),t.prototype.concat=function(){for(var t=[],r=0;r<arguments.length;r++)t[r]=arguments[r];return e.prototype.concat.apply(this,t)},t.prototype.prepend=function(){for(var e=[],r=0;r<arguments.length;r++)e[r]=arguments[r];return 1===e.length&&Array.isArray(e[0])?new(t.bind.apply(t,__spreadArray([void 0],e[0].concat(this)))):new(t.bind.apply(t,__spreadArray([void 0],e.concat(this))))},t}(Array);function freezeDraftable(e){return(0,import_immer2.isDraftable)(e)?(0,import_immer2.default)(e,(function(){})):e}var isProduction=!1,prefix="Invariant failed";function invariant(e,t){if(!e){if(isProduction)throw new Error(prefix);throw new Error(prefix+": "+(t||""))}}function stringify(e,t,r,n){return JSON.stringify(e,getSerialize(t,n),r)}function getSerialize(e,t){var r=[],n=[];return t||(t=function(e,t){return r[0]===t?"[Circular ~]":"[Circular ~."+n.slice(0,r.indexOf(t)).join(".")+"]"}),function(i,a){if(r.length>0){var o=r.indexOf(this);~o?r.splice(o+1):r.push(this),~o?n.splice(o,1/0,i):n.push(i),~r.indexOf(a)&&(a=t.call(this,i,a))}else r.push(a);return null==e?a:e.call(this,i,a)}}function isImmutableDefault(e){return"object"!=typeof e||null==e||Object.isFrozen(e)}function trackForMutations(e,t,r){var n=trackProperties(e,t,r);return{detectMutations:function(){return detectMutations(e,t,n,r)}}}function trackProperties(e,t,r,n,i){void 0===t&&(t=[]),void 0===n&&(n=""),void 0===i&&(i=new Set);var a={value:r};if(!e(r)&&!i.has(r))for(var o in i.add(r),a.children={},r){var u=n?n+"."+o:o;t.length&&-1!==t.indexOf(u)||(a.children[o]=trackProperties(e,t,r[o],u))}return a}function detectMutations(e,t,r,n,i,a){void 0===t&&(t=[]),void 0===i&&(i=!1),void 0===a&&(a="");var o=r?r.value:void 0,u=o===n;if(i&&!u&&!Number.isNaN(n))return{wasMutated:!0,path:a};if(e(o)||e(n))return{wasMutated:!1};var c={};for(var s in r.children)c[s]=!0;for(var s in n)c[s]=!0;var l=t.length>0,d=function(i){var o=a?a+"."+i:i;if(l&&t.some((function(e){return e instanceof RegExp?e.test(o):o===e})))return"continue";var c=detectMutations(e,t,r.children[i],n[i],u,o);if(c.wasMutated)return{value:c}};for(var s in c){var f=d(s);if("object"==typeof f)return f.value}return{wasMutated:!1}}function createImmutableStateInvariantMiddleware(e){void 0===e&&(e={});var t=e.isImmutable,r=void 0===t?isImmutableDefault:t,n=e.ignoredPaths,i=e.warnAfter,a=void 0===i?32:i,o=e.ignore;n=n||o;var u=trackForMutations.bind(null,r,n);return function(e){var t,r=e.getState,n=r(),i=u(n);return function(e){return function(o){var c=getTimeMeasureUtils(a,"ImmutableStateInvariantMiddleware");c.measureTime((function(){n=r(),t=i.detectMutations(),i=u(n),invariant(!t.wasMutated,"A state mutation was detected between dispatches, in the path '"+(t.path||"")+"'.  This may cause incorrect behavior. (https://redux.js.org/style-guide/style-guide#do-not-mutate-state)")}));var s=e(o);return c.measureTime((function(){n=r(),t=i.detectMutations(),i=u(n),t.wasMutated&&invariant(!t.wasMutated,"A state mutation was detected inside a dispatch, in the path: "+(t.path||"")+". Take a look at the reducer(s) handling the action "+stringify(o)+". (https://redux.js.org/style-guide/style-guide#do-not-mutate-state)")})),c.warnIfExceeded(),s}}}}function isPlain(e){var t=typeof e;return null==e||"string"===t||"boolean"===t||"number"===t||Array.isArray(e)||isPlainObject(e)}function findNonSerializableValue(e,t,r,n,i,a){var o;if(void 0===t&&(t=""),void 0===r&&(r=isPlain),void 0===i&&(i=[]),!r(e))return{keyPath:t||"<root>",value:e};if("object"!=typeof e||null===e)return!1;if(null==a?void 0:a.has(e))return!1;for(var u=null!=n?n(e):Object.entries(e),c=i.length>0,s=function(e,u){var s=t?t+"."+e:e;if(c&&i.some((function(e){return e instanceof RegExp?e.test(s):s===e})))return"continue";return r(u)?"object"==typeof u&&(o=findNonSerializableValue(u,s,r,n,i,a))?{value:o}:void 0:{value:{keyPath:s,value:u}}},l=0,d=u;l<d.length;l++){var f=d[l],p=s(f[0],f[1]);if("object"==typeof p)return p.value}return a&&isNestedFrozen(e)&&a.add(e),!1}function isNestedFrozen(e){if(!Object.isFrozen(e))return!1;for(var t=0,r=Object.values(e);t<r.length;t++){var n=r[t];if("object"==typeof n&&null!==n&&!isNestedFrozen(n))return!1}return!0}function createSerializableStateInvariantMiddleware(e){void 0===e&&(e={});var t=e.isSerializable,r=void 0===t?isPlain:t,n=e.getEntries,i=e.ignoredActions,a=void 0===i?[]:i,o=e.ignoredActionPaths,u=void 0===o?["meta.arg","meta.baseQueryMeta"]:o,c=e.ignoredPaths,s=void 0===c?[]:c,l=e.warnAfter,d=void 0===l?32:l,f=e.ignoreState,p=void 0!==f&&f,h=e.ignoreActions,v=void 0!==h&&h,y=e.disableCache,m=!(void 0!==y&&y)&&WeakSet?new WeakSet:void 0;return function(e){return function(t){return function(i){var o=t(i),c=getTimeMeasureUtils(d,"SerializableStateInvariantMiddleware");return v||a.length&&-1!==a.indexOf(i.type)||c.measureTime((function(){var e=findNonSerializableValue(i,"",r,n,u,m);if(e){var t=e.keyPath,a=e.value;console.error("A non-serializable value was detected in an action, in the path: `"+t+"`. Value:",a,"\nTake a look at the logic that dispatched this action: ",i,"\n(See https://redux.js.org/faq/actions#why-should-type-be-a-string-or-at-least-serializable-why-should-my-action-types-be-constants)","\n(To allow non-serializable values see: https://redux-toolkit.js.org/usage/usage-guide#working-with-non-serializable-data)")}})),p||(c.measureTime((function(){var t=findNonSerializableValue(e.getState(),"",r,n,s,m);if(t){var a=t.keyPath,o=t.value;console.error("A non-serializable value was detected in the state, in the path: `"+a+"`. Value:",o,"\nTake a look at the reducer(s) handling this action type: "+i.type+".\n(See https://redux.js.org/faq/organizing-state#can-i-put-functions-promises-or-other-non-serializable-items-in-my-store-state)")}})),c.warnIfExceeded()),o}}}}function isBoolean(e){return"boolean"==typeof e}function curryGetDefaultMiddleware(){return function(e){return getDefaultMiddleware(e)}}function getDefaultMiddleware(e){void 0===e&&(e={});var t=e.thunk,r=void 0===t||t,n=e.immutableCheck,i=void 0===n||n,a=e.serializableCheck,o=void 0===a||a,u=e.actionCreatorCheck,c=void 0===u||u,s=new MiddlewareArray;if(r&&(isBoolean(r)?s.push(import_redux_thunk.default):s.push(import_redux_thunk.default.withExtraArgument(r.extraArgument))),i){var l={};isBoolean(i)||(l=i),s.unshift(createImmutableStateInvariantMiddleware(l))}if(o){var d={};isBoolean(o)||(d=o),s.push(createSerializableStateInvariantMiddleware(d))}if(c){var f={};isBoolean(c)||(f=c),s.unshift(createActionCreatorInvariantMiddleware(f))}return s}var IS_PRODUCTION=!1;function configureStore(e){var t,r=curryGetDefaultMiddleware(),n=e||{},i=n.reducer,a=void 0===i?void 0:i,o=n.middleware,u=void 0===o?r():o,c=n.devTools,s=void 0===c||c,l=n.preloadedState,d=void 0===l?void 0:l,f=n.enhancers,p=void 0===f?void 0:f;if("function"==typeof a)t=a;else{if(!isPlainObject(a))throw new Error('"reducer" is a required argument, and must be a function or an object of functions that can be passed to combineReducers');t=(0,import_redux2.combineReducers)(a)}var h=u;if("function"==typeof h&&(h=h(r),!IS_PRODUCTION&&!Array.isArray(h)))throw new Error("when using a middleware builder function, an array of middleware must be returned");if(!IS_PRODUCTION&&h.some((function(e){return"function"!=typeof e})))throw new Error("each middleware provided to configureStore must be a function");var v=import_redux2.applyMiddleware.apply(void 0,h),y=import_redux2.compose;s&&(y=composeWithDevTools(__spreadValues({trace:!IS_PRODUCTION},"object"==typeof s&&s)));var m=new EnhancerArray(v),b=m;Array.isArray(p)?b=__spreadArray([v],p):"function"==typeof p&&(b=p(m));var g=y.apply(void 0,b);return(0,import_redux2.createStore)(t,d,g)}var import_immer3=__toModule(require("immer"));function executeReducerBuilderCallback(e){var t,r={},n=[],i={addCase:function(e,a){if(n.length>0)throw new Error("`builder.addCase` should only be called before calling `builder.addMatcher`");if(t)throw new Error("`builder.addCase` should only be called before calling `builder.addDefaultCase`");var o="string"==typeof e?e:e.type;if(!o)throw new Error("`builder.addCase` cannot be called with an empty action type");if(o in r)throw new Error("`builder.addCase` cannot be called with two reducers for the same action type");return r[o]=a,i},addMatcher:function(e,r){if(t)throw new Error("`builder.addMatcher` should only be called before calling `builder.addDefaultCase`");return n.push({matcher:e,reducer:r}),i},addDefaultCase:function(e){if(t)throw new Error("`builder.addDefaultCase` can only be called once");return t=e,i}};return e(i),[r,n,t]}function isStateFunction(e){return"function"==typeof e}var hasWarnedAboutObjectNotation=!1;function createReducer(e,t,r,n){void 0===r&&(r=[]),"object"==typeof t&&(hasWarnedAboutObjectNotation||(hasWarnedAboutObjectNotation=!0,console.warn("The object notation for `createReducer` is deprecated, and will be removed in RTK 2.0. Please use the 'builder callback' notation instead: https://redux-toolkit.js.org/api/createReducer")));var i,a="function"==typeof t?executeReducerBuilderCallback(t):[t,r,n],o=a[0],u=a[1],c=a[2];if(isStateFunction(e))i=function(){return freezeDraftable(e())};else{var s=freezeDraftable(e);i=function(){return s}}function l(e,t){void 0===e&&(e=i());var r=__spreadArray([o[t.type]],u.filter((function(e){return(0,e.matcher)(t)})).map((function(e){return e.reducer})));return 0===r.filter((function(e){return!!e})).length&&(r=[c]),r.reduce((function(e,r){if(r){var n;if((0,import_immer3.isDraft)(e))return void 0===(n=r(e,t))?e:n;if((0,import_immer3.isDraftable)(e))return(0,import_immer3.default)(e,(function(e){return r(e,t)}));if(void 0===(n=r(e,t))){if(null===e)return e;throw Error("A case reducer on a non-draftable value must not return undefined")}return n}return e}),e)}return l.getInitialState=i,l}var hasWarnedAboutObjectNotation2=!1;function getType2(e,t){return e+"/"+t}function createSlice(e){var t=e.name;if(!t)throw new Error("`name` is a required option for createSlice");"undefined"!=typeof process&&void 0===e.initialState&&console.error("You must provide an `initialState` value that is not `undefined`. You may have misspelled `initialState`");var r,n="function"==typeof e.initialState?e.initialState:freezeDraftable(e.initialState),i=e.reducers||{},a=Object.keys(i),o={},u={},c={};function s(){"object"==typeof e.extraReducers&&(hasWarnedAboutObjectNotation2||(hasWarnedAboutObjectNotation2=!0,console.warn("The object notation for `createSlice.extraReducers` is deprecated, and will be removed in RTK 2.0. Please use the 'builder callback' notation instead: https://redux-toolkit.js.org/api/createSlice")));var t="function"==typeof e.extraReducers?executeReducerBuilderCallback(e.extraReducers):[e.extraReducers],r=t[0],i=void 0===r?{}:r,a=t[1],o=void 0===a?[]:a,c=t[2],s=void 0===c?void 0:c,l=__spreadValues(__spreadValues({},i),u);return createReducer(n,(function(e){for(var t in l)e.addCase(t,l[t]);for(var r=0,n=o;r<n.length;r++){var i=n[r];e.addMatcher(i.matcher,i.reducer)}s&&e.addDefaultCase(s)}))}return a.forEach((function(e){var r,n,a=i[e],s=getType2(t,e);"reducer"in a?(r=a.reducer,n=a.prepare):r=a,o[e]=r,u[s]=r,c[e]=n?createAction(s,n):createAction(s)})),{name:t,reducer:function(e,t){return r||(r=s()),r(e,t)},actions:c,caseReducers:o,getInitialState:function(){return r||(r=s()),r.getInitialState()}}}function getInitialEntityState(){return{ids:[],entities:{}}}function createInitialStateFactory(){return{getInitialState:function(e){return void 0===e&&(e={}),Object.assign(getInitialEntityState(),e)}}}function createSelectorsFactory(){return{getSelectors:function(e){var t=function(e){return e.ids},r=function(e){return e.entities},n=createDraftSafeSelector(t,r,(function(e,t){return e.map((function(e){return t[e]}))})),i=function(e,t){return t},a=function(e,t){return e[t]},o=createDraftSafeSelector(t,(function(e){return e.length}));if(!e)return{selectIds:t,selectEntities:r,selectAll:n,selectTotal:o,selectById:createDraftSafeSelector(r,i,a)};var u=createDraftSafeSelector(e,r);return{selectIds:createDraftSafeSelector(e,t),selectEntities:u,selectAll:createDraftSafeSelector(e,n),selectTotal:createDraftSafeSelector(e,o),selectById:createDraftSafeSelector(u,i,a)}}}}var import_immer4=__toModule(require("immer"));function createSingleArgumentStateOperator(e){var t=createStateOperator((function(t,r){return e(r)}));return function(e){return t(e,void 0)}}function createStateOperator(e){return function(t,r){var n=function(t){isFSA(r)?e(r.payload,t):e(r,t)};return(0,import_immer4.isDraft)(t)?(n(t),t):(0,import_immer4.default)(t,n)}}function selectIdValue(e,t){var r=t(e);return void 0===r&&console.warn("The entity passed to the `selectId` implementation returned undefined.","You should probably provide your own `selectId` implementation.","The entity that was passed:",e,"The `selectId` implementation:",t.toString()),r}function ensureEntitiesArray(e){return Array.isArray(e)||(e=Object.values(e)),e}function splitAddedUpdatedEntities(e,t,r){for(var n=[],i=[],a=0,o=e=ensureEntitiesArray(e);a<o.length;a++){var u=o[a],c=selectIdValue(u,t);c in r.entities?i.push({id:c,changes:u}):n.push(u)}return[n,i]}function createUnsortedStateAdapter(e){function t(t,r){var n=selectIdValue(t,e);n in r.entities||(r.ids.push(n),r.entities[n]=t)}function r(e,r){for(var n=0,i=e=ensureEntitiesArray(e);n<i.length;n++){t(i[n],r)}}function n(t,r){var n=selectIdValue(t,e);n in r.entities||r.ids.push(n),r.entities[n]=t}function i(e,t){var r=!1;e.forEach((function(e){e in t.entities&&(delete t.entities[e],r=!0)})),r&&(t.ids=t.ids.filter((function(e){return e in t.entities})))}function a(t,r){var n={},i={};if(t.forEach((function(e){e.id in r.entities&&(i[e.id]={id:e.id,changes:__spreadValues(__spreadValues({},i[e.id]?i[e.id].changes:null),e.changes)})})),(t=Object.values(i)).length>0){var a=t.filter((function(t){return function(t,r,n){var i=n.entities[r.id],a=Object.assign({},i,r.changes),o=selectIdValue(a,e),u=o!==r.id;return u&&(t[r.id]=o,delete n.entities[r.id]),n.entities[o]=a,u}(n,t,r)})).length>0;a&&(r.ids=Object.keys(r.entities))}}function o(t,n){var i=splitAddedUpdatedEntities(t,e,n),o=i[0];a(i[1],n),r(o,n)}return{removeAll:createSingleArgumentStateOperator((function(e){Object.assign(e,{ids:[],entities:{}})})),addOne:createStateOperator(t),addMany:createStateOperator(r),setOne:createStateOperator(n),setMany:createStateOperator((function(e,t){for(var r=0,i=e=ensureEntitiesArray(e);r<i.length;r++){n(i[r],t)}})),setAll:createStateOperator((function(e,t){e=ensureEntitiesArray(e),t.ids=[],t.entities={},r(e,t)})),updateOne:createStateOperator((function(e,t){return a([e],t)})),updateMany:createStateOperator(a),upsertOne:createStateOperator((function(e,t){return o([e],t)})),upsertMany:createStateOperator(o),removeOne:createStateOperator((function(e,t){return i([e],t)})),removeMany:createStateOperator(i)}}function createSortedStateAdapter(e,t){var r=createUnsortedStateAdapter(e);function n(t,r){var n=(t=ensureEntitiesArray(t)).filter((function(t){return!(selectIdValue(t,e)in r.entities)}));0!==n.length&&u(n,r)}function i(e,t){0!==(e=ensureEntitiesArray(e)).length&&u(e,t)}function a(t,r){for(var n=!1,i=0,a=t;i<a.length;i++){var o=a[i],u=r.entities[o.id];if(u){n=!0,Object.assign(u,o.changes);var s=e(u);o.id!==s&&(delete r.entities[o.id],r.entities[s]=u)}}n&&c(r)}function o(t,r){var i=splitAddedUpdatedEntities(t,e,r),o=i[0];a(i[1],r),n(o,r)}function u(t,r){t.forEach((function(t){r.entities[e(t)]=t})),c(r)}function c(r){var n=Object.values(r.entities);n.sort(t);var i=n.map(e);(function(e,t){if(e.length!==t.length)return!1;for(var r=0;r<e.length&&r<t.length;r++)if(e[r]!==t[r])return!1;return!0})(r.ids,i)||(r.ids=i)}return{removeOne:r.removeOne,removeMany:r.removeMany,removeAll:r.removeAll,addOne:createStateOperator((function(e,t){return n([e],t)})),updateOne:createStateOperator((function(e,t){return a([e],t)})),upsertOne:createStateOperator((function(e,t){return o([e],t)})),setOne:createStateOperator((function(e,t){return i([e],t)})),setMany:createStateOperator(i),setAll:createStateOperator((function(e,t){e=ensureEntitiesArray(e),t.entities={},t.ids=[],n(e,t)})),addMany:createStateOperator(n),updateMany:createStateOperator(a),upsertMany:createStateOperator(o)}}function createEntityAdapter(e){void 0===e&&(e={});var t=__spreadValues({sortComparer:!1,selectId:function(e){return e.id}},e),r=t.selectId,n=t.sortComparer,i=createInitialStateFactory(),a=createSelectorsFactory(),o=n?createSortedStateAdapter(r,n):createUnsortedStateAdapter(r);return __spreadValues(__spreadValues(__spreadValues({selectId:r,sortComparer:n},i),a),o)}var urlAlphabet="ModuleSymbhasOwnPr-0123456789ABCDEFGHNRVfgctiUvz_KqYTJkLxpZXIjQW",nanoid=function(e){void 0===e&&(e=21);for(var t="",r=e;r--;)t+=urlAlphabet[64*Math.random()|0];return t},commonProperties=["name","message","stack","code"],RejectWithValue=function(e,t){this.payload=e,this.meta=t},FulfillWithMeta=function(e,t){this.payload=e,this.meta=t},miniSerializeError=function(e){if("object"==typeof e&&null!==e){for(var t={},r=0,n=commonProperties;r<n.length;r++){var i=n[r];"string"==typeof e[i]&&(t[i]=e[i])}return t}return{message:String(e)}},createAsyncThunk=function(){function e(e,t,r){var n=createAction(e+"/fulfilled",(function(e,t,r,n){return{payload:e,meta:__spreadProps(__spreadValues({},n||{}),{arg:r,requestId:t,requestStatus:"fulfilled"})}})),i=createAction(e+"/pending",(function(e,t,r){return{payload:void 0,meta:__spreadProps(__spreadValues({},r||{}),{arg:t,requestId:e,requestStatus:"pending"})}})),a=createAction(e+"/rejected",(function(e,t,n,i,a){return{payload:i,error:(r&&r.serializeError||miniSerializeError)(e||"Rejected"),meta:__spreadProps(__spreadValues({},a||{}),{arg:n,requestId:t,rejectedWithValue:!!i,requestStatus:"rejected",aborted:"AbortError"===(null==e?void 0:e.name),condition:"ConditionError"===(null==e?void 0:e.name)})}})),o=!1,u="undefined"!=typeof AbortController?AbortController:function(){function e(){this.signal={aborted:!1,addEventListener:function(){},dispatchEvent:function(){return!1},onabort:function(){},removeEventListener:function(){},reason:void 0,throwIfAborted:function(){}}}return e.prototype.abort=function(){o||(o=!0,console.info("This platform does not implement AbortController. \nIf you want to use the AbortController to react to `abort` events, please consider importing a polyfill like 'abortcontroller-polyfill/dist/abortcontroller-polyfill-only'."))},e}();return Object.assign((function(e){return function(o,c,s){var l,d=(null==r?void 0:r.idGenerator)?r.idGenerator(e):nanoid(),f=new u;function p(e){l=e,f.abort()}var h=function(){return __async(this,null,(function(){var u,h,v,y,m,b;return __generator(this,(function(g){switch(g.label){case 0:return g.trys.push([0,4,,5]),isThenable(y=null==(u=null==r?void 0:r.condition)?void 0:u.call(r,e,{getState:c,extra:s}))?[4,y]:[3,2];case 1:y=g.sent(),g.label=2;case 2:if(!1===y||f.signal.aborted)throw{name:"ConditionError",message:"Aborted due to condition callback returning false."};return!0,m=new Promise((function(e,t){return f.signal.addEventListener("abort",(function(){return t({name:"AbortError",message:l||"Aborted"})}))})),o(i(d,e,null==(h=null==r?void 0:r.getPendingMeta)?void 0:h.call(r,{requestId:d,arg:e},{getState:c,extra:s}))),[4,Promise.race([m,Promise.resolve(t(e,{dispatch:o,getState:c,extra:s,requestId:d,signal:f.signal,abort:p,rejectWithValue:function(e,t){return new RejectWithValue(e,t)},fulfillWithValue:function(e,t){return new FulfillWithMeta(e,t)}})).then((function(t){if(t instanceof RejectWithValue)throw t;return t instanceof FulfillWithMeta?n(t.payload,d,e,t.meta):n(t,d,e)}))])];case 3:return v=g.sent(),[3,5];case 4:return b=g.sent(),v=b instanceof RejectWithValue?a(null,d,e,b.payload,b.meta):a(b,d,e),[3,5];case 5:return r&&!r.dispatchConditionRejection&&a.match(v)&&v.meta.condition||o(v),[2,v]}}))}))}();return Object.assign(h,{abort:p,requestId:d,arg:e,unwrap:function(){return h.then(unwrapResult)}})}}),{pending:i,rejected:a,fulfilled:n,typePrefix:e})}return e.withTypes=function(){return e},e}();function unwrapResult(e){if(e.meta&&e.meta.rejectedWithValue)throw e.payload;if(e.error)throw e.error;return e.payload}function isThenable(e){return null!==e&&"object"==typeof e&&"function"==typeof e.then}var matches=function(e,t){return hasMatchFunction(e)?e.match(t):e(t)};function isAnyOf(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return function(t){return e.some((function(e){return matches(e,t)}))}}function isAllOf(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return function(t){return e.every((function(e){return matches(e,t)}))}}function hasExpectedRequestMetadata(e,t){if(!e||!e.meta)return!1;var r="string"==typeof e.meta.requestId,n=t.indexOf(e.meta.requestStatus)>-1;return r&&n}function isAsyncThunkArray(e){return"function"==typeof e[0]&&"pending"in e[0]&&"fulfilled"in e[0]&&"rejected"in e[0]}function isPending(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return 0===e.length?function(e){return hasExpectedRequestMetadata(e,["pending"])}:isAsyncThunkArray(e)?function(t){var r=e.map((function(e){return e.pending}));return isAnyOf.apply(void 0,r)(t)}:isPending()(e[0])}function isRejected(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return 0===e.length?function(e){return hasExpectedRequestMetadata(e,["rejected"])}:isAsyncThunkArray(e)?function(t){var r=e.map((function(e){return e.rejected}));return isAnyOf.apply(void 0,r)(t)}:isRejected()(e[0])}function isRejectedWithValue(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];var r=function(e){return e&&e.meta&&e.meta.rejectedWithValue};return 0===e.length||isAsyncThunkArray(e)?function(t){return isAllOf(isRejected.apply(void 0,e),r)(t)}:isRejectedWithValue()(e[0])}function isFulfilled(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return 0===e.length?function(e){return hasExpectedRequestMetadata(e,["fulfilled"])}:isAsyncThunkArray(e)?function(t){var r=e.map((function(e){return e.fulfilled}));return isAnyOf.apply(void 0,r)(t)}:isFulfilled()(e[0])}function isAsyncThunkAction(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return 0===e.length?function(e){return hasExpectedRequestMetadata(e,["pending","fulfilled","rejected"])}:isAsyncThunkArray(e)?function(t){for(var r=[],n=0,i=e;n<i.length;n++){var a=i[n];r.push(a.pending,a.rejected,a.fulfilled)}return isAnyOf.apply(void 0,r)(t)}:isAsyncThunkAction()(e[0])}var assertFunction=function(e,t){if("function"!=typeof e)throw new TypeError(t+" is not a function")},noop=function(){},catchRejection=function(e,t){return void 0===t&&(t=noop),e.catch(t),e},addAbortSignalListener=function(e,t){return e.addEventListener("abort",t,{once:!0}),function(){return e.removeEventListener("abort",t)}},abortControllerWithReason=function(e,t){var r=e.signal;r.aborted||("reason"in r||Object.defineProperty(r,"reason",{enumerable:!0,value:t,configurable:!0,writable:!0}),e.abort(t))},task="task",listener="listener",completed="completed",cancelled="cancelled",taskCancelled="task-"+cancelled,taskCompleted="task-"+completed,listenerCancelled=listener+"-"+cancelled,listenerCompleted=listener+"-"+completed,TaskAbortError=function(e){this.code=e,this.name="TaskAbortError",this.message=task+" "+cancelled+" (reason: "+e+")"},validateActive=function(e){if(e.aborted)throw new TaskAbortError(e.reason)};function raceWithSignal(e,t){var r=noop;return new Promise((function(n,i){var a=function(){return i(new TaskAbortError(e.reason))};e.aborted?a():(r=addAbortSignalListener(e,a),t.finally((function(){return r()})).then(n,i))})).finally((function(){r=noop}))}var runTask=function(e,t){return __async(void 0,null,(function(){var r;return __generator(this,(function(n){switch(n.label){case 0:return n.trys.push([0,3,4,5]),[4,Promise.resolve()];case 1:return n.sent(),[4,e()];case 2:return[2,{status:"ok",value:n.sent()}];case 3:return[2,{status:(r=n.sent())instanceof TaskAbortError?"cancelled":"rejected",error:r}];case 4:return null==t||t(),[7];case 5:return[2]}}))}))},createPause=function(e){return function(t){return catchRejection(raceWithSignal(e,t).then((function(t){return validateActive(e),t})))}},createDelay=function(e){var t=createPause(e);return function(e){return t(new Promise((function(t){return setTimeout(t,e)})))}},assign=Object.assign,INTERNAL_NIL_TOKEN={},alm="listenerMiddleware",createFork=function(e,t){return function(r,n){assertFunction(r,"taskExecutor");var i,a=new AbortController;i=a,addAbortSignalListener(e,(function(){return abortControllerWithReason(i,e.reason)}));var o=runTask((function(){return __async(void 0,null,(function(){var t;return __generator(this,(function(n){switch(n.label){case 0:return validateActive(e),validateActive(a.signal),[4,r({pause:createPause(a.signal),delay:createDelay(a.signal),signal:a.signal})];case 1:return t=n.sent(),validateActive(a.signal),[2,t]}}))}))}),(function(){return abortControllerWithReason(a,taskCompleted)}));return(null==n?void 0:n.autoJoin)&&t.push(o),{result:createPause(e)(o),cancel:function(){abortControllerWithReason(a,taskCancelled)}}}},createTakePattern=function(e,t){return function(r,n){return catchRejection(function(r,n){return __async(void 0,null,(function(){var i,a,o,u;return __generator(this,(function(c){switch(c.label){case 0:validateActive(t),i=function(){},a=new Promise((function(t,n){var a=e({predicate:r,effect:function(e,r){r.unsubscribe(),t([e,r.getState(),r.getOriginalState()])}});i=function(){a(),n()}})),o=[a],null!=n&&o.push(new Promise((function(e){return setTimeout(e,n,null)}))),c.label=1;case 1:return c.trys.push([1,,3,4]),[4,raceWithSignal(t,Promise.race(o))];case 2:return u=c.sent(),validateActive(t),[2,u];case 3:return i(),[7];case 4:return[2]}}))}))}(r,n))}},getListenerEntryPropsFrom=function(e){var t=e.type,r=e.actionCreator,n=e.matcher,i=e.predicate,a=e.effect;if(t)i=createAction(t).match;else if(r)t=r.type,i=r.match;else if(n)i=n;else if(!i)throw new Error("Creating or removing a listener requires one of the known fields for matching an action");return assertFunction(a,"options.listener"),{predicate:i,type:t,effect:a}},createListenerEntry=function(e){var t=getListenerEntryPropsFrom(e),r=t.type,n=t.predicate,i=t.effect;return{id:nanoid(),effect:i,type:r,predicate:n,pending:new Set,unsubscribe:function(){throw new Error("Unsubscribe not initialized")}}},cancelActiveListeners=function(e){e.pending.forEach((function(e){abortControllerWithReason(e,listenerCancelled)}))},createClearListenerMiddleware=function(e){return function(){e.forEach(cancelActiveListeners),e.clear()}},safelyNotifyError=function(e,t,r){try{e(t,r)}catch(e){setTimeout((function(){throw e}),0)}},addListener=createAction(alm+"/add"),clearAllListeners=createAction(alm+"/removeAll"),removeListener=createAction(alm+"/remove"),defaultErrorHandler=function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];console.error.apply(console,__spreadArray([alm+"/error"],e))};function createListenerMiddleware(e){var t=this;void 0===e&&(e={});var r=new Map,n=e.extra,i=e.onError,a=void 0===i?defaultErrorHandler:i;assertFunction(a,"onError");var o=function(e){for(var t=0,n=Array.from(r.values());t<n.length;t++){var i=n[t];if(e(i))return i}},u=function(e){var t=o((function(t){return t.effect===e.effect}));return t||(t=createListenerEntry(e)),function(e){return e.unsubscribe=function(){return r.delete(e.id)},r.set(e.id,e),function(t){e.unsubscribe(),(null==t?void 0:t.cancelActive)&&cancelActiveListeners(e)}}(t)},c=function(e){var t=getListenerEntryPropsFrom(e),r=t.type,n=t.effect,i=t.predicate,a=o((function(e){return("string"==typeof r?e.type===r:e.predicate===i)&&e.effect===n}));return a&&(a.unsubscribe(),e.cancelActive&&cancelActiveListeners(a)),!!a},s=function(e,i,o,c){return __async(t,null,(function(){var t,s,l,d;return __generator(this,(function(f){switch(f.label){case 0:t=new AbortController,s=createTakePattern(u,t.signal),l=[],f.label=1;case 1:return f.trys.push([1,3,4,6]),e.pending.add(t),[4,Promise.resolve(e.effect(i,assign({},o,{getOriginalState:c,condition:function(e,t){return s(e,t).then(Boolean)},take:s,delay:createDelay(t.signal),pause:createPause(t.signal),extra:n,signal:t.signal,fork:createFork(t.signal,l),unsubscribe:e.unsubscribe,subscribe:function(){r.set(e.id,e)},cancelActiveListeners:function(){e.pending.forEach((function(e,r,n){e!==t&&(abortControllerWithReason(e,listenerCancelled),n.delete(e))}))}})))];case 2:return f.sent(),[3,6];case 3:return(d=f.sent())instanceof TaskAbortError||safelyNotifyError(a,d,{raisedBy:"effect"}),[3,6];case 4:return[4,Promise.allSettled(l)];case 5:return f.sent(),abortControllerWithReason(t,listenerCompleted),e.pending.delete(t),[7];case 6:return[2]}}))}))},l=createClearListenerMiddleware(r);return{middleware:function(e){return function(t){return function(n){if(!isAction(n))return t(n);if(addListener.match(n))return u(n.payload);if(!clearAllListeners.match(n)){if(removeListener.match(n))return c(n.payload);var i,o=e.getState(),d=function(){if(o===INTERNAL_NIL_TOKEN)throw new Error(alm+": getOriginalState can only be called synchronously");return o};try{if(i=t(n),r.size>0)for(var f=e.getState(),p=Array.from(r.values()),h=0,v=p;h<v.length;h++){var y=v[h],m=!1;try{m=y.predicate(n,f,o)}catch(e){m=!1,safelyNotifyError(a,e,{raisedBy:"predicate"})}m&&s(y,n,e,d)}}finally{o=INTERNAL_NIL_TOKEN}return i}l()}}},startListening:u,stopListening:c,clearListeners:l}}var promise,SHOULD_AUTOBATCH="RTK_autoBatch",prepareAutoBatched=function(){return function(e){var t;return{payload:e,meta:(t={},t[SHOULD_AUTOBATCH]=!0,t)}}},queueMicrotaskShim="function"==typeof queueMicrotask?queueMicrotask.bind("undefined"!=typeof window?window:"undefined"!=typeof global?global:globalThis):function(e){return(promise||(promise=Promise.resolve())).then(e).catch((function(e){return setTimeout((function(){throw e}),0)}))},createQueueWithTimer=function(e){return function(t){setTimeout(t,e)}},rAF="undefined"!=typeof window&&window.requestAnimationFrame?window.requestAnimationFrame:createQueueWithTimer(10),autoBatchEnhancer=function(e){return void 0===e&&(e={type:"raf"}),function(t){return function(){for(var r=[],n=0;n<arguments.length;n++)r[n]=arguments[n];var i=t.apply(void 0,r),a=!0,o=!1,u=!1,c=new Set,s="tick"===e.type?queueMicrotaskShim:"raf"===e.type?rAF:"callback"===e.type?e.queueNotification:createQueueWithTimer(e.timeout),l=function(){u=!1,o&&(o=!1,c.forEach((function(e){return e()})))};return Object.assign({},i,{subscribe:function(e){var t=i.subscribe((function(){return a&&e()}));return c.add(e),function(){t(),c.delete(e)}},dispatch:function(e){var t;try{return a=!(null==(t=null==e?void 0:e.meta)?void 0:t[SHOULD_AUTOBATCH]),(o=!a)&&(u||(u=!0,s(l))),i.dispatch(e)}finally{a=!0}}})}}};(0,import_immer5.enableES5)();

}).call(this)}).call(this,require('_process'),typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})
},{"_process":103,"immer":89,"redux":165,"redux-thunk":164,"reselect":168}],19:[function(require,module,exports){
(function (global){(function (){
var e,n=this&&this.__extends||(e=function(n,t){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,n){e.__proto__=n}||function(e,n){for(var t in n)Object.prototype.hasOwnProperty.call(n,t)&&(e[t]=n[t])},e(n,t)},function(n,t){if("function"!=typeof t&&null!==t)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");function r(){this.constructor=n}e(n,t),n.prototype=null===t?Object.create(t):(r.prototype=t.prototype,new r)}),t=this&&this.__generator||function(e,n){var t,r,i,o,u={label:0,sent:function(){if(1&i[0])throw i[1];return i[1]},trys:[],ops:[]};return o={next:a(0),throw:a(1),return:a(2)},"function"==typeof Symbol&&(o[Symbol.iterator]=function(){return this}),o;function a(o){return function(a){return function(o){if(t)throw new TypeError("Generator is already executing.");for(;u;)try{if(t=1,r&&(i=2&o[0]?r.return:o[0]?r.throw||((i=r.return)&&i.call(r),0):r.next)&&!(i=i.call(r,o[1])).done)return i;switch(r=0,i&&(o=[2&o[0],i.value]),o[0]){case 0:case 1:i=o;break;case 4:return u.label++,{value:o[1],done:!1};case 5:u.label++,r=o[1],o=[0];continue;case 7:o=u.ops.pop(),u.trys.pop();continue;default:if(!((i=(i=u.trys).length>0&&i[i.length-1])||6!==o[0]&&2!==o[0])){u=0;continue}if(3===o[0]&&(!i||o[1]>i[0]&&o[1]<i[3])){u.label=o[1];break}if(6===o[0]&&u.label<i[1]){u.label=i[1],i=o;break}if(i&&u.label<i[2]){u.label=i[2],u.ops.push(o);break}i[2]&&u.ops.pop(),u.trys.pop();continue}o=n.call(e,u)}catch(e){o=[6,e],r=0}finally{t=i=0}if(5&o[0])throw o[1];return{value:o[0]?o[1]:void 0,done:!0}}([o,a])}}},r=this&&this.__spreadArray||function(e,n){for(var t=0,r=n.length,i=e.length;t<r;t++,i++)e[i]=n[t];return e},i=Object.create,o=Object.defineProperty,u=Object.defineProperties,a=Object.getOwnPropertyDescriptor,c=Object.getOwnPropertyDescriptors,f=Object.getOwnPropertyNames,l=Object.getOwnPropertySymbols,s=Object.getPrototypeOf,d=Object.prototype.hasOwnProperty,p=Object.prototype.propertyIsEnumerable,v=function(e,n,t){return n in e?o(e,n,{enumerable:!0,configurable:!0,writable:!0,value:t}):e[n]=t},y=function(e,n){for(var t in n||(n={}))d.call(n,t)&&v(e,t,n[t]);if(l)for(var r=0,i=l(n);r<i.length;r++)p.call(n,t=i[r])&&v(e,t,n[t]);return e},h=function(e,n){return u(e,c(n))},g=function(e){return o(e,"__esModule",{value:!0})},b=function(e,n,t){if(n&&"object"==typeof n||"function"==typeof n)for(var r=function(r){d.call(e,r)||"default"===r||o(e,r,{get:function(){return n[r]},enumerable:!(t=a(n,r))||t.enumerable})},i=0,u=f(n);i<u.length;i++)r(u[i]);return e},m=function(e){return b(g(o(null!=e?i(s(e)):{},"default",e&&e.__esModule&&"default"in e?{get:function(){return e.default},enumerable:!0}:{value:e,enumerable:!0})),e)},w=function(e,n,t){return new Promise((function(r,i){var o=function(e){try{a(t.next(e))}catch(e){i(e)}},u=function(e){try{a(t.throw(e))}catch(e){i(e)}},a=function(e){return e.done?r(e.value):Promise.resolve(e.value).then(o,u)};a((t=t.apply(e,n)).next())}))};g(exports),function(e,n){for(var t in n)o(e,t,{get:n[t],enumerable:!0})}(exports,{EnhancerArray:function(){return F},MiddlewareArray:function(){return B},SHOULD_AUTOBATCH:function(){return Je},TaskAbortError:function(){return ke},addListener:function(){return Fe},autoBatchEnhancer:function(){return $e},clearAllListeners:function(){return Ue},configureStore:function(){return Y},createAction:function(){return T},createActionCreatorInvariantMiddleware:function(){return N},createAsyncThunk:function(){return ve},createDraftSafeSelector:function(){return P},createEntityAdapter:function(){return ce},createImmutableStateInvariantMiddleware:function(){return X},createListenerMiddleware:function(){return Ge},createNextState:function(){return j.default},createReducer:function(){return ee},createSelector:function(){return A.createSelector},createSerializableStateInvariantMiddleware:function(){return K},createSlice:function(){return ne},current:function(){return j.current},findNonSerializableValue:function(){return H},freeze:function(){return j.freeze},getDefaultMiddleware:function(){return Q},getType:function(){return z},isAction:function(){return C},isActionCreator:function(){return D},isAllOf:function(){return be},isAnyOf:function(){return ge},isAsyncThunkAction:function(){return Se},isDraft:function(){return j.isDraft},isFluxStandardAction:function(){return L},isFulfilled:function(){return Ee},isImmutableDefault:function(){return W},isPending:function(){return Oe},isPlain:function(){return G},isPlainObject:function(){return M},isRejected:function(){return je},isRejectedWithValue:function(){return Ae},miniSerializeError:function(){return pe},nanoid:function(){return fe},original:function(){return j.original},prepareAutoBatched:function(){return Ke},removeListener:function(){return We},unwrapResult:function(){return ye}});var O=m(require("immer"));b(exports,m(require("redux")));var j=m(require("immer")),A=m(require("reselect")),E=m(require("immer")),S=m(require("reselect")),P=function(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];var t=S.createSelector.apply(void 0,e);return function(e){for(var n=[],i=1;i<arguments.length;i++)n[i-1]=arguments[i];return t.apply(void 0,r([(0,E.isDraft)(e)?(0,E.current)(e):e],n))}},_=m(require("redux")),q=m(require("redux")),x="undefined"!=typeof window&&window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__?window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__:function(){if(0!==arguments.length)return"object"==typeof arguments[0]?q.compose:q.compose.apply(null,arguments)};function M(e){if("object"!=typeof e||null===e)return!1;var n=Object.getPrototypeOf(e);if(null===n)return!0;for(var t=n;null!==Object.getPrototypeOf(t);)t=Object.getPrototypeOf(t);return n===t}"undefined"!=typeof window&&window.__REDUX_DEVTOOLS_EXTENSION__&&window;var k=m(require("redux-thunk")),I=function(e){return e&&"function"==typeof e.match};function T(e,n){function t(){for(var t=[],r=0;r<arguments.length;r++)t[r]=arguments[r];if(n){var i=n.apply(void 0,t);if(!i)throw new Error("prepareAction did not return an object");return y(y({type:e,payload:i.payload},"meta"in i&&{meta:i.meta}),"error"in i&&{error:i.error})}return{type:e,payload:t[0]}}return t.toString=function(){return""+e},t.type=e,t.match=function(n){return n.type===e},t}function C(e){return M(e)&&"type"in e}function D(e){return"function"==typeof e&&"type"in e&&I(e)}function L(e){return C(e)&&"string"==typeof e.type&&Object.keys(e).every(R)}function R(e){return["type","payload","error","meta"].indexOf(e)>-1}function z(e){return""+e}function N(e){return void 0===e&&(e={}),function(){return function(e){return function(n){return e(n)}}}}var V=m(require("immer")),B=function(e){function t(){for(var n=[],r=0;r<arguments.length;r++)n[r]=arguments[r];var i=e.apply(this,n)||this;return Object.setPrototypeOf(i,t.prototype),i}return n(t,e),Object.defineProperty(t,Symbol.species,{get:function(){return t},enumerable:!1,configurable:!0}),t.prototype.concat=function(){for(var n=[],t=0;t<arguments.length;t++)n[t]=arguments[t];return e.prototype.concat.apply(this,n)},t.prototype.prepend=function(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];return 1===e.length&&Array.isArray(e[0])?new(t.bind.apply(t,r([void 0],e[0].concat(this)))):new(t.bind.apply(t,r([void 0],e.concat(this))))},t}(Array),F=function(e){function t(){for(var n=[],r=0;r<arguments.length;r++)n[r]=arguments[r];var i=e.apply(this,n)||this;return Object.setPrototypeOf(i,t.prototype),i}return n(t,e),Object.defineProperty(t,Symbol.species,{get:function(){return t},enumerable:!1,configurable:!0}),t.prototype.concat=function(){for(var n=[],t=0;t<arguments.length;t++)n[t]=arguments[t];return e.prototype.concat.apply(this,n)},t.prototype.prepend=function(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];return 1===e.length&&Array.isArray(e[0])?new(t.bind.apply(t,r([void 0],e[0].concat(this)))):new(t.bind.apply(t,r([void 0],e.concat(this))))},t}(Array);function U(e){return(0,V.isDraftable)(e)?(0,V.default)(e,(function(){})):e}function W(e){return"object"!=typeof e||null==e||Object.isFrozen(e)}function X(e){return void 0===e&&(e={}),function(){return function(e){return function(n){return e(n)}}}}function G(e){var n=typeof e;return null==e||"string"===n||"boolean"===n||"number"===n||Array.isArray(e)||M(e)}function H(e,n,t,r,i,o){var u;if(void 0===n&&(n=""),void 0===t&&(t=G),void 0===i&&(i=[]),!t(e))return{keyPath:n||"<root>",value:e};if("object"!=typeof e||null===e)return!1;if(null==o?void 0:o.has(e))return!1;for(var a=null!=r?r(e):Object.entries(e),c=i.length>0,f=function(e,a){var f=n?n+"."+e:e;return c&&i.some((function(e){return e instanceof RegExp?e.test(f):f===e}))?"continue":t(a)?"object"==typeof a&&(u=H(a,f,t,r,i,o))?{value:u}:void 0:{value:{keyPath:f,value:a}}},l=0,s=a;l<s.length;l++){var d=s[l],p=f(d[0],d[1]);if("object"==typeof p)return p.value}return o&&J(e)&&o.add(e),!1}function J(e){if(!Object.isFrozen(e))return!1;for(var n=0,t=Object.values(e);n<t.length;n++){var r=t[n];if("object"==typeof r&&null!==r&&!J(r))return!1}return!0}function K(e){return void 0===e&&(e={}),function(){return function(e){return function(n){return e(n)}}}}function Q(e){void 0===e&&(e={});var n=e.thunk,t=void 0===n||n,r=new B;return t&&r.push("boolean"==typeof t?k.default:k.default.withExtraArgument(t.extraArgument)),r}function Y(e){var n,t=function(e){return Q(e)},i=e||{},o=i.reducer,u=void 0===o?void 0:o,a=i.middleware,c=void 0===a?t():a,f=i.devTools,l=void 0===f||f,s=i.preloadedState,d=void 0===s?void 0:s,p=i.enhancers,v=void 0===p?void 0:p;if("function"==typeof u)n=u;else{if(!M(u))throw new Error('"reducer" is a required argument, and must be a function or an object of functions that can be passed to combineReducers');n=(0,_.combineReducers)(u)}var h=c;"function"==typeof h&&(h=h(t));var g=_.applyMiddleware.apply(void 0,h),b=_.compose;l&&(b=x(y({trace:!1},"object"==typeof l&&l)));var m=new F(g),w=m;Array.isArray(v)?w=r([g],v):"function"==typeof v&&(w=v(m));var O=b.apply(void 0,w);return(0,_.createStore)(n,d,O)}var Z=m(require("immer"));function $(e){var n,t={},r=[],i={addCase:function(e,n){var r="string"==typeof e?e:e.type;if(!r)throw new Error("`builder.addCase` cannot be called with an empty action type");if(r in t)throw new Error("`builder.addCase` cannot be called with two reducers for the same action type");return t[r]=n,i},addMatcher:function(e,n){return r.push({matcher:e,reducer:n}),i},addDefaultCase:function(e){return n=e,i}};return e(i),[t,r,n]}function ee(e,n,t,i){void 0===t&&(t=[]);var o,u="function"==typeof n?$(n):[n,t,i],a=u[0],c=u[1],f=u[2];if("function"==typeof e)o=function(){return U(e())};else{var l=U(e);o=function(){return l}}function s(e,n){void 0===e&&(e=o());var t=r([a[n.type]],c.filter((function(e){return(0,e.matcher)(n)})).map((function(e){return e.reducer})));return 0===t.filter((function(e){return!!e})).length&&(t=[f]),t.reduce((function(e,t){if(t){var r;if((0,Z.isDraft)(e))return void 0===(r=t(e,n))?e:r;if((0,Z.isDraftable)(e))return(0,Z.default)(e,(function(e){return t(e,n)}));if(void 0===(r=t(e,n))){if(null===e)return e;throw Error("A case reducer on a non-draftable value must not return undefined")}return r}return e}),e)}return s.getInitialState=o,s}function ne(e){var n=e.name;if(!n)throw new Error("`name` is a required option for createSlice");var t,r="function"==typeof e.initialState?e.initialState:U(e.initialState),i=e.reducers||{},o=Object.keys(i),u={},a={},c={};function f(){var n="function"==typeof e.extraReducers?$(e.extraReducers):[e.extraReducers],t=n[0],i=n[1],o=void 0===i?[]:i,u=n[2],c=void 0===u?void 0:u,f=y(y({},void 0===t?{}:t),a);return ee(r,(function(e){for(var n in f)e.addCase(n,f[n]);for(var t=0,r=o;t<r.length;t++){var i=r[t];e.addMatcher(i.matcher,i.reducer)}c&&e.addDefaultCase(c)}))}return o.forEach((function(e){var t,r,o=i[e],f=n+"/"+e;"reducer"in o?(t=o.reducer,r=o.prepare):t=o,u[e]=t,a[f]=t,c[e]=r?T(f,r):T(f)})),{name:n,reducer:function(e,n){return t||(t=f()),t(e,n)},actions:c,caseReducers:u,getInitialState:function(){return t||(t=f()),t.getInitialState()}}}var te=m(require("immer"));function re(e){return function(n,t){var r=function(n){L(t)?e(t.payload,n):e(t,n)};return(0,te.isDraft)(n)?(r(n),n):(0,te.default)(n,r)}}function ie(e,n){return n(e)}function oe(e){return Array.isArray(e)||(e=Object.values(e)),e}function ue(e,n,t){for(var r=[],i=[],o=0,u=e=oe(e);o<u.length;o++){var a=u[o],c=ie(a,n);c in t.entities?i.push({id:c,changes:a}):r.push(a)}return[r,i]}function ae(e){function n(n,t){var r=ie(n,e);r in t.entities||(t.ids.push(r),t.entities[r]=n)}function t(e,t){for(var r=0,i=e=oe(e);r<i.length;r++)n(i[r],t)}function r(n,t){var r=ie(n,e);r in t.entities||t.ids.push(r),t.entities[r]=n}function i(e,n){var t=!1;e.forEach((function(e){e in n.entities&&(delete n.entities[e],t=!0)})),t&&(n.ids=n.ids.filter((function(e){return e in n.entities})))}function o(n,t){var r={},i={};if(n.forEach((function(e){e.id in t.entities&&(i[e.id]={id:e.id,changes:y(y({},i[e.id]?i[e.id].changes:null),e.changes)})})),(n=Object.values(i)).length>0){var o=n.filter((function(n){return function(n,t,r){var i=Object.assign({},r.entities[t.id],t.changes),o=ie(i,e),u=o!==t.id;return u&&(n[t.id]=o,delete r.entities[t.id]),r.entities[o]=i,u}(r,n,t)})).length>0;o&&(t.ids=Object.keys(t.entities))}}function u(n,r){var i=ue(n,e,r),u=i[0];o(i[1],r),t(u,r)}return{removeAll:(a=function(e){Object.assign(e,{ids:[],entities:{}})},c=re((function(e,n){return a(n)})),function(e){return c(e,void 0)}),addOne:re(n),addMany:re(t),setOne:re(r),setMany:re((function(e,n){for(var t=0,i=e=oe(e);t<i.length;t++)r(i[t],n)})),setAll:re((function(e,n){e=oe(e),n.ids=[],n.entities={},t(e,n)})),updateOne:re((function(e,n){return o([e],n)})),updateMany:re(o),upsertOne:re((function(e,n){return u([e],n)})),upsertMany:re(u),removeOne:re((function(e,n){return i([e],n)})),removeMany:re(i)};var a,c}function ce(e){void 0===e&&(e={});var n=y({sortComparer:!1,selectId:function(e){return e.id}},e),t=n.selectId,r=n.sortComparer,i={getInitialState:function(e){return void 0===e&&(e={}),Object.assign({ids:[],entities:{}},e)}},o={getSelectors:function(e){var n=function(e){return e.ids},t=function(e){return e.entities},r=P(n,t,(function(e,n){return e.map((function(e){return n[e]}))})),i=function(e,n){return n},o=function(e,n){return e[n]},u=P(n,(function(e){return e.length}));if(!e)return{selectIds:n,selectEntities:t,selectAll:r,selectTotal:u,selectById:P(t,i,o)};var a=P(e,t);return{selectIds:P(e,n),selectEntities:a,selectAll:P(e,r),selectTotal:P(e,u),selectById:P(a,i,o)}}},u=r?function(e,n){var t=ae(e);function r(n,t){var r=(n=oe(n)).filter((function(n){return!(ie(n,e)in t.entities)}));0!==r.length&&a(r,t)}function i(e,n){0!==(e=oe(e)).length&&a(e,n)}function o(n,t){for(var r=!1,i=0,o=n;i<o.length;i++){var u=o[i],a=t.entities[u.id];if(a){r=!0,Object.assign(a,u.changes);var f=e(a);u.id!==f&&(delete t.entities[u.id],t.entities[f]=a)}}r&&c(t)}function u(n,t){var i=ue(n,e,t),u=i[0];o(i[1],t),r(u,t)}function a(n,t){n.forEach((function(n){t.entities[e(n)]=n})),c(t)}function c(t){var r=Object.values(t.entities);r.sort(n);var i=r.map(e);(function(e,n){if(e.length!==n.length)return!1;for(var t=0;t<e.length&&t<n.length;t++)if(e[t]!==n[t])return!1;return!0})(t.ids,i)||(t.ids=i)}return{removeOne:t.removeOne,removeMany:t.removeMany,removeAll:t.removeAll,addOne:re((function(e,n){return r([e],n)})),updateOne:re((function(e,n){return o([e],n)})),upsertOne:re((function(e,n){return u([e],n)})),setOne:re((function(e,n){return i([e],n)})),setMany:re(i),setAll:re((function(e,n){e=oe(e),n.entities={},n.ids=[],r(e,n)})),addMany:re(r),updateMany:re(o),upsertMany:re(u)}}(t,r):ae(t);return y(y(y({selectId:t,sortComparer:r},i),o),u)}var fe=function(e){void 0===e&&(e=21);for(var n="",t=e;t--;)n+="ModuleSymbhasOwnPr-0123456789ABCDEFGHNRVfgctiUvz_KqYTJkLxpZXIjQW"[64*Math.random()|0];return n},le=["name","message","stack","code"],se=function(e,n){this.payload=e,this.meta=n},de=function(e,n){this.payload=e,this.meta=n},pe=function(e){if("object"==typeof e&&null!==e){for(var n={},t=0,r=le;t<r.length;t++){var i=r[t];"string"==typeof e[i]&&(n[i]=e[i])}return n}return{message:String(e)}},ve=function(){function e(e,n,r){var i=T(e+"/fulfilled",(function(e,n,t,r){return{payload:e,meta:h(y({},r||{}),{arg:t,requestId:n,requestStatus:"fulfilled"})}})),o=T(e+"/pending",(function(e,n,t){return{payload:void 0,meta:h(y({},t||{}),{arg:n,requestId:e,requestStatus:"pending"})}})),u=T(e+"/rejected",(function(e,n,t,i,o){return{payload:i,error:(r&&r.serializeError||pe)(e||"Rejected"),meta:h(y({},o||{}),{arg:t,requestId:n,rejectedWithValue:!!i,requestStatus:"rejected",aborted:"AbortError"===(null==e?void 0:e.name),condition:"ConditionError"===(null==e?void 0:e.name)})}})),a="undefined"!=typeof AbortController?AbortController:function(){function e(){this.signal={aborted:!1,addEventListener:function(){},dispatchEvent:function(){return!1},onabort:function(){},removeEventListener:function(){},reason:void 0,throwIfAborted:function(){}}}return e.prototype.abort=function(){},e}();return Object.assign((function(e){return function(c,f,l){var s,d=(null==r?void 0:r.idGenerator)?r.idGenerator(e):fe(),p=new a;function v(e){s=e,p.abort()}var y=function(){return w(this,null,(function(){var a,y,h,g,b,m;return t(this,(function(t){switch(t.label){case 0:return t.trys.push([0,4,,5]),null===(w=g=null==(a=null==r?void 0:r.condition)?void 0:a.call(r,e,{getState:f,extra:l}))||"object"!=typeof w||"function"!=typeof w.then?[3,2]:[4,g];case 1:g=t.sent(),t.label=2;case 2:if(!1===g||p.signal.aborted)throw{name:"ConditionError",message:"Aborted due to condition callback returning false."};return b=new Promise((function(e,n){return p.signal.addEventListener("abort",(function(){return n({name:"AbortError",message:s||"Aborted"})}))})),c(o(d,e,null==(y=null==r?void 0:r.getPendingMeta)?void 0:y.call(r,{requestId:d,arg:e},{getState:f,extra:l}))),[4,Promise.race([b,Promise.resolve(n(e,{dispatch:c,getState:f,extra:l,requestId:d,signal:p.signal,abort:v,rejectWithValue:function(e,n){return new se(e,n)},fulfillWithValue:function(e,n){return new de(e,n)}})).then((function(n){if(n instanceof se)throw n;return n instanceof de?i(n.payload,d,e,n.meta):i(n,d,e)}))])];case 3:return h=t.sent(),[3,5];case 4:return m=t.sent(),h=m instanceof se?u(null,d,e,m.payload,m.meta):u(m,d,e),[3,5];case 5:return r&&!r.dispatchConditionRejection&&u.match(h)&&h.meta.condition||c(h),[2,h]}var w}))}))}();return Object.assign(y,{abort:v,requestId:d,arg:e,unwrap:function(){return y.then(ye)}})}}),{pending:o,rejected:u,fulfilled:i,typePrefix:e})}return e.withTypes=function(){return e},e}();function ye(e){if(e.meta&&e.meta.rejectedWithValue)throw e.payload;if(e.error)throw e.error;return e.payload}var he=function(e,n){return I(e)?e.match(n):e(n)};function ge(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];return function(n){return e.some((function(e){return he(e,n)}))}}function be(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];return function(n){return e.every((function(e){return he(e,n)}))}}function me(e,n){if(!e||!e.meta)return!1;var t="string"==typeof e.meta.requestId,r=n.indexOf(e.meta.requestStatus)>-1;return t&&r}function we(e){return"function"==typeof e[0]&&"pending"in e[0]&&"fulfilled"in e[0]&&"rejected"in e[0]}function Oe(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];return 0===e.length?function(e){return me(e,["pending"])}:we(e)?function(n){var t=e.map((function(e){return e.pending}));return ge.apply(void 0,t)(n)}:Oe()(e[0])}function je(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];return 0===e.length?function(e){return me(e,["rejected"])}:we(e)?function(n){var t=e.map((function(e){return e.rejected}));return ge.apply(void 0,t)(n)}:je()(e[0])}function Ae(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];var t=function(e){return e&&e.meta&&e.meta.rejectedWithValue};return 0===e.length||we(e)?function(n){return be(je.apply(void 0,e),t)(n)}:Ae()(e[0])}function Ee(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];return 0===e.length?function(e){return me(e,["fulfilled"])}:we(e)?function(n){var t=e.map((function(e){return e.fulfilled}));return ge.apply(void 0,t)(n)}:Ee()(e[0])}function Se(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];return 0===e.length?function(e){return me(e,["pending","fulfilled","rejected"])}:we(e)?function(n){for(var t=[],r=0,i=e;r<i.length;r++){var o=i[r];t.push(o.pending,o.rejected,o.fulfilled)}return ge.apply(void 0,t)(n)}:Se()(e[0])}var Pe=function(e,n){if("function"!=typeof e)throw new TypeError(n+" is not a function")},_e=function(){},qe=function(e,n){return void 0===n&&(n=_e),e.catch(n),e},xe=function(e,n){return e.addEventListener("abort",n,{once:!0}),function(){return e.removeEventListener("abort",n)}},Me=function(e,n){var t=e.signal;t.aborted||("reason"in t||Object.defineProperty(t,"reason",{enumerable:!0,value:n,configurable:!0,writable:!0}),e.abort(n))},ke=function(e){this.code=e,this.name="TaskAbortError",this.message="task cancelled (reason: "+e+")"},Ie=function(e){if(e.aborted)throw new ke(e.reason)};function Te(e,n){var t=_e;return new Promise((function(r,i){var o=function(){return i(new ke(e.reason))};e.aborted?o():(t=xe(e,o),n.finally((function(){return t()})).then(r,i))})).finally((function(){t=_e}))}var Ce=function(e){return function(n){return qe(Te(e,n).then((function(n){return Ie(e),n})))}},De=function(e){var n=Ce(e);return function(e){return n(new Promise((function(n){return setTimeout(n,e)})))}},Le=Object.assign,Re={},ze="listenerMiddleware",Ne=function(e){var n=e.type,t=e.actionCreator,r=e.matcher,i=e.predicate,o=e.effect;if(n)i=T(n).match;else if(t)n=t.type,i=t.match;else if(r)i=r;else if(!i)throw new Error("Creating or removing a listener requires one of the known fields for matching an action");return Pe(o,"options.listener"),{predicate:i,type:n,effect:o}},Ve=function(e){e.pending.forEach((function(e){Me(e,"listener-cancelled")}))},Be=function(e,n,t){try{e(n,t)}catch(e){setTimeout((function(){throw e}),0)}},Fe=T(ze+"/add"),Ue=T(ze+"/removeAll"),We=T(ze+"/remove"),Xe=function(){for(var e=[],n=0;n<arguments.length;n++)e[n]=arguments[n];console.error.apply(console,r([ze+"/error"],e))};function Ge(e){var n=this;void 0===e&&(e={});var r=new Map,i=e.extra,o=e.onError,u=void 0===o?Xe:o;Pe(u,"onError");var a=function(e){for(var n=0,t=Array.from(r.values());n<t.length;n++){var i=t[n];if(e(i))return i}},c=function(e){var n=a((function(n){return n.effect===e.effect}));return n||(n=function(e){var n=Ne(e),t=n.type,r=n.predicate,i=n.effect;return{id:fe(),effect:i,type:t,predicate:r,pending:new Set,unsubscribe:function(){throw new Error("Unsubscribe not initialized")}}}(e)),function(e){return e.unsubscribe=function(){return r.delete(e.id)},r.set(e.id,e),function(n){e.unsubscribe(),(null==n?void 0:n.cancelActive)&&Ve(e)}}(n)},f=function(e){var n=Ne(e),t=n.type,r=n.effect,i=n.predicate,o=a((function(e){return("string"==typeof t?e.type===t:e.predicate===i)&&e.effect===r}));return o&&(o.unsubscribe(),e.cancelActive&&Ve(o)),!!o},l=function(e,o,a,f){return w(n,null,(function(){var n,l,s,d;return t(this,(function(p){switch(p.label){case 0:n=new AbortController,l=function(e,n){return function(r,i){return qe(function(r,i){return w(void 0,null,(function(){var o,u,a,c;return t(this,(function(t){switch(t.label){case 0:Ie(n),o=function(){},u=new Promise((function(n,t){var i=e({predicate:r,effect:function(e,t){t.unsubscribe(),n([e,t.getState(),t.getOriginalState()])}});o=function(){i(),t()}})),a=[u],null!=i&&a.push(new Promise((function(e){return setTimeout(e,i,null)}))),t.label=1;case 1:return t.trys.push([1,,3,4]),[4,Te(n,Promise.race(a))];case 2:return c=t.sent(),Ie(n),[2,c];case 3:return o(),[7];case 4:return[2]}}))}))}(r,i))}}(c,n.signal),s=[],p.label=1;case 1:return p.trys.push([1,3,4,6]),e.pending.add(n),[4,Promise.resolve(e.effect(o,Le({},a,{getOriginalState:f,condition:function(e,n){return l(e,n).then(Boolean)},take:l,delay:De(n.signal),pause:Ce(n.signal),extra:i,signal:n.signal,fork:(v=n.signal,y=s,function(e,n){Pe(e,"taskExecutor");var r,i=new AbortController;r=i,xe(v,(function(){return Me(r,v.reason)}));var o,u,a=(o=function(){return w(void 0,null,(function(){var n;return t(this,(function(t){switch(t.label){case 0:return Ie(v),Ie(i.signal),[4,e({pause:Ce(i.signal),delay:De(i.signal),signal:i.signal})];case 1:return n=t.sent(),Ie(i.signal),[2,n]}}))}))},u=function(){return Me(i,"task-completed")},w(void 0,null,(function(){var e;return t(this,(function(n){switch(n.label){case 0:return n.trys.push([0,3,4,5]),[4,Promise.resolve()];case 1:return n.sent(),[4,o()];case 2:return[2,{status:"ok",value:n.sent()}];case 3:return[2,{status:(e=n.sent())instanceof ke?"cancelled":"rejected",error:e}];case 4:return null==u||u(),[7];case 5:return[2]}}))})));return(null==n?void 0:n.autoJoin)&&y.push(a),{result:Ce(v)(a),cancel:function(){Me(i,"task-cancelled")}}}),unsubscribe:e.unsubscribe,subscribe:function(){r.set(e.id,e)},cancelActiveListeners:function(){e.pending.forEach((function(e,t,r){e!==n&&(Me(e,"listener-cancelled"),r.delete(e))}))}})))];case 2:return p.sent(),[3,6];case 3:return(d=p.sent())instanceof ke||Be(u,d,{raisedBy:"effect"}),[3,6];case 4:return[4,Promise.allSettled(s)];case 5:return p.sent(),Me(n,"listener-completed"),e.pending.delete(n),[7];case 6:return[2]}var v,y}))}))},s=function(e){return function(){e.forEach(Ve),e.clear()}}(r);return{middleware:function(e){return function(n){return function(t){if(!C(t))return n(t);if(Fe.match(t))return c(t.payload);if(!Ue.match(t)){if(We.match(t))return f(t.payload);var i,o=e.getState(),a=function(){if(o===Re)throw new Error(ze+": getOriginalState can only be called synchronously");return o};try{if(i=n(t),r.size>0)for(var d=e.getState(),p=Array.from(r.values()),v=0,y=p;v<y.length;v++){var h=y[v],g=!1;try{g=h.predicate(t,d,o)}catch(e){g=!1,Be(u,e,{raisedBy:"predicate"})}g&&l(h,t,e,a)}}finally{o=Re}return i}s()}}},startListening:c,stopListening:f,clearListeners:s}}var He,Je="RTK_autoBatch",Ke=function(){return function(e){var n;return{payload:e,meta:(n={},n[Je]=!0,n)}}},Qe="function"==typeof queueMicrotask?queueMicrotask.bind("undefined"!=typeof window?window:"undefined"!=typeof global?global:globalThis):function(e){return(He||(He=Promise.resolve())).then(e).catch((function(e){return setTimeout((function(){throw e}),0)}))},Ye=function(e){return function(n){setTimeout(n,e)}},Ze="undefined"!=typeof window&&window.requestAnimationFrame?window.requestAnimationFrame:Ye(10),$e=function(e){return void 0===e&&(e={type:"raf"}),function(n){return function(){for(var t=[],r=0;r<arguments.length;r++)t[r]=arguments[r];var i=n.apply(void 0,t),o=!0,u=!1,a=!1,c=new Set,f="tick"===e.type?Qe:"raf"===e.type?Ze:"callback"===e.type?e.queueNotification:Ye(e.timeout),l=function(){a=!1,u&&(u=!1,c.forEach((function(e){return e()})))};return Object.assign({},i,{subscribe:function(e){var n=i.subscribe((function(){return o&&e()}));return c.add(e),function(){n(),c.delete(e)}},dispatch:function(e){var n;try{return o=!(null==(n=null==e?void 0:e.meta)?void 0:n[Je]),(u=!o)&&(a||(a=!0,f(l))),i.dispatch(e)}finally{o=!0}}})}}};(0,O.enableES5)();

}).call(this)}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})
},{"immer":89,"redux":165,"redux-thunk":164,"reselect":168}],155:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.default=persistCombineReducers;var _redux=require("redux"),_persistReducer=_interopRequireDefault(require("./persistReducer")),_autoMergeLevel=_interopRequireDefault(require("./stateReconciler/autoMergeLevel2"));function _interopRequireDefault(e){return e&&e.__esModule?e:{default:e}}function persistCombineReducers(e,r){return e.stateReconciler=void 0===e.stateReconciler?_autoMergeLevel.default:e.stateReconciler,(0,_persistReducer.default)(e,(0,_redux.combineReducers)(r))}

},{"./persistReducer":156,"./stateReconciler/autoMergeLevel2":160,"redux":165}],157:[function(require,module,exports){
"use strict";exports.__esModule=!0,exports.default=persistStore;var _redux=require("redux"),_constants=require("./constants");function _toConsumableArray(e){return _arrayWithoutHoles(e)||_iterableToArray(e)||_nonIterableSpread()}function _nonIterableSpread(){throw new TypeError("Invalid attempt to spread non-iterable instance")}function _iterableToArray(e){if(Symbol.iterator in Object(e)||"[object Arguments]"===Object.prototype.toString.call(e))return Array.from(e)}function _arrayWithoutHoles(e){if(Array.isArray(e)){for(var t=0,r=new Array(e.length);t<e.length;t++)r[t]=e[t];return r}}function ownKeys(e,t){var r=Object.keys(e);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(e);t&&(n=n.filter((function(t){return Object.getOwnPropertyDescriptor(e,t).enumerable}))),r.push.apply(r,n)}return r}function _objectSpread(e){for(var t=1;t<arguments.length;t++){var r=null!=arguments[t]?arguments[t]:{};t%2?ownKeys(r,!0).forEach((function(t){_defineProperty(e,t,r[t])})):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(r)):ownKeys(r).forEach((function(t){Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(r,t))}))}return e}function _defineProperty(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var initialState={registry:[],bootstrapped:!1},persistorReducer=function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:initialState,t=arguments.length>1?arguments[1]:void 0;switch(t.type){case _constants.REGISTER:return _objectSpread({},e,{registry:[].concat(_toConsumableArray(e.registry),[t.key])});case _constants.REHYDRATE:var r=e.registry.indexOf(t.key),n=_toConsumableArray(e.registry);return n.splice(r,1),_objectSpread({},e,{registry:n,bootstrapped:0===n.length});default:return e}};function persistStore(e,t,r){if("production"!=="production"){var n=t||{};["blacklist","whitelist","transforms","storage","keyPrefix","migrate"].forEach((function(e){n[e]&&console.error('redux-persist: invalid option passed to persistStore: "'.concat(e,'". You may be incorrectly passing persistConfig into persistStore, whereas it should be passed into persistReducer.'))}))}var o=r||!1,s=(0,_redux.createStore)(persistorReducer,initialState,t&&t.enhancer?t.enhancer:void 0),i=function(e){s.dispatch({type:_constants.REGISTER,key:e})},a=function(t,r,n){var i={type:_constants.REHYDRATE,payload:r,err:n,key:t};e.dispatch(i),s.dispatch(i),o&&c.getState().bootstrapped&&(o(),o=!1)},c=_objectSpread({},s,{purge:function(){var t=[];return e.dispatch({type:_constants.PURGE,result:function(e){t.push(e)}}),Promise.all(t)},flush:function(){var t=[];return e.dispatch({type:_constants.FLUSH,result:function(e){t.push(e)}}),Promise.all(t)},pause:function(){e.dispatch({type:_constants.PAUSE})},persist:function(){e.dispatch({type:_constants.PERSIST,register:i,rehydrate:a})}});return t&&t.manualPersist||c.persist(),c}

},{"./constants":148,"redux":165}],65:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),system=require("ariakit-react-utils/system"),reactDom=require("react-dom");function afterTimeout(e,t){const n=setTimeout(t,e);return()=>clearTimeout(n)}function afterPaint(e){let t=requestAnimationFrame((()=>{t=requestAnimationFrame(e)}));return()=>cancelAnimationFrame(t)}function parseCSSTime(){for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];return t.join(", ").split(", ").reduce(((e,t)=>{const n=1e3*parseFloat(t||"0s");return n>e?n:e}),0)}const useDisclosureContent=system.createHook((e=>{let{state:t,...n}=e;const o=hooks.useId(n.id),[r,i]=react.useState(null);hooks.useSafeLayoutEffect((()=>{if(t.animated){if(t.contentElement?.isConnected)return afterPaint((()=>{i(t.open?"enter":"leave")}));i(null)}}),[t.animated,t.contentElement,t.open]),hooks.useSafeLayoutEffect((()=>{if(!t.animated)return;if(!t.contentElement)return;if(!r)return;if("enter"===r&&!t.open)return;if("leave"===r&&t.open)return;if("number"==typeof t.animated){return afterTimeout(t.animated,(()=>reactDom.flushSync(t.stopAnimation)))}const{transitionDuration:e,animationDuration:n,transitionDelay:o,animationDelay:i}=getComputedStyle(t.contentElement),s=parseCSSTime(o,i)+parseCSSTime(e,n);return s?afterTimeout(s,(()=>reactDom.flushSync(t.stopAnimation))):void 0}),[t.animated,t.contentElement,r,t.open,t.stopAnimation]);const s=t.mounted||!1===n.hidden?n.style:{...n.style,display:"none"};return n={id:o,"data-enter":"enter"===r?"":void 0,"data-leave":"leave"===r?"":void 0,hidden:!t.mounted,...n,ref:hooks.useForkRef(o?t.setContentElement:null,n.ref),style:s},n})),DisclosureContent=system.createComponent((e=>{const t=useDisclosureContent(e);return system.createElement("div",t)}));"production"!=="production"&&(DisclosureContent.displayName="DisclosureContent"),exports.DisclosureContent=DisclosureContent,exports.useDisclosureContent=useDisclosureContent;

},{"ariakit-react-utils/hooks":20,"ariakit-react-utils/system":23,"react":146,"react-dom":110}],75:[function(require,module,exports){
"use strict";var react=require("react"),dom=require("@floating-ui/dom"),hooks=require("ariakit-react-utils/hooks"),reactDom=require("react-dom"),dialog_dialogState=require("../dialog/dialog-state.js");const middlewares={arrow:dom.arrow,flip:dom.flip,offset:dom.offset,shift:dom.shift,size:dom.size};function createDOMRect(e,t,o,r){if(void 0===e&&(e=0),void 0===t&&(t=0),void 0===o&&(o=0),void 0===r&&(r=0),"function"==typeof DOMRect)return new DOMRect(e,t,o,r);const i={x:e,y:t,width:o,height:r,top:t,right:e+o,bottom:t+r,left:e};return{...i,toJSON:()=>i}}function getDOMRect(e){if(!e)return createDOMRect();const{x:t,y:o,width:r,height:i}=e;return createDOMRect(t,o,r,i)}function getAnchorElement(e,t){return{contextElement:e.current||void 0,getBoundingClientRect:()=>{const o=e.current,r=t(o);return r||!o?getDOMRect(r):o.getBoundingClientRect()}}}function isValidPlacement(e){return/^(?:top|bottom|left|right)(?:-(?:start|end))?$/.test(e)}function usePopoverState(e){let{placement:t="bottom",fixed:o=!1,gutter:r,flip:i=!0,shift:a=0,slide:n=!0,overlap:l=!1,sameWidth:s=!1,fitViewport:d=!1,arrowPadding:c=4,overflowPadding:p=8,renderCallback:u,...f}=void 0===e?{}:e;const m=dialog_dialogState.useDialogState(f),h=hooks.useEvent(f.getAnchorRect||(e=>e?.getBoundingClientRect()||null)),g=react.useRef(null),w=react.useRef(null),v=react.useRef(null),[x,y]=react.useState(t),[R,P]=hooks.useForceUpdate();hooks.useSafeLayoutEffect((()=>{if(!m.contentElement?.isConnected)return;const e=w.current;if(!e)return;const f=getAnchorElement(g,h),x=v.current,R=(x?.clientHeight||0)/2,P="number"==typeof r?r+R:r??R;e.style.setProperty("--popover-overflow-padding",`${p}px`);const b=()=>dom.autoUpdate(f,e,(async()=>{if(!m.mounted)return;const r=[middlewares.offset((e=>{let{placement:t}=e;return{crossAxis:!!t.split("-")[1]?void 0:a,mainAxis:P,alignmentAxis:a}}))];if(!1!==i){const e="string"==typeof i?i.split(" "):void 0;if(void 0!==e&&!e.every(isValidPlacement))throw new Error("`flip` expects a spaced-delimited list of placements");r.push(middlewares.flip({padding:p,fallbackPlacements:e}))}(n||l)&&r.push(middlewares.shift({mainAxis:n,crossAxis:l,padding:p})),r.push(middlewares.size({padding:p,apply(t){let{availableWidth:o,availableHeight:r,rects:i}=t;const a=Math.round(i.reference.width);o=Math.floor(o),r=Math.floor(r),e.style.setProperty("--popover-anchor-width",`${a}px`),e.style.setProperty("--popover-available-width",`${o}px`),e.style.setProperty("--popover-available-height",`${r}px`),s&&(e.style.width=`${a}px`),d&&(e.style.maxWidth=`${o}px`,e.style.maxHeight=`${r}px`)}})),x&&r.push(middlewares.arrow({element:x,padding:c}));const u=await dom.computePosition(f,e,{placement:t,strategy:o?"fixed":"absolute",middleware:r});reactDom.flushSync((()=>{y(u.placement)}));const h=Math.round(u.x),g=Math.round(u.y);if(Object.assign(e.style,{top:"0",left:"0",transform:`translate3d(${h}px, ${g}px, 0)`}),x&&u.middlewareData.arrow){const{x:e,y:t}=u.middlewareData.arrow,o=u.placement.split("-")[0];Object.assign(x.style,{left:null!=e?`${e}px`:"",top:null!=t?`${t}px`:"",[o]:"100%"})}}),{elementResize:"function"==typeof ResizeObserver});return u?u({mounted:m.mounted,placement:t,fixed:o,gutter:P,shift:a,overlap:l,flip:i,sameWidth:s,fitViewport:d,arrowPadding:c,overflowPadding:p,popover:e,anchor:f,arrow:x,setPlacement:y,defaultRenderCallback:b}):b()}),[R,m.contentElement,h,r,m.mounted,a,l,i,p,n,s,d,c,t,o,u]);return react.useMemo((()=>({...m,getAnchorRect:h,anchorRef:g,popoverRef:w,arrowRef:v,currentPlacement:x,placement:t,fixed:o,gutter:r,shift:a,flip:i,slide:n,overlap:l,sameWidth:s,fitViewport:d,arrowPadding:c,overflowPadding:p,render:P,renderCallback:u})),[m,h,x,t,o,r,a,i,n,l,s,d,c,p,P,u])}exports.usePopoverState=usePopoverState;

},{"../dialog/dialog-state.js":63,"@floating-ui/dom":10,"ariakit-react-utils/hooks":20,"react":146,"react-dom":110}],109:[function(require,module,exports){
"use strict";var i,m=require("react-dom");exports.createRoot=m.createRoot,exports.hydrateRoot=m.hydrateRoot;

},{"react-dom":110}],135:[function(require,module,exports){
"use strict";exports.__esModule=!0,Object.defineProperty(exports,"unstable_batchedUpdates",{enumerable:!0,get:function(){return _reactDom.unstable_batchedUpdates}});var _reactDom=require("react-dom");

},{"react-dom":110}],124:[function(require,module,exports){
"use strict";var _interopRequireDefault=require("@babel/runtime/helpers/interopRequireDefault");exports.__esModule=!0;var _exportNames={Provider:!0,connect:!0,ReactReduxContext:!0,useDispatch:!0,createDispatchHook:!0,useSelector:!0,createSelectorHook:!0,useStore:!0,createStoreHook:!0,shallowEqual:!0};Object.defineProperty(exports,"Provider",{enumerable:!0,get:function(){return _Provider.default}}),Object.defineProperty(exports,"connect",{enumerable:!0,get:function(){return _connect.default}}),Object.defineProperty(exports,"ReactReduxContext",{enumerable:!0,get:function(){return _Context.ReactReduxContext}}),Object.defineProperty(exports,"useDispatch",{enumerable:!0,get:function(){return _useDispatch.useDispatch}}),Object.defineProperty(exports,"createDispatchHook",{enumerable:!0,get:function(){return _useDispatch.createDispatchHook}}),Object.defineProperty(exports,"useSelector",{enumerable:!0,get:function(){return _useSelector.useSelector}}),Object.defineProperty(exports,"createSelectorHook",{enumerable:!0,get:function(){return _useSelector.createSelectorHook}}),Object.defineProperty(exports,"useStore",{enumerable:!0,get:function(){return _useStore.useStore}}),Object.defineProperty(exports,"createStoreHook",{enumerable:!0,get:function(){return _useStore.createStoreHook}}),Object.defineProperty(exports,"shallowEqual",{enumerable:!0,get:function(){return _shallowEqual.default}});var _Provider=_interopRequireDefault(require("./components/Provider")),_connect=_interopRequireDefault(require("./components/connect")),_Context=require("./components/Context"),_useDispatch=require("./hooks/useDispatch"),_useSelector=require("./hooks/useSelector"),_useStore=require("./hooks/useStore"),_shallowEqual=_interopRequireDefault(require("./utils/shallowEqual")),_types=require("./types");Object.keys(_types).forEach((function(e){"default"!==e&&"__esModule"!==e&&(Object.prototype.hasOwnProperty.call(_exportNames,e)||e in exports&&exports[e]===_types[e]||Object.defineProperty(exports,e,{enumerable:!0,get:function(){return _types[e]}}))}));

},{"./components/Context":114,"./components/Provider":115,"./components/connect":116,"./hooks/useDispatch":125,"./hooks/useSelector":127,"./hooks/useStore":128,"./types":130,"./utils/shallowEqual":136,"@babel/runtime/helpers/interopRequireDefault":3}],30:[function(require,module,exports){
"use strict";var react=require("react"),store=require("ariakit-react-utils/store"),dom=require("ariakit-utils/dom");const NULL_ITEM={id:null,ref:{current:null}};function getMaxRowLength(e){let t=0;for(const{length:o}of e)o>t&&(t=o);return t}function getEnabledItems(e,t){return e.filter((e=>t?!e.disabled&&e.id!==t:!e.disabled))}function findFirstEnabledItem(e,t){return e.find((e=>t?!e.disabled&&e.id!==t:!e.disabled))}function normalizeRows(e,t,o){const n=getMaxRowLength(e);for(const i of e)for(let e=0;e<n;e+=1){const n=i[e];if(!n||o&&n.disabled){const n=0===e&&o?findFirstEnabledItem(i):i[e-1];i[e]=n&&t!==n.id&&o?n:createEmptyItem(n?.rowId)}}return e}function createEmptyItem(e){return{id:"__EMPTY_ITEM__",disabled:!0,ref:{current:null},rowId:e}}function findEnabledItemById(e,t){if(t)return e.find((e=>e.id===t&&!e.disabled))}function getActiveId(e,t,o){return void 0!==o?o:void 0!==t?t:findFirstEnabledItem(e)?.id}function getItemsInRow(e,t){return e.filter((e=>e.rowId===t))}function getOppositeOrientation(e){return"vertical"===e?"horizontal":"horizontal"===e?"vertical":void 0}function groupItemsByRows(e){const t=[];for(const o of e){const e=t.find((e=>e[0]?.rowId===o.rowId));e?e.push(o):t.push([o])}return t}function flipItems(e,t,o){void 0===o&&(o=!1);const n=e.findIndex((e=>e.id===t));return[...e.slice(n+1),...o?[NULL_ITEM]:[],...e.slice(0,n)]}function verticalizeItems(e){const t=groupItemsByRows(e),o=getMaxRowLength(t),n=[];for(let e=0;e<o;e+=1)for(const o of t){const t=o[e];t&&n.push({...t,rowId:t.rowId?`${e}`:void 0})}return n}function getContextId(e,t){return t?.baseRef&&t.baseRef===e?.baseRef?t.id:void 0}function selectTextField(e,t){if(void 0===t&&(t=!1),dom.isTextField(e))e.setSelectionRange(t?e.value.length:0,e.value.length);else if(e.isContentEditable){const o=dom.getDocument(e).getSelection();o?.selectAllChildren(e),t&&o?.collapseToEnd()}}const FOCUS_SILENTLY=Symbol("FOCUS_SILENTLY");function focusSilently(e){e[FOCUS_SILENTLY]=!0,e.focus()}function silentlyFocused(e){const t=e[FOCUS_SILENTLY];return delete e[FOCUS_SILENTLY],t}function isItem(e,t,o){return!!t&&e.some((e=>(!o||e.ref.current!==o)&&e.ref.current===t))}const CompositeContext=store.createStoreContext(),CompositeRowContext=react.createContext(void 0),CompositeItemContext=react.createContext(void 0);exports.CompositeContext=CompositeContext,exports.CompositeItemContext=CompositeItemContext,exports.CompositeRowContext=CompositeRowContext,exports.findEnabledItemById=findEnabledItemById,exports.findFirstEnabledItem=findFirstEnabledItem,exports.flipItems=flipItems,exports.focusSilently=focusSilently,exports.getActiveId=getActiveId,exports.getContextId=getContextId,exports.getEnabledItems=getEnabledItems,exports.getItemsInRow=getItemsInRow,exports.getOppositeOrientation=getOppositeOrientation,exports.groupItemsByRows=groupItemsByRows,exports.isItem=isItem,exports.normalizeRows=normalizeRows,exports.selectTextField=selectTextField,exports.silentlyFocused=silentlyFocused,exports.verticalizeItems=verticalizeItems;

},{"ariakit-react-utils/store":22,"ariakit-utils/dom":25,"react":146}],33:[function(require,module,exports){
"use strict";var react=require("react"),store=require("ariakit-react-utils/store");const ComboboxContext=store.createStoreContext(),ComboboxItemValueContext=react.createContext(void 0);exports.ComboboxContext=ComboboxContext,exports.ComboboxItemValueContext=ComboboxItemValueContext;

},{"ariakit-react-utils/store":22,"react":146}],37:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),store=require("ariakit-react-utils/store"),system=require("ariakit-react-utils/system"),__utils=require("../__utils-165d0dc9.js");function identity(e){return e}const useCollectionItem=system.createHook((e=>{let{state:t,shouldRegisterItem:o=!0,getItem:r=identity,...s}=e;t=store.useStore(t,["registerItem"]);const i=react.useContext(__utils.CollectionItemContext),l=t?.registerItem||i,u=react.useRef(null);return hooks.useSafeLayoutEffect((()=>{if(o)return l?.(r({ref:u}))}),[o,r,l]),s={...s,ref:hooks.useForkRef(u,s.ref)},s})),CollectionItem=system.createComponent((e=>{const t=useCollectionItem(e);return system.createElement("div",t)}));"production"!=="production"&&(CollectionItem.displayName="CollectionItem"),exports.CollectionItem=CollectionItem,exports.useCollectionItem=useCollectionItem;

},{"../__utils-165d0dc9.js":32,"ariakit-react-utils/hooks":20,"ariakit-react-utils/store":22,"ariakit-react-utils/system":23,"react":146}],52:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),system=require("ariakit-react-utils/system"),dom=require("ariakit-utils/dom"),events=require("ariakit-utils/events"),misc=require("ariakit-utils/misc"),platform=require("ariakit-utils/platform"),focusable_focusable=require("../focusable/focusable.js");function isNativeClick(e){if(!e.isTrusted)return!1;const t=e.currentTarget;return dom.isButton(t)||"SUMMARY"===t.tagName||"INPUT"===t.tagName||"TEXTAREA"===t.tagName||"A"===t.tagName||"SELECT"===t.tagName}const useCommand=system.createHook((e=>{let{clickOnEnter:t=!0,clickOnSpace:r=!0,...a}=e;const s=react.useRef(null),i=hooks.useTagName(s,a.as),[n,o]=react.useState((()=>!!i&&dom.isButton({tagName:i,type:a.type})));react.useEffect((()=>{s.current&&o(dom.isButton(s.current))}),[]);const[u,c]=react.useState(!1),m=react.useRef(!1),f="data-command"in a,l=a.onKeyDown,d=hooks.useEvent((e=>{l?.(e);const s=e.currentTarget;if(e.defaultPrevented)return;if(f)return;if(a.disabled)return;if(!events.isSelfTarget(e))return;if(dom.isTextField(s))return;if(s.isContentEditable)return;const i=t&&"Enter"===e.key,n=r&&" "===e.key,o="Enter"===e.key&&!t,u=" "===e.key&&!r;if(o||u)e.preventDefault();else if(i||n){const t=isNativeClick(e);if(i){if(!t){e.preventDefault();const{view:t,...r}=e,a=()=>events.fireClickEvent(s,r);platform.isFirefox()?events.queueBeforeEvent(s,"keyup",a):misc.queueMicrotask(a)}}else n&&(m.current=!0,t||(e.preventDefault(),c(!0)))}})),k=a.onKeyUp,v=hooks.useEvent((e=>{if(k?.(e),e.defaultPrevented)return;if(f)return;if(a.disabled)return;if(e.metaKey)return;const t=r&&" "===e.key;if(m.current&&t&&(m.current=!1,!isNativeClick(e))){c(!1);const t=e.currentTarget,{view:r,...a}=e;misc.queueMicrotask((()=>events.fireClickEvent(t,a)))}}));return a={"data-command":"","data-active":u?"":void 0,type:n?"button":void 0,...a,ref:hooks.useForkRef(s,a.ref),onKeyDown:d,onKeyUp:v},a=focusable_focusable.useFocusable(a),a})),Command=system.createComponent((e=>(e=useCommand(e),system.createElement("button",e))));"production"!=="production"&&(Command.displayName="Command"),exports.Command=Command,exports.useCommand=useCommand;

},{"../focusable/focusable.js":70,"ariakit-react-utils/hooks":20,"ariakit-react-utils/system":23,"ariakit-utils/dom":25,"ariakit-utils/events":26,"ariakit-utils/misc":28,"ariakit-utils/platform":29,"react":146}],53:[function(require,module,exports){
"use strict";var system=require("ariakit-react-utils/system"),group_groupLabel=require("../group/group-label.js");const useCompositeGroupLabel=system.createHook((e=>{let{state:o,...s}=e;return s=group_groupLabel.useGroupLabel(s),s})),CompositeGroupLabel=system.createComponent((e=>{const o=useCompositeGroupLabel(e);return system.createElement("div",o)}));"production"!=="production"&&(CompositeGroupLabel.displayName="CompositeGroupLabel"),exports.CompositeGroupLabel=CompositeGroupLabel,exports.useCompositeGroupLabel=useCompositeGroupLabel;

},{"../group/group-label.js":71,"ariakit-react-utils/system":23}],54:[function(require,module,exports){
"use strict";var system=require("ariakit-react-utils/system"),group_group=require("../group/group.js");const useCompositeGroup=system.createHook((o=>{let{state:e,...s}=o;return s=group_group.useGroup(s),s})),CompositeGroup=system.createComponent((o=>{const e=useCompositeGroup(o);return system.createElement("div",e)}));"production"!=="production"&&(CompositeGroup.displayName="CompositeGroup"),exports.CompositeGroup=CompositeGroup,exports.useCompositeGroup=useCompositeGroup;

},{"../group/group.js":72,"ariakit-react-utils/system":23}],69:[function(require,module,exports){
"use strict";var system=require("ariakit-react-utils/system"),visuallyHidden_visuallyHidden=require("../visually-hidden/visually-hidden.js");const useFocusTrap=system.createHook((s=>(s={"data-focus-trap":"",tabIndex:0,"aria-hidden":!0,...s,style:{position:"fixed",top:0,left:0,...s.style}},s=visuallyHidden_visuallyHidden.useVisuallyHidden(s)))),FocusTrap=system.createComponent((s=>{const e=useFocusTrap(s);return system.createElement("span",e)}));"production"!=="production"&&(FocusTrap.displayName="FocusTrap"),exports.FocusTrap=FocusTrap,exports.useFocusTrap=useFocusTrap;

},{"../visually-hidden/visually-hidden.js":80,"ariakit-react-utils/system":23}],237:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});var reactDeps=require("./react-deps.js"),useSyncExternalStore=require("./use-sync-external-store");const relativePath=(e="",t=location.pathname)=>t.toLowerCase().indexOf(e.toLowerCase())?"~"+t:t.slice(e.length)||"/",absolutePath=(e,t="")=>"~"===e[0]?e.slice(1):t+e,eventPopstate="popstate",eventPushState="pushState",eventReplaceState="replaceState",eventHashchange="hashchange",events=["popstate","pushState","replaceState","hashchange"],subscribeToLocationUpdates=e=>{for(const t of events)addEventListener(t,e);return()=>{for(const t of events)removeEventListener(t,e)}},useLocationProperty=(e,t)=>useSyncExternalStore.useSyncExternalStore(subscribeToLocationUpdates,e,t),currentSearch=()=>location.search,useSearch=()=>useLocationProperty(currentSearch),currentPathname=()=>location.pathname,usePathname=({ssrPath:e}={})=>useLocationProperty(currentPathname,e?()=>e:currentPathname),navigate=(e,{replace:t=!1}={})=>history[t?"replaceState":"pushState"](null,"",e),useLocation=(e={})=>[relativePath(e.base,usePathname(e)),reactDeps.useEvent(((t,a)=>navigate(absolutePath(t,e.base),a)))];if("undefined"!=typeof history)for(const e of["pushState","replaceState"]){const t=history[e];history[e]=function(){const a=t.apply(this,arguments),s=new Event(e);return s.arguments=arguments,dispatchEvent(s),a}}exports.default=useLocation,exports.events=events,exports.navigate=navigate,exports.useLocationProperty=useLocationProperty,exports.usePathname=usePathname,exports.useSearch=useSearch;

},{"./react-deps.js":236,"./use-sync-external-store":238}],202:[function(require,module,exports){
"use strict";var __assign=this&&this.__assign||function(){return __assign=Object.assign||function(r){for(var e,n=1,t=arguments.length;n<t;n++)for(var i in e=arguments[n])Object.prototype.hasOwnProperty.call(e,i)&&(r[i]=e[i]);return r},__assign.apply(this,arguments)};Object.defineProperty(exports,"__esModule",{value:!0}),exports.Namespace=void 0;var Namespace,RandomGenerator_1=require("../utils/RandomGenerator"),TypeGuardError_1=require("../TypeGuardError"),_HeadersReader_1=require("./$HeadersReader"),_ParameterReader_1=require("./$ParameterReader"),_ProtobufReader_1=require("./$ProtobufReader"),_ProtobufSizer_1=require("./$ProtobufSizer"),_ProtobufWriter_1=require("./$ProtobufWriter"),_QueryReader_1=require("./$QueryReader"),_any_1=require("./$any"),_every_1=require("./$every"),_guard_1=require("./$guard"),_is_between_1=require("./$is_between"),_join_1=require("./$join"),_number_1=require("./$number"),_report_1=require("./$report"),_rest_1=require("./$rest"),_string_1=require("./$string"),_strlen_1=require("./$strlen"),_tail_1=require("./$tail");!function(r){r.is=function(){return{is_between:_is_between_1.$is_between}},r.assert=function(e){return __assign(__assign({},r.is()),{join:_join_1.$join,every:_every_1.$every,guard:(0,_guard_1.$guard)("typia.".concat(e)),predicate:function(r,n,t){if(!1===r&&!0===n)throw new TypeGuardError_1.TypeGuardError(__assign(__assign({},t()),{method:"typia.".concat(e)}));return r}})},r.validate=function(){return __assign(__assign({},r.is()),{join:_join_1.$join,report:_report_1.$report,predicate:function(r){return function(e,n,t){return!1===e&&!0===n&&function(){r.success&&(r.success=!1);var e=r.errors,n=t();if(e.length){var i=e[e.length-1].path;if(i.length>=n.path.length&&i.substring(0,n.path.length)===n.path)return}e.push(n)}(),e}}})},function(n){n.stringify=function(n){return __assign(__assign({},r.is()),{number:_number_1.$number,string:_string_1.$string,tail:_tail_1.$tail,rest:_rest_1.$rest,throws:e("json.".concat(n))})}}(r.json||(r.json={})),function(r){r.decode=function(r){return{Reader:_ProtobufReader_1.$ProtobufReader,throws:e("protobuf.".concat(r))}},r.encode=function(r){return{Sizer:_ProtobufSizer_1.$ProtobufSizer,Writer:_ProtobufWriter_1.$ProtobufWriter,strlen:_strlen_1.$strlen,throws:e(r)}}}(r.protobuf||(r.protobuf={})),function(r){r.query=function(){return _QueryReader_1.$QueryReader},r.headers=function(){return _HeadersReader_1.$HeadersReader},r.parameter=function(){return _ParameterReader_1.$ParameterReader}}(r.http||(r.http={})),function(n){n.clone=function(n){return __assign(__assign({},r.is()),{throws:e("misc.".concat(n)),any:_any_1.$any})},n.prune=function(n){return __assign(__assign({},r.is()),{throws:e("misc.".concat(n))})}}(r.misc||(r.misc={})),r.random=function(){return{generator:RandomGenerator_1.RandomGenerator,pick:RandomGenerator_1.RandomGenerator.pick}};var e=function(r){return function(e){throw new TypeGuardError_1.TypeGuardError(__assign(__assign({},e),{method:"typia.".concat(r)}))}}}(Namespace||(exports.Namespace=Namespace={}));

},{"../TypeGuardError":183,"../utils/RandomGenerator":227,"./$HeadersReader":184,"./$ParameterReader":185,"./$ProtobufReader":186,"./$ProtobufSizer":187,"./$ProtobufWriter":188,"./$QueryReader":189,"./$any":190,"./$every":192,"./$guard":193,"./$is_between":194,"./$join":195,"./$number":196,"./$report":197,"./$rest":198,"./$string":199,"./$strlen":200,"./$tail":201}],11:[function(require,module,exports){
"use strict";"production"==="production"?module.exports=require("./redux-toolkit.cjs.production.min.js"):module.exports=require("./redux-toolkit.cjs.development.js");

},{"./redux-toolkit.cjs.development.js":18,"./redux-toolkit.cjs.production.min.js":19}],153:[function(require,module,exports){
"use strict";exports.__esModule=!0;var _exportNames={persistReducer:!0,persistCombineReducers:!0,persistStore:!0,createMigrate:!0,createTransform:!0,getStoredState:!0,createPersistoid:!0,purgeStoredState:!0};exports.purgeStoredState=exports.createPersistoid=exports.getStoredState=exports.createTransform=exports.createMigrate=exports.persistStore=exports.persistCombineReducers=exports.persistReducer=void 0;var _persistReducer=_interopRequireDefault(require("./persistReducer"));exports.persistReducer=_persistReducer.default;var _persistCombineReducers=_interopRequireDefault(require("./persistCombineReducers"));exports.persistCombineReducers=_persistCombineReducers.default;var _persistStore=_interopRequireDefault(require("./persistStore"));exports.persistStore=_persistStore.default;var _createMigrate=_interopRequireDefault(require("./createMigrate"));exports.createMigrate=_createMigrate.default;var _createTransform=_interopRequireDefault(require("./createTransform"));exports.createTransform=_createTransform.default;var _getStoredState=_interopRequireDefault(require("./getStoredState"));exports.getStoredState=_getStoredState.default;var _createPersistoid=_interopRequireDefault(require("./createPersistoid"));exports.createPersistoid=_createPersistoid.default;var _purgeStoredState=_interopRequireDefault(require("./purgeStoredState"));exports.purgeStoredState=_purgeStoredState.default;var _constants=require("./constants");function _interopRequireDefault(e){return e&&e.__esModule?e:{default:e}}Object.keys(_constants).forEach((function(e){"default"!==e&&"__esModule"!==e&&(Object.prototype.hasOwnProperty.call(_exportNames,e)||(exports[e]=_constants[e]))}));

},{"./constants":148,"./createMigrate":149,"./createPersistoid":150,"./createTransform":151,"./getStoredState":152,"./persistCombineReducers":155,"./persistReducer":156,"./persistStore":157,"./purgeStoredState":158}],129:[function(require,module,exports){
"use strict";exports.__esModule=!0;var _exportNames={batch:!0};Object.defineProperty(exports,"batch",{enumerable:!0,get:function(){return _reactBatchedUpdates.unstable_batchedUpdates}});var _shim=require("use-sync-external-store/shim"),_withSelector=require("use-sync-external-store/shim/with-selector"),_reactBatchedUpdates=require("./utils/reactBatchedUpdates"),_batch=require("./utils/batch"),_useSelector=require("./hooks/useSelector"),_connect=require("./components/connect"),_exports=require("./exports");Object.keys(_exports).forEach((function(e){"default"!==e&&"__esModule"!==e&&(Object.prototype.hasOwnProperty.call(_exportNames,e)||e in exports&&exports[e]===_exports[e]||Object.defineProperty(exports,e,{enumerable:!0,get:function(){return _exports[e]}}))})),(0,_useSelector.initializeUseSelector)(_withSelector.useSyncExternalStoreWithSelector),(0,_connect.initializeConnect)(_shim.useSyncExternalStore),(0,_batch.setBatch)(_reactBatchedUpdates.unstable_batchedUpdates);

},{"./components/connect":116,"./exports":124,"./hooks/useSelector":127,"./utils/batch":132,"./utils/reactBatchedUpdates":135,"use-sync-external-store/shim":232,"use-sync-external-store/shim/with-selector":233}],55:[function(require,module,exports){
"use strict";var hooks=require("ariakit-react-utils/hooks"),store=require("ariakit-react-utils/store"),system=require("ariakit-react-utils/system"),dom=require("ariakit-utils/dom"),focus=require("ariakit-utils/focus"),__utils=require("../__utils-09a0f6df.js");function getMouseDestination(e){const o=e.relatedTarget;return o?.nodeType===Node.ELEMENT_NODE?o:null}function hoveringInside(e){const o=getMouseDestination(e);return!!o&&dom.contains(e.currentTarget,o)}function movingToAnotherItem(e){const o=getMouseDestination(e);if(!o)return!1;return!!dom.closest(o,"[data-composite-hover]")}const useCompositeHover=system.createHook((e=>{let{state:o,focusOnHover:t=!0,...s}=e;o=store.useStore(o||__utils.CompositeContext,["setActiveId","baseRef"]);const r=hooks.useIsMouseMoving(),i=s.onMouseMove,n=hooks.useBooleanEvent(t),u=hooks.useEvent((e=>{i?.(e),e.defaultPrevented||r()&&n(e)&&(focus.hasFocusWithin(e.currentTarget)||o?.baseRef.current?.focus(),o?.setActiveId(e.currentTarget.id))})),a=s.onMouseLeave,c=hooks.useEvent((e=>{a?.(e),e.defaultPrevented||r()&&(hoveringInside(e)||movingToAnotherItem(e)||n(e)&&(o?.setActiveId(null),o?.baseRef.current?.focus()))}));return s={"data-composite-hover":"",...s,onMouseMove:u,onMouseLeave:c},s})),CompositeHover=store.createMemoComponent((e=>{const o=useCompositeHover(e);return system.createElement("div",o)}));"production"!=="production"&&(CompositeHover.displayName="CompositeHover"),exports.CompositeHover=CompositeHover,exports.useCompositeHover=useCompositeHover;

},{"../__utils-09a0f6df.js":30,"ariakit-react-utils/hooks":20,"ariakit-react-utils/store":22,"ariakit-react-utils/system":23,"ariakit-utils/dom":25,"ariakit-utils/focus":27}],57:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),system=require("ariakit-react-utils/system"),__utils=require("../__utils-09a0f6df.js"),jsxRuntime=require("react/jsx-runtime");const useCompositeRow=system.createHook((e=>{let{state:s,...o}=e;const t=react.useContext(__utils.CompositeContext);s=s||t;const r=react.useRef(null),i=hooks.useId(o.id),u=react.useMemo((()=>({id:i,baseRef:s?.baseRef})),[i,s?.baseRef]);return o=hooks.useWrapElement(o,(e=>jsxRuntime.jsx(__utils.CompositeRowContext.Provider,{value:u,children:e})),[u]),o={id:i,...o,ref:hooks.useForkRef(r,o.ref)},o})),CompositeRow=system.createComponent((e=>{const s=useCompositeRow(e);return system.createElement("div",s)}));"production"!=="production"&&(CompositeRow.displayName="CompositeRow"),exports.CompositeRow=CompositeRow,exports.useCompositeRow=useCompositeRow;

},{"../__utils-09a0f6df.js":30,"ariakit-react-utils/hooks":20,"ariakit-react-utils/system":23,"react":146,"react/jsx-runtime":147}],58:[function(require,module,exports){
"use strict";var store=require("ariakit-react-utils/store"),system=require("ariakit-react-utils/system"),separator_separator=require("../separator/separator.js"),__utils=require("../__utils-09a0f6df.js");const useCompositeSeparator=system.createHook((e=>{let{state:t,...r}=e;t=store.useStore(t||__utils.CompositeContext,["orientation"]);const o="horizontal"===t?.orientation?"vertical":"horizontal";return r=separator_separator.useSeparator({...r,orientation:o}),r})),CompositeSeparator=system.createComponent((e=>{const t=useCompositeSeparator(e);return system.createElement("hr",t)}));"production"!=="production"&&(CompositeSeparator.displayName="CompositeSeparator"),exports.CompositeSeparator=CompositeSeparator,exports.useCompositeSeparator=useCompositeSeparator;

},{"../__utils-09a0f6df.js":30,"../separator/separator.js":79,"ariakit-react-utils/store":22,"ariakit-react-utils/system":23}],59:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),store=require("ariakit-react-utils/store"),array=require("ariakit-utils/array"),collection_collectionState=require("../collection/collection-state.js"),__utils=require("../__utils-09a0f6df.js");function useCompositeState(e){let{orientation:t="both",rtl:r=!1,virtualFocus:s=!1,focusLoop:i=!1,focusWrap:l=!1,focusShift:a=!1,...o}=void 0===e?{}:e;const u=collection_collectionState.useCollectionState(o),n=react.useRef(null),[c,d]=hooks.useControlledState(0,o.moves,o.setMoves),[_,m]=hooks.useControlledState(o.defaultActiveId,o.activeId,o.setActiveId),f=react.useMemo((()=>__utils.getActiveId(u.items,_)),[u.items,_]),I=hooks.useInitialValue(f),v=o.includesBaseElement??null===I,b=hooks.useLiveRef(f),k=react.useCallback((e=>{void 0!==e&&(d((e=>e+1)),m(e))}),[]),y=react.useCallback((()=>{const e=__utils.findFirstEnabledItem(u.items);return e?.id}),[u.items]),p=react.useCallback((()=>{const e=__utils.findFirstEnabledItem(array.reverseArray(u.items));return e?.id}),[u.items]),C=react.useCallback(((e,t,s,a)=>{const o=r&&"vertical"!==t?array.reverseArray(e):e;if(null==b.current)return __utils.findFirstEnabledItem(o)?.id;const u=o.find((e=>e.id===b.current));if(!u)return __utils.findFirstEnabledItem(o)?.id;const n=!!u.rowId,c=o.indexOf(u),d=o.slice(c+1),_=__utils.getItemsInRow(d,u.rowId);if(void 0!==a){const e=__utils.getEnabledItems(_,b.current),t=e.slice(a)[0]||e[e.length-1];return t?.id}const m=__utils.getOppositeOrientation(n?t||"horizontal":t),f=i&&i!==m,I=n&&l&&l!==m;if(s=s||!n&&f&&v,f){const e=I&&!s?o:__utils.getItemsInRow(o,u.rowId),t=__utils.flipItems(e,b.current,s),r=__utils.findFirstEnabledItem(t,b.current);return r?.id}if(I){const e=__utils.findFirstEnabledItem(s?_:d,b.current);return s?e?.id||null:e?.id}const k=__utils.findFirstEnabledItem(_,b.current);return!k&&s?null:k?.id}),[i,l,v]),h=react.useCallback((e=>C(u.items,t,!1,e)),[C,u.items,t]),w=react.useCallback((e=>{const r=!!!__utils.findFirstEnabledItem(u.items)?.rowId&&v;return C(array.reverseArray(u.items),t,r,e)}),[u.items,C,t,v]),E=react.useCallback((e=>{const t=a&&!e,r=__utils.verticalizeItems(array.flatten2DArray(__utils.normalizeRows(__utils.groupItemsByRows(u.items),b.current,t)));return C(r,"vertical",i&&"horizontal"!==i&&v,e)}),[u.items,C,a,i]),S=react.useCallback((e=>{const t=a&&!e,r=__utils.verticalizeItems(array.reverseArray(array.flatten2DArray(__utils.normalizeRows(__utils.groupItemsByRows(u.items),b.current,t))));return C(r,"vertical",v,e)}),[u.items,C,a]),A=react.useMemo((()=>({...u,baseRef:n,orientation:t,rtl:r,virtualFocus:s,focusLoop:i,focusWrap:l,focusShift:a,moves:c,setMoves:d,includesBaseElement:v,activeId:f,setActiveId:m,move:k,next:h,previous:w,up:S,down:E,first:y,last:p})),[u,n,t,r,s,i,l,a,c,d,v,f,m,k,h,w,S,E,y,p]);return store.useStorePublisher(A)}exports.useCompositeState=useCompositeState;

},{"../__utils-09a0f6df.js":30,"../collection/collection-state.js":38,"ariakit-react-utils/hooks":20,"ariakit-react-utils/store":22,"ariakit-utils/array":24,"react":146}],60:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),store=require("ariakit-react-utils/store"),system=require("ariakit-react-utils/system"),array=require("ariakit-utils/array"),dom=require("ariakit-utils/dom"),events=require("ariakit-utils/events"),focus=require("ariakit-utils/focus"),misc=require("ariakit-utils/misc"),focusable_focusable=require("../focusable/focusable.js"),__utils=require("../__utils-09a0f6df.js");function isGrid(e){return e.some((e=>!!e.rowId))}function isPrintableKey(e){return 1===e.key.length&&!e.ctrlKey&&!e.metaKey}function isModifierKey(e){return"Shift"===e.key||"Control"===e.key||"Alt"===e.key||"Meta"===e.key}function canProxyKeyboardEvent(e,t){if(!events.isSelfTarget(e))return!1;if(isModifierKey(e))return!1;const r=e.target;if(!r)return!0;if(dom.isTextField(r)){if(isPrintableKey(e))return!1;const r=isGrid(t.items),s=null===t.activeId,o=r&&!s,n="Home"===e.key||"End"===e.key;if(!o&&n)return!1}return!e.isPropagationStopped()}function useKeyboardEventProxy(e,t,r,s){return hooks.useEvent((o=>{if(r?.(o),o.defaultPrevented)return;const n=t?.ref.current;if(!n)return;if(!canProxyKeyboardEvent(o,e))return;const{view:i,...u}=o,a=s?.current;n!==a&&n.focus(),events.fireKeyboardEvent(n,o.type,u)||o.preventDefault(),o.currentTarget.contains(n)&&o.stopPropagation()}))}function findFirstEnabledItemInTheLastRow(e){return __utils.findFirstEnabledItem(array.flatten2DArray(array.reverseArray(__utils.groupItemsByRows(e))))}function useScheduleFocus(e){const[t,r]=react.useState(!1),s=react.useCallback((()=>r(!0)),[]);return react.useEffect((()=>{const s=e?.ref.current;t&&s&&(r(!1),focus.focusIntoView(s))}),[e,t]),s}const useComposite=system.createHook((e=>{let{state:t,composite:r=!0,focusOnMove:s=r,moveOnKeyPress:o=!0,...n}=e;const i=react.useRef(null),u=r&&t.virtualFocus,a=react.useMemo((()=>__utils.findEnabledItemById(t.items,t.activeId)),[t.items,t.activeId]),c=hooks.useLiveRef(a),f=react.useRef(null),l=null===t.activeId,v=hooks.useLiveRef(l),d=useScheduleFocus(a);hooks.useSafeLayoutEffect((()=>{if(!r)return;if(!s)return;if(!t.moves)return;const e=c.current?.ref.current;e&&d()}),[r,s,t.moves]),hooks.useSafeLayoutEffect((()=>{if(!r)return;if(!t.moves)return;if(!v.current)return;const e=i.current;if(!e)return;const s=f.current;f.current=null,s&&events.fireBlurEvent(s,{relatedTarget:e}),focus.hasFocus(e)?events.fireFocusEvent(e,{relatedTarget:s}):e.focus()}),[r,t.moves]),hooks.useSafeLayoutEffect((()=>{if(!u)return;if(!r)return;const e=f.current;if(f.current=null,!e)return;const t=c.current?.ref.current,s=t||dom.getActiveElement(e);events.fireBlurEvent(e,{relatedTarget:s})}),[u,r,t.activeId]);const m=useKeyboardEventProxy(t,a,n.onKeyDownCapture,f),y=useKeyboardEventProxy(t,a,n.onKeyUpCapture,f),p=n.onFocusCapture,k=hooks.useEvent((e=>{if(p?.(e),e.defaultPrevented)return;if(!u)return;const t=e.relatedTarget,r=__utils.silentlyFocused(e.currentTarget);events.isSelfTarget(e)&&r&&(e.stopPropagation(),f.current=t)})),E=n.onFocus,g=hooks.useEvent((e=>{E?.(e),e.defaultPrevented||r&&(u?events.isSelfTarget(e)&&!__utils.isItem(t.items,e.relatedTarget)&&misc.queueMicrotask(d):events.isSelfTarget(e)&&t.setActiveId(null))})),h=n.onBlurCapture,_=hooks.useEvent((e=>{if(h?.(e),e.defaultPrevented)return;if(!u)return;const r=a?.ref.current||null,s=e.relatedTarget,o=__utils.isItem(t.items,s),n=f.current;if(f.current=null,events.isSelfTarget(e)&&o)s===r?n&&n!==s&&events.fireBlurEvent(n,e):r&&events.fireBlurEvent(r,e),e.stopPropagation();else{!__utils.isItem(t.items,e.target)&&r&&events.fireBlurEvent(r,e)}})),b=n.onKeyDown,C=hooks.useBooleanEvent(o),I=hooks.useEvent((e=>{if(b?.(e),e.defaultPrevented)return;if(!events.isSelfTarget(e))return;if(c.current)return;const r="horizontal"!==t.orientation,s="vertical"!==t.orientation,o=isGrid(t.items),n={ArrowUp:(o||r)&&(()=>{if(o){const e=t.items&&findFirstEnabledItemInTheLastRow(t.items);return e?.id}return t.last()}),ArrowRight:(o||s)&&t.first,ArrowDown:(o||r)&&t.first,ArrowLeft:(o||s)&&t.last,Home:t.first,End:t.last,PageUp:t.first,PageDown:t.last}[e.key];if(n){const r=n();if(void 0!==r){if(!C(e))return;e.preventDefault(),t.move(r)}}}));n=store.useStoreProvider({state:t,...n},__utils.CompositeContext);n={"aria-activedescendant":u?a?.id||void 0:void 0,...n,ref:hooks.useForkRef(i,r?t.baseRef:void 0,n.ref),onKeyDownCapture:m,onKeyUpCapture:y,onFocusCapture:k,onFocus:g,onBlurCapture:_,onKeyDown:I};const P=r&&(u||null===t.activeId);return n=focusable_focusable.useFocusable({focusable:P,...n}),n})),Composite=system.createComponent((e=>{const t=useComposite(e);return system.createElement("div",t)}));"production"!=="production"&&(Composite.displayName="Composite"),exports.Composite=Composite,exports.useComposite=useComposite;

},{"../__utils-09a0f6df.js":30,"../focusable/focusable.js":70,"ariakit-react-utils/hooks":20,"ariakit-react-utils/store":22,"ariakit-react-utils/system":23,"ariakit-utils/array":24,"ariakit-utils/dom":25,"ariakit-utils/events":26,"ariakit-utils/focus":27,"ariakit-utils/misc":28,"react":146}],43:[function(require,module,exports){
"use strict";var react=require("react"),store=require("ariakit-react-utils/store"),system=require("ariakit-react-utils/system"),misc=require("ariakit-utils/misc"),__utils=require("../__utils-2acb1967.js"),jsxRuntime=require("react/jsx-runtime");function normalizeValue(e){return misc.normalizeString(e).toLowerCase()}function splitValue(e,t){t=normalizeValue(t);let o=normalizeValue(e).indexOf(t);const s=[];for(;-1!==o;)0!==o&&s.push(jsxRuntime.jsx("span",{"data-autocomplete-value":"",children:e.substr(0,o)},s.length)),s.push(jsxRuntime.jsx("span",{"data-user-value":"",children:e.substr(o,t.length)},s.length)),o=normalizeValue(e=e.substr(o+t.length)).indexOf(t);return e&&s.push(jsxRuntime.jsx("span",{"data-autocomplete-value":"",children:e},s.length)),s}const useComboboxItemValue=system.createHook((e=>{let{state:t,value:o,...s}=e;t=store.useStore(t||__utils.ComboboxContext,["value"]);const u=react.useContext(__utils.ComboboxItemValueContext),a=o??u;return s={children:react.useMemo((()=>a&&t?.value?splitValue(a,t.value):a),[a,t?.value]),...s},s})),ComboboxItemValue=system.createComponent((e=>{const t=useComboboxItemValue(e);return system.createElement("span",t)}));"production"!=="production"&&(ComboboxItemValue.displayName="ComboboxItemValue"),exports.ComboboxItemValue=ComboboxItemValue,exports.useComboboxItemValue=useComboboxItemValue;

},{"../__utils-2acb1967.js":33,"ariakit-react-utils/store":22,"ariakit-react-utils/system":23,"ariakit-utils/misc":28,"react":146,"react/jsx-runtime":147}],45:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),store=require("ariakit-react-utils/store"),system=require("ariakit-react-utils/system"),__utils=require("../__utils-2acb1967.js");const useComboboxList=system.createHook((e=>{let{state:o,...t}=e;const s=react.useRef(null),r=hooks.useId(t.id),i=t.onKeyDown,u=hooks.useEvent((e=>{i?.(e),e.defaultPrevented||"Escape"===e.key&&o.move(null)}));t=store.useStoreProvider({state:o,...t},__utils.ComboboxContext);const n=o.mounted?t.style:{...t.style,display:"none"};return t={id:r,role:"listbox",hidden:!o.mounted,...t,ref:hooks.useForkRef(r?o.setContentElement:null,s,t.ref),style:n,onKeyDown:u},t})),ComboboxList=system.createComponent((e=>{const o=useComboboxList(e);return system.createElement("div",o)}));"production"!=="production"&&(ComboboxList.displayName="ComboboxList"),exports.ComboboxList=ComboboxList,exports.useComboboxList=useComboboxList;

},{"../__utils-2acb1967.js":33,"ariakit-react-utils/hooks":20,"ariakit-react-utils/store":22,"ariakit-react-utils/system":23,"react":146}],36:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),system=require("ariakit-react-utils/system"),dom=require("ariakit-utils/dom"),command_command=require("../command/command.js");const useButton=system.createHook((t=>{const e=react.useRef(null),o=hooks.useTagName(e,t.as||"button"),[r,s]=react.useState((()=>!!o&&dom.isButton({tagName:o,type:t.type})));return react.useEffect((()=>{e.current&&s(dom.isButton(e.current))}),[]),t={role:r||"a"===o?void 0:"button",...t,ref:hooks.useForkRef(e,t.ref)},t=command_command.useCommand(t)})),Button=system.createComponent((t=>{const e=useButton(t);return system.createElement("button",e)}));"production"!=="production"&&(Button.displayName="Button"),exports.Button=Button,exports.useButton=useButton;

},{"../command/command.js":52,"ariakit-react-utils/hooks":20,"ariakit-react-utils/system":23,"ariakit-utils/dom":25,"react":146}],56:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),store=require("ariakit-react-utils/store"),system=require("ariakit-react-utils/system"),dom=require("ariakit-utils/dom"),events=require("ariakit-utils/events"),collection_collectionItem=require("../collection/collection-item.js"),command_command=require("../command/command.js"),__utils=require("../__utils-09a0f6df.js"),jsxRuntime=require("react/jsx-runtime");function isEditableElement(e){return!!e.isContentEditable||(!!dom.isTextField(e)||"INPUT"===e.tagName&&!dom.isButton(e))}function getNextPageOffset(e,t){void 0===t&&(t=!1);const r=e.clientHeight,{top:o}=e.getBoundingClientRect(),i=1.5*Math.max(.875*r,r-40),n=t?r-i+o:i+o;return"HTML"===e.tagName?n+e.scrollTop:n}function getItemOffset(e,t){void 0===t&&(t=!1);const{top:r}=e.getBoundingClientRect();return t?r+e.clientHeight:r}function findNextPageItemId(e,t,r,o){if(void 0===o&&(o=!1),!t)return;if(!r)return;const i=dom.getScrollingElement(e);if(!i)return;const n=getNextPageOffset(i,o);let s,u;for(let e=0;e<t.length;e+=1){const i=s;if(s=r(e),!s)break;if(s===i)continue;const a=__utils.findEnabledItemById(t,s),c=a?.ref.current;if(!c)continue;const l=getItemOffset(c,o)-n,m=Math.abs(l);if(o&&l<=0||!o&&l>=0){void 0!==u&&u<m&&(s=i);break}u=m}return s}function useItem(e,t){return react.useMemo((()=>{if(t)return e?.find((e=>e.id===t))}),[e,t])}function targetIsAnotherItem(e,t){if(events.isSelfTarget(e))return!1;const r=e.target;return __utils.isItem(t,r,e.currentTarget)}function useRole(e,t){const[r,o]=react.useState(t.role);return hooks.useSafeLayoutEffect((()=>{const r=e.current;r&&o(r.getAttribute("role")||t.role)}),[t.role]),r}function requiresAriaSelected(e){return"option"===e||"treeitem"===e}function supportsAriaSelected(e){return"option"===e||("tab"===e||("treeitem"===e||("gridcell"===e||("row"===e||("columnheader"===e||"rowheader"===e)))))}const useCompositeItem=system.createHook((e=>{let{state:t,rowId:r,preventScrollOnKeyDown:o=!1,moveOnKeyPress:i=!0,getItem:n,...s}=e;const u=hooks.useId(s.id);t=store.useStore(t||__utils.CompositeContext,[react.useCallback((e=>e.activeId===u),[u]),"baseRef","items","virtualFocus","registerItem","setActiveId","orientation","up","next","down","previous","first","last","move"]);const a=react.useRef(null),c=react.useContext(__utils.CompositeRowContext),l=r??__utils.getContextId(t,c),m=s.disabled&&!s.accessibleWhenDisabled,d=react.useCallback((e=>{const t={...e,id:u,rowId:l,disabled:!!m};return n?n(t):t}),[u,l,m,n]),f=s.onFocus,I=react.useRef(!1),v=hooks.useEvent((e=>{if(f?.(e),e.defaultPrevented)return;if(events.isPortalEvent(e))return;if(!u)return;if(t?.items&&targetIsAnotherItem(e,t.items))return;if(t?.activeId!==u&&t?.setActiveId(u),!t?.virtualFocus)return;if(!events.isSelfTarget(e))return;if(isEditableElement(e.currentTarget))return;const r=t.baseRef.current;if(!r)return;I.current=!0;e.relatedTarget===r||__utils.isItem(t.items,e.relatedTarget)?__utils.focusSilently(r):r.focus()})),g=s.onBlurCapture,p=hooks.useEvent((e=>{g?.(e),e.defaultPrevented||t?.virtualFocus&&I.current&&(I.current=!1,e.preventDefault(),e.stopPropagation())})),h=s.onKeyDown,C=hooks.useBooleanEvent(o),_=hooks.useBooleanEvent(i),b=useItem(t?.items,u),k=!!b?.rowId,x=hooks.useEvent((e=>{if(h?.(e),e.defaultPrevented)return;if(!events.isSelfTarget(e))return;const r="horizontal"!==t?.orientation,o="vertical"!==t?.orientation,i={ArrowUp:(k||r)&&t?.up,ArrowRight:(k||o)&&t?.next,ArrowDown:(k||r)&&t?.down,ArrowLeft:(k||o)&&t?.previous,Home:()=>!k||e.ctrlKey?t?.first():t?.previous(-1),End:()=>!k||e.ctrlKey?t?.last():t?.next(-1),PageUp:()=>findNextPageItemId(e.currentTarget,t?.items,t?.up,!0),PageDown:()=>findNextPageItemId(e.currentTarget,t?.items,t?.down)}[e.key];if(i){const r=i();if(C(e)||void 0!==r){if(!_(e))return;e.preventDefault(),t?.move(r)}}})),E=react.useMemo((()=>({id:u,baseRef:t?.baseRef})),[u,t?.baseRef]);s=hooks.useWrapElement(s,(e=>jsxRuntime.jsx(__utils.CompositeItemContext.Provider,{value:E,children:e})),[E]);const w=t?.activeId===u,R=useRole(a,s);let y;w&&(requiresAriaSelected(R)||t?.virtualFocus&&supportsAriaSelected(R))&&(y=!0);const P=!t?.virtualFocus&&w||!t?.items.length;return s={id:u,"aria-selected":y,"data-active-item":w?"":void 0,...s,ref:hooks.useForkRef(a,s.ref),tabIndex:P?s.tabIndex:-1,onFocus:v,onBlurCapture:p,onKeyDown:x},s=command_command.useCommand(s),s=collection_collectionItem.useCollectionItem({state:t,...s,getItem:d,shouldRegisterItem:!!u&&s.shouldRegisterItem}),s})),CompositeItem=store.createMemoComponent((e=>{const t=useCompositeItem(e);return system.createElement("button",t)}));"production"!=="production"&&(CompositeItem.displayName="CompositeItem"),exports.CompositeItem=CompositeItem,exports.useCompositeItem=useCompositeItem;

},{"../__utils-09a0f6df.js":30,"../collection/collection-item.js":37,"../command/command.js":52,"ariakit-react-utils/hooks":20,"ariakit-react-utils/store":22,"ariakit-react-utils/system":23,"ariakit-utils/dom":25,"ariakit-utils/events":26,"react":146,"react/jsx-runtime":147}],41:[function(require,module,exports){
"use strict";var system=require("ariakit-react-utils/system"),composite_compositeGroupLabel=require("../composite/composite-group-label.js");const useComboboxGroupLabel=system.createHook((o=>o=composite_compositeGroupLabel.useCompositeGroupLabel(o))),ComboboxGroupLabel=system.createComponent((o=>{const e=useComboboxGroupLabel(o);return system.createElement("div",e)}));"production"!=="production"&&(ComboboxGroupLabel.displayName="ComboboxGroupLabel"),exports.ComboboxGroupLabel=ComboboxGroupLabel,exports.useComboboxGroupLabel=useComboboxGroupLabel;

},{"../composite/composite-group-label.js":53,"ariakit-react-utils/system":23}],42:[function(require,module,exports){
"use strict";var system=require("ariakit-react-utils/system"),composite_compositeGroup=require("../composite/composite-group.js");const useComboboxGroup=system.createHook((o=>o=composite_compositeGroup.useCompositeGroup(o))),ComboboxGroup=system.createComponent((o=>{const e=useComboboxGroup(o);return system.createElement("div",e)}));"production"!=="production"&&(ComboboxGroup.displayName="ComboboxGroup"),exports.ComboboxGroup=ComboboxGroup,exports.useComboboxGroup=useComboboxGroup;

},{"../composite/composite-group.js":54,"ariakit-react-utils/system":23}],68:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),system=require("ariakit-react-utils/system"),focus=require("ariakit-utils/focus"),focusTrap_focusTrap=require("./focus-trap.js"),jsxRuntime=require("react/jsx-runtime");const useFocusTrapRegion=system.createHook((e=>{let{enabled:s=!1,...r}=e;const o=react.useRef(null);return r=hooks.useWrapElement(r,(e=>{const r=()=>s?jsxRuntime.jsx(focusTrap_focusTrap.FocusTrap,{onFocus:e=>{const s=o.current;if(!s)return;const r=focus.getAllTabbableIn(s,!0),t=r[0],u=r[r.length-1];r.length?e.relatedTarget===t?u?.focus():t?.focus():s.focus()}}):null;return jsxRuntime.jsxs(jsxRuntime.Fragment,{children:[r(),e,r()]})}),[s]),r={...r,ref:hooks.useForkRef(o,r.ref)},r})),FocusTrapRegion=system.createComponent((e=>{const s=useFocusTrapRegion(e);return system.createElement("div",s)}));"production"!=="production"&&(FocusTrapRegion.displayName="FocusTrapRegion"),exports.FocusTrapRegion=FocusTrapRegion,exports.useFocusTrapRegion=useFocusTrapRegion;

},{"./focus-trap.js":69,"ariakit-react-utils/hooks":20,"ariakit-react-utils/system":23,"ariakit-utils/focus":27,"react":146,"react/jsx-runtime":147}],78:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),misc=require("ariakit-react-utils/misc"),system=require("ariakit-react-utils/system"),dom=require("ariakit-utils/dom"),events=require("ariakit-utils/events"),focus=require("ariakit-utils/focus"),misc$1=require("ariakit-utils/misc"),reactDom=require("react-dom"),portal_portalContext=require("./portal-context.js"),jsxRuntime=require("react/jsx-runtime"),focusTrap_focusTrap=require("../focus-trap/focus-trap.js");function getRootElement(e){return dom.getDocument(e).body}function getPortalElement(e,t){return t?"function"==typeof t?t(e):t:dom.getDocument(e).createElement("div")}function getRandomId(e){return void 0===e&&(e="id"),`${e?`${e}-`:""}${Math.random().toString(36).substr(2,6)}`}function queueFocus(e){misc$1.queueMicrotask((()=>{e?.focus()}))}const usePortal=system.createHook((e=>{let{preserveTabOrder:t,portalElement:r,portalRef:s,portal:u=!0,...o}=e;const n=react.useRef(null),i=hooks.useForkRef(n,o.ref),c=react.useContext(portal_portalContext.PortalContext),[a,l]=react.useState(null),f=react.useRef(null),m=react.useRef(null),d=react.useRef(null),p=react.useRef(null);return hooks.useSafeLayoutEffect((()=>{const e=n.current;if(!e||!u)return void l(null);const t=getPortalElement(e,r);if(!t)return void l(null);const o=t.isConnected;if(!o){(c||getRootElement(e)).appendChild(t)}return t.id||(t.id=e.id?`${e.id}-portal`:getRandomId()),l(t),misc.setRef(s,t),o?void 0:()=>{t.remove(),misc.setRef(s,null)}}),[u,r,c,s]),react.useEffect((()=>{if(!a)return;if(!t)return;let e=0;const r=t=>{if(events.isFocusEventOutside(t)){if("focusin"===t.type)return focus.restoreFocusIn(a);cancelAnimationFrame(e),e=requestAnimationFrame((()=>{focus.disableFocusIn(a,!0)}))}};return a.addEventListener("focusin",r,!0),a.addEventListener("focusout",r,!0),()=>{a.removeEventListener("focusin",r,!0),a.removeEventListener("focusout",r,!0)}}),[a,t]),o=hooks.useWrapElement(o,(e=>(e=jsxRuntime.jsx(portal_portalContext.PortalContext.Provider,{value:a||c,children:e}),u?a?(e=jsxRuntime.jsxs(jsxRuntime.Fragment,{children:[t&&a&&jsxRuntime.jsx(focusTrap_focusTrap.FocusTrap,{ref:m,onFocus:e=>{if(events.isFocusEventOutside(e,a)){const e=focus.getNextTabbable();e!==d.current&&queueFocus(e)}else queueFocus(f.current)}}),e,t&&a&&jsxRuntime.jsx(focusTrap_focusTrap.FocusTrap,{ref:d,onFocus:e=>{if(events.isFocusEventOutside(e,a)){const e=focus.getPreviousTabbable();e!==m.current&&queueFocus(e)}else queueFocus(p.current)}})]}),a&&(e=reactDom.createPortal(e,a)),e=jsxRuntime.jsxs(jsxRuntime.Fragment,{children:[t&&a&&jsxRuntime.jsx(focusTrap_focusTrap.FocusTrap,{ref:f,onFocus:e=>{events.isFocusEventOutside(e,a)?queueFocus(m.current):queueFocus(focus.getPreviousTabbable())}}),t&&jsxRuntime.jsx("span",{"aria-owns":a?.id,style:{position:"fixed"}}),e,t&&a&&jsxRuntime.jsx(focusTrap_focusTrap.FocusTrap,{ref:p,onFocus:e=>{events.isFocusEventOutside(e,a)?queueFocus(d.current):queueFocus(focus.getNextTabbable())}})]})):jsxRuntime.jsx("span",{ref:i,id:o.id,style:{position:"fixed"}}):e)),[a,c,u,o.id,t]),o={...o,ref:i},o})),Portal=system.createComponent((e=>{const t=usePortal(e);return system.createElement("div",t)}));"production"!=="production"&&(Portal.displayName="Portal"),exports.Portal=Portal,exports.usePortal=usePortal;

},{"../focus-trap/focus-trap.js":69,"./portal-context.js":77,"ariakit-react-utils/hooks":20,"ariakit-react-utils/misc":21,"ariakit-react-utils/system":23,"ariakit-utils/dom":25,"ariakit-utils/events":26,"ariakit-utils/focus":27,"ariakit-utils/misc":28,"react":146,"react-dom":110,"react/jsx-runtime":147}],234:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});var useLocation$1=require("./use-location.js"),matcher=require("./matcher.js"),reactDeps=require("./react-deps.js"),React=require("react");const defaultRouter={hook:useLocation$1.default,matcher:matcher.default(),base:""},RouterCtx=React.createContext(defaultRouter),useRouter=()=>React.useContext(RouterCtx),useLocationFromRouter=e=>e.hook(e),useLocation=()=>useLocationFromRouter(useRouter()),useRoute=e=>{const t=useRouter(),[r]=useLocationFromRouter(t);return t.matcher(e,r)},Router=({hook:e,matcher:t,ssrPath:r,base:o="",parent:a,children:u})=>{const s=(u,s=a||defaultRouter)=>(u.hook=e||s.hook,u.matcher=t||s.matcher,u.ssrPath=r||s.ssrPath,u.ownBase=o,u.parent=a,u),[c]=React.useState((()=>s({get base(){return(c.parent||defaultRouter).base+c.ownBase}})));return reactDeps.useInsertionEffect((()=>{s(c)})),React.createElement(RouterCtx.Provider,{value:c,children:u})},Route=({path:e,match:t,component:r,children:o})=>{const a=useRoute(e),[u,s]=t||a;return u?r?React.createElement(r,{params:s}):"function"==typeof o?o(s):o:null},Link=React.forwardRef(((e,t)=>{const r=useRouter(),[,o]=useLocationFromRouter(r),{to:a,href:u=a,children:s,onClick:c}=e,n=reactDeps.useEvent((t=>{t.ctrlKey||t.metaKey||t.altKey||t.shiftKey||0!==t.button||(c&&c(t),t.defaultPrevented||(t.preventDefault(),o(a||u,e)))})),l={href:"~"===u[0]?u.slice(1):r.base+u,onClick:n,to:null,ref:t},i=React.isValidElement(s)?s:React.createElement("a",e);return React.cloneElement(i,l)})),flattenChildren=e=>Array.isArray(e)?[].concat(...e.map((e=>e&&e.type===React.Fragment?flattenChildren(e.props.children):flattenChildren(e)))):[e],Switch=({children:e,location:t})=>{const r=useRouter(),o=r.matcher,[a]=useLocationFromRouter(r);for(const r of flattenChildren(e)){let e=0;if(React.isValidElement(r)&&(e=r.props.path?o(r.props.path,t||a):[!0,{}])[0])return React.cloneElement(r,{match:e})}return null},Redirect=e=>{const{to:t,href:r=t}=e,[,o]=useLocation(),a=reactDeps.useEvent((()=>o(t||r,e)));return reactDeps.useIsomorphicLayoutEffect((()=>{a()}),[]),null};exports.Link=Link,exports.Redirect=Redirect,exports.Route=Route,exports.Router=Router,exports.Switch=Switch,exports.default=useRoute,exports.useLocation=useLocation,exports.useRoute=useRoute,exports.useRouter=useRouter;

},{"./matcher.js":235,"./react-deps.js":236,"./use-location.js":237,"react":146}],203:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.createParameter=exports.createValidateHeaders=exports.createIsHeaders=exports.createAssertHeaders=exports.createHeaders=exports.createValidateQuery=exports.createIsQuery=exports.createAssertQuery=exports.createQuery=exports.parameter=exports.validateHeaders=exports.isHeaders=exports.assertHeaders=exports.headers=exports.validateQuery=exports.isQuery=exports.assertQuery=exports.query=void 0;var Namespace_1=require("./functional/Namespace");function query(){halt("query")}function assertQuery(){halt("assertQuery")}function isQuery(){halt("isQuery")}function validateQuery(){halt("validateQuery")}function headers(){halt("headers")}function assertHeaders(){halt("assertHeaders")}function isHeaders(){halt("isHeaders")}function validateHeaders(){halt("validateHeaders")}function parameter(){halt("parameter")}function createQuery(){halt("createQuery")}function createAssertQuery(){halt("createAssertQuery")}function createIsQuery(){halt("createIsQuery")}function createValidateQuery(){halt("createValidateQuery")}function createHeaders(){halt("createHeaders")}function createAssertHeaders(){halt("createAssertHeaders")}function createIsHeaders(){halt("createIsHeaders")}function createValidateHeaders(){halt("createValidateHeaders")}function createParameter(){halt("createParameter")}function halt(e){throw new Error("Error on typia.http.".concat(e,"(): no transform has been configured. Read and follow https://typia.misc.io/docs/setup please."))}exports.query=query,Object.assign(query,Namespace_1.Namespace.http.query()),exports.assertQuery=assertQuery,Object.assign(assertQuery,Namespace_1.Namespace.http.query()),Object.assign(assertQuery,Namespace_1.Namespace.assert("http.assertQuery")),exports.isQuery=isQuery,Object.assign(isQuery,Namespace_1.Namespace.http.query()),Object.assign(isQuery,Namespace_1.Namespace.is()),exports.validateQuery=validateQuery,Object.assign(validateQuery,Namespace_1.Namespace.http.query()),Object.assign(validateQuery,Namespace_1.Namespace.validate()),exports.headers=headers,Object.assign(headers,Namespace_1.Namespace.http.headers()),exports.assertHeaders=assertHeaders,Object.assign(assertHeaders,Namespace_1.Namespace.http.headers()),Object.assign(assertHeaders,Namespace_1.Namespace.assert("http.assertHeaders")),exports.isHeaders=isHeaders,Object.assign(isHeaders,Namespace_1.Namespace.http.headers()),Object.assign(isHeaders,Namespace_1.Namespace.is()),exports.validateHeaders=validateHeaders,Object.assign(validateHeaders,Namespace_1.Namespace.http.headers()),Object.assign(validateHeaders,Namespace_1.Namespace.validate()),exports.parameter=parameter,Object.assign(parameter,Namespace_1.Namespace.http.parameter()),Object.assign(parameter,Namespace_1.Namespace.assert("http.parameter")),exports.createQuery=createQuery,Object.assign(createQuery,Namespace_1.Namespace.http.query()),exports.createAssertQuery=createAssertQuery,Object.assign(createAssertQuery,Namespace_1.Namespace.http.query()),Object.assign(createAssertQuery,Namespace_1.Namespace.assert("http.createAssertQuery")),exports.createIsQuery=createIsQuery,Object.assign(createIsQuery,Namespace_1.Namespace.http.query()),Object.assign(createIsQuery,Namespace_1.Namespace.is()),exports.createValidateQuery=createValidateQuery,Object.assign(createValidateQuery,Namespace_1.Namespace.http.query()),Object.assign(createValidateQuery,Namespace_1.Namespace.validate()),exports.createHeaders=createHeaders,Object.assign(createHeaders,Namespace_1.Namespace.http.headers()),exports.createAssertHeaders=createAssertHeaders,Object.assign(createAssertHeaders,Namespace_1.Namespace.http.headers()),Object.assign(createAssertHeaders,Namespace_1.Namespace.assert("http.createAssertHeaders")),exports.createIsHeaders=createIsHeaders,Object.assign(createIsHeaders,Namespace_1.Namespace.http.headers()),Object.assign(createIsHeaders,Namespace_1.Namespace.is()),exports.createValidateHeaders=createValidateHeaders,Object.assign(createValidateHeaders,Namespace_1.Namespace.http.headers()),Object.assign(createValidateHeaders,Namespace_1.Namespace.validate()),exports.createParameter=createParameter,Object.assign(createParameter,Namespace_1.Namespace.http.parameter()),Object.assign(createParameter,Namespace_1.Namespace.assert("http.createParameter"));

},{"./functional/Namespace":202}],205:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.createValidateStringify=exports.createIsStringify=exports.createAssertStringify=exports.createStringify=exports.createValidateParse=exports.createAssertParse=exports.createIsParse=exports.validateStringify=exports.isStringify=exports.assertStringify=exports.stringify=exports.validateParse=exports.isParse=exports.assertParse=exports.application=void 0;var Namespace_1=require("./functional/Namespace");function application(){halt("application")}function assertParse(){halt("assertParse")}function isParse(){halt("isParse")}function validateParse(){halt("validateParse")}function stringify(){halt("stringify")}function assertStringify(){halt("assertStringify")}function isStringify(){halt("isStringify")}function validateStringify(){halt("validateStringify")}function createIsParse(){halt("createIsParse")}function createAssertParse(){halt("createAssertParse")}function createValidateParse(){halt("createValidateParse")}function createStringify(){halt("createStringify")}function createAssertStringify(){halt("createAssertStringify")}function createIsStringify(){halt("createIsStringify")}function createValidateStringify(){halt("createValidateStringify")}function halt(e){throw new Error("Error on typia.json.".concat(e,"(): no transform has been configured. Read and follow https://typia.json.io/docs/setup please."))}exports.application=application,exports.assertParse=assertParse,Object.assign(assertParse,Namespace_1.Namespace.assert("json.assertParse")),exports.isParse=isParse,Object.assign(isParse,Namespace_1.Namespace.is()),exports.validateParse=validateParse,Object.assign(validateParse,Namespace_1.Namespace.validate()),exports.stringify=stringify,Object.assign(stringify,Namespace_1.Namespace.json.stringify("stringify")),exports.assertStringify=assertStringify,Object.assign(assertStringify,Namespace_1.Namespace.assert("json.assertStringify")),Object.assign(assertStringify,Namespace_1.Namespace.json.stringify("assertStringify")),exports.isStringify=isStringify,Object.assign(isStringify,Namespace_1.Namespace.is()),Object.assign(isStringify,Namespace_1.Namespace.json.stringify("isStringify")),exports.validateStringify=validateStringify,Object.assign(validateStringify,Namespace_1.Namespace.validate()),Object.assign(validateStringify,Namespace_1.Namespace.json.stringify("validateStringify")),exports.createIsParse=createIsParse,Object.assign(createIsParse,isParse),exports.createAssertParse=createAssertParse,Object.assign(createAssertParse,assertParse),exports.createValidateParse=createValidateParse,Object.assign(createValidateParse,validateParse),exports.createStringify=createStringify,Object.assign(createStringify,stringify),exports.createAssertStringify=createAssertStringify,Object.assign(createAssertStringify,assertStringify),exports.createIsStringify=createIsStringify,Object.assign(createIsStringify,isStringify),exports.createValidateStringify=createValidateStringify,Object.assign(createValidateStringify,validateStringify);

},{"./functional/Namespace":202}],206:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.createValidatePrune=exports.createIsPrune=exports.createAssertPrune=exports.createPrune=exports.createValidateClone=exports.createIsClone=exports.createAssertClone=exports.createClone=exports.validatePrune=exports.isPrune=exports.assertPrune=exports.prune=exports.validateClone=exports.isClone=exports.assertClone=exports.clone=exports.literals=void 0;var Namespace_1=require("./functional/Namespace");function literals(){halt("literals")}function clone(){halt("clone")}function assertClone(){halt("assertClone")}function isClone(){halt("isClone")}function validateClone(){halt("validateClone")}function prune(){halt("prune")}function assertPrune(){halt("assertPrune")}function isPrune(){halt("isPrune")}function validatePrune(){halt("validatePrune")}function createClone(){halt("createClone")}function createAssertClone(){halt("createAssertClone")}function createIsClone(){halt("createIsClone")}function createValidateClone(){halt("createValidateClone")}function createPrune(){halt("createPrune")}function createAssertPrune(){halt("createAssertPrune")}function createIsPrune(){halt("createIsPrune")}function createValidatePrune(){halt("createValidatePrune")}function halt(e){throw new Error("Error on typia.misc.".concat(e,"(): no transform has been configured. Read and follow https://typia.misc.io/docs/setup please."))}exports.literals=literals,exports.clone=clone,Object.assign(clone,Namespace_1.Namespace.misc.clone("clone")),exports.assertClone=assertClone,Object.assign(assertClone,Namespace_1.Namespace.assert("misc.assertClone")),Object.assign(assertClone,Namespace_1.Namespace.misc.clone("assertClone")),exports.isClone=isClone,Object.assign(isClone,Namespace_1.Namespace.is()),Object.assign(isClone,Namespace_1.Namespace.misc.clone("isClone")),exports.validateClone=validateClone,Object.assign(validateClone,Namespace_1.Namespace.validate()),Object.assign(validateClone,Namespace_1.Namespace.misc.clone("validateClone")),exports.prune=prune,Object.assign(prune,Namespace_1.Namespace.misc.prune("prune")),exports.assertPrune=assertPrune,Object.assign(assertPrune,Namespace_1.Namespace.assert("misc.assertPrune")),Object.assign(assertPrune,Namespace_1.Namespace.misc.prune("assertPrune")),exports.isPrune=isPrune,Object.assign(isPrune,Namespace_1.Namespace.is()),Object.assign(isPrune,Namespace_1.Namespace.misc.prune("isPrune")),exports.validatePrune=validatePrune,Object.assign(validatePrune,Namespace_1.Namespace.misc.prune("validatePrune")),Object.assign(validatePrune,Namespace_1.Namespace.validate()),exports.createClone=createClone,Object.assign(createClone,clone),exports.createAssertClone=createAssertClone,Object.assign(createAssertClone,assertClone),exports.createIsClone=createIsClone,Object.assign(createIsClone,isClone),exports.createValidateClone=createValidateClone,Object.assign(createValidateClone,validateClone),exports.createPrune=createPrune,Object.assign(createPrune,prune),exports.createAssertPrune=createAssertPrune,Object.assign(createAssertPrune,assertPrune),exports.createIsPrune=createIsPrune,Object.assign(createIsPrune,isPrune),exports.createValidatePrune=createValidatePrune,Object.assign(createValidatePrune,validatePrune);

},{"./functional/Namespace":202}],208:[function(require,module,exports){
"use strict";Object.defineProperty(exports,"__esModule",{value:!0}),exports.createValidateEncode=exports.createAssertEncode=exports.createIsEncode=exports.createEncode=exports.createValidateDecode=exports.createAssertDecode=exports.createIsDecode=exports.createDecode=exports.validateEncode=exports.isEncode=exports.assertEncode=exports.encode=exports.validateDecode=exports.isDecode=exports.assertDecode=exports.decode=exports.message=void 0;var Namespace_1=require("./functional/Namespace");function message(){halt("message")}function decode(){halt("decode")}function assertDecode(){halt("assertDecode")}function isDecode(){halt("isDecode")}function validateDecode(){halt("validateDecode")}function encode(){halt("encode")}function assertEncode(){halt("assertEncode")}function isEncode(){halt("isEncode")}function validateEncode(){halt("validateEncode")}function createDecode(){halt("createDecode")}function createIsDecode(){halt("createIsDecode")}function createAssertDecode(){halt("createAssertDecode")}function createValidateDecode(){halt("createValidateDecode")}function createEncode(){halt("createEncode")}function createIsEncode(){halt("createIsEncode")}function createAssertEncode(){halt("createAssertEncode")}function createValidateEncode(){halt("createValidateEncode")}function halt(e){throw new Error("Error on typia.protobuf.".concat(e,"(): no transform has been configured. Read and follow https://typia.io/docs/setup please."))}exports.message=message,exports.decode=decode,Object.assign(decode,Namespace_1.Namespace.protobuf.decode("decode")),exports.assertDecode=assertDecode,Object.assign(assertDecode,Namespace_1.Namespace.assert("protobuf.assertDecode")),Object.assign(assertDecode,Namespace_1.Namespace.protobuf.decode("assertDecode")),exports.isDecode=isDecode,Object.assign(isDecode,Namespace_1.Namespace.is()),Object.assign(isDecode,Namespace_1.Namespace.protobuf.decode("isDecode")),exports.validateDecode=validateDecode,Object.assign(validateDecode,Namespace_1.Namespace.validate()),Object.assign(validateDecode,Namespace_1.Namespace.protobuf.decode("validateDecode")),exports.encode=encode,Object.assign(encode,Namespace_1.Namespace.protobuf.encode("encode")),exports.assertEncode=assertEncode,Object.assign(assertEncode,Namespace_1.Namespace.assert("protobuf.assertEncode")),Object.assign(assertEncode,Namespace_1.Namespace.protobuf.encode("assertEncode")),exports.isEncode=isEncode,Object.assign(isEncode,Namespace_1.Namespace.is()),Object.assign(isEncode,Namespace_1.Namespace.protobuf.encode("isEncode")),exports.validateEncode=validateEncode,Object.assign(validateEncode,Namespace_1.Namespace.validate()),Object.assign(validateEncode,Namespace_1.Namespace.protobuf.encode("validateEncode")),exports.createDecode=createDecode,Object.assign(createDecode,Namespace_1.Namespace.protobuf.decode("createDecode")),exports.createIsDecode=createIsDecode,Object.assign(createIsDecode,Namespace_1.Namespace.is()),Object.assign(createIsDecode,Namespace_1.Namespace.protobuf.decode("createIsDecode")),exports.createAssertDecode=createAssertDecode,Object.assign(createAssertDecode,Namespace_1.Namespace.assert("protobuf.createAssertDecode")),Object.assign(createAssertDecode,Namespace_1.Namespace.protobuf.decode("createAssertDecode")),exports.createValidateDecode=createValidateDecode,Object.assign(createValidateDecode,Namespace_1.Namespace.validate()),Object.assign(createValidateDecode,Namespace_1.Namespace.protobuf.decode("createValidateDecode")),exports.createEncode=createEncode,Object.assign(createEncode,Namespace_1.Namespace.protobuf.encode("createEncode")),exports.createIsEncode=createIsEncode,Object.assign(createIsEncode,Namespace_1.Namespace.is()),Object.assign(createIsEncode,Namespace_1.Namespace.protobuf.encode("createIsEncode")),exports.createAssertEncode=createAssertEncode,Object.assign(createAssertEncode,Namespace_1.Namespace.assert("protobuf.createAssertEncode")),Object.assign(createAssertEncode,Namespace_1.Namespace.protobuf.encode("createAssertEncode")),exports.createValidateEncode=createValidateEncode,Object.assign(createValidateEncode,Namespace_1.Namespace.validate()),Object.assign(createValidateEncode,Namespace_1.Namespace.protobuf.encode("createValidateEncode"));

},{"./functional/Namespace":202}],16:[function(require,module,exports){
(function (process,global){(function (){
var QueryStatus,__generator=this&&this.__generator||function(e,t){var r,n,i,a,o={label:0,sent:function(){if(1&i[0])throw i[1];return i[1]},trys:[],ops:[]};return a={next:u(0),throw:u(1),return:u(2)},"function"==typeof Symbol&&(a[Symbol.iterator]=function(){return this}),a;function u(a){return function(u){return function(a){if(r)throw new TypeError("Generator is already executing.");for(;o;)try{if(r=1,n&&(i=2&a[0]?n.return:a[0]?n.throw||((i=n.return)&&i.call(n),0):n.next)&&!(i=i.call(n,a[1])).done)return i;switch(n=0,i&&(a=[2&a[0],i.value]),a[0]){case 0:case 1:i=a;break;case 4:return o.label++,{value:a[1],done:!1};case 5:o.label++,n=a[1],a=[0];continue;case 7:a=o.ops.pop(),o.trys.pop();continue;default:if(!(i=o.trys,(i=i.length>0&&i[i.length-1])||6!==a[0]&&2!==a[0])){o=0;continue}if(3===a[0]&&(!i||a[1]>i[0]&&a[1]<i[3])){o.label=a[1];break}if(6===a[0]&&o.label<i[1]){o.label=i[1],i=a;break}if(i&&o.label<i[2]){o.label=i[2],o.ops.push(a);break}i[2]&&o.ops.pop(),o.trys.pop();continue}a=t.call(e,o)}catch(e){a=[6,e],n=0}finally{r=i=0}if(5&a[0])throw a[1];return{value:a[0]?a[1]:void 0,done:!0}}([a,u])}}},__spreadArray=this&&this.__spreadArray||function(e,t){for(var r=0,n=t.length,i=e.length;r<n;r++,i++)e[i]=t[r];return e},__create=Object.create,__defProp=Object.defineProperty,__defProps=Object.defineProperties,__getOwnPropDesc=Object.getOwnPropertyDescriptor,__getOwnPropDescs=Object.getOwnPropertyDescriptors,__getOwnPropNames=Object.getOwnPropertyNames,__getOwnPropSymbols=Object.getOwnPropertySymbols,__getProtoOf=Object.getPrototypeOf,__hasOwnProp=Object.prototype.hasOwnProperty,__propIsEnum=Object.prototype.propertyIsEnumerable,__defNormalProp=function(e,t,r){return t in e?__defProp(e,t,{enumerable:!0,configurable:!0,writable:!0,value:r}):e[t]=r},__spreadValues=function(e,t){for(var r in t||(t={}))__hasOwnProp.call(t,r)&&__defNormalProp(e,r,t[r]);if(__getOwnPropSymbols)for(var n=0,i=__getOwnPropSymbols(t);n<i.length;n++){r=i[n];__propIsEnum.call(t,r)&&__defNormalProp(e,r,t[r])}return e},__spreadProps=function(e,t){return __defProps(e,__getOwnPropDescs(t))},__markAsModule=function(e){return __defProp(e,"__esModule",{value:!0})},__objRest=function(e,t){var r={};for(var n in e)__hasOwnProp.call(e,n)&&t.indexOf(n)<0&&(r[n]=e[n]);if(null!=e&&__getOwnPropSymbols)for(var i=0,a=__getOwnPropSymbols(e);i<a.length;i++){n=a[i];t.indexOf(n)<0&&__propIsEnum.call(e,n)&&(r[n]=e[n])}return r},__export=function(e,t){for(var r in t)__defProp(e,r,{get:t[r],enumerable:!0})},__reExport=function(e,t,r){if(t&&"object"==typeof t||"function"==typeof t)for(var n=function(n){__hasOwnProp.call(e,n)||"default"===n||__defProp(e,n,{get:function(){return t[n]},enumerable:!(r=__getOwnPropDesc(t,n))||r.enumerable})},i=0,a=__getOwnPropNames(t);i<a.length;i++){n(a[i])}return e},__toModule=function(e){return __reExport(__markAsModule(__defProp(null!=e?__create(__getProtoOf(e)):{},"default",e&&e.__esModule&&"default"in e?{get:function(){return e.default},enumerable:!0}:{value:e,enumerable:!0})),e)},__async=function(e,t,r){return new Promise((function(n,i){var a=function(e){try{u(r.next(e))}catch(e){i(e)}},o=function(e){try{u(r.throw(e))}catch(e){i(e)}},u=function(e){return e.done?n(e.value):Promise.resolve(e.value).then(a,o)};u((r=r.apply(e,t)).next())}))};function getRequestStatusFlags(e){return{status:e,isUninitialized:e===QueryStatus.uninitialized,isLoading:e===QueryStatus.pending,isSuccess:e===QueryStatus.fulfilled,isError:e===QueryStatus.rejected}}function isAbsoluteUrl(e){return new RegExp("(^|:)//").test(e)}__markAsModule(exports),__export(exports,{QueryStatus:function(){return QueryStatus},buildCreateApi:function(){return buildCreateApi},copyWithStructuralSharing:function(){return copyWithStructuralSharing},coreModule:function(){return coreModule},coreModuleName:function(){return coreModuleName},createApi:function(){return createApi},defaultSerializeQueryArgs:function(){return defaultSerializeQueryArgs},fakeBaseQuery:function(){return fakeBaseQuery},fetchBaseQuery:function(){return fetchBaseQuery},retry:function(){return retry},setupListeners:function(){return setupListeners},skipSelector:function(){return skipSelector},skipToken:function(){return skipToken}}),function(e){e.uninitialized="uninitialized",e.pending="pending",e.fulfilled="fulfilled",e.rejected="rejected"}(QueryStatus||(QueryStatus={}));var withoutTrailingSlash=function(e){return e.replace(/\/$/,"")},withoutLeadingSlash=function(e){return e.replace(/^\//,"")};function joinUrls(e,t){if(!e)return t;if(!t)return e;if(isAbsoluteUrl(t))return t;var r=e.endsWith("/")||!t.startsWith("?")?"/":"";return""+(e=withoutTrailingSlash(e))+r+(t=withoutLeadingSlash(t))}var flatten=function(e){return[].concat.apply([],e)};function isOnline(){return"undefined"==typeof navigator||(void 0===navigator.onLine||navigator.onLine)}function isDocumentVisible(){return"undefined"==typeof document||"hidden"!==document.visibilityState}var import_toolkit=__toModule(require("@reduxjs/toolkit")),isPlainObject=import_toolkit.isPlainObject;function copyWithStructuralSharing(e,t){if(e===t||!(isPlainObject(e)&&isPlainObject(t)||Array.isArray(e)&&Array.isArray(t)))return t;for(var r=Object.keys(t),n=Object.keys(e),i=r.length===n.length,a=Array.isArray(t)?[]:{},o=0,u=r;o<u.length;o++){var s=u[o];a[s]=copyWithStructuralSharing(e[s],t[s]),i&&(i=e[s]===a[s])}return i?e:a}var import_toolkit2=__toModule(require("@reduxjs/toolkit")),defaultFetchFn=function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return fetch.apply(void 0,e)},defaultValidateStatus=function(e){return e.status>=200&&e.status<=299},defaultIsJsonContentType=function(e){return/ion\/(vnd\.api\+)?json/.test(e.get("content-type")||"")};function stripUndefined(e){if(!(0,import_toolkit2.isPlainObject)(e))return e;for(var t=__spreadValues({},e),r=0,n=Object.entries(t);r<n.length;r++){var i=n[r],a=i[0];void 0===i[1]&&delete t[a]}return t}function fetchBaseQuery(e){var t=this;void 0===e&&(e={});var r=e,n=r.baseUrl,i=r.prepareHeaders,a=void 0===i?function(e){return e}:i,o=r.fetchFn,u=void 0===o?defaultFetchFn:o,s=r.paramsSerializer,l=r.isJsonContentType,c=void 0===l?defaultIsJsonContentType:l,d=r.jsonContentType,f=void 0===d?"application/json":d,p=r.jsonReplacer,y=r.timeout,h=r.responseHandler,m=r.validateStatus,v=__objRest(r,["baseUrl","prepareHeaders","fetchFn","paramsSerializer","isJsonContentType","jsonContentType","jsonReplacer","timeout","responseHandler","validateStatus"]);return"undefined"==typeof fetch&&u===defaultFetchFn&&console.warn("Warning: `fetch` is not available. Please supply a custom `fetchFn` property to use `fetchBaseQuery` on SSR environments."),function(e,r){return __async(t,null,(function(){var t,i,o,l,d,_,b,S,k,T,O,q,A,w,P,Q,R,j,M,x,I,C,D,E,N,F,K,B,H,U,z,V,L,W,J,Y;return __generator(this,(function(X){switch(X.label){case 0:return t=r.signal,i=r.getState,o=r.extra,l=r.endpoint,d=r.forced,_=r.type,k=(S="string"==typeof e?{url:e}:e).url,T=S.headers,O=void 0===T?new Headers(v.headers):T,q=S.params,A=void 0===q?void 0:q,w=S.responseHandler,P=void 0===w?null!=h?h:"json":w,Q=S.validateStatus,R=void 0===Q?null!=m?m:defaultValidateStatus:Q,j=S.timeout,M=void 0===j?y:j,x=__objRest(S,["url","headers","params","responseHandler","validateStatus","timeout"]),I=__spreadValues(__spreadProps(__spreadValues({},v),{signal:t}),x),O=new Headers(stripUndefined(O)),C=I,[4,a(O,{getState:i,extra:o,endpoint:l,forced:d,type:_})];case 1:C.headers=X.sent()||O,D=function(e){return"object"==typeof e&&((0,import_toolkit2.isPlainObject)(e)||Array.isArray(e)||"function"==typeof e.toJSON)},!I.headers.has("content-type")&&D(I.body)&&I.headers.set("content-type",f),D(I.body)&&c(I.headers)&&(I.body=JSON.stringify(I.body,p)),A&&(E=~k.indexOf("?")?"&":"?",N=s?s(A):new URLSearchParams(stripUndefined(A)),k+=E+N),k=joinUrls(n,k),F=new Request(k,I),K=new Request(k,I),b={request:K},H=!1,U=M&&setTimeout((function(){H=!0,r.abort()}),M),X.label=2;case 2:return X.trys.push([2,4,5,6]),[4,u(F)];case 3:return B=X.sent(),[3,6];case 4:return z=X.sent(),[2,{error:{status:H?"TIMEOUT_ERROR":"FETCH_ERROR",error:String(z)},meta:b}];case 5:return U&&clearTimeout(U),[7];case 6:V=B.clone(),b.response=V,W="",X.label=7;case 7:return X.trys.push([7,9,,10]),[4,Promise.all([g(B,P).then((function(e){return L=e}),(function(e){return J=e})),V.text().then((function(e){return W=e}),(function(){}))])];case 8:if(X.sent(),J)throw J;return[3,10];case 9:return Y=X.sent(),[2,{error:{status:"PARSING_ERROR",originalStatus:B.status,data:W,error:String(Y)},meta:b}];case 10:return[2,R(B,L)?{data:L,meta:b}:{error:{status:B.status,data:L},meta:b}]}}))}))};function g(e,t){return __async(this,null,(function(){var r;return __generator(this,(function(n){switch(n.label){case 0:return"function"==typeof t?[2,t(e)]:("content-type"===t&&(t=c(e.headers)?"json":"text"),"json"!==t?[3,2]:[4,e.text()]);case 1:return[2,(r=n.sent()).length?JSON.parse(r):null];case 2:return[2,e.text()]}}))}))}}var HandledError=function(e,t){void 0===t&&(t=void 0),this.value=e,this.meta=t};function defaultBackoff(e,t){return void 0===e&&(e=0),void 0===t&&(t=5),__async(this,null,(function(){var r,n;return __generator(this,(function(i){switch(i.label){case 0:return r=Math.min(e,t),n=~~((Math.random()+.4)*(300<<r)),[4,new Promise((function(e){return setTimeout((function(t){return e(t)}),n)}))];case 1:return i.sent(),[2]}}))}))}function fail(e){throw Object.assign(new HandledError({error:e}),{throwImmediately:!0})}var EMPTY_OPTIONS={},retryWithBackoff=function(e,t){return function(r,n,i){return __async(void 0,null,(function(){var a,o,u,s,l,c,d;return __generator(this,(function(f){switch(f.label){case 0:a=[5,(t||EMPTY_OPTIONS).maxRetries,(i||EMPTY_OPTIONS).maxRetries].filter((function(e){return void 0!==e})),o=a.slice(-1)[0],u=function(e,t,r){return r.attempt<=o},s=__spreadValues(__spreadValues({maxRetries:o,backoff:defaultBackoff,retryCondition:u},t),i),l=0,f.label=1;case 1:0,f.label=2;case 2:return f.trys.push([2,4,,6]),[4,e(r,n,i)];case 3:if((c=f.sent()).error)throw new HandledError(c);return[2,c];case 4:if(d=f.sent(),l++,d.throwImmediately){if(d instanceof HandledError)return[2,d.value];throw d}return d instanceof HandledError&&!s.retryCondition(d.value.error,r,{attempt:l,baseQueryApi:n,extraOptions:i})?[2,d.value]:[4,s.backoff(l,s.maxRetries)];case 5:return f.sent(),[3,6];case 6:return[3,1];case 7:return[2]}}))}))}},retry=Object.assign(retryWithBackoff,{fail:fail}),import_toolkit3=__toModule(require("@reduxjs/toolkit")),onFocus=(0,import_toolkit3.createAction)("__rtkq/focused"),onFocusLost=(0,import_toolkit3.createAction)("__rtkq/unfocused"),onOnline=(0,import_toolkit3.createAction)("__rtkq/online"),onOffline=(0,import_toolkit3.createAction)("__rtkq/offline"),initialized=!1;function setupListeners(e,t){return t?t(e,{onFocus:onFocus,onFocusLost:onFocusLost,onOffline:onOffline,onOnline:onOnline}):(r=function(){return e(onFocus())},n=function(){return e(onOnline())},i=function(){return e(onOffline())},a=function(){"visible"===window.document.visibilityState?r():e(onFocusLost())},initialized||"undefined"!=typeof window&&window.addEventListener&&(window.addEventListener("visibilitychange",a,!1),window.addEventListener("focus",r,!1),window.addEventListener("online",n,!1),window.addEventListener("offline",i,!1),initialized=!0),function(){window.removeEventListener("focus",r),window.removeEventListener("visibilitychange",a),window.removeEventListener("online",n),window.removeEventListener("offline",i),initialized=!1});var r,n,i,a}var DefinitionType,import_toolkit7=__toModule(require("@reduxjs/toolkit"));function isQueryDefinition(e){return e.type===DefinitionType.query}function isMutationDefinition(e){return e.type===DefinitionType.mutation}function calculateProvidedBy(e,t,r,n,i,a){return isFunction(e)?e(t,r,n,i).map(expandTagDescription).map(a):Array.isArray(e)?e.map(expandTagDescription).map(a):[]}function isFunction(e){return"function"==typeof e}function expandTagDescription(e){return"string"==typeof e?{type:e}:e}!function(e){e.query="query",e.mutation="mutation"}(DefinitionType||(DefinitionType={}));var import_toolkit6=__toModule(require("@reduxjs/toolkit"));function isNotNullish(e){return null!=e}var forceQueryFnSymbol=Symbol("forceQueryFn"),isUpsertQuery=function(e){return"function"==typeof e[forceQueryFnSymbol]};function buildInitiate(e){var t=e.serializeQueryArgs,r=e.queryThunk,n=e.mutationThunk,i=e.api,a=e.context,o=new Map,u=new Map,s=i.internalActions,l=s.unsubscribeQueryResult,c=s.removeMutationResult,d=s.updateSubscriptionOptions;return{buildInitiateQuery:function(e,n){var a=function(u,s){var c=void 0===s?{}:s,f=c.subscribe,y=void 0===f||f,h=c.forceRefetch,m=c.subscriptionOptions,v=c[forceQueryFnSymbol];return function(s,c){var f,g,_=t({queryArgs:u,endpointDefinition:n,endpointName:e}),b=r(((f={type:"query",subscribe:y,forceRefetch:h,subscriptionOptions:m,endpointName:e,originalArgs:u,queryCacheKey:_})[forceQueryFnSymbol]=v,f)),S=i.endpoints[e].select(u),k=s(b),T=S(c());p(s);var O=k.requestId,q=k.abort,A=T.requestId!==O,w=null==(g=o.get(s))?void 0:g[_],P=function(){return S(c())},Q=Object.assign(v?k.then(P):A&&!w?Promise.resolve(T):Promise.all([w,k]).then(P),{arg:u,requestId:O,subscriptionOptions:m,queryCacheKey:_,abort:q,unwrap:function(){return __async(this,null,(function(){var e;return __generator(this,(function(t){switch(t.label){case 0:return[4,Q];case 1:if((e=t.sent()).isError)throw e.error;return[2,e.data]}}))}))},refetch:function(){return s(a(u,{subscribe:!1,forceRefetch:!0}))},unsubscribe:function(){y&&s(l({queryCacheKey:_,requestId:O}))},updateSubscriptionOptions:function(t){Q.subscriptionOptions=t,s(d({endpointName:e,requestId:O,queryCacheKey:_,options:t}))}});if(!w&&!A&&!v){var R=o.get(s)||{};R[_]=Q,o.set(s,R),Q.then((function(){delete R[_],Object.keys(R).length||o.delete(s)}))}return Q}};return a},buildInitiateMutation:function(e){return function(t,r){var i=void 0===r?{}:r,a=i.track,o=void 0===a||a,s=i.fixedCacheKey;return function(r,i){var a=n({type:"mutation",endpointName:e,originalArgs:t,track:o,fixedCacheKey:s}),l=r(a);p(r);var d=l.requestId,f=l.abort,y=l.unwrap,h=l.unwrap().then((function(e){return{data:e}})).catch((function(e){return{error:e}})),m=function(){r(c({requestId:d,fixedCacheKey:s}))},v=Object.assign(h,{arg:l.arg,requestId:d,abort:f,unwrap:y,unsubscribe:m,reset:m}),g=u.get(r)||{};return u.set(r,g),g[d]=v,v.then((function(){delete g[d],Object.keys(g).length||u.delete(r)})),s&&(g[s]=v,v.then((function(){g[s]===v&&(delete g[s],Object.keys(g).length||u.delete(r))}))),v}}},getRunningQueryThunk:function(e,r){return function(n){var i,u=a.endpointDefinitions[e],s=t({queryArgs:r,endpointDefinition:u,endpointName:e});return null==(i=o.get(n))?void 0:i[s]}},getRunningMutationThunk:function(e,t){return function(e){var r;return null==(r=u.get(e))?void 0:r[t]}},getRunningQueriesThunk:function(){return function(e){return Object.values(o.get(e)||{}).filter(isNotNullish)}},getRunningMutationsThunk:function(){return function(e){return Object.values(u.get(e)||{}).filter(isNotNullish)}},getRunningOperationPromises:function(){if("undefined"==typeof process){var e=function(e){return Array.from(e.values()).flatMap((function(e){return e?Object.values(e):[]}))};return __spreadArray(__spreadArray([],e(o)),e(u)).filter(isNotNullish)}f()},removalWarning:f};function f(){throw new Error("This method had to be removed due to a conceptual bug in RTK.\n       Please see https://github.com/reduxjs/redux-toolkit/pull/2481 for details.\n       See https://redux-toolkit.js.org/rtk-query/usage/server-side-rendering for new guidance on SSR.")}function p(e){if(!p.triggered){var t=e(i.internalActions.internal_probeSubscription({queryCacheKey:"DOES_NOT_EXIST",requestId:"DUMMY_REQUEST_ID"}));if(p.triggered=!0,"boolean"!=typeof t)throw new Error('Warning: Middleware for RTK-Query API at reducerPath "'+i.reducerPath+'" has not been added to the store.\nYou must add the middleware for RTK-Query to function correctly!')}}}var import_toolkit4=__toModule(require("@reduxjs/toolkit")),import_immer=__toModule(require("immer")),import_toolkit5=__toModule(require("@reduxjs/toolkit"));function defaultTransformResponse(e){return e}function buildThunks(e){var t=this,r=e.reducerPath,n=e.baseQuery,i=e.context.endpointDefinitions,a=e.serializeQueryArgs,o=e.api,u=e.assertTagType,s=function(e,r){return __async(t,[e,r],(function(e,t){var r,a,o,u,s,c,d,f,p,y,h,m,v,g,_,b,S,k,T=t.signal,O=t.abort,q=t.rejectWithValue,A=t.fulfillWithValue,w=t.dispatch,P=t.getState,Q=t.extra;return __generator(this,(function(t){switch(t.label){case 0:r=i[e.endpointName],t.label=1;case 1:return t.trys.push([1,8,,13]),a=defaultTransformResponse,o=void 0,u={signal:T,abort:O,dispatch:w,getState:P,extra:Q,endpoint:e.endpointName,type:e.type,forced:"query"===e.type?l(e,P()):void 0},(s="query"===e.type?e[forceQueryFnSymbol]:void 0)?(o=s(),[3,6]):[3,2];case 2:return r.query?[4,n(r.query(e.originalArgs),u,r.extraOptions)]:[3,4];case 3:return o=t.sent(),r.transformResponse&&(a=r.transformResponse),[3,6];case 4:return[4,r.queryFn(e.originalArgs,u,r.extraOptions,(function(e){return n(e,u,r.extraOptions)}))];case 5:o=t.sent(),t.label=6;case 6:if("undefined"!=typeof process){if(c=r.query?"`baseQuery`":"`queryFn`",d=void 0,o){if("object"!=typeof o)d=c+" did not return an object.";else if(o.error&&o.data)d=c+" returned an object containing both `error` and `result`.";else if(void 0===o.error&&void 0===o.data)d=c+" returned an object containing neither a valid `error` and `result`. At least one of them should not be `undefined`";else for(f=0,p=Object.keys(o);f<p.length;f++)if("error"!==(y=p[f])&&"data"!==y&&"meta"!==y){d="The object returned by "+c+" has the unknown property "+y+".";break}}else d=c+" did not return anything.";d&&console.error("Error encountered handling the endpoint "+e.endpointName+".\n              "+d+"\n              It needs to return an object with either the shape `{ data: <value> }` or `{ error: <value> }` that may contain an optional `meta` property.\n              Object returned was:",o)}if(o.error)throw new HandledError(o.error,o.meta);return h=A,[4,a(o.data,o.meta,e.originalArgs)];case 7:return[2,h.apply(void 0,[t.sent(),(S={fulfilledTimeStamp:Date.now(),baseQueryMeta:o.meta},S[import_toolkit5.SHOULD_AUTOBATCH]=!0,S)])];case 8:if(m=t.sent(),!((v=m)instanceof HandledError))return[3,12];g=defaultTransformResponse,r.query&&r.transformErrorResponse&&(g=r.transformErrorResponse),t.label=9;case 9:return t.trys.push([9,11,,12]),_=q,[4,g(v.value,v.meta,e.originalArgs)];case 10:return[2,_.apply(void 0,[t.sent(),(k={baseQueryMeta:v.meta},k[import_toolkit5.SHOULD_AUTOBATCH]=!0,k)])];case 11:return b=t.sent(),v=b,[3,12];case 12:throw"undefined"!=typeof process?console.error('An unhandled error occurred processing a request for the endpoint "'+e.endpointName+'".\nIn the case of an unhandled error, no tags will be "provided" or "invalidated".',v):console.error(v),v;case 13:return[2]}}))}))};function l(e,t){var n,i,a,o,u=null==(i=null==(n=t[r])?void 0:n.queries)?void 0:i[e.queryCacheKey],s=null==(a=t[r])?void 0:a.config.refetchOnMountOrArgChange,l=null==u?void 0:u.fulfilledTimeStamp,c=null!=(o=e.forceRefetch)?o:e.subscribe&&s;return!!c&&(!0===c||(Number(new Date)-Number(l))/1e3>=c)}var c=(0,import_toolkit5.createAsyncThunk)(r+"/executeQuery",s,{getPendingMeta:function(){var e;return(e={startedTimeStamp:Date.now()})[import_toolkit5.SHOULD_AUTOBATCH]=!0,e},condition:function(e,t){var n,a,o,u=(0,t.getState)(),s=null==(a=null==(n=u[r])?void 0:n.queries)?void 0:a[e.queryCacheKey],c=null==s?void 0:s.fulfilledTimeStamp,d=e.originalArgs,f=null==s?void 0:s.originalArgs,p=i[e.endpointName];return!!isUpsertQuery(e)||"pending"!==(null==s?void 0:s.status)&&(!!l(e,u)||(!(!isQueryDefinition(p)||!(null==(o=null==p?void 0:p.forceRefetch)?void 0:o.call(p,{currentArg:d,previousArg:f,endpointState:s,state:u})))||!c))},dispatchConditionRejection:!0}),d=(0,import_toolkit5.createAsyncThunk)(r+"/executeMutation",s,{getPendingMeta:function(){var e;return(e={startedTimeStamp:Date.now()})[import_toolkit5.SHOULD_AUTOBATCH]=!0,e}});function f(e){return function(t){var r,n;return(null==(n=null==(r=null==t?void 0:t.meta)?void 0:r.arg)?void 0:n.endpointName)===e}}return{queryThunk:c,mutationThunk:d,prefetch:function(e,t,r){return function(n,i){var a=function(e){return"force"in e}(r)&&r.force,u=function(e){return"ifOlderThan"in e}(r)&&r.ifOlderThan,s=function(r){return void 0===r&&(r=!0),o.endpoints[e].initiate(t,{forceRefetch:r})},l=o.endpoints[e].select(t)(i());if(a)n(s());else if(u){var c=null==l?void 0:l.fulfilledTimeStamp;if(!c)return void n(s());(Number(new Date)-Number(new Date(c)))/1e3>=u&&n(s())}else n(s(!1))}},updateQueryData:function(e,t,r,n){return void 0===n&&(n=!0),function(i,a){var u,s,l,c=o.endpoints[e].select(t)(a()),d={patches:[],inversePatches:[],undo:function(){return i(o.util.patchQueryData(e,t,d.inversePatches,n))}};if(c.status===QueryStatus.uninitialized)return d;if("data"in c)if((0,import_immer.isDraftable)(c.data)){var f=(0,import_immer.produceWithPatches)(c.data,r),p=f[0],y=f[1],h=f[2];(u=d.patches).push.apply(u,y),(s=d.inversePatches).push.apply(s,h),l=p}else l=r(c.data),d.patches.push({op:"replace",path:[],value:l}),d.inversePatches.push({op:"replace",path:[],value:c.data});return i(o.util.patchQueryData(e,t,d.patches,n)),d}},upsertQueryData:function(e,t,r){return function(n){var i;return n(o.endpoints[e].initiate(t,((i={subscribe:!1,forceRefetch:!0})[forceQueryFnSymbol]=function(){return{data:r}},i)))}},patchQueryData:function(e,t,r,n){return function(s,l){var c=i[e],d=a({queryArgs:t,endpointDefinition:c,endpointName:e});if(s(o.internalActions.queryResultPatched({queryCacheKey:d,patches:r})),n){var f=o.endpoints[e].select(t)(l()),p=calculateProvidedBy(c.providesTags,f.data,void 0,t,{},u);s(o.internalActions.updateProvidedBy({queryCacheKey:d,providedTags:p}))}}},buildMatchThunkActions:function(e,t){return{matchPending:(0,import_toolkit4.isAllOf)((0,import_toolkit4.isPending)(e),f(t)),matchFulfilled:(0,import_toolkit4.isAllOf)((0,import_toolkit4.isFulfilled)(e),f(t)),matchRejected:(0,import_toolkit4.isAllOf)((0,import_toolkit4.isRejected)(e),f(t))}}}}function calculateProvidedByThunk(e,t,r,n){return calculateProvidedBy(r[e.meta.arg.endpointName][t],(0,import_toolkit4.isFulfilled)(e)?e.payload:void 0,(0,import_toolkit4.isRejectedWithValue)(e)?e.payload:void 0,e.meta.arg.originalArgs,"baseQueryMeta"in e.meta?e.meta.baseQueryMeta:void 0,n)}var import_immer2=__toModule(require("immer")),import_immer3=__toModule(require("immer"));function updateQuerySubstateIfExists(e,t,r){var n=e[t];n&&r(n)}function getMutationCacheKey(e){var t;return null!=(t="arg"in e?e.arg.fixedCacheKey:e.fixedCacheKey)?t:e.requestId}function updateMutationSubstateIfExists(e,t,r){var n=e[getMutationCacheKey(t)];n&&r(n)}var initialState={};function buildSlice(e){var t=e.reducerPath,r=e.queryThunk,n=e.mutationThunk,i=e.context,a=i.endpointDefinitions,o=i.apiUid,u=i.extractRehydrationInfo,s=i.hasRehydrationInfo,l=e.assertTagType,c=e.config,d=(0,import_toolkit6.createAction)(t+"/resetApiState"),f=(0,import_toolkit6.createSlice)({name:t+"/queries",initialState:initialState,reducers:{removeQueryResult:{reducer:function(e,t){delete e[t.payload.queryCacheKey]},prepare:(0,import_toolkit6.prepareAutoBatched)()},queryResultPatched:{reducer:function(e,t){var r=t.payload,n=r.queryCacheKey,i=r.patches;updateQuerySubstateIfExists(e,n,(function(e){e.data=(0,import_immer3.applyPatches)(e.data,i.concat())}))},prepare:(0,import_toolkit6.prepareAutoBatched)()}},extraReducers:function(e){e.addCase(r.pending,(function(e,t){var r,n=t.meta,i=t.meta.arg,a=isUpsertQuery(i);(i.subscribe||a)&&(null!=e[r=i.queryCacheKey]||(e[r]={status:QueryStatus.uninitialized,endpointName:i.endpointName})),updateQuerySubstateIfExists(e,i.queryCacheKey,(function(e){e.status=QueryStatus.pending,e.requestId=a&&e.requestId?e.requestId:n.requestId,void 0!==i.originalArgs&&(e.originalArgs=i.originalArgs),e.startedTimeStamp=n.startedTimeStamp}))})).addCase(r.fulfilled,(function(e,t){var r=t.meta,n=t.payload;updateQuerySubstateIfExists(e,r.arg.queryCacheKey,(function(e){var t;if(e.requestId===r.requestId||isUpsertQuery(r.arg)){var i=a[r.arg.endpointName].merge;if(e.status=QueryStatus.fulfilled,i)if(void 0!==e.data){var o=r.fulfilledTimeStamp,u=r.arg,s=r.baseQueryMeta,l=r.requestId,c=(0,import_toolkit6.createNextState)(e.data,(function(e){return i(e,n,{arg:u.originalArgs,baseQueryMeta:s,fulfilledTimeStamp:o,requestId:l})}));e.data=c}else e.data=n;else e.data=null==(t=a[r.arg.endpointName].structuralSharing)||t?copyWithStructuralSharing((0,import_immer2.isDraft)(e.data)?(0,import_immer3.original)(e.data):e.data,n):n;delete e.error,e.fulfilledTimeStamp=r.fulfilledTimeStamp}}))})).addCase(r.rejected,(function(e,t){var r=t.meta,n=r.condition,i=r.arg,a=r.requestId,o=t.error,u=t.payload;updateQuerySubstateIfExists(e,i.queryCacheKey,(function(e){if(n);else{if(e.requestId!==a)return;e.status=QueryStatus.rejected,e.error=null!=u?u:o}}))})).addMatcher(s,(function(e,t){for(var r=u(t).queries,n=0,i=Object.entries(r);n<i.length;n++){var a=i[n],o=a[0],s=a[1];(null==s?void 0:s.status)!==QueryStatus.fulfilled&&(null==s?void 0:s.status)!==QueryStatus.rejected||(e[o]=s)}}))}}),p=(0,import_toolkit6.createSlice)({name:t+"/mutations",initialState:initialState,reducers:{removeMutationResult:{reducer:function(e,t){var r=getMutationCacheKey(t.payload);r in e&&delete e[r]},prepare:(0,import_toolkit6.prepareAutoBatched)()}},extraReducers:function(e){e.addCase(n.pending,(function(e,t){var r=t.meta,n=t.meta,i=n.requestId,a=n.arg,o=n.startedTimeStamp;a.track&&(e[getMutationCacheKey(r)]={requestId:i,status:QueryStatus.pending,endpointName:a.endpointName,startedTimeStamp:o})})).addCase(n.fulfilled,(function(e,t){var r=t.payload,n=t.meta;n.arg.track&&updateMutationSubstateIfExists(e,n,(function(e){e.requestId===n.requestId&&(e.status=QueryStatus.fulfilled,e.data=r,e.fulfilledTimeStamp=n.fulfilledTimeStamp)}))})).addCase(n.rejected,(function(e,t){var r=t.payload,n=t.error,i=t.meta;i.arg.track&&updateMutationSubstateIfExists(e,i,(function(e){e.requestId===i.requestId&&(e.status=QueryStatus.rejected,e.error=null!=r?r:n)}))})).addMatcher(s,(function(e,t){for(var r=u(t).mutations,n=0,i=Object.entries(r);n<i.length;n++){var a=i[n],o=a[0],s=a[1];(null==s?void 0:s.status)!==QueryStatus.fulfilled&&(null==s?void 0:s.status)!==QueryStatus.rejected||o===(null==s?void 0:s.requestId)||(e[o]=s)}}))}}),y=(0,import_toolkit6.createSlice)({name:t+"/invalidation",initialState:initialState,reducers:{updateProvidedBy:{reducer:function(e,t){for(var r,n,i,a,o=t.payload,u=o.queryCacheKey,s=o.providedTags,l=0,c=Object.values(e);l<c.length;l++)for(var d=c[l],f=0,p=Object.values(d);f<p.length;f++){var y=p[f],h=y.indexOf(u);-1!==h&&y.splice(h,1)}for(var m=0,v=s;m<v.length;m++){var g=v[m],_=g.type,b=g.id,S=null!=(a=(n=null!=(r=e[_])?r:e[_]={})[i=b||"__internal_without_id"])?a:n[i]=[];S.includes(u)||S.push(u)}},prepare:(0,import_toolkit6.prepareAutoBatched)()}},extraReducers:function(e){e.addCase(f.actions.removeQueryResult,(function(e,t){for(var r=t.payload.queryCacheKey,n=0,i=Object.values(e);n<i.length;n++)for(var a=i[n],o=0,u=Object.values(a);o<u.length;o++){var s=u[o],l=s.indexOf(r);-1!==l&&s.splice(l,1)}})).addMatcher(s,(function(e,t){for(var r,n,i,a,o=u(t).provided,s=0,l=Object.entries(o);s<l.length;s++)for(var c=l[s],d=c[0],f=c[1],p=0,y=Object.entries(f);p<y.length;p++)for(var h=y[p],m=h[0],v=h[1],g=null!=(a=(n=null!=(r=e[d])?r:e[d]={})[i=m||"__internal_without_id"])?a:n[i]=[],_=0,b=v;_<b.length;_++){var S=b[_];g.includes(S)||g.push(S)}})).addMatcher((0,import_toolkit6.isAnyOf)((0,import_toolkit6.isFulfilled)(r),(0,import_toolkit6.isRejectedWithValue)(r)),(function(e,t){var r=calculateProvidedByThunk(t,"providesTags",a,l),n=t.meta.arg.queryCacheKey;y.caseReducers.updateProvidedBy(e,y.actions.updateProvidedBy({queryCacheKey:n,providedTags:r}))}))}}),h=(0,import_toolkit6.createSlice)({name:t+"/subscriptions",initialState:initialState,reducers:{updateSubscriptionOptions:function(e,t){},unsubscribeQueryResult:function(e,t){},internal_probeSubscription:function(e,t){}}}),m=(0,import_toolkit6.createSlice)({name:t+"/internalSubscriptions",initialState:initialState,reducers:{subscriptionsUpdated:{reducer:function(e,t){return(0,import_immer3.applyPatches)(e,t.payload)},prepare:(0,import_toolkit6.prepareAutoBatched)()}}}),v=(0,import_toolkit6.createSlice)({name:t+"/config",initialState:__spreadValues({online:isOnline(),focused:isDocumentVisible(),middlewareRegistered:!1},c),reducers:{middlewareRegistered:function(e,t){var r=t.payload;e.middlewareRegistered="conflict"!==e.middlewareRegistered&&o===r||"conflict"}},extraReducers:function(e){e.addCase(onOnline,(function(e){e.online=!0})).addCase(onOffline,(function(e){e.online=!1})).addCase(onFocus,(function(e){e.focused=!0})).addCase(onFocusLost,(function(e){e.focused=!1})).addMatcher(s,(function(e){return __spreadValues({},e)}))}}),g=(0,import_toolkit6.combineReducers)({queries:f.reducer,mutations:p.reducer,provided:y.reducer,subscriptions:m.reducer,config:v.reducer});return{reducer:function(e,t){return g(d.match(t)?void 0:e,t)},actions:__spreadProps(__spreadValues(__spreadValues(__spreadValues(__spreadValues(__spreadValues(__spreadValues({},v.actions),f.actions),h.actions),m.actions),p.actions),y.actions),{unsubscribeMutationResult:p.actions.removeMutationResult,resetApiState:d})}}var skipToken=Symbol.for("RTKQ/skipToken"),skipSelector=skipToken,initialSubState={status:QueryStatus.uninitialized},defaultQuerySubState=(0,import_toolkit7.createNextState)(initialSubState,(function(){})),defaultMutationSubState=(0,import_toolkit7.createNextState)(initialSubState,(function(){}));function buildSelectors(e){var t=e.serializeQueryArgs,r=e.reducerPath,n=function(e){return defaultQuerySubState},i=function(e){return defaultMutationSubState};return{buildQuerySelector:function(e,r){return function(i){var u=t({queryArgs:i,endpointDefinition:r,endpointName:e}),s=i===skipToken?n:function(e){var t,r,n;return null!=(n=null==(r=null==(t=o(e))?void 0:t.queries)?void 0:r[u])?n:defaultQuerySubState};return(0,import_toolkit7.createSelector)(s,a)}},buildMutationSelector:function(){return function(e){var t,r,n=(r="object"==typeof e?null!=(t=getMutationCacheKey(e))?t:skipToken:e)===skipToken?i:function(e){var t,n,i;return null!=(i=null==(n=null==(t=o(e))?void 0:t.mutations)?void 0:n[r])?i:defaultMutationSubState};return(0,import_toolkit7.createSelector)(n,a)}},selectInvalidatedBy:function(e,t){for(var n,i=e[r],a=new Set,o=0,u=t.map(expandTagDescription);o<u.length;o++){var s=u[o],l=i.provided[s.type];if(l)for(var c=0,d=null!=(n=void 0!==s.id?l[s.id]:flatten(Object.values(l)))?n:[];c<d.length;c++){var f=d[c];a.add(f)}}return flatten(Array.from(a.values()).map((function(e){var t=i.queries[e];return t?[{queryCacheKey:e,endpointName:t.endpointName,originalArgs:t.originalArgs}]:[]})))}};function a(e){return __spreadValues(__spreadValues({},e),getRequestStatusFlags(e.status))}function o(e){var t=e[r];if(!t){if(o.triggered)return t;o.triggered=!0,console.error("Error: No data found at `state."+r+"`. Did you forget to add the reducer to the store?")}return t}}var import_toolkit8=__toModule(require("@reduxjs/toolkit")),cache=WeakMap?new WeakMap:void 0,defaultSerializeQueryArgs=function(e){var t=e.endpointName,r=e.queryArgs,n="",i=null==cache?void 0:cache.get(r);if("string"==typeof i)n=i;else{var a=JSON.stringify(r,(function(e,t){return(0,import_toolkit8.isPlainObject)(t)?Object.keys(t).sort().reduce((function(e,r){return e[r]=t[r],e}),{}):t}));(0,import_toolkit8.isPlainObject)(r)&&(null==cache||cache.set(r,a)),n=a}return t+"("+n+")"},import_toolkit9=__toModule(require("@reduxjs/toolkit")),import_reselect=__toModule(require("reselect"));function buildCreateApi(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return function(t){var r=(0,import_reselect.defaultMemoize)((function(e){var r,n;return null==(n=t.extractRehydrationInfo)?void 0:n.call(t,e,{reducerPath:null!=(r=t.reducerPath)?r:"api"})})),n=__spreadProps(__spreadValues({reducerPath:"api",keepUnusedDataFor:60,refetchOnMountOrArgChange:!1,refetchOnFocus:!1,refetchOnReconnect:!1},t),{extractRehydrationInfo:r,serializeQueryArgs:function(e){var r=defaultSerializeQueryArgs;if("serializeQueryArgs"in e.endpointDefinition){var n=e.endpointDefinition.serializeQueryArgs;r=function(e){var t=n(e);return"string"==typeof t?t:defaultSerializeQueryArgs(__spreadProps(__spreadValues({},e),{queryArgs:t}))}}else t.serializeQueryArgs&&(r=t.serializeQueryArgs);return r(e)},tagTypes:__spreadArray([],t.tagTypes||[])}),i={endpointDefinitions:{},batch:function(e){e()},apiUid:(0,import_toolkit9.nanoid)(),extractRehydrationInfo:r,hasRehydrationInfo:(0,import_reselect.defaultMemoize)((function(e){return null!=r(e)}))},a={injectEndpoints:function(e){for(var t=e.endpoints({query:function(e){return __spreadProps(__spreadValues({},e),{type:DefinitionType.query})},mutation:function(e){return __spreadProps(__spreadValues({},e),{type:DefinitionType.mutation})}}),r=0,n=Object.entries(t);r<n.length;r++){var u=n[r],s=u[0],l=u[1];if(e.overrideExisting||!(s in i.endpointDefinitions)){i.endpointDefinitions[s]=l;for(var c=0,d=o;c<d.length;c++){d[c].injectEndpoint(s,l)}}else"undefined"!=typeof process&&console.error("called `injectEndpoints` to override already-existing endpointName "+s+" without specifying `overrideExisting: true`")}return a},enhanceEndpoints:function(e){var t=e.addTagTypes,r=e.endpoints;if(t)for(var o=0,u=t;o<u.length;o++){var s=u[o];n.tagTypes.includes(s)||n.tagTypes.push(s)}if(r)for(var l=0,c=Object.entries(r);l<c.length;l++){var d=c[l],f=d[0],p=d[1];"function"==typeof p?p(i.endpointDefinitions[f]):Object.assign(i.endpointDefinitions[f]||{},p)}return a}},o=e.map((function(e){return e.init(a,n,i)}));return a.injectEndpoints({endpoints:t.endpoints})}}function fakeBaseQuery(){return function(){throw new Error("When using `fakeBaseQuery`, all queries & mutations must use the `queryFn` definition syntax.")}}var import_toolkit13=__toModule(require("@reduxjs/toolkit"));function isObjectEmpty(e){for(var t in e)return!1;return!0}var promise,THIRTY_TWO_BIT_MAX_TIMER_SECONDS=2147482.647,buildCacheCollectionHandler=function(e){var t=e.reducerPath,r=e.api,n=e.context,i=e.internalState,a=r.internalActions,o=a.removeQueryResult,u=a.unsubscribeQueryResult;function s(e){var t=i.currentSubscriptions[e];return!!t&&!isObjectEmpty(t)}var l={};function c(e,t,r,i){var a,u=n.endpointDefinitions[t],c=null!=(a=null==u?void 0:u.keepUnusedDataFor)?a:i.keepUnusedDataFor;if(c!==1/0){var d=Math.max(0,Math.min(c,THIRTY_TWO_BIT_MAX_TIMER_SECONDS));if(!s(e)){var f=l[e];f&&clearTimeout(f),l[e]=setTimeout((function(){s(e)||r.dispatch(o({queryCacheKey:e})),delete l[e]}),1e3*d)}}}return function(e,i,a){var o;if(u.match(e)){var s=i.getState()[t];c(b=e.payload.queryCacheKey,null==(o=s.queries[b])?void 0:o.endpointName,i,s.config)}if(r.util.resetApiState.match(e))for(var d=0,f=Object.entries(l);d<f.length;d++){var p=f[d],y=p[0],h=p[1];h&&clearTimeout(h),delete l[y]}if(n.hasRehydrationInfo(e)){s=i.getState()[t];for(var m=n.extractRehydrationInfo(e).queries,v=0,g=Object.entries(m);v<g.length;v++){var _=g[v],b=_[0],S=_[1];c(b,null==S?void 0:S.endpointName,i,s.config)}}}},import_toolkit10=__toModule(require("@reduxjs/toolkit")),buildInvalidationByTagsHandler=function(e){var t=e.reducerPath,r=e.context,n=e.context.endpointDefinitions,i=e.mutationThunk,a=e.api,o=e.assertTagType,u=e.refetchQuery,s=a.internalActions.removeQueryResult,l=(0,import_toolkit10.isAnyOf)((0,import_toolkit10.isFulfilled)(i),(0,import_toolkit10.isRejectedWithValue)(i));function c(e,n){var i=n.getState(),o=i[t],l=a.util.selectInvalidatedBy(i,e);r.batch((function(){for(var e,t=0,r=Array.from(l.values());t<r.length;t++){var i=r[t].queryCacheKey,a=o.queries[i],c=null!=(e=o.subscriptions[i])?e:{};a&&(0===Object.keys(c).length?n.dispatch(s({queryCacheKey:i})):a.status!==QueryStatus.uninitialized&&n.dispatch(u(a,i)))}}))}return function(e,t){l(e)&&c(calculateProvidedByThunk(e,"invalidatesTags",n,o),t),a.util.invalidateTags.match(e)&&c(calculateProvidedBy(e.payload,void 0,void 0,void 0,void 0,o),t)}},buildPollingHandler=function(e){var t=e.reducerPath,r=e.queryThunk,n=e.api,i=e.refetchQuery,a=e.internalState,o={};function u(e,r){var n=e.queryCacheKey,u=r.getState()[t].queries[n],s=a.currentSubscriptions[n];if(u&&u.status!==QueryStatus.uninitialized){var l=c(s);if(Number.isFinite(l)){var d=o[n];(null==d?void 0:d.timeout)&&(clearTimeout(d.timeout),d.timeout=void 0);var f=Date.now()+l,p=o[n]={nextPollTimestamp:f,pollingInterval:l,timeout:setTimeout((function(){p.timeout=void 0,r.dispatch(i(u,n))}),l)}}}}function s(e,r){var n=e.queryCacheKey,i=r.getState()[t].queries[n],s=a.currentSubscriptions[n];if(i&&i.status!==QueryStatus.uninitialized){var d=c(s);if(Number.isFinite(d)){var f=o[n],p=Date.now()+d;(!f||p<f.nextPollTimestamp)&&u({queryCacheKey:n},r)}else l(n)}}function l(e){var t=o[e];(null==t?void 0:t.timeout)&&clearTimeout(t.timeout),delete o[e]}function c(e){void 0===e&&(e={});var t=Number.POSITIVE_INFINITY;for(var r in e)e[r].pollingInterval&&(t=Math.min(e[r].pollingInterval,t));return t}return function(e,t){(n.internalActions.updateSubscriptionOptions.match(e)||n.internalActions.unsubscribeQueryResult.match(e))&&s(e.payload,t),(r.pending.match(e)||r.rejected.match(e)&&e.meta.condition)&&s(e.meta.arg,t),(r.fulfilled.match(e)||r.rejected.match(e)&&!e.meta.condition)&&u(e.meta.arg,t),n.util.resetApiState.match(e)&&function(){for(var e=0,t=Object.keys(o);e<t.length;e++){l(t[e])}}()}},buildWindowEventHandler=function(e){var t=e.reducerPath,r=e.context,n=e.api,i=e.refetchQuery,a=e.internalState,o=n.internalActions.removeQueryResult;function u(e,n){var u=e.getState()[t],s=u.queries,l=a.currentSubscriptions;r.batch((function(){for(var t=0,r=Object.keys(l);t<r.length;t++){var a=r[t],c=s[a],d=l[a];if(d&&c)(Object.values(d).some((function(e){return!0===e[n]}))||Object.values(d).every((function(e){return void 0===e[n]}))&&u.config[n])&&(0===Object.keys(d).length?e.dispatch(o({queryCacheKey:a})):c.status!==QueryStatus.uninitialized&&e.dispatch(i(c,a)))}}))}return function(e,t){onFocus.match(e)&&u(t,"refetchOnFocus"),onOnline.match(e)&&u(t,"refetchOnReconnect")}},import_toolkit11=__toModule(require("@reduxjs/toolkit")),neverResolvedError=new Error("Promise never resolved before cacheEntryRemoved."),buildCacheLifecycleHandler=function(e){var t=e.api,r=e.reducerPath,n=e.context,i=e.queryThunk,a=e.mutationThunk,o=(e.internalState,(0,import_toolkit11.isAsyncThunkAction)(i)),u=(0,import_toolkit11.isAsyncThunkAction)(a),s=(0,import_toolkit11.isFulfilled)(i,a),l={};function c(e,r,i,a,o){var u=n.endpointDefinitions[e],s=null==u?void 0:u.onCacheEntryAdded;if(s){var c={},d=new Promise((function(e){c.cacheEntryRemoved=e})),f=Promise.race([new Promise((function(e){c.valueResolved=e})),d.then((function(){throw neverResolvedError}))]);f.catch((function(){})),l[i]=c;var p=t.endpoints[e].select(u.type===DefinitionType.query?r:i),y=a.dispatch((function(e,t,r){return r})),h=__spreadProps(__spreadValues({},a),{getCacheEntry:function(){return p(a.getState())},requestId:o,extra:y,updateCachedData:u.type===DefinitionType.query?function(n){return a.dispatch(t.util.updateQueryData(e,r,n))}:void 0,cacheDataLoaded:f,cacheEntryRemoved:d}),m=s(r,h);Promise.resolve(m).catch((function(e){if(e!==neverResolvedError)throw e}))}}return function(e,n,d){var f=function(e){return o(e)?e.meta.arg.queryCacheKey:u(e)?e.meta.requestId:t.internalActions.removeQueryResult.match(e)?e.payload.queryCacheKey:t.internalActions.removeMutationResult.match(e)?getMutationCacheKey(e.payload):""}(e);if(i.pending.match(e)){var p=d[r].queries[f],y=n.getState()[r].queries[f];!p&&y&&c(e.meta.arg.endpointName,e.meta.arg.originalArgs,f,n,e.meta.requestId)}else if(a.pending.match(e)){(y=n.getState()[r].mutations[f])&&c(e.meta.arg.endpointName,e.meta.arg.originalArgs,f,n,e.meta.requestId)}else if(s(e)){(null==(_=l[f])?void 0:_.valueResolved)&&(_.valueResolved({data:e.payload,meta:e.meta.baseQueryMeta}),delete _.valueResolved)}else if(t.internalActions.removeQueryResult.match(e)||t.internalActions.removeMutationResult.match(e)){(_=l[f])&&(delete l[f],_.cacheEntryRemoved())}else if(t.util.resetApiState.match(e))for(var h=0,m=Object.entries(l);h<m.length;h++){var v=m[h],g=v[0],_=v[1];delete l[g],_.cacheEntryRemoved()}}},import_toolkit12=__toModule(require("@reduxjs/toolkit")),buildQueryLifecycleHandler=function(e){var t=e.api,r=e.context,n=e.queryThunk,i=e.mutationThunk,a=(0,import_toolkit12.isPending)(n,i),o=(0,import_toolkit12.isRejected)(n,i),u=(0,import_toolkit12.isFulfilled)(n,i),s={};return function(e,n){var i,l,c;if(a(e)){var d=e.meta,f=d.requestId,p=d.arg,y=p.endpointName,h=p.originalArgs,m=r.endpointDefinitions[y],v=null==m?void 0:m.onQueryStarted;if(v){var g={},_=new Promise((function(e,t){g.resolve=e,g.reject=t}));_.catch((function(){})),s[f]=g;var b=t.endpoints[y].select(m.type===DefinitionType.query?h:f),S=n.dispatch((function(e,t,r){return r})),k=__spreadProps(__spreadValues({},n),{getCacheEntry:function(){return b(n.getState())},requestId:f,extra:S,updateCachedData:m.type===DefinitionType.query?function(e){return n.dispatch(t.util.updateQueryData(y,h,e))}:void 0,queryFulfilled:_});v(h,k)}}else if(u(e)){var T=e.meta,O=(f=T.requestId,T.baseQueryMeta);null==(i=s[f])||i.resolve({data:e.payload,meta:O}),delete s[f]}else if(o(e)){var q=e.meta,A=(f=q.requestId,q.rejectedWithValue);O=q.baseQueryMeta;null==(c=s[f])||c.reject({error:null!=(l=e.payload)?l:e.error,isUnhandledError:!A,meta:O}),delete s[f]}}},buildDevCheckHandler=function(e){var t=e.api,r=e.context.apiUid,n=e.reducerPath;return function(e,i){var a,o;t.util.resetApiState.match(e)&&i.dispatch(t.internalActions.middlewareRegistered(r)),"undefined"!=typeof process&&t.internalActions.middlewareRegistered.match(e)&&e.payload===r&&"conflict"===(null==(o=null==(a=i.getState()[n])?void 0:a.config)?void 0:o.middlewareRegistered)&&console.warn('There is a mismatch between slice and middleware for the reducerPath "'+n+'".\nYou can only have one api per reducer path, this will lead to crashes in various situations!'+("api"===n?"\nIf you have multiple apis, you *have* to specify the reducerPath option when using createApi!":""))}},import_immer4=__toModule(require("immer")),queueMicrotaskShim="function"==typeof queueMicrotask?queueMicrotask.bind("undefined"!=typeof window?window:"undefined"!=typeof global?global:globalThis):function(e){return(promise||(promise=Promise.resolve())).then(e).catch((function(e){return setTimeout((function(){throw e}),0)}))},buildBatchedActionsHandler=function(e){var t=e.api,r=e.queryThunk,n=e.internalState,i=t.reducerPath+"/subscriptions",a=null,o=!1,u=t.internalActions,s=u.updateSubscriptionOptions,l=u.unsubscribeQueryResult;return function(e,u){var c,d;if(a||(a=JSON.parse(JSON.stringify(n.currentSubscriptions))),t.util.resetApiState.match(e))return a=n.currentSubscriptions={},[!0,!1];if(t.internalActions.internal_probeSubscription.match(e)){var f=e.payload,p=f.queryCacheKey,y=f.requestId;return[!1,!!(null==(c=n.currentSubscriptions[p])?void 0:c[y])]}var h=function(e,n){var i,a,o,u,c,d,f,p,y;if(s.match(n)){var h=n.payload,m=h.queryCacheKey,v=h.requestId,g=h.options;return(null==(i=null==e?void 0:e[m])?void 0:i[v])&&(e[m][v]=g),!0}if(l.match(n)){var _=n.payload;return m=_.queryCacheKey,v=_.requestId,e[m]&&delete e[m][v],!0}if(t.internalActions.removeQueryResult.match(n))return delete e[n.payload.queryCacheKey],!0;if(r.pending.match(n)){var b=n.meta,S=b.arg;if(v=b.requestId,S.subscribe)return(k=null!=(o=e[a=S.queryCacheKey])?o:e[a]={})[v]=null!=(c=null!=(u=S.subscriptionOptions)?u:k[v])?c:{},!0}if(r.rejected.match(n)){var k,T=n.meta,O=T.condition;if(S=T.arg,v=T.requestId,O&&S.subscribe)return(k=null!=(f=e[d=S.queryCacheKey])?f:e[d]={})[v]=null!=(y=null!=(p=S.subscriptionOptions)?p:k[v])?y:{},!0}return!1}(n.currentSubscriptions,e);if(h){o||(queueMicrotaskShim((function(){var e=JSON.parse(JSON.stringify(n.currentSubscriptions)),r=(0,import_immer4.produceWithPatches)(a,(function(){return e}))[1];u.next(t.internalActions.subscriptionsUpdated(r)),a=e,o=!1})),o=!0);var m=!!(null==(d=e.type)?void 0:d.startsWith(i)),v=r.rejected.match(e)&&e.meta.condition&&!!e.meta.arg.subscribe;return[!m&&!v,!1]}return[!0,!1]}};function buildMiddleware(e){var t=e.reducerPath,r=e.queryThunk,n=e.api,i=e.context,a=i.apiUid,o={invalidateTags:(0,import_toolkit13.createAction)(t+"/invalidateTags")},u=[buildDevCheckHandler,buildCacheCollectionHandler,buildInvalidationByTagsHandler,buildPollingHandler,buildCacheLifecycleHandler,buildQueryLifecycleHandler];return{middleware:function(r){var o=!1,l=__spreadProps(__spreadValues({},e),{internalState:{currentSubscriptions:{}},refetchQuery:s}),c=u.map((function(e){return e(l)})),d=buildBatchedActionsHandler(l),f=buildWindowEventHandler(l);return function(e){return function(u){o||(o=!0,r.dispatch(n.internalActions.middlewareRegistered(a)));var s,l=__spreadProps(__spreadValues({},r),{next:e}),p=r.getState(),y=d(u,l,p),h=y[0],m=y[1];if(s=h?e(u):m,r.getState()[t]&&(f(u,l,p),function(e){return!!e&&"string"==typeof e.type&&e.type.startsWith(t+"/")}(u)||i.hasRehydrationInfo(u)))for(var v=0,g=c;v<g.length;v++){(0,g[v])(u,l,p)}return s}}},actions:o};function s(e,t,n){return void 0===n&&(n={}),r(__spreadValues({type:"query",endpointName:e.endpointName,originalArgs:e.originalArgs,subscribe:!1,forceRefetch:!0,queryCacheKey:t},n))}}function assertCast(e){}function safeAssign(e){for(var t=[],r=1;r<arguments.length;r++)t[r-1]=arguments[r];Object.assign.apply(Object,__spreadArray([e],t))}var import_immer5=__toModule(require("immer")),coreModuleName=Symbol(),coreModule=function(){return{name:coreModuleName,init:function(e,t,r){var n=t.baseQuery,i=t.tagTypes,a=t.reducerPath,o=t.serializeQueryArgs,u=t.keepUnusedDataFor,s=t.refetchOnMountOrArgChange,l=t.refetchOnFocus,c=t.refetchOnReconnect;(0,import_immer5.enablePatches)(),assertCast(o);var d=function(e){return"undefined"!=typeof process&&(i.includes(e.type)||console.error("Tag type '"+e.type+"' was used, but not specified in `tagTypes`!")),e};Object.assign(e,{reducerPath:a,endpoints:{},internalActions:{onOnline:onOnline,onOffline:onOffline,onFocus:onFocus,onFocusLost:onFocusLost},util:{}});var f=buildThunks({baseQuery:n,reducerPath:a,context:r,api:e,serializeQueryArgs:o,assertTagType:d}),p=f.queryThunk,y=f.mutationThunk,h=f.patchQueryData,m=f.updateQueryData,v=f.upsertQueryData,g=f.prefetch,_=f.buildMatchThunkActions,b=buildSlice({context:r,queryThunk:p,mutationThunk:y,reducerPath:a,assertTagType:d,config:{refetchOnFocus:l,refetchOnReconnect:c,refetchOnMountOrArgChange:s,keepUnusedDataFor:u,reducerPath:a}}),S=b.reducer,k=b.actions;safeAssign(e.util,{patchQueryData:h,updateQueryData:m,upsertQueryData:v,prefetch:g,resetApiState:k.resetApiState}),safeAssign(e.internalActions,k);var T=buildMiddleware({reducerPath:a,context:r,queryThunk:p,mutationThunk:y,api:e,assertTagType:d}),O=T.middleware,q=T.actions;safeAssign(e.util,q),safeAssign(e,{reducer:S,middleware:O});var A=buildSelectors({serializeQueryArgs:o,reducerPath:a}),w=A.buildQuerySelector,P=A.buildMutationSelector,Q=A.selectInvalidatedBy;safeAssign(e.util,{selectInvalidatedBy:Q});var R=buildInitiate({queryThunk:p,mutationThunk:y,api:e,serializeQueryArgs:o,context:r}),j=R.buildInitiateQuery,M=R.buildInitiateMutation,x=R.getRunningMutationThunk,I=R.getRunningMutationsThunk,C=R.getRunningQueriesThunk,D=R.getRunningQueryThunk,E=R.getRunningOperationPromises,N=R.removalWarning;return safeAssign(e.util,{getRunningOperationPromises:E,getRunningOperationPromise:N,getRunningMutationThunk:x,getRunningMutationsThunk:I,getRunningQueryThunk:D,getRunningQueriesThunk:C}),{name:coreModuleName,injectEndpoint:function(t,r){var n,i=e;null!=(n=i.endpoints)[t]||(n[t]={}),isQueryDefinition(r)?safeAssign(i.endpoints[t],{name:t,select:w(t,r),initiate:j(t,r)},_(p,t)):isMutationDefinition(r)&&safeAssign(i.endpoints[t],{name:t,select:P(),initiate:M(t)},_(y,t))}}}}},createApi=buildCreateApi(coreModule());

}).call(this)}).call(this,require('_process'),typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})
},{"@reduxjs/toolkit":11,"_process":103,"immer":89,"reselect":168}],17:[function(require,module,exports){
(function (global){(function (){
var e,t,n=this&&this.__generator||function(e,t){var n,r,i,a,u={label:0,sent:function(){if(1&i[0])throw i[1];return i[1]},trys:[],ops:[]};return a={next:o(0),throw:o(1),return:o(2)},"function"==typeof Symbol&&(a[Symbol.iterator]=function(){return this}),a;function o(a){return function(o){return function(a){if(n)throw new TypeError("Generator is already executing.");for(;u;)try{if(n=1,r&&(i=2&a[0]?r.return:a[0]?r.throw||((i=r.return)&&i.call(r),0):r.next)&&!(i=i.call(r,a[1])).done)return i;switch(r=0,i&&(a=[2&a[0],i.value]),a[0]){case 0:case 1:i=a;break;case 4:return u.label++,{value:a[1],done:!1};case 5:u.label++,r=a[1],a=[0];continue;case 7:a=u.ops.pop(),u.trys.pop();continue;default:if(!((i=(i=u.trys).length>0&&i[i.length-1])||6!==a[0]&&2!==a[0])){u=0;continue}if(3===a[0]&&(!i||a[1]>i[0]&&a[1]<i[3])){u.label=a[1];break}if(6===a[0]&&u.label<i[1]){u.label=i[1],i=a;break}if(i&&u.label<i[2]){u.label=i[2],u.ops.push(a);break}i[2]&&u.ops.pop(),u.trys.pop();continue}a=t.call(e,u)}catch(e){a=[6,e],r=0}finally{n=i=0}if(5&a[0])throw a[1];return{value:a[0]?a[1]:void 0,done:!0}}([a,o])}}},r=this&&this.__spreadArray||function(e,t){for(var n=0,r=t.length,i=e.length;n<r;n++,i++)e[i]=t[n];return e},i=Object.create,a=Object.defineProperty,u=Object.defineProperties,o=Object.getOwnPropertyDescriptor,s=Object.getOwnPropertyDescriptors,c=Object.getOwnPropertyNames,l=Object.getOwnPropertySymbols,d=Object.getPrototypeOf,f=Object.prototype.hasOwnProperty,p=Object.prototype.propertyIsEnumerable,h=function(e,t,n){return t in e?a(e,t,{enumerable:!0,configurable:!0,writable:!0,value:n}):e[t]=n},v=function(e,t){for(var n in t||(t={}))f.call(t,n)&&h(e,n,t[n]);if(l)for(var r=0,i=l(t);r<i.length;r++)p.call(t,n=i[r])&&h(e,n,t[n]);return e},y=function(e,t){return u(e,s(t))},m=function(e){return a(e,"__esModule",{value:!0})},g=function(e,t){var n={};for(var r in e)f.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(null!=e&&l)for(var i=0,a=l(e);i<a.length;i++)t.indexOf(r=a[i])<0&&p.call(e,r)&&(n[r]=e[r]);return n},b=function(e){return function(e,t,n){if(t&&"object"==typeof t||"function"==typeof t)for(var r=function(r){f.call(e,r)||"default"===r||a(e,r,{get:function(){return t[r]},enumerable:!(n=o(t,r))||n.enumerable})},i=0,u=c(t);i<u.length;i++)r(u[i]);return e}(m(a(null!=e?i(d(e)):{},"default",e&&e.__esModule&&"default"in e?{get:function(){return e.default},enumerable:!0}:{value:e,enumerable:!0})),e)},q=function(e,t,n){return new Promise((function(r,i){var a=function(e){try{o(n.next(e))}catch(e){i(e)}},u=function(e){try{o(n.throw(e))}catch(e){i(e)}},o=function(e){return e.done?r(e.value):Promise.resolve(e.value).then(a,u)};o((n=n.apply(e,t)).next())}))};m(exports),function(e,t){for(var n in t)a(e,n,{get:t[n],enumerable:!0})}(exports,{QueryStatus:function(){return e},buildCreateApi:function(){return ge},copyWithStructuralSharing:function(){return A},coreModule:function(){return Ke},coreModuleName:function(){return Ne},createApi:function(){return Ee},defaultSerializeQueryArgs:function(){return ve},fakeBaseQuery:function(){return be},fetchBaseQuery:function(){return x},retry:function(){return I},setupListeners:function(){return F},skipSelector:function(){return ce},skipToken:function(){return se}}),(t=e||(e={})).uninitialized="uninitialized",t.pending="pending",t.fulfilled="fulfilled",t.rejected="rejected";var S=function(e){return[].concat.apply([],e)},O=b(require("@reduxjs/toolkit")).isPlainObject;function A(e,t){if(e===t||!(O(e)&&O(t)||Array.isArray(e)&&Array.isArray(t)))return t;for(var n=Object.keys(t),r=Object.keys(e),i=n.length===r.length,a=Array.isArray(t)?[]:{},u=0,o=n;u<o.length;u++){var s=o[u];a[s]=A(e[s],t[s]),i&&(i=e[s]===a[s])}return i?e:a}var T=b(require("@reduxjs/toolkit")),R=function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return fetch.apply(void 0,e)},j=function(e){return e.status>=200&&e.status<=299},w=function(e){return/ion\/(vnd\.api\+)?json/.test(e.get("content-type")||"")};function k(e){if(!(0,T.isPlainObject)(e))return e;for(var t=v({},e),n=0,r=Object.entries(t);n<r.length;n++){var i=r[n];void 0===i[1]&&delete t[i[0]]}return t}function x(e){var t=this;void 0===e&&(e={});var r=e.baseUrl,i=e.prepareHeaders,a=void 0===i?function(e){return e}:i,u=e.fetchFn,o=void 0===u?R:u,s=e.paramsSerializer,c=e.isJsonContentType,l=void 0===c?w:c,d=e.jsonContentType,f=void 0===d?"application/json":d,p=e.jsonReplacer,h=e.timeout,m=e.responseHandler,b=e.validateStatus,S=g(e,["baseUrl","prepareHeaders","fetchFn","paramsSerializer","isJsonContentType","jsonContentType","jsonReplacer","timeout","responseHandler","validateStatus"]);return"undefined"==typeof fetch&&o===R&&console.warn("Warning: `fetch` is not available. Please supply a custom `fetchFn` property to use `fetchBaseQuery` on SSR environments."),function(e,i){return q(t,null,(function(){var t,u,c,d,q,A,R,w,x,P,C,Q,I,M,D,N,K,E,z,_,F,J,U,B,L,W,H,V,$,G,Z,Y,X,ee,te,ne;return n(this,(function(n){switch(n.label){case 0:return t=i.signal,u=i.getState,c=i.extra,d=i.endpoint,q=i.forced,A=i.type,x=(w="string"==typeof e?{url:e}:e).url,C=void 0===(P=w.headers)?new Headers(S.headers):P,I=void 0===(Q=w.params)?void 0:Q,D=void 0===(M=w.responseHandler)?null!=m?m:"json":M,K=void 0===(N=w.validateStatus)?null!=b?b:j:N,z=void 0===(E=w.timeout)?h:E,_=g(w,["url","headers","params","responseHandler","validateStatus","timeout"]),F=v(y(v({},S),{signal:t}),_),C=new Headers(k(C)),J=F,[4,a(C,{getState:u,extra:c,endpoint:d,forced:q,type:A})];case 1:J.headers=n.sent()||C,U=function(e){return"object"==typeof e&&((0,T.isPlainObject)(e)||Array.isArray(e)||"function"==typeof e.toJSON)},!F.headers.has("content-type")&&U(F.body)&&F.headers.set("content-type",f),U(F.body)&&l(F.headers)&&(F.body=JSON.stringify(F.body,p)),I&&(B=~x.indexOf("?")?"&":"?",L=s?s(I):new URLSearchParams(k(I)),x+=B+L),x=function(e,t){if(!e)return t;if(!t)return e;if(function(e){return new RegExp("(^|:)//").test(e)}(t))return t;var n=e.endsWith("/")||!t.startsWith("?")?"/":"";return""+(e=function(e){return e.replace(/\/$/,"")}(e))+n+function(e){return e.replace(/^\//,"")}(t)}(r,x),W=new Request(x,F),H=new Request(x,F),R={request:H},$=!1,G=z&&setTimeout((function(){$=!0,i.abort()}),z),n.label=2;case 2:return n.trys.push([2,4,5,6]),[4,o(W)];case 3:return V=n.sent(),[3,6];case 4:return Z=n.sent(),[2,{error:{status:$?"TIMEOUT_ERROR":"FETCH_ERROR",error:String(Z)},meta:R}];case 5:return G&&clearTimeout(G),[7];case 6:Y=V.clone(),R.response=Y,ee="",n.label=7;case 7:return n.trys.push([7,9,,10]),[4,Promise.all([O(V,D).then((function(e){return X=e}),(function(e){return te=e})),Y.text().then((function(e){return ee=e}),(function(){}))])];case 8:if(n.sent(),te)throw te;return[3,10];case 9:return ne=n.sent(),[2,{error:{status:"PARSING_ERROR",originalStatus:V.status,data:ee,error:String(ne)},meta:R}];case 10:return[2,K(V,X)?{data:X,meta:R}:{error:{status:V.status,data:X},meta:R}]}}))}))};function O(e,t){return q(this,null,(function(){var r;return n(this,(function(n){switch(n.label){case 0:return"function"==typeof t?[2,t(e)]:("content-type"===t&&(t=l(e.headers)?"json":"text"),"json"!==t?[3,2]:[4,e.text()]);case 1:return[2,(r=n.sent()).length?JSON.parse(r):null];case 2:return[2,e.text()]}}))}))}}var P=function(e,t){void 0===t&&(t=void 0),this.value=e,this.meta=t};function Q(e,t){return void 0===e&&(e=0),void 0===t&&(t=5),q(this,null,(function(){var r,i;return n(this,(function(n){switch(n.label){case 0:return r=Math.min(e,t),i=~~((Math.random()+.4)*(300<<r)),[4,new Promise((function(e){return setTimeout((function(t){return e(t)}),i)}))];case 1:return n.sent(),[2]}}))}))}var C={},I=Object.assign((function(e,t){return function(r,i,a){return q(void 0,null,(function(){var u,o,s,c,l,d,f;return n(this,(function(n){switch(n.label){case 0:u=[5,(t||C).maxRetries,(a||C).maxRetries].filter((function(e){return void 0!==e})),o=u.slice(-1)[0],s=function(e,t,n){return n.attempt<=o},c=v(v({maxRetries:o,backoff:Q,retryCondition:s},t),a),l=0,n.label=1;case 1:n.label=2;case 2:return n.trys.push([2,4,,6]),[4,e(r,i,a)];case 3:if((d=n.sent()).error)throw new P(d);return[2,d];case 4:if(f=n.sent(),l++,f.throwImmediately){if(f instanceof P)return[2,f.value];throw f}return f instanceof P&&!c.retryCondition(f.value.error,r,{attempt:l,baseQueryApi:i,extraOptions:a})?[2,f.value]:[4,c.backoff(l,c.maxRetries)];case 5:return n.sent(),[3,6];case 6:return[3,1];case 7:return[2]}}))}))}}),{fail:function(e){throw Object.assign(new P({error:e}),{throwImmediately:!0})}}),M=b(require("@reduxjs/toolkit")),D=(0,M.createAction)("__rtkq/focused"),N=(0,M.createAction)("__rtkq/unfocused"),K=(0,M.createAction)("__rtkq/online"),E=(0,M.createAction)("__rtkq/offline"),_=!1;function F(e,t){return t?t(e,{onFocus:D,onFocusLost:N,onOffline:E,onOnline:K}):(n=function(){return e(D())},r=function(){return e(K())},i=function(){return e(E())},a=function(){"visible"===window.document.visibilityState?n():e(N())},_||"undefined"!=typeof window&&window.addEventListener&&(window.addEventListener("visibilitychange",a,!1),window.addEventListener("focus",n,!1),window.addEventListener("online",r,!1),window.addEventListener("offline",i,!1),_=!0),function(){window.removeEventListener("focus",n),window.removeEventListener("visibilitychange",a),window.removeEventListener("online",r),window.removeEventListener("offline",i),_=!1});var n,r,i,a}var z,U,B=b(require("@reduxjs/toolkit"));function L(e){return e.type===z.query}function W(e,t,n,r,i,a){return"function"==typeof e?e(t,n,r,i).map(H).map(a):Array.isArray(e)?e.map(H).map(a):[]}function H(e){return"string"==typeof e?{type:e}:e}(U=z||(z={})).query="query",U.mutation="mutation";var J=b(require("@reduxjs/toolkit"));function V(e){return null!=e}var G=Symbol("forceQueryFn"),Y=function(e){return"function"==typeof e[G]},$=b(require("@reduxjs/toolkit")),X=b(require("immer")),Z=b(require("@reduxjs/toolkit"));function ee(e){return e}function te(e,t,n,r){return W(n[e.meta.arg.endpointName][t],(0,$.isFulfilled)(e)?e.payload:void 0,(0,$.isRejectedWithValue)(e)?e.payload:void 0,e.meta.arg.originalArgs,"baseQueryMeta"in e.meta?e.meta.baseQueryMeta:void 0,r)}var ne=b(require("immer")),re=b(require("immer"));function ie(e,t,n){var r=e[t];r&&n(r)}function ae(e){var t;return null!=(t="arg"in e?e.arg.fixedCacheKey:e.fixedCacheKey)?t:e.requestId}function ue(e,t,n){var r=e[ae(t)];r&&n(r)}var oe={},se=Symbol.for("RTKQ/skipToken"),ce=se,le={status:e.uninitialized},de=(0,B.createNextState)(le,(function(){})),fe=(0,B.createNextState)(le,(function(){})),pe=b(require("@reduxjs/toolkit")),he=WeakMap?new WeakMap:void 0,ve=function(e){var t=e.endpointName,n=e.queryArgs,r="",i=null==he?void 0:he.get(n);if("string"==typeof i)r=i;else{var a=JSON.stringify(n,(function(e,t){return(0,pe.isPlainObject)(t)?Object.keys(t).sort().reduce((function(e,n){return e[n]=t[n],e}),{}):t}));(0,pe.isPlainObject)(n)&&(null==he||he.set(n,a)),r=a}return t+"("+r+")"},ye=b(require("@reduxjs/toolkit")),me=b(require("reselect"));function ge(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return function(t){var n=(0,me.defaultMemoize)((function(e){var n,r;return null==(r=t.extractRehydrationInfo)?void 0:r.call(t,e,{reducerPath:null!=(n=t.reducerPath)?n:"api"})})),i=y(v({reducerPath:"api",keepUnusedDataFor:60,refetchOnMountOrArgChange:!1,refetchOnFocus:!1,refetchOnReconnect:!1},t),{extractRehydrationInfo:n,serializeQueryArgs:function(e){var n=ve;if("serializeQueryArgs"in e.endpointDefinition){var r=e.endpointDefinition.serializeQueryArgs;n=function(e){var t=r(e);return"string"==typeof t?t:ve(y(v({},e),{queryArgs:t}))}}else t.serializeQueryArgs&&(n=t.serializeQueryArgs);return n(e)},tagTypes:r([],t.tagTypes||[])}),a={endpointDefinitions:{},batch:function(e){e()},apiUid:(0,ye.nanoid)(),extractRehydrationInfo:n,hasRehydrationInfo:(0,me.defaultMemoize)((function(e){return null!=n(e)}))},u={injectEndpoints:function(e){for(var t=e.endpoints({query:function(e){return y(v({},e),{type:z.query})},mutation:function(e){return y(v({},e),{type:z.mutation})}}),n=0,r=Object.entries(t);n<r.length;n++){var i=r[n],s=i[0],c=i[1];if(e.overrideExisting||!(s in a.endpointDefinitions)){a.endpointDefinitions[s]=c;for(var l=0,d=o;l<d.length;l++)d[l].injectEndpoint(s,c)}}return u},enhanceEndpoints:function(e){var t=e.addTagTypes,n=e.endpoints;if(t)for(var r=0,o=t;r<o.length;r++){var s=o[r];i.tagTypes.includes(s)||i.tagTypes.push(s)}if(n)for(var c=0,l=Object.entries(n);c<l.length;c++){var d=l[c],f=d[0],p=d[1];"function"==typeof p?p(a.endpointDefinitions[f]):Object.assign(a.endpointDefinitions[f]||{},p)}return u}},o=e.map((function(e){return e.init(u,i,a)}));return u.injectEndpoints({endpoints:t.endpoints})}}function be(){return function(){throw new Error("When using `fakeBaseQuery`, all queries & mutations must use the `queryFn` definition syntax.")}}var qe,Se=b(require("@reduxjs/toolkit")),Oe=function(e){var t=e.reducerPath,n=e.api,r=e.context,i=e.internalState,a=n.internalActions,u=a.removeQueryResult,o=a.unsubscribeQueryResult;function s(e){var t=i.currentSubscriptions[e];return!!t&&!function(e){for(var t in e)return!1;return!0}(t)}var c={};function l(e,t,n,i){var a,o=r.endpointDefinitions[t],l=null!=(a=null==o?void 0:o.keepUnusedDataFor)?a:i.keepUnusedDataFor;if(1/0!==l){var d=Math.max(0,Math.min(l,2147482.647));if(!s(e)){var f=c[e];f&&clearTimeout(f),c[e]=setTimeout((function(){s(e)||n.dispatch(u({queryCacheKey:e})),delete c[e]}),1e3*d)}}}return function(e,i,a){var u;if(o.match(e)){var s=i.getState()[t];l(b=e.payload.queryCacheKey,null==(u=s.queries[b])?void 0:u.endpointName,i,s.config)}if(n.util.resetApiState.match(e))for(var d=0,f=Object.entries(c);d<f.length;d++){var p=f[d],v=p[0],h=p[1];h&&clearTimeout(h),delete c[v]}if(r.hasRehydrationInfo(e)){s=i.getState()[t];for(var y=r.extractRehydrationInfo(e).queries,m=0,g=Object.entries(y);m<g.length;m++){var b,q=g[m],S=q[1];l(b=q[0],null==S?void 0:S.endpointName,i,s.config)}}}},Ae=b(require("@reduxjs/toolkit")),Te=function(t){var n=t.reducerPath,r=t.context,i=t.context.endpointDefinitions,a=t.mutationThunk,u=t.api,o=t.assertTagType,s=t.refetchQuery,c=u.internalActions.removeQueryResult,l=(0,Ae.isAnyOf)((0,Ae.isFulfilled)(a),(0,Ae.isRejectedWithValue)(a));function d(t,i){var a=i.getState(),o=a[n],l=u.util.selectInvalidatedBy(a,t);r.batch((function(){for(var t,n=0,r=Array.from(l.values());n<r.length;n++){var a=r[n].queryCacheKey,u=o.queries[a],d=null!=(t=o.subscriptions[a])?t:{};u&&(0===Object.keys(d).length?i.dispatch(c({queryCacheKey:a})):u.status!==e.uninitialized&&i.dispatch(s(u,a)))}}))}return function(e,t){l(e)&&d(te(e,"invalidatesTags",i,o),t),u.util.invalidateTags.match(e)&&d(W(e.payload,void 0,void 0,void 0,void 0,o),t)}},Re=function(t){var n=t.reducerPath,r=t.queryThunk,i=t.api,a=t.refetchQuery,u=t.internalState,o={};function s(t,r){var i=t.queryCacheKey,s=r.getState()[n].queries[i];if(s&&s.status!==e.uninitialized){var c=d(u.currentSubscriptions[i]);if(Number.isFinite(c)){var l=o[i];(null==l?void 0:l.timeout)&&(clearTimeout(l.timeout),l.timeout=void 0);var f=Date.now()+c,p=o[i]={nextPollTimestamp:f,pollingInterval:c,timeout:setTimeout((function(){p.timeout=void 0,r.dispatch(a(s,i))}),c)}}}}function c(t,r){var i=t.queryCacheKey,a=r.getState()[n].queries[i];if(a&&a.status!==e.uninitialized){var c=d(u.currentSubscriptions[i]);if(Number.isFinite(c)){var f=o[i],p=Date.now()+c;(!f||p<f.nextPollTimestamp)&&s({queryCacheKey:i},r)}else l(i)}}function l(e){var t=o[e];(null==t?void 0:t.timeout)&&clearTimeout(t.timeout),delete o[e]}function d(e){void 0===e&&(e={});var t=Number.POSITIVE_INFINITY;for(var n in e)e[n].pollingInterval&&(t=Math.min(e[n].pollingInterval,t));return t}return function(e,t){(i.internalActions.updateSubscriptionOptions.match(e)||i.internalActions.unsubscribeQueryResult.match(e))&&c(e.payload,t),(r.pending.match(e)||r.rejected.match(e)&&e.meta.condition)&&c(e.meta.arg,t),(r.fulfilled.match(e)||r.rejected.match(e)&&!e.meta.condition)&&s(e.meta.arg,t),i.util.resetApiState.match(e)&&function(){for(var e=0,t=Object.keys(o);e<t.length;e++)l(t[e])}()}},je=b(require("@reduxjs/toolkit")),we=new Error("Promise never resolved before cacheEntryRemoved."),ke=function(e){var t=e.api,n=e.reducerPath,r=e.context,i=e.queryThunk,a=e.mutationThunk,u=(0,je.isAsyncThunkAction)(i),o=(0,je.isAsyncThunkAction)(a),s=(0,je.isFulfilled)(i,a),c={};function l(e,n,i,a,u){var o=r.endpointDefinitions[e],s=null==o?void 0:o.onCacheEntryAdded;if(s){var l={},d=new Promise((function(e){l.cacheEntryRemoved=e})),f=Promise.race([new Promise((function(e){l.valueResolved=e})),d.then((function(){throw we}))]);f.catch((function(){})),c[i]=l;var p=t.endpoints[e].select(o.type===z.query?n:i),h=a.dispatch((function(e,t,n){return n})),m=y(v({},a),{getCacheEntry:function(){return p(a.getState())},requestId:u,extra:h,updateCachedData:o.type===z.query?function(r){return a.dispatch(t.util.updateQueryData(e,n,r))}:void 0,cacheDataLoaded:f,cacheEntryRemoved:d}),g=s(n,m);Promise.resolve(g).catch((function(e){if(e!==we)throw e}))}}return function(e,r,d){var f=function(e){return u(e)?e.meta.arg.queryCacheKey:o(e)?e.meta.requestId:t.internalActions.removeQueryResult.match(e)?e.payload.queryCacheKey:t.internalActions.removeMutationResult.match(e)?ae(e.payload):""}(e);if(i.pending.match(e)){var p=d[n].queries[f],v=r.getState()[n].queries[f];!p&&v&&l(e.meta.arg.endpointName,e.meta.arg.originalArgs,f,r,e.meta.requestId)}else if(a.pending.match(e))(v=r.getState()[n].mutations[f])&&l(e.meta.arg.endpointName,e.meta.arg.originalArgs,f,r,e.meta.requestId);else if(s(e))(null==(g=c[f])?void 0:g.valueResolved)&&(g.valueResolved({data:e.payload,meta:e.meta.baseQueryMeta}),delete g.valueResolved);else if(t.internalActions.removeQueryResult.match(e)||t.internalActions.removeMutationResult.match(e))(g=c[f])&&(delete c[f],g.cacheEntryRemoved());else if(t.util.resetApiState.match(e))for(var h=0,y=Object.entries(c);h<y.length;h++){var m=y[h],g=m[1];delete c[m[0]],g.cacheEntryRemoved()}}},xe=b(require("@reduxjs/toolkit")),Pe=function(e){var t=e.api,n=e.context,r=e.queryThunk,i=e.mutationThunk,a=(0,xe.isPending)(r,i),u=(0,xe.isRejected)(r,i),o=(0,xe.isFulfilled)(r,i),s={};return function(e,r){var i,c,l;if(a(e)){var d=e.meta,f=d.requestId,p=d.arg,h=p.endpointName,m=p.originalArgs,g=n.endpointDefinitions[h],b=null==g?void 0:g.onQueryStarted;if(b){var q={},S=new Promise((function(e,t){q.resolve=e,q.reject=t}));S.catch((function(){})),s[f]=q;var O=t.endpoints[h].select(g.type===z.query?m:f),A=r.dispatch((function(e,t,n){return n})),T=y(v({},r),{getCacheEntry:function(){return O(r.getState())},requestId:f,extra:A,updateCachedData:g.type===z.query?function(e){return r.dispatch(t.util.updateQueryData(h,m,e))}:void 0,queryFulfilled:S});b(m,T)}}else if(o(e)){var R=e.meta,j=R.baseQueryMeta;null==(i=s[f=R.requestId])||i.resolve({data:e.payload,meta:j}),delete s[f]}else if(u(e)){var w=e.meta;j=w.baseQueryMeta,null==(l=s[f=w.requestId])||l.reject({error:null!=(c=e.payload)?c:e.error,isUnhandledError:!w.rejectedWithValue,meta:j}),delete s[f]}}},Qe=function(e){var t=e.api,n=e.context.apiUid;return function(e,r){t.util.resetApiState.match(e)&&r.dispatch(t.internalActions.middlewareRegistered(n))}},Ce=b(require("immer")),Ie="function"==typeof queueMicrotask?queueMicrotask.bind("undefined"!=typeof window?window:"undefined"!=typeof global?global:globalThis):function(e){return(qe||(qe=Promise.resolve())).then(e).catch((function(e){return setTimeout((function(){throw e}),0)}))};function Me(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];Object.assign.apply(Object,r([e],t))}var De=b(require("immer")),Ne=Symbol(),Ke=function(){return{name:Ne,init:function(t,i,a){var u=i.baseQuery,o=i.reducerPath,s=i.serializeQueryArgs,c=i.keepUnusedDataFor,l=i.refetchOnMountOrArgChange,d=i.refetchOnFocus,f=i.refetchOnReconnect;(0,De.enablePatches)();var p=function(e){return e};Object.assign(t,{reducerPath:o,endpoints:{},internalActions:{onOnline:K,onOffline:E,onFocus:D,onFocusLost:N},util:{}});var h=function(t){var r=this,i=t.reducerPath,a=t.baseQuery,u=t.context.endpointDefinitions,o=t.serializeQueryArgs,s=t.api,c=t.assertTagType,l=function(e,t){return q(r,[e,t],(function(e,t){var r,i,o,s,c,l,f,p,v,h,y,m,g,b=t.signal,q=t.abort,S=t.rejectWithValue,O=t.fulfillWithValue,A=t.dispatch,T=t.getState,R=t.extra;return n(this,(function(t){switch(t.label){case 0:r=u[e.endpointName],t.label=1;case 1:return t.trys.push([1,8,,13]),i=ee,o=void 0,s={signal:b,abort:q,dispatch:A,getState:T,extra:R,endpoint:e.endpointName,type:e.type,forced:"query"===e.type?d(e,T()):void 0},(c="query"===e.type?e[G]:void 0)?(o=c(),[3,6]):[3,2];case 2:return r.query?[4,a(r.query(e.originalArgs),s,r.extraOptions)]:[3,4];case 3:return o=t.sent(),r.transformResponse&&(i=r.transformResponse),[3,6];case 4:return[4,r.queryFn(e.originalArgs,s,r.extraOptions,(function(e){return a(e,s,r.extraOptions)}))];case 5:o=t.sent(),t.label=6;case 6:if(o.error)throw new P(o.error,o.meta);return l=O,[4,i(o.data,o.meta,e.originalArgs)];case 7:return[2,l.apply(void 0,[t.sent(),(m={fulfilledTimeStamp:Date.now(),baseQueryMeta:o.meta},m[Z.SHOULD_AUTOBATCH]=!0,m)])];case 8:if(f=t.sent(),!((p=f)instanceof P))return[3,12];v=ee,r.query&&r.transformErrorResponse&&(v=r.transformErrorResponse),t.label=9;case 9:return t.trys.push([9,11,,12]),h=S,[4,v(p.value,p.meta,e.originalArgs)];case 10:return[2,h.apply(void 0,[t.sent(),(g={baseQueryMeta:p.meta},g[Z.SHOULD_AUTOBATCH]=!0,g)])];case 11:return y=t.sent(),p=y,[3,12];case 12:throw console.error(p),p;case 13:return[2]}}))}))};function d(e,t){var n,r,a,u,o=null==(r=null==(n=t[i])?void 0:n.queries)?void 0:r[e.queryCacheKey],s=null==(a=t[i])?void 0:a.config.refetchOnMountOrArgChange,c=null==o?void 0:o.fulfilledTimeStamp,l=null!=(u=e.forceRefetch)?u:e.subscribe&&s;return!!l&&(!0===l||(Number(new Date)-Number(c))/1e3>=l)}var f=(0,Z.createAsyncThunk)(i+"/executeQuery",l,{getPendingMeta:function(){var e;return(e={startedTimeStamp:Date.now()})[Z.SHOULD_AUTOBATCH]=!0,e},condition:function(e,t){var n,r,a,o=(0,t.getState)(),s=null==(r=null==(n=o[i])?void 0:n.queries)?void 0:r[e.queryCacheKey],c=null==s?void 0:s.fulfilledTimeStamp,l=e.originalArgs,f=null==s?void 0:s.originalArgs,p=u[e.endpointName];return!(!Y(e)&&("pending"===(null==s?void 0:s.status)||!d(e,o)&&(!L(p)||!(null==(a=null==p?void 0:p.forceRefetch)?void 0:a.call(p,{currentArg:l,previousArg:f,endpointState:s,state:o})))&&c))},dispatchConditionRejection:!0}),p=(0,Z.createAsyncThunk)(i+"/executeMutation",l,{getPendingMeta:function(){var e;return(e={startedTimeStamp:Date.now()})[Z.SHOULD_AUTOBATCH]=!0,e}});function v(e){return function(t){var n,r;return(null==(r=null==(n=null==t?void 0:t.meta)?void 0:n.arg)?void 0:r.endpointName)===e}}return{queryThunk:f,mutationThunk:p,prefetch:function(e,t,n){return function(r,i){var a=function(e){return"force"in e}(n)&&n.force,u=function(e){return"ifOlderThan"in e}(n)&&n.ifOlderThan,o=function(n){return void 0===n&&(n=!0),s.endpoints[e].initiate(t,{forceRefetch:n})},c=s.endpoints[e].select(t)(i());if(a)r(o());else if(u){var l=null==c?void 0:c.fulfilledTimeStamp;if(!l)return void r(o());(Number(new Date)-Number(new Date(l)))/1e3>=u&&r(o())}else r(o(!1))}},updateQueryData:function(t,n,r,i){return void 0===i&&(i=!0),function(a,u){var o,c,l,d=s.endpoints[t].select(n)(u()),f={patches:[],inversePatches:[],undo:function(){return a(s.util.patchQueryData(t,n,f.inversePatches,i))}};if(d.status===e.uninitialized)return f;if("data"in d)if((0,X.isDraftable)(d.data)){var p=(0,X.produceWithPatches)(d.data,r),v=p[0],h=p[2];(o=f.patches).push.apply(o,p[1]),(c=f.inversePatches).push.apply(c,h),l=v}else l=r(d.data),f.patches.push({op:"replace",path:[],value:l}),f.inversePatches.push({op:"replace",path:[],value:d.data});return a(s.util.patchQueryData(t,n,f.patches,i)),f}},upsertQueryData:function(e,t,n){return function(r){var i;return r(s.endpoints[e].initiate(t,((i={subscribe:!1,forceRefetch:!0})[G]=function(){return{data:n}},i)))}},patchQueryData:function(e,t,n,r){return function(i,a){var l=u[e],d=o({queryArgs:t,endpointDefinition:l,endpointName:e});if(i(s.internalActions.queryResultPatched({queryCacheKey:d,patches:n})),r){var f=s.endpoints[e].select(t)(a()),p=W(l.providesTags,f.data,void 0,t,{},c);i(s.internalActions.updateProvidedBy({queryCacheKey:d,providedTags:p}))}}},buildMatchThunkActions:function(e,t){return{matchPending:(0,$.isAllOf)((0,$.isPending)(e),v(t)),matchFulfilled:(0,$.isAllOf)((0,$.isFulfilled)(e),v(t)),matchRejected:(0,$.isAllOf)((0,$.isRejected)(e),v(t))}}}}({baseQuery:u,reducerPath:o,context:a,api:t,serializeQueryArgs:s,assertTagType:p}),m=h.queryThunk,g=h.mutationThunk,b=h.patchQueryData,O=h.updateQueryData,T=h.upsertQueryData,R=h.prefetch,j=h.buildMatchThunkActions,w=function(t){var n=t.reducerPath,r=t.queryThunk,i=t.mutationThunk,a=t.context,u=a.endpointDefinitions,o=a.apiUid,s=a.extractRehydrationInfo,c=a.hasRehydrationInfo,l=t.assertTagType,d=t.config,f=(0,J.createAction)(n+"/resetApiState"),p=(0,J.createSlice)({name:n+"/queries",initialState:oe,reducers:{removeQueryResult:{reducer:function(e,t){delete e[t.payload.queryCacheKey]},prepare:(0,J.prepareAutoBatched)()},queryResultPatched:{reducer:function(e,t){var n=t.payload,r=n.patches;ie(e,n.queryCacheKey,(function(e){e.data=(0,re.applyPatches)(e.data,r.concat())}))},prepare:(0,J.prepareAutoBatched)()}},extraReducers:function(t){t.addCase(r.pending,(function(t,n){var r,i=n.meta,a=n.meta.arg,u=Y(a);(a.subscribe||u)&&(null!=t[r=a.queryCacheKey]||(t[r]={status:e.uninitialized,endpointName:a.endpointName})),ie(t,a.queryCacheKey,(function(t){t.status=e.pending,t.requestId=u&&t.requestId?t.requestId:i.requestId,void 0!==a.originalArgs&&(t.originalArgs=a.originalArgs),t.startedTimeStamp=i.startedTimeStamp}))})).addCase(r.fulfilled,(function(t,n){var r=n.meta,i=n.payload;ie(t,r.arg.queryCacheKey,(function(t){var n;if(t.requestId===r.requestId||Y(r.arg)){var a=u[r.arg.endpointName].merge;if(t.status=e.fulfilled,a)if(void 0!==t.data){var o=r.fulfilledTimeStamp,s=r.arg,c=r.baseQueryMeta,l=r.requestId,d=(0,J.createNextState)(t.data,(function(e){return a(e,i,{arg:s.originalArgs,baseQueryMeta:c,fulfilledTimeStamp:o,requestId:l})}));t.data=d}else t.data=i;else t.data=null==(n=u[r.arg.endpointName].structuralSharing)||n?A((0,ne.isDraft)(t.data)?(0,re.original)(t.data):t.data,i):i;delete t.error,t.fulfilledTimeStamp=r.fulfilledTimeStamp}}))})).addCase(r.rejected,(function(t,n){var r=n.meta,i=r.condition,a=r.requestId,u=n.error,o=n.payload;ie(t,r.arg.queryCacheKey,(function(t){if(i);else{if(t.requestId!==a)return;t.status=e.rejected,t.error=null!=o?o:u}}))})).addMatcher(c,(function(t,n){for(var r=s(n).queries,i=0,a=Object.entries(r);i<a.length;i++){var u=a[i],o=u[1];(null==o?void 0:o.status)!==e.fulfilled&&(null==o?void 0:o.status)!==e.rejected||(t[u[0]]=o)}}))}}),h=(0,J.createSlice)({name:n+"/mutations",initialState:oe,reducers:{removeMutationResult:{reducer:function(e,t){var n=ae(t.payload);n in e&&delete e[n]},prepare:(0,J.prepareAutoBatched)()}},extraReducers:function(t){t.addCase(i.pending,(function(t,n){var r=n.meta,i=r.requestId,a=r.arg,u=r.startedTimeStamp;a.track&&(t[ae(n.meta)]={requestId:i,status:e.pending,endpointName:a.endpointName,startedTimeStamp:u})})).addCase(i.fulfilled,(function(t,n){var r=n.payload,i=n.meta;i.arg.track&&ue(t,i,(function(t){t.requestId===i.requestId&&(t.status=e.fulfilled,t.data=r,t.fulfilledTimeStamp=i.fulfilledTimeStamp)}))})).addCase(i.rejected,(function(t,n){var r=n.payload,i=n.error,a=n.meta;a.arg.track&&ue(t,a,(function(t){t.requestId===a.requestId&&(t.status=e.rejected,t.error=null!=r?r:i)}))})).addMatcher(c,(function(t,n){for(var r=s(n).mutations,i=0,a=Object.entries(r);i<a.length;i++){var u=a[i],o=u[0],c=u[1];(null==c?void 0:c.status)!==e.fulfilled&&(null==c?void 0:c.status)!==e.rejected||o===(null==c?void 0:c.requestId)||(t[o]=c)}}))}}),m=(0,J.createSlice)({name:n+"/invalidation",initialState:oe,reducers:{updateProvidedBy:{reducer:function(e,t){for(var n,r,i,a,u=t.payload,o=u.queryCacheKey,s=u.providedTags,c=0,l=Object.values(e);c<l.length;c++)for(var d=0,f=Object.values(l[c]);d<f.length;d++){var p=f[d],v=p.indexOf(o);-1!==v&&p.splice(v,1)}for(var h=0,y=s;h<y.length;h++){var m=y[h],g=m.type,b=m.id,q=null!=(a=(r=null!=(n=e[g])?n:e[g]={})[i=b||"__internal_without_id"])?a:r[i]=[];q.includes(o)||q.push(o)}},prepare:(0,J.prepareAutoBatched)()}},extraReducers:function(e){e.addCase(p.actions.removeQueryResult,(function(e,t){for(var n=t.payload.queryCacheKey,r=0,i=Object.values(e);r<i.length;r++)for(var a=0,u=Object.values(i[r]);a<u.length;a++){var o=u[a],s=o.indexOf(n);-1!==s&&o.splice(s,1)}})).addMatcher(c,(function(e,t){for(var n,r,i,a,u=s(t).provided,o=0,c=Object.entries(u);o<c.length;o++)for(var l=c[o],d=l[0],f=0,p=Object.entries(l[1]);f<p.length;f++)for(var v=p[f],h=v[0],y=v[1],m=null!=(a=(r=null!=(n=e[d])?n:e[d]={})[i=h||"__internal_without_id"])?a:r[i]=[],g=0,b=y;g<b.length;g++){var q=b[g];m.includes(q)||m.push(q)}})).addMatcher((0,J.isAnyOf)((0,J.isFulfilled)(r),(0,J.isRejectedWithValue)(r)),(function(e,t){var n=te(t,"providesTags",u,l);m.caseReducers.updateProvidedBy(e,m.actions.updateProvidedBy({queryCacheKey:t.meta.arg.queryCacheKey,providedTags:n}))}))}}),g=(0,J.createSlice)({name:n+"/subscriptions",initialState:oe,reducers:{updateSubscriptionOptions:function(e,t){},unsubscribeQueryResult:function(e,t){},internal_probeSubscription:function(e,t){}}}),b=(0,J.createSlice)({name:n+"/internalSubscriptions",initialState:oe,reducers:{subscriptionsUpdated:{reducer:function(e,t){return(0,re.applyPatches)(e,t.payload)},prepare:(0,J.prepareAutoBatched)()}}}),q=(0,J.createSlice)({name:n+"/config",initialState:v({online:"undefined"==typeof navigator||void 0===navigator.onLine||navigator.onLine,focused:"undefined"==typeof document||"hidden"!==document.visibilityState,middlewareRegistered:!1},d),reducers:{middlewareRegistered:function(e,t){e.middlewareRegistered="conflict"!==e.middlewareRegistered&&o===t.payload||"conflict"}},extraReducers:function(e){e.addCase(K,(function(e){e.online=!0})).addCase(E,(function(e){e.online=!1})).addCase(D,(function(e){e.focused=!0})).addCase(N,(function(e){e.focused=!1})).addMatcher(c,(function(e){return v({},e)}))}}),S=(0,J.combineReducers)({queries:p.reducer,mutations:h.reducer,provided:m.reducer,subscriptions:b.reducer,config:q.reducer});return{reducer:function(e,t){return S(f.match(t)?void 0:e,t)},actions:y(v(v(v(v(v(v({},q.actions),p.actions),g.actions),b.actions),h.actions),m.actions),{unsubscribeMutationResult:h.actions.removeMutationResult,resetApiState:f})}}({context:a,queryThunk:m,mutationThunk:g,reducerPath:o,assertTagType:p,config:{refetchOnFocus:d,refetchOnReconnect:f,refetchOnMountOrArgChange:l,keepUnusedDataFor:c,reducerPath:o}}),k=w.reducer,x=w.actions;Me(t.util,{patchQueryData:b,updateQueryData:O,upsertQueryData:T,prefetch:R,resetApiState:x.resetApiState}),Me(t.internalActions,x);var C=function(t){var n=t.reducerPath,r=t.queryThunk,i=t.api,a=t.context,u=a.apiUid,o={invalidateTags:(0,Se.createAction)(n+"/invalidateTags")},s=[Qe,Oe,Te,Re,ke,Pe];return{middleware:function(r){var o=!1,l=y(v({},t),{internalState:{currentSubscriptions:{}},refetchQuery:c}),d=s.map((function(e){return e(l)})),f=function(e){var t=e.api,n=e.queryThunk,r=e.internalState,i=t.reducerPath+"/subscriptions",a=null,u=!1,o=t.internalActions,s=o.updateSubscriptionOptions,c=o.unsubscribeQueryResult;return function(e,o){var l,d;if(a||(a=JSON.parse(JSON.stringify(r.currentSubscriptions))),t.util.resetApiState.match(e))return a=r.currentSubscriptions={},[!0,!1];if(t.internalActions.internal_probeSubscription.match(e)){var f=e.payload;return[!1,!!(null==(l=r.currentSubscriptions[f.queryCacheKey])?void 0:l[f.requestId])]}var p=function(e,r){var i,a,u,o,l,d,f,p,v;if(s.match(r)){var h=r.payload,y=h.queryCacheKey,m=h.requestId;return(null==(i=null==e?void 0:e[y])?void 0:i[m])&&(e[y][m]=h.options),!0}if(c.match(r)){var g=r.payload;return m=g.requestId,e[y=g.queryCacheKey]&&delete e[y][m],!0}if(t.internalActions.removeQueryResult.match(r))return delete e[r.payload.queryCacheKey],!0;if(n.pending.match(r)){var b=r.meta;if(m=b.requestId,(O=b.arg).subscribe)return(q=null!=(u=e[a=O.queryCacheKey])?u:e[a]={})[m]=null!=(l=null!=(o=O.subscriptionOptions)?o:q[m])?l:{},!0}if(n.rejected.match(r)){var q,S=r.meta,O=S.arg;if(m=S.requestId,S.condition&&O.subscribe)return(q=null!=(f=e[d=O.queryCacheKey])?f:e[d]={})[m]=null!=(v=null!=(p=O.subscriptionOptions)?p:q[m])?v:{},!0}return!1}(r.currentSubscriptions,e);if(p){u||(Ie((function(){var e=JSON.parse(JSON.stringify(r.currentSubscriptions)),n=(0,Ce.produceWithPatches)(a,(function(){return e}));o.next(t.internalActions.subscriptionsUpdated(n[1])),a=e,u=!1})),u=!0);var v=!!(null==(d=e.type)?void 0:d.startsWith(i)),h=n.rejected.match(e)&&e.meta.condition&&!!e.meta.arg.subscribe;return[!v&&!h,!1]}return[!0,!1]}}(l),p=function(t){var n=t.reducerPath,r=t.context,i=t.refetchQuery,a=t.internalState,u=t.api.internalActions.removeQueryResult;function o(t,o){var s=t.getState()[n],c=s.queries,l=a.currentSubscriptions;r.batch((function(){for(var n=0,r=Object.keys(l);n<r.length;n++){var a=r[n],d=c[a],f=l[a];f&&d&&(Object.values(f).some((function(e){return!0===e[o]}))||Object.values(f).every((function(e){return void 0===e[o]}))&&s.config[o])&&(0===Object.keys(f).length?t.dispatch(u({queryCacheKey:a})):d.status!==e.uninitialized&&t.dispatch(i(d,a)))}}))}return function(e,t){D.match(e)&&o(t,"refetchOnFocus"),K.match(e)&&o(t,"refetchOnReconnect")}}(l);return function(e){return function(t){o||(o=!0,r.dispatch(i.internalActions.middlewareRegistered(u)));var s,c=y(v({},r),{next:e}),l=r.getState(),h=f(t,c,l),m=h[1];if(s=h[0]?e(t):m,r.getState()[n]&&(p(t,c,l),function(e){return!!e&&"string"==typeof e.type&&e.type.startsWith(n+"/")}(t)||a.hasRehydrationInfo(t)))for(var g=0,b=d;g<b.length;g++)(0,b[g])(t,c,l);return s}}},actions:o};function c(e,t,n){return void 0===n&&(n={}),r(v({type:"query",endpointName:e.endpointName,originalArgs:e.originalArgs,subscribe:!1,forceRefetch:!0,queryCacheKey:t},n))}}({reducerPath:o,context:a,queryThunk:m,mutationThunk:g,api:t,assertTagType:p}),Q=C.middleware;Me(t.util,C.actions),Me(t,{reducer:k,middleware:Q});var I=function(t){var n=t.serializeQueryArgs,r=t.reducerPath,i=function(e){return de},a=function(e){return fe};return{buildQuerySelector:function(e,t){return function(r){var a=n({queryArgs:r,endpointDefinition:t,endpointName:e});return(0,B.createSelector)(r===se?i:function(e){var t,n,r;return null!=(r=null==(n=null==(t=o(e))?void 0:t.queries)?void 0:n[a])?r:de},u)}},buildMutationSelector:function(){return function(e){var t,n;return n="object"==typeof e?null!=(t=ae(e))?t:se:e,(0,B.createSelector)(n===se?a:function(e){var t,r,i;return null!=(i=null==(r=null==(t=o(e))?void 0:t.mutations)?void 0:r[n])?i:fe},u)}},selectInvalidatedBy:function(e,t){for(var n,i=e[r],a=new Set,u=0,o=t.map(H);u<o.length;u++){var s=o[u],c=i.provided[s.type];if(c)for(var l=0,d=null!=(n=void 0!==s.id?c[s.id]:S(Object.values(c)))?n:[];l<d.length;l++)a.add(d[l])}return S(Array.from(a.values()).map((function(e){var t=i.queries[e];return t?[{queryCacheKey:e,endpointName:t.endpointName,originalArgs:t.originalArgs}]:[]})))}};function u(t){return v(v({},t),{status:n=t.status,isUninitialized:n===e.uninitialized,isLoading:n===e.pending,isSuccess:n===e.fulfilled,isError:n===e.rejected});var n}function o(e){return e[r]}}({serializeQueryArgs:s,reducerPath:o}),M=I.buildQuerySelector,_=I.buildMutationSelector;Me(t.util,{selectInvalidatedBy:I.selectInvalidatedBy});var F=function(e){var t=e.serializeQueryArgs,i=e.queryThunk,a=e.mutationThunk,u=e.api,o=e.context,s=new Map,c=new Map,l=u.internalActions,d=l.unsubscribeQueryResult,f=l.removeMutationResult,p=l.updateSubscriptionOptions;return{buildInitiateQuery:function(e,r){var a=function(o,c){var l=void 0===c?{}:c,f=l.subscribe,v=void 0===f||f,h=l.forceRefetch,y=l.subscriptionOptions,m=l[G];return function(c,l){var f,g,b=t({queryArgs:o,endpointDefinition:r,endpointName:e}),S=i(((f={type:"query",subscribe:v,forceRefetch:h,subscriptionOptions:y,endpointName:e,originalArgs:o,queryCacheKey:b})[G]=m,f)),O=u.endpoints[e].select(o),A=c(S),T=O(l()),R=A.requestId,j=A.abort,w=T.requestId!==R,k=null==(g=s.get(c))?void 0:g[b],x=function(){return O(l())},P=Object.assign(m?A.then(x):w&&!k?Promise.resolve(T):Promise.all([k,A]).then(x),{arg:o,requestId:R,subscriptionOptions:y,queryCacheKey:b,abort:j,unwrap:function(){return q(this,null,(function(){var e;return n(this,(function(t){switch(t.label){case 0:return[4,P];case 1:if((e=t.sent()).isError)throw e.error;return[2,e.data]}}))}))},refetch:function(){return c(a(o,{subscribe:!1,forceRefetch:!0}))},unsubscribe:function(){v&&c(d({queryCacheKey:b,requestId:R}))},updateSubscriptionOptions:function(t){P.subscriptionOptions=t,c(p({endpointName:e,requestId:R,queryCacheKey:b,options:t}))}});if(!k&&!w&&!m){var C=s.get(c)||{};C[b]=P,s.set(c,C),P.then((function(){delete C[b],Object.keys(C).length||s.delete(c)}))}return P}};return a},buildInitiateMutation:function(e){return function(t,n){var r=void 0===n?{}:n,i=r.track,u=void 0===i||i,o=r.fixedCacheKey;return function(n,r){var i=a({type:"mutation",endpointName:e,originalArgs:t,track:u,fixedCacheKey:o}),s=n(i),l=s.requestId,d=s.abort,p=s.unwrap,v=s.unwrap().then((function(e){return{data:e}})).catch((function(e){return{error:e}})),h=function(){n(f({requestId:l,fixedCacheKey:o}))},y=Object.assign(v,{arg:s.arg,requestId:l,abort:d,unwrap:p,unsubscribe:h,reset:h}),m=c.get(n)||{};return c.set(n,m),m[l]=y,y.then((function(){delete m[l],Object.keys(m).length||c.delete(n)})),o&&(m[o]=y,y.then((function(){m[o]===y&&(delete m[o],Object.keys(m).length||c.delete(n))}))),y}}},getRunningQueryThunk:function(e,n){return function(r){var i,a=t({queryArgs:n,endpointDefinition:o.endpointDefinitions[e],endpointName:e});return null==(i=s.get(r))?void 0:i[a]}},getRunningMutationThunk:function(e,t){return function(e){var n;return null==(n=c.get(e))?void 0:n[t]}},getRunningQueriesThunk:function(){return function(e){return Object.values(s.get(e)||{}).filter(V)}},getRunningMutationsThunk:function(){return function(e){return Object.values(c.get(e)||{}).filter(V)}},getRunningOperationPromises:function(){var e=function(e){return Array.from(e.values()).flatMap((function(e){return e?Object.values(e):[]}))};return r(r([],e(s)),e(c)).filter(V)},removalWarning:function(){throw new Error("This method had to be removed due to a conceptual bug in RTK.\n       Please see https://github.com/reduxjs/redux-toolkit/pull/2481 for details.\n       See https://redux-toolkit.js.org/rtk-query/usage/server-side-rendering for new guidance on SSR.")}}}({queryThunk:m,mutationThunk:g,api:t,serializeQueryArgs:s,context:a}),U=F.buildInitiateQuery,ce=F.buildInitiateMutation;return Me(t.util,{getRunningOperationPromises:F.getRunningOperationPromises,getRunningOperationPromise:F.removalWarning,getRunningMutationThunk:F.getRunningMutationThunk,getRunningMutationsThunk:F.getRunningMutationsThunk,getRunningQueryThunk:F.getRunningQueryThunk,getRunningQueriesThunk:F.getRunningQueriesThunk}),{name:Ne,injectEndpoint:function(e,n){var r,i=t;null!=(r=i.endpoints)[e]||(r[e]={}),L(n)?Me(i.endpoints[e],{name:e,select:M(e,n),initiate:U(e,n)},j(m,e)):n.type===z.mutation&&Me(i.endpoints[e],{name:e,select:_(),initiate:ce(e)},j(g,e))}}}}},Ee=ge(Ke());

}).call(this)}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})
},{"@reduxjs/toolkit":11,"immer":89,"reselect":168}],310:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.useChecklistReducer = exports.actions = void 0;
const toolkit_1 = require("@reduxjs/toolkit");
const react_1 = require("react");
// https://immerjs.github.io/immer/installation#pick-your-immer-version
const immer_1 = require("immer");
(0, immer_1.enableMapSet)();
const initialState = {
    entries: {},
    selectedEntries: new Set(),
};
function initialHookState({ entries, uniqueKey, initialValue, }) {
    const selectedEntries = new Set();
    const mappedEntries = Object.fromEntries(entries.map((entry) => {
        var _a;
        const key = entry[uniqueKey];
        const checked = (_a = entry.checked) !== null && _a !== void 0 ? _a : initialValue;
        if (checked) {
            selectedEntries.add(key);
        }
        else {
            selectedEntries.delete(key);
        }
        return [key, Object.assign(Object.assign({}, entry), { key, checked })];
    }));
    return {
        entries: mappedEntries,
        selectedEntries
    };
}
const checklistSlice = (0, toolkit_1.createSlice)({
    name: "checklist",
    initialState,
    reducers: {
        updateAll: (state, { payload: checked }) => {
            const selectedEntries = new Set();
            const entries = Object.fromEntries(Object.values(state.entries).map((entry) => {
                if (checked) {
                    // Cheekily add this to selected
                    // entries while we're here.
                    selectedEntries.add(entry.key);
                }
                return [entry.key, Object.assign(Object.assign({}, entry), { checked })];
            }));
            return { entries, selectedEntries };
        },
        update: (state, { payload: { key, value } }) => {
            if (value.checked !== undefined) {
                if (value.checked) {
                    state.selectedEntries.add(key);
                }
                else {
                    state.selectedEntries.delete(key);
                }
            }
            state.entries[key] = Object.assign(Object.assign({}, state.entries[key]), value);
        },
        updateMultiple: (state, { payload }) => {
            payload.forEach(([key, value]) => {
                if (value.checked !== undefined) {
                    if (value.checked) {
                        state.selectedEntries.add(key);
                    }
                    else {
                        state.selectedEntries.delete(key);
                    }
                }
                state.entries[key] = Object.assign(Object.assign({}, state.entries[key]), value);
            });
        }
    }
});
exports.actions = checklistSlice.actions;
/**
 * useChecklistReducer wraps the react 'useReducer'
 * hook with logic specific to the checklist reducer.
 *
 * Use it in components where you need to keep track
 * of checklist state.
 *
 * To update it, use dispatch with the actions
 * exported from this module.
 *
 * @example
 *
 * ```javascript
 * // Start with one entry with "checked" set to "false".
 * const initialEntries = [{ key: "some_key", id: "some_id", value: "some_value", checked: false }];
 * const [state, dispatch] = useChecklistReducer(initialEntries, "id", false);
 *
 * // Dispatch an action to set "checked" of all entries to "true".
 * let checked = true;
 * dispatch(actions.updateAll(checked));
 *
 * // Will log `["some_id"]`
 * console.log(state.selectedEntries)
 *
 * // Will log `{ key: "some_key", id: "some_id", value: "some_value", checked: true }`
 * console.log(state.entries["some_id"])
 * ```
 */
const useChecklistReducer = (entries, uniqueKey, initialValue) => {
    return (0, react_1.useReducer)(checklistSlice.reducer, initialState, (_) => initialHookState({ entries, uniqueKey, initialValue }));
};
exports.useChecklistReducer = useChecklistReducer;

},{"@reduxjs/toolkit":11,"immer":89,"react":146}],311:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
exports.remove = exports.setToken = exports.authorize = exports.oauthSlice = void 0;
const toolkit_1 = require("@reduxjs/toolkit");
const initialState = {
    loginState: 'none',
    expectingRedirect: false,
};
exports.oauthSlice = (0, toolkit_1.createSlice)({
    name: "oauth",
    initialState: initialState,
    reducers: {
        authorize: (_state, action) => {
            // Overrides state with payload.
            return action.payload;
        },
        setToken: (state, action) => {
            // Mark us as logged in by storing token.
            state.token = `${action.payload.token_type} ${action.payload.access_token}`;
            state.loginState = "login";
        },
        remove: (state) => {
            // Mark us as logged out by clearing auth.
            delete state.token;
            delete state.app;
            state.loginState = "logout";
        }
    }
});
_a = exports.oauthSlice.actions, exports.authorize = _a.authorize, exports.setToken = _a.setToken, exports.remove = _a.remove;

},{"@reduxjs/toolkit":11}],47:[function(require,module,exports){
"use strict";var react=require("react"),system=require("ariakit-react-utils/system"),dom=require("ariakit-utils/dom"),composite_compositeRow=require("../composite/composite-row.js"),__utils=require("../__utils-2acb1967.js");const useComboboxRow=system.createHook((o=>{let{state:e,...t}=o;const s=react.useContext(__utils.ComboboxContext);e=e||s;return t={role:"grid"===dom.getPopupRole(e?.contentElement)?"row":"presentation",...t},t=composite_compositeRow.useCompositeRow({state:e,...t}),t})),ComboboxRow=system.createComponent((o=>{const e=useComboboxRow(o);return system.createElement("div",e)}));"production"!=="production"&&(ComboboxRow.displayName="ComboboxRow"),exports.ComboboxRow=ComboboxRow,exports.useComboboxRow=useComboboxRow;

},{"../__utils-2acb1967.js":33,"../composite/composite-row.js":57,"ariakit-react-utils/system":23,"ariakit-utils/dom":25,"react":146}],48:[function(require,module,exports){
"use strict";var system=require("ariakit-react-utils/system"),composite_compositeSeparator=require("../composite/composite-separator.js");const useComboboxSeparator=system.createHook((o=>o=composite_compositeSeparator.useCompositeSeparator(o))),ComboboxSeparator=system.createComponent((o=>{const e=useComboboxSeparator(o);return system.createElement("hr",e)}));"production"!=="production"&&(ComboboxSeparator.displayName="ComboboxSeparator"),exports.ComboboxSeparator=ComboboxSeparator,exports.useComboboxSeparator=useComboboxSeparator;

},{"../composite/composite-separator.js":58,"ariakit-react-utils/system":23}],49:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),store=require("ariakit-react-utils/store"),misc=require("ariakit-utils/misc"),platform=require("ariakit-utils/platform"),composite_compositeState=require("../composite/composite-state.js"),popover_popoverState=require("../popover/popover-state.js");const isSafariOnMobile=platform.isSafari()&&platform.isTouchDevice();function escapeRegExp(e){return e.replace(/[.*+?^${}()|[\]\\]/g,"\\$&")}function getMatches(e){if(0===e.limit)return[];const t=misc.normalizeString(e.value),o=!1===e.limit?void 0:e.limit,s=new RegExp(escapeRegExp(t),"i"),i=new Set;for(const t of e.list){if(o&&i.size>=o)break;0===misc.normalizeString(t).search(s)&&i.add(t)}for(const t of e.list){if(o&&i.size>=o)break;s.test(misc.normalizeString(t))&&i.add(t)}return Array.from(i)}function useComboboxState(e){let{limit:t=!1,defaultActiveId:o=null,includesBaseElement:s=!0,orientation:i="vertical",focusLoop:a=!0,focusWrap:r=!0,placement:u="bottom-start",virtualFocus:c=!isSafariOnMobile,...l}=void 0===e?{}:e;const[n,m]=hooks.useControlledState(l.defaultValue??"",l.value,l.setValue),[p,v]=hooks.useControlledState(l.defaultList||[],l.list,l.setList),f=composite_compositeState.useCompositeState({...l,defaultActiveId:o,orientation:i,focusLoop:a,focusWrap:r,virtualFocus:c,includesBaseElement:s}),d=popover_popoverState.usePopoverState({...l,placement:u}),S=hooks.usePreviousValue(f.activeId),h=hooks.usePreviousValue(f.moves),[k,b]=react.useState(!1);S!==f.activeId&&b(h!==f.moves);const g=react.useMemo((()=>{if(k)return f.items.find((e=>e.id===f.activeId&&e.value))?.value}),[k,f.items,f.activeId]),M=hooks.useDeferredValue(n),I=react.useMemo((()=>getMatches({limit:t,list:p,value:M})),[t,p,M]);hooks.useUpdateLayoutEffect((()=>{d.open||(f.setActiveId(o),f.setMoves(0))}),[d.open,f.setActiveId,f.setMoves]);const q=react.useMemo((()=>({...f,...d,value:n,setValue:m,activeValue:g,list:p,setList:v,limit:t,matches:I})),[f,d,n,m,g,p,v,t,I]);return store.useStorePublisher(q)}exports.useComboboxState=useComboboxState;

},{"../composite/composite-state.js":59,"../popover/popover-state.js":75,"ariakit-react-utils/hooks":20,"ariakit-react-utils/store":22,"ariakit-utils/misc":28,"ariakit-utils/platform":29,"react":146}],50:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),system=require("ariakit-react-utils/system"),dom=require("ariakit-utils/dom"),events=require("ariakit-utils/events"),misc=require("ariakit-utils/misc"),composite_composite=require("../composite/composite.js"),popover_popoverAnchor=require("../popover/popover-anchor.js");function isFirstItemAutoSelected(e,t,o){if(!o)return!1;const n=e.find((e=>!e.disabled&&e.value));return n?.value===t}function hasCompletionString(e,t){return!!t&&(null!=e&&(e=misc.normalizeString(e),t.length>e.length&&0===t.toLowerCase().indexOf(e.toLowerCase())))}function isInputEvent(e){return"input"===e.type}const useCombobox=system.createHook((e=>{let{state:t,focusable:o=!0,autoSelect:n=!1,showOnChange:s=!0,setValueOnChange:r=!0,showOnMouseDown:u=!0,setValueOnClick:a=!0,showOnKeyDown:i=!0,moveOnKeyPress:c=!0,autoComplete:l=(t.list.length?"list":"none"),...v}=e;const m=react.useRef(null),[f,p]=hooks.useForceUpdate(),h=react.useRef(!1);n=!!n&&t.virtualFocus;const d="inline"===l||"both"===l,[E,k]=react.useState(d);hooks.useUpdateLayoutEffect((()=>{d&&k(!0)}),[d]);const b=react.useMemo((()=>{if(!d)return t.value;if(!E)return t.value;if(isFirstItemAutoSelected(t.items,t.activeValue,n)){if(hasCompletionString(t.value,t.activeValue)){const e=t.activeValue?.slice(t.value.length)||"";return t.value+e}return t.value}return t.activeValue||t.value}),[d,t.value,E,t.items,n,t.activeValue]);react.useEffect((()=>{const e=m.current;if(!e)return;const t=()=>k(!0);return e.addEventListener("combobox-item-move",t),()=>{e.removeEventListener("combobox-item-move",t)}}),[]),react.useEffect((()=>{if(!d)return;if(!E)return;if(!t.activeValue)return;if(!isFirstItemAutoSelected(t.items,t.activeValue,n))return;if(!hasCompletionString(t.value,t.activeValue))return;const e=m.current;e&&e.setSelectionRange(t.value.length,t.activeValue.length)}),[f,d,E,t.activeValue,t.items,n,t.value]),hooks.useUpdateLayoutEffect((()=>{t.value&&(h.current=!0)}),[t.value]),hooks.useSafeLayoutEffect((()=>{t.open||(h.current=!1)}),[t.open]),hooks.useUpdateLayoutEffect((()=>{n&&t.items.length&&h.current&&t.move(t.first())}),[f,t.value,n,t.items,t.move,t.first]),hooks.useSafeLayoutEffect((()=>{n||t.setActiveId(null)}),[f,n,t.setActiveId]),react.useEffect((()=>{if(!d)return;const e=m.current;if(!e)return;const o=[e,t.contentElement].filter(Boolean),n=e=>{o.every((t=>events.isFocusEventOutside(e,t)))&&t.setValue(b)};return o.forEach((e=>e?.addEventListener("focusout",n))),()=>{o.forEach((e=>e?.removeEventListener("focusout",n)))}}),[d,t.contentElement,t.setValue,b]);const y=v.onChange,C=hooks.useBooleanEvent(s),g=hooks.useBooleanEvent(r),x=hooks.useEvent((e=>{if(y?.(e),e.defaultPrevented)return;const{target:o}=e,s=e.nativeEvent;if(h.current=!0,isInputEvent(s)&&d){const e="insertText"===s.inputType,t=o.selectionStart===o.value.length;k(e&&t)}C(e)&&t.show(),g(e)&&t.setValue(o.value),d&&n&&p(),n&&h.current||t.setActiveId(null)})),w=v.onCompositionEnd,V=hooks.useEvent((e=>{w?.(e),e.defaultPrevented||(h.current=!0,n&&p())})),S=v.onMouseDown,A=hooks.useBooleanEvent(a),I=hooks.useBooleanEvent(u),L=hooks.useEvent((e=>{S?.(e),e.defaultPrevented||e.button||e.ctrlKey||(t.setActiveId(null),A(e)&&t.setValue(b),I(e)&&events.queueBeforeEvent(e.currentTarget,"mouseup",t.show))})),B=v.onKeyDown,K=hooks.useBooleanEvent(i),O=hooks.useEvent((e=>{B?.(e),e.defaultPrevented||(h.current=!1,e.ctrlKey||e.altKey||e.shiftKey||e.metaKey||t.open||null===t.activeId&&("ArrowUp"!==e.key&&"ArrowDown"!==e.key||K(e)&&(e.preventDefault(),t.show())))})),q=v.onBlur,D=hooks.useEvent((e=>{q?.(e),e.defaultPrevented||(h.current=!1)}));v={id:hooks.useId(v.id),role:"combobox","aria-autocomplete":l,"aria-haspopup":dom.getPopupRole(t.contentElement,"listbox"),"aria-expanded":t.open,"aria-controls":t.contentElement?.id,value:b,...v,ref:hooks.useForkRef(m,v.ref),onChange:x,onCompositionEnd:V,onMouseDown:L,onKeyDown:O,onBlur:D};const P=hooks.useBooleanEvent(c);return v=composite_composite.useComposite({state:t,focusable:o,...v,moveOnKeyPress:e=>!!P(e)&&(d&&k(!0),!0)}),v=popover_popoverAnchor.usePopoverAnchor({state:t,...v}),{autoComplete:"off",...v}})),Combobox=system.createComponent((e=>{const t=useCombobox(e);return system.createElement("input",t)}));"production"!=="production"&&(Combobox.displayName="Combobox"),exports.Combobox=Combobox,exports.useCombobox=useCombobox;

},{"../composite/composite.js":60,"../popover/popover-anchor.js":74,"ariakit-react-utils/hooks":20,"ariakit-react-utils/system":23,"ariakit-utils/dom":25,"ariakit-utils/events":26,"ariakit-utils/misc":28,"react":146}],39:[function(require,module,exports){
"use strict";var hooks=require("ariakit-react-utils/hooks"),system=require("ariakit-react-utils/system"),jsxRuntime=require("react/jsx-runtime"),button_button=require("../button/button.js");const children=jsxRuntime.jsxs("svg",{"aria-hidden":"true",display:"block",viewBox:"0 0 16 16",fill:"none",stroke:"currentColor",strokeLinecap:"round",strokeLinejoin:"round",strokeWidth:"1pt",width:"1em",height:"1em",pointerEvents:"none",children:[jsxRuntime.jsx("line",{x1:"5",y1:"5",x2:"11",y2:"11"}),jsxRuntime.jsx("line",{x1:"5",y1:"11",x2:"11",y2:"5"})]}),useComboboxCancel=system.createHook((e=>{let{state:o,...t}=e;const n=t.onClick,s=hooks.useEvent((e=>{n?.(e),e.defaultPrevented||(o.setValue(""),o.move(null))})),r=hooks.useRefId(o.baseRef);return t={children:children,"aria-label":"Clear input","aria-controls":r,...t,onClick:s},t=button_button.useButton(t),t})),ComboboxCancel=system.createComponent((e=>{const o=useComboboxCancel(e);return system.createElement("button",o)}));"production"!=="production"&&(ComboboxCancel.displayName="ComboboxCancel"),exports.ComboboxCancel=ComboboxCancel,exports.useComboboxCancel=useComboboxCancel;

},{"../button/button.js":36,"ariakit-react-utils/hooks":20,"ariakit-react-utils/system":23,"react/jsx-runtime":147}],67:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),system=require("ariakit-react-utils/system"),button_button=require("../button/button.js");const useDisclosure=system.createHook((e=>{let{state:s,toggleOnClick:t=!0,...o}=e;const r=react.useRef(null),[u,n]=react.useState(!1);hooks.useSafeLayoutEffect((()=>{const e=s.disclosureRef.current;e&&e.isConnected||(s.disclosureRef.current=r.current);const t=s.disclosureRef.current===r.current;n(s.open&&t)}),[s.disclosureRef,s.open]);const c=o.onMouseDown,i=hooks.useEvent((e=>{s.disclosureRef.current=e.currentTarget,c?.(e)})),a=o.onClick,l=hooks.useBooleanEvent(t),d="data-disclosure"in o,f=hooks.useEvent((e=>{s.disclosureRef.current=e.currentTarget,a?.(e),e.defaultPrevented||d||l(e)&&s.toggle()}));return o={"data-disclosure":"","aria-expanded":u,"aria-controls":s.contentElement?.id,...o,ref:hooks.useForkRef(r,o.ref),onMouseDown:i,onClick:f},o=button_button.useButton(o),o})),Disclosure=system.createComponent((e=>{const s=useDisclosure(e);return system.createElement("button",s)}));"production"!=="production"&&(Disclosure.displayName="Disclosure"),exports.Disclosure=Disclosure,exports.useDisclosure=useDisclosure;

},{"../button/button.js":36,"ariakit-react-utils/hooks":20,"ariakit-react-utils/system":23,"react":146}],44:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),store=require("ariakit-react-utils/store"),system=require("ariakit-react-utils/system"),dom=require("ariakit-utils/dom"),events=require("ariakit-utils/events"),focus=require("ariakit-utils/focus"),misc=require("ariakit-utils/misc"),composite_compositeHover=require("../composite/composite-hover.js"),composite_compositeItem=require("../composite/composite-item.js"),__utils=require("../__utils-2acb1967.js"),jsxRuntime=require("react/jsx-runtime");const useComboboxItem=system.createHook((e=>{let{state:o,value:t,hideOnClick:s=null!=t,setValueOnClick:r=!0,shouldRegisterItem:i=!0,focusOnHover:u=!1,moveOnKeyPress:n=!0,getItem:m,...c}=e;o=store.useStore(o||__utils.ComboboxContext,["setValue","move","hide","baseRef","contentElement","mounted"]);const a=react.useCallback((e=>{const o={...e,value:t};return m?m(o):o}),[t,m]),l=c.onClick,v=hooks.useBooleanEvent(r),b=hooks.useBooleanEvent(s),k=hooks.useEvent((e=>{l?.(e),e.defaultPrevented||events.isDownloading(e)||events.isOpeningInNewTab(e)||(null!=t&&v(e)&&o?.setValue(t),b(e)&&(o?.move(null),o?.hide()))})),p=c.onKeyDown,d=hooks.useEvent((e=>{if(p?.(e),e.defaultPrevented)return;const t=o?.baseRef.current;if(!t)return;if(focus.hasFocus(t))return;(1===e.key.length||"Backspace"===e.key||"Delete"===e.key)&&(misc.queueMicrotask((()=>t.focus())),dom.isTextField(t)&&o?.setValue(t.value))}));c=hooks.useWrapElement(c,(e=>jsxRuntime.jsx(__utils.ComboboxItemValueContext.Provider,{value:t,children:e})),[t]),c={role:dom.getPopupItemRole(o?.contentElement),children:t,...c,onClick:k,onKeyDown:d};const x=hooks.useBooleanEvent(n);return c=composite_compositeItem.useCompositeItem({state:o,...c,getItem:a,shouldRegisterItem:o?.mounted&&i,moveOnKeyPress:e=>{if(!x(e))return!1;const t=new Event("combobox-item-move");return o?.baseRef.current?.dispatchEvent(t),!0}}),c=composite_compositeHover.useCompositeHover({state:o,focusOnHover:u,...c}),c})),ComboboxItem=store.createMemoComponent((e=>{const o=useComboboxItem(e);return system.createElement("div",o)}));"production"!=="production"&&(ComboboxItem.displayName="ComboboxItem"),exports.ComboboxItem=ComboboxItem,exports.useComboboxItem=useComboboxItem;

},{"../__utils-2acb1967.js":33,"../composite/composite-hover.js":55,"../composite/composite-item.js":56,"ariakit-react-utils/hooks":20,"ariakit-react-utils/store":22,"ariakit-react-utils/system":23,"ariakit-utils/dom":25,"ariakit-utils/events":26,"ariakit-utils/focus":27,"ariakit-utils/misc":28,"react":146,"react/jsx-runtime":147}],64:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),system=require("ariakit-react-utils/system"),dom=require("ariakit-utils/dom"),events=require("ariakit-utils/events"),focus=require("ariakit-utils/focus"),misc=require("ariakit-utils/misc"),platform=require("ariakit-utils/platform"),disclosure_disclosureContent=require("../disclosure/disclosure-content.js"),focusTrap_focusTrapRegion=require("../focus-trap/focus-trap-region.js"),focusable_focusable=require("../focusable/focusable.js"),heading_headingLevel=require("../heading/heading-level.js"),portal_portal=require("../portal/portal.js"),jsxRuntime=require("react/jsx-runtime"),dialogContext=require("../dialog-context-75cce90b.js"),reactDom=require("react-dom");function usePreviousMouseDownRef(e){const t=react.useRef();return react.useEffect((()=>{if(!e)return void(t.current=null);return events.addGlobalEventListener("mousedown",(e=>{t.current=e.target}),!0)}),[e]),t}function DialogBackdrop(e){let{state:t,backdrop:n,backdropProps:o,hideOnInteractOutside:r=!0,hideOnEscape:s=!0,hidden:i,children:u}=e;const a=react.useRef(null);t=react.useMemo((()=>({...t,setContentElement:misc.noop})),[t]),hooks.useSafeLayoutEffect((()=>{const e=a.current,n=t.contentElement;e&&n&&(e.style.zIndex=getComputedStyle(n).zIndex)}),[t.contentElement]);const c=o?.onClick,d=hooks.useBooleanEvent(r),l=usePreviousMouseDownRef(t.mounted),f=hooks.useEvent((e=>{c?.(e),e.defaultPrevented||events.isSelfTarget(e)&&l.current===e.currentTarget&&d(e)&&(e.stopPropagation(),t.hide())})),p=o?.onKeyDown,m=hooks.useBooleanEvent(s),g=hooks.useEvent((e=>{p?.(e),e.defaultPrevented||"Escape"===e.key&&events.isSelfTarget(e)&&m(e)&&t.hide()})),h=disclosure_disclosureContent.useDisclosureContent({state:t,id:void 0,role:"presentation",tabIndex:-1,hidden:i,...o,ref:hooks.useForkRef(o?.ref,a),onClick:f,onKeyDown:g,style:{position:"fixed",top:0,right:0,bottom:0,left:0,...o?.style}}),v="boolean"!=typeof n&&n||"div";return jsxRuntime.jsx(v,{...h,"data-backdrop":t.contentElement?.id,children:u})}const ignoreTags=["SCRIPT","STYLE"];function isValidElement(e,t){return!ignoreTags.includes(e.tagName)&&!t.some((t=>t&&dom.contains(e,t)))}function walkTreeOutside(e,t){for(let n of e){const o=dom.getDocument(n);for(;n?.parentElement&&n!==o.body;){for(const o of n.parentElement.children)isValidElement(o,e)&&t(o);n=n.parentElement}}}function disableElement$1(e){const t=e.getAttribute("aria-hidden")||"";e.setAttribute("aria-hidden","true");return()=>{t?e.setAttribute("aria-hidden",t):e.removeAttribute("aria-hidden")}}function disableAccessibilityTreeOutside(){const e=[];for(var t=arguments.length,n=new Array(t),o=0;o<t;o++)n[o]=arguments[o];walkTreeOutside(n,(t=>{e.unshift(disableElement$1(t))}));return()=>{e.forEach((e=>e()))}}function disableElement(e){if(!("style"in e))return misc.noop;const t=e.style.pointerEvents;e.style.pointerEvents="none";return()=>{e.style.pointerEvents=t??""}}function disablePointerEventsOutside(){const e=[];for(var t=arguments.length,n=new Array(t),o=0;o<t;o++)n[o]=arguments[o];walkTreeOutside(n,(t=>{e.unshift(disableElement(t))}));return()=>{e.forEach((e=>e()))}}function prependHiddenDismiss(e,t){const n=dom.getDocument(e).createElement("button");n.type="button",n.tabIndex=-1,n.textContent="Dismiss popup",n.style.border="0px",n.style.clip="rect(0 0 0 0)",n.style.height="1px",n.style.margin="-1px",n.style.overflow="hidden",n.style.padding="0px",n.style.position="absolute",n.style.whiteSpace="nowrap",n.style.width="1px",n.addEventListener("click",t),e.prepend(n);return()=>{n.removeEventListener("click",t),n.remove()}}function useChampionDialog(e,t,n){const[o,r]=hooks.useForceUpdate(),s=react.useCallback((()=>{if(!n)return!1;const o=e.current;if(!o)return!1;const{body:r}=dom.getDocument(o),s=r.getAttribute(t);return!s||s===o.id}),[o,n,t]);return hooks.useSafeLayoutEffect((()=>{const o=e.current;if(!o)return;if(!n)return;const{body:i}=dom.getDocument(o);if(!s()){const e=new MutationObserver((()=>reactDom.flushSync(r)));return e.observe(i,{attributeFilter:[t]}),()=>e.disconnect()}return i.setAttribute(t,o.id),()=>{i.removeAttribute(t)}}),[o,e,n,s,t]),s}function useFocusOnChildUnmount(e,t){react.useEffect((()=>{if(!t.open)return;const n=e.current;if(!n)return;const o=new MutationObserver((e=>{let[t]=e;if(!t)return;if(t.target!==n)return;const o=dom.getDocument(n);dom.getActiveElement(n)===o.body&&n.focus()}));return o.observe(n,{childList:!0,subtree:!0}),()=>o.disconnect()}),[t.open,e])}function isInDocument(e){return"HTML"===e.tagName||dom.contains(dom.getDocument(e).body,e)}function isDisclosure(e,t){if(dom.contains(e,t))return!0;const n=t.getAttribute("aria-activedescendant");if(n){const t=dom.getDocument(e).getElementById(n);if(t)return dom.contains(e,t)}return!1}function isBackdrop$1(e,t){return!!e&&(!!t&&(t.hasAttribute("data-backdrop")&&t.getAttribute("data-backdrop")===e.id))}function dialogContains(e){return t=>{const n=t.current;return!!n&&(!!dom.contains(n,e)||!!isBackdrop$1(n,e))}}function useEventOutside(e){let{type:t,listener:n,dialogRef:o,nestedDialogs:r,disclosureRef:s,enabled:i,capture:u}=e;const a=hooks.useEvent(n),c=hooks.useLiveRef(r);react.useEffect((()=>{if(!i)return;return events.addGlobalEventListener(t,(e=>{const t=o.current,n=s?.current,r=e.target;t&&r&&isInDocument(r)&&(dom.contains(t,r)||n&&isDisclosure(n,r)||r.hasAttribute("data-focus-trap")||c.current.some(dialogContains(r))||a(e))}),u)}),[i,o,s,a,u])}function shouldHideOnInteractOutside(e,t){return"function"==typeof e?e(t):!!e}function useHideOnInteractOutside(e,t,n){let{state:o,modal:r,hideOnInteractOutside:s,enabled:i=o.open}=n;const u=usePreviousMouseDownRef(i),a={disclosureRef:o.disclosureRef,enabled:i,dialogRef:e,nestedDialogs:t,capture:!0};useEventOutside({...a,type:"mousedown",listener:t=>{const n=e.current;n&&r&&!shouldHideOnInteractOutside(s,t)&&(n.focus(),t.preventDefault(),t.stopPropagation())}}),useEventOutside({...a,type:"click",listener:t=>{const n=u.current;if(!n)return;if(!shouldHideOnInteractOutside(s,t)){if(!r)return;return t.preventDefault(),void t.stopPropagation()}const i=e.current;i&&dom.contains(i,n)||o.hide()}}),useEventOutside({...a,type:"focusin",listener:t=>{const n=e.current;if(n){if(!shouldHideOnInteractOutside(s,t)){if(!r)return;return n.focus(),t.preventDefault(),void t.stopPropagation()}t.target!==dom.getDocument(n)&&o.hide()}}}),useEventOutside({...a,type:"contextmenu",listener:t=>{const n=e.current;if(n){if(!shouldHideOnInteractOutside(s,t)){if(!r)return;return n.focus(),t.preventDefault(),void t.stopPropagation()}o.hide()}}})}const NestedDialogsContext=react.createContext({});function useNestedDialogs(e,t){let{state:n,modal:o}=t;const r=react.useContext(NestedDialogsContext),[s,i]=react.useState([]),[u,a]=react.useState([]),c=react.useCallback((e=>{const t=r.addDialog?.(e);return a((t=>[...t,e])),()=>{t?.(),a((t=>t.filter((t=>t!==e))))}}),[r.addDialog]),d=react.useCallback((e=>{const t=r.showModal?.(e);return i((t=>[...t,e])),()=>{t?.(),i((t=>t.filter((t=>t!==e))))}}),[r.showModal]);hooks.useSafeLayoutEffect((()=>r.addDialog?.(e)),[r.addDialog,e]),hooks.useSafeLayoutEffect((()=>{if(o&&n.open)return r.showModal?.(e)}),[o,n.open,r.showModal,e]),hooks.useSafeLayoutEffect((()=>{!1===r.open&&n.open&&n.hide()}),[r.open,n.open,n.hide]);const l=react.useMemo((()=>({open:n.open,addDialog:c,showModal:d})),[n.open,c,d]);return{nestedDialogs:u,openModals:s,wrapElement:react.useCallback((e=>jsxRuntime.jsx(NestedDialogsContext.Provider,{value:l,children:e})),[l])}}function assignStyle(e,t){if(!e)return()=>{};const n=e.style.cssText;return Object.assign(e.style,t),()=>{e.style.cssText=n}}function setCSSProperty(e,t,n){if(!e)return()=>{};const o=e.style.getPropertyValue(t);return e.style.setProperty(t,n),()=>{o?e.style.setProperty(t,o):e.style.removeProperty(t)}}function getPaddingProperty(e){const t=e.getBoundingClientRect().left;return Math.round(t)+e.scrollLeft?"paddingLeft":"paddingRight"}function usePreventBodyScroll(e,t){const n=useChampionDialog(e,"data-dialog-body-scroll",t);hooks.useSafeLayoutEffect((()=>{const t=e.current;if(!t)return;if(!n())return;const o=dom.getDocument(t),r=dom.getWindow(t),{documentElement:s,body:i}=o,u=r.innerWidth-s.clientWidth,a=getPaddingProperty(s),c=platform.isApple()&&!platform.isMac();return misc.chain(setCSSProperty(s,"--scrollbar-width",`${u}px`),c?(()=>{const{scrollX:e,scrollY:t,visualViewport:n}=r,o=n?.offsetLeft??0,s=n?.offsetTop??0,c=assignStyle(i,{position:"fixed",overflow:"hidden",top:-(t-Math.floor(s))+"px",left:-(e-Math.floor(o))+"px",right:"0",[a]:`${u}px`});return()=>{c(),"test"!=="production"&&r.scrollTo(e,t)}})():assignStyle(i,{overflow:"hidden",[a]:`${u}px`}))}),[e,n])}const isSafariBrowser=platform.isSafari();function isBackdrop(e,t){const n=e.id;if(n)return t.getAttribute("data-backdrop")===n}function isInDialog(e){return t=>t.current&&dom.contains(t.current,e)}function isAlreadyFocusingAnotherElement(e,t){const n=dom.getActiveElement();return!!n&&(!dom.contains(e,n)&&(!isBackdrop(e,n)&&(!t?.some(isInDialog(n))&&!!focus.isFocusable(n))))}const useDialog=system.createHook((e=>{let{state:t,focusable:n=!0,modal:o=!0,portal:r=!!o,backdrop:s=!!o,backdropProps:i,hideOnEscape:u=!0,hideOnInteractOutside:a=!0,preventBodyScroll:c=!!o,autoFocusOnShow:d=!0,autoFocusOnHide:l=!0,initialFocusRef:f,finalFocusRef:p,...m}=e;const g=react.useRef(null),h=react.useRef(t.open),{portalRef:v,portalNode:b,domReady:y}=hooks.usePortalRef(r,m.portalRef),E=m.preserveTabOrder&&!o&&t.mounted,k=t.open&&!t.animating,D=o||r&&E&&platform.isSafari(),x=hooks.useId(m.id);hooks.useSafeLayoutEffect((()=>{if(!k)return;const e=g.current,n=dom.getActiveElement(e,!0);n&&"BODY"!==n.tagName&&(e&&dom.contains(e,n)||(t.disclosureRef.current=n))}),[k]);const O=useNestedDialogs(g,{state:t,modal:o}),{nestedDialogs:R,openModals:C,wrapElement:S}=O,w=hooks.useLiveRef(R);usePreventBodyScroll(g,c&&t.mounted),useFocusOnChildUnmount(g,t),useHideOnInteractOutside(g,R,{state:t,modal:o,hideOnInteractOutside:a,enabled:t.open}),isSafariBrowser&&react.useEffect((()=>{if(!t.mounted)return;const e=t.disclosureRef.current;if(!e)return;if(!dom.isButton(e))return;const n=()=>{let t=!1;const n=()=>{t=!0};e.addEventListener("focusin",n,{capture:!0,once:!0}),events.queueBeforeEvent(e,"mouseup",(()=>{e.removeEventListener("focusin",n,!0),t||focus.focusIfNeeded(e)}))};return e.addEventListener("mousedown",n),()=>{e.removeEventListener("mousedown",n)}}),[t.mounted,t.disclosureRef]),react.useEffect((()=>{if(!t.mounted)return;if(!y)return;const e=g.current;if(e&&D){if(e.querySelector("[data-dialog-dismiss]"))return;return prependHiddenDismiss(e,t.hide)}}),[t.mounted,y,D,t.hide]);const P=useChampionDialog(g,"data-dialog-disable-outside",k&&!C.length&&D);hooks.useSafeLayoutEffect((()=>{if(!P())return;const e=r?b:g.current;return o?misc.chain(disableAccessibilityTreeOutside(e),s?null:disablePointerEventsOutside(e)):disableAccessibilityTreeOutside(e)}),[P,r,b,o,s]);const L=react.useRef(),I=!!d,A=hooks.useBooleanEvent(d);react.useEffect((()=>{if(!k)return;if(!I)return;if(!y)return;const e=w.current?.some((e=>e.current&&!e.current.hidden));if(e)return;const n=t.contentElement;if(!n?.isConnected)return;const o=f?.current,s=o||focus.getFirstTabbableIn(n,!0,r&&E)||n,i=L.current;if(L.current=o,o===i){const e=dom.getActiveElement(n,!0);if(e&&dom.contains(n,e))return}A(s)&&s.focus()}),[k,I,y,t.contentElement,f,r,E,A]);const T=!!l,j=hooks.useBooleanEvent(l);react.useEffect((()=>{const e=g.current,n=h.current;if(h.current=t.open,!n)return;if(!T)return;if(!e)return;const o=()=>{const n=w.current;if(isAlreadyFocusingAnotherElement(e,n))return;let o=p?.current||t.disclosureRef.current;if(o){if(o.id){const e=dom.getDocument(o),t=`[aria-activedescendant="${o.id}"]`,n=e.querySelector(t);n&&(o=n)}if(!focus.isFocusable(o)){const e=dom.closest(o,"[data-dialog]");if(e&&e.id){const t=dom.getDocument(e),n=`[aria-controls~="${e.id}"]`,r=t.querySelector(n);r&&(o=r)}}if(!j(o))return;o.focus()}};return t.open?o:o()}),[T,t.open,p,t.disclosureRef,j]);const B=hooks.useBooleanEvent(u);react.useEffect((()=>{if(!y)return;if(!t.mounted)return;return events.addGlobalEventListener("keydown",(e=>{const n=g.current;if(!n)return;const o=e.target,r=t.disclosureRef.current;if("Escape"!==e.key)return;if(e.defaultPrevented)return;if(!o)return;(()=>{if(dom.contains(n,o)){return!w.current.some(isInDialog(o))}return!(!r||!dom.contains(r,o))})()&&B(e)&&t.hide()}))}),[y,t.mounted,t.disclosureRef,B,t.hide]),m=hooks.useWrapElement(m,S,[S]),m=hooks.useWrapElement(m,(e=>jsxRuntime.jsx(heading_headingLevel.HeadingLevel,{level:o?1:void 0,children:e})),[o]),m=focusTrap_focusTrapRegion.useFocusTrapRegion({...m,enabled:t.open&&o&&!C.length});const q=m.hidden;m=hooks.useWrapElement(m,(e=>s?jsxRuntime.jsx(DialogBackdrop,{state:t,backdrop:s,backdropProps:i,hideOnInteractOutside:a,hideOnEscape:u,hidden:q,children:e}):e),[t,s,i,a,u,q]);const[M,F]=react.useState(),[N,H]=react.useState();return m=hooks.useWrapElement(m,(e=>jsxRuntime.jsx(dialogContext.DialogContext.Provider,{value:t,children:jsxRuntime.jsx(dialogContext.DialogHeadingContext.Provider,{value:F,children:jsxRuntime.jsx(dialogContext.DialogDescriptionContext.Provider,{value:H,children:e})})})),[t]),m={id:x,"data-dialog":"",role:"dialog",tabIndex:n?-1:void 0,"aria-labelledby":M,"aria-describedby":N,...m,ref:hooks.useForkRef(g,m.ref)},m=disclosure_disclosureContent.useDisclosureContent({state:t,...m}),m=focusable_focusable.useFocusable({...m,focusable:n}),m=portal_portal.usePortal({portal:r,...m,portalRef:v,preserveTabOrder:E}),m})),Dialog=system.createComponent((e=>{const t=useDialog(e);return system.createElement("div",t)}));"production"!=="production"&&(Dialog.displayName="Dialog"),exports.Dialog=Dialog,exports.useDialog=useDialog;

},{"../dialog-context-75cce90b.js":61,"../disclosure/disclosure-content.js":65,"../focus-trap/focus-trap-region.js":68,"../focusable/focusable.js":70,"../heading/heading-level.js":73,"../portal/portal.js":78,"ariakit-react-utils/hooks":20,"ariakit-react-utils/system":23,"ariakit-utils/dom":25,"ariakit-utils/events":26,"ariakit-utils/focus":27,"ariakit-utils/misc":28,"ariakit-utils/platform":29,"react":146,"react-dom":110,"react/jsx-runtime":147}],262:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
const {
  Link
} = require("wouter");
module.exports = function Username(_ref) {
  let {
    user,
    link = true
  } = _ref;
  let className = "user";
  let isLocal = user.domain == null;
  if (user.suspended) {
    className += " suspended";
  }
  if (isLocal) {
    className += " local";
  }
  let icon = isLocal ? {
    fa: "fa-home",
    info: "Local user"
  } : {
    fa: "fa-external-link-square",
    info: "Remote user"
  };
  let Element = "div";
  let href = null;
  if (link) {
    Element = Link;
    href = `/settings/admin/accounts/${user.id}`;
  }
  return React.createElement(Element, {
    className: className,
    to: href
  }, React.createElement("span", {
    className: "acct"
  }, "@", user.account.acct), React.createElement("i", {
    className: `fa fa-fw ${icon.fa}`,
    "aria-hidden": "true",
    title: icon.info
  }), React.createElement("span", {
    className: "sr-only"
  }, icon.info));
};

},{"react":146,"wouter":234}],267:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
const {
  Link
} = require("wouter");
module.exports = function BackButton(_ref) {
  let {
    to
  } = _ref;
  return React.createElement(Link, {
    to: to
  }, React.createElement("a", {
    className: "button"
  }, "< back"));
};

},{"react":146,"wouter":234}],290:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
const {
  Link,
  Route,
  Redirect,
  Switch,
  useLocation,
  useRouter
} = require("wouter");
const syncpipe = require("syncpipe");
const {
  RoleContext,
  useHasPermission,
  checkPermission,
  BaseUrlContext
} = require("./util");
const ActiveRouteCtx = React.createContext();
function useActiveRoute() {
  return React.useContext(ActiveRouteCtx);
}
function Sidebar(menuTree, routing) {
  const components = menuTree.map(m => m.MenuEntry);
  return function SidebarComponent() {
    var _a;
    const router = useRouter();
    const [location] = useLocation();
    let activeRoute = (_a = routing.find(l => {
      let [match] = router.matcher(l.routingUrl, location);
      return match;
    })) === null || _a === void 0 ? void 0 : _a.routingUrl;
    return React.createElement("nav", {
      className: "menu-tree"
    }, React.createElement("ul", {
      className: "top-level"
    }, React.createElement(ActiveRouteCtx.Provider, {
      value: activeRoute
    }, components)));
  };
}
function ViewRouter(routing, defaultRoute) {
  return function ViewRouterComponent() {
    const permissions = React.useContext(RoleContext);
    const filteredRoutes = React.useMemo(() => {
      return syncpipe(routing, [_ => _.filter(route => checkPermission(route.permissions, permissions)), _ => _.map(route => {
        return React.createElement(Route, {
          path: route.routingUrl,
          key: route.key
        }, React.createElement(ErrorBoundary, null, React.createElement(BaseUrlContext.Provider, {
          value: route.url
        }, route.view)));
      })]);
    }, [permissions]);
    return React.createElement(Switch, null, filteredRoutes, React.createElement(Redirect, {
      to: defaultRoute
    }));
  };
}
function MenuComponent(_ref) {
  let {
    type,
    name,
    url,
    icon,
    permissions,
    links,
    level,
    children
  } = _ref;
  const activeRoute = useActiveRoute();
  if (!useHasPermission(permissions)) {
    return null;
  }
  const classes = [type];
  if (level == 0) {
    classes.push("top-level");
  } else if (level == 1) {
    classes.push("expanding");
  } else {
    classes.push("nested");
  }
  const isActive = links.includes(activeRoute);
  if (isActive) {
    classes.push("active");
  }
  const className = classes.join(" ");
  return React.createElement("li", {
    className: className
  }, React.createElement(Link, {
    href: url
  }, React.createElement("a", {
    tabIndex: level == 0 ? "-1" : null,
    className: "title"
  }, icon && React.createElement("i", {
    className: `icon fa fa-fw ${icon}`,
    "aria-hidden": "true"
  }), name)), type == "category" && (level == 0 || isActive) && (children === null || children === void 0 ? void 0 : children.length) > 0 && React.createElement("ul", null, children));
}
class ErrorBoundary extends React.Component {
  constructor() {
    super();
    this.state = {};
    this.resetErrorBoundary = () => {
      this.setState({});
    };
  }
  static getDerivedStateFromError(error) {
    return {
      hadError: true,
      error
    };
  }
  componentDidCatch(_e, info) {
    this.setState(Object.assign(Object.assign({}, this.state), {
      componentStack: info.componentStack
    }));
  }
  render() {
    if (this.state.hadError) {
      return React.createElement(ErrorFallback, {
        error: this.state.error,
        componentStack: this.state.componentStack,
        resetErrorBoundary: this.resetErrorBoundary
      });
    } else {
      return this.props.children;
    }
  }
}
function ErrorFallback(_ref2) {
  let {
    error,
    componentStack,
    resetErrorBoundary
  } = _ref2;
  return React.createElement("div", {
    className: "error"
  }, React.createElement("p", null, "An error occured, please report this on the ", React.createElement("a", {
    href: "https://github.com/superseriousbusiness/gotosocial/issues"
  }, "GoToSocial issue tracker"), " or ", React.createElement("a", {
    href: "https://matrix.to/#/#gotosocial-help:superseriousbusiness.org"
  }, "Matrix support room"), ".", React.createElement("br", null), "Include the details below:"), React.createElement("div", {
    className: "details"
  }, React.createElement("pre", null, error.name, ": ", error.message, componentStack && ["\n\nComponent trace:", componentStack], ["\n\nError trace: ", error.stack])), React.createElement("p", null, React.createElement("button", {
    onClick: resetErrorBoundary
  }, "Try again"), " or ", React.createElement("a", {
    href: ""
  }, "refresh the page")));
}
module.exports = {
  Sidebar,
  ViewRouter,
  MenuComponent
};

},{"./util":292,"react":146,"syncpipe":177,"wouter":234}],207:[function(require,module,exports){
"use strict";var __createBinding=this&&this.__createBinding||(Object.create?function(e,t,a,s){void 0===s&&(s=a);var r=Object.getOwnPropertyDescriptor(t,a);r&&!("get"in r?!t.__esModule:r.writable||r.configurable)||(r={enumerable:!0,get:function(){return t[a]}}),Object.defineProperty(e,s,r)}:function(e,t,a,s){void 0===s&&(s=a),e[s]=t[a]}),__setModuleDefault=this&&this.__setModuleDefault||(Object.create?function(e,t){Object.defineProperty(e,"default",{enumerable:!0,value:t})}:function(e,t){e.default=t}),__importStar=this&&this.__importStar||function(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var a in e)"default"!==a&&Object.prototype.hasOwnProperty.call(e,a)&&__createBinding(t,e,a);return __setModuleDefault(t,e),t},__exportStar=this&&this.__exportStar||function(e,t){for(var a in e)"default"===a||Object.prototype.hasOwnProperty.call(t,a)||__createBinding(t,e,a)};Object.defineProperty(exports,"__esModule",{value:!0}),exports.createRandom=exports.createValidateEquals=exports.createEquals=exports.createAssertEquals=exports.createValidate=exports.createIs=exports.createAssert=exports.metadata=exports.random=exports.validateEquals=exports.equals=exports.assertEquals=exports.validate=exports.is=exports.assert=exports.tags=exports.protobuf=exports.misc=exports.json=exports.http=void 0;var Namespace_1=require("./functional/Namespace");function assert(){halt("assert")}function is(){halt("is")}function validate(){halt("validate")}function assertEquals(){halt("assertEquals")}function equals(){halt("equals")}function validateEquals(){halt("validateEquals")}function random(){halt("random")}function metadata(){halt("metadata")}function createAssert(){halt("createAssert")}function createIs(){halt("createIs")}function createValidate(){halt("createValidate")}function createAssertEquals(){halt("createAssertEquals")}function createEquals(){halt("createEquals")}function createValidateEquals(){halt("createValidateEquals")}function createRandom(){halt("createRandom")}function halt(e){throw new Error("Error on typia.".concat(e,"(): no transform has been configured. Read and follow https://typia.io/docs/setup please."))}exports.http=__importStar(require("./http")),exports.json=__importStar(require("./json")),exports.misc=__importStar(require("./misc")),exports.protobuf=__importStar(require("./protobuf")),exports.tags=__importStar(require("./tags")),__exportStar(require("./schemas/json/IJsonApplication"),exports),__exportStar(require("./schemas/json/IJsonComponents"),exports),__exportStar(require("./schemas/json/IJsonSchema"),exports),__exportStar(require("./IRandomGenerator"),exports),__exportStar(require("./IValidation"),exports),__exportStar(require("./Primitive"),exports),__exportStar(require("./Resolved"),exports),__exportStar(require("./TypeGuardError"),exports),exports.assert=assert,Object.assign(assert,Namespace_1.Namespace.assert("assert")),exports.is=is,Object.assign(is,Namespace_1.Namespace.assert("is")),exports.validate=validate,Object.assign(validate,Namespace_1.Namespace.validate()),exports.assertEquals=assertEquals,Object.assign(assertEquals,Namespace_1.Namespace.assert("assertEquals")),exports.equals=equals,Object.assign(equals,Namespace_1.Namespace.is()),exports.validateEquals=validateEquals,Object.assign(validateEquals,Namespace_1.Namespace.validate()),exports.random=random,Object.assign(random,Namespace_1.Namespace.random()),exports.metadata=metadata,exports.createAssert=createAssert,Object.assign(createAssert,assert),exports.createIs=createIs,Object.assign(createIs,is),exports.createValidate=createValidate,Object.assign(createValidate,validate),exports.createAssertEquals=createAssertEquals,Object.assign(createAssertEquals,assertEquals),exports.createEquals=createEquals,Object.assign(createEquals,equals),exports.createValidateEquals=createValidateEquals,Object.assign(createValidateEquals,validateEquals),exports.createRandom=createRandom,Object.assign(createRandom,random);

},{"./IRandomGenerator":179,"./IValidation":180,"./Primitive":181,"./Resolved":182,"./TypeGuardError":183,"./functional/Namespace":202,"./http":203,"./json":205,"./misc":206,"./protobuf":208,"./schemas/json/IJsonApplication":209,"./schemas/json/IJsonComponents":210,"./schemas/json/IJsonSchema":211,"./tags":226}],12:[function(require,module,exports){
"use strict";"production"==="production"?module.exports=require("./rtk-query.cjs.production.min.js"):module.exports=require("./rtk-query.cjs.development.js");

},{"./rtk-query.cjs.development.js":16,"./rtk-query.cjs.production.min.js":17}],279:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const checklist_1 = require("../../redux/checklist");
const _default = {};
function useCheckListInput(
/* eslint-disable no-unused-vars */
{ name, Name }, { entries = [], uniqueKey = "key", initialValue = false, }) {
    const [state, dispatch] = (0, checklist_1.useChecklistReducer)(entries, uniqueKey, initialValue);
    const toggleAllRef = (0, react_1.useRef)(null);
    (0, react_1.useEffect)(() => {
        if (toggleAllRef.current != null) {
            let some = state.selectedEntries.size > 0;
            let all = false;
            if (some) {
                all = state.selectedEntries.size == Object.values(state.entries).length;
            }
            toggleAllRef.current.checked = all;
            toggleAllRef.current.indeterminate = some && !all;
        }
        // only needs to update when state.selectedEntries changes, not state.entries
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [state.selectedEntries]);
    const reset = (0, react_1.useCallback)(() => dispatch(checklist_1.actions.updateAll(initialValue)), [initialValue, dispatch]);
    const onChange = (0, react_1.useCallback)((key, value) => dispatch(checklist_1.actions.update({ key, value })), [dispatch]);
    const updateMultiple = (0, react_1.useCallback)((entries) => dispatch(checklist_1.actions.updateMultiple(entries)), [dispatch]);
    return (0, react_1.useMemo)(() => {
        function toggleAll(e) {
            let checked = e.target.checked;
            if (e.target.indeterminate) {
                checked = false;
            }
            dispatch(checklist_1.actions.updateAll(checked));
        }
        function selectedValues() {
            return Array.from((state.selectedEntries)).map((key) => (Object.assign({}, state.entries[key] // returned as new object, because reducer state is immutable
            )));
        }
        return Object.assign([
            state,
            reset,
            { name }
        ], {
            _default,
            hasChanged: () => true,
            name,
            Name: "",
            value: state.entries,
            onChange,
            selectedValues,
            reset,
            someSelected: state.selectedEntries.size > 0,
            updateMultiple,
            toggleAll: {
                ref: toggleAllRef,
                onChange: toggleAll
            }
        });
    }, [state, reset, name, onChange, updateMultiple, dispatch]);
}
exports.default = useCheckListInput;

},{"../../redux/checklist":310,"react":146}],62:[function(require,module,exports){
"use strict";var system=require("ariakit-react-utils/system"),disclosure_disclosure=require("../disclosure/disclosure.js");const useDialogDisclosure=system.createHook((s=>{let{state:e,...o}=s;return o=disclosure_disclosure.useDisclosure({state:e,...o}),o})),DialogDisclosure=system.createComponent((s=>{const e=useDialogDisclosure(s);return system.createElement("button",e)}));"production"!=="production"&&(DialogDisclosure.displayName="DialogDisclosure"),exports.DialogDisclosure=DialogDisclosure,exports.useDialogDisclosure=useDialogDisclosure;

},{"../disclosure/disclosure.js":67,"ariakit-react-utils/system":23}],76:[function(require,module,exports){
"use strict";var react=require("react"),hooks=require("ariakit-react-utils/hooks"),system=require("ariakit-react-utils/system"),dialog_dialog=require("../dialog/dialog.js"),__utils=require("../__utils-0b3ca09c.js"),jsxRuntime=require("react/jsx-runtime");const usePopover=system.createHook((e=>{let{state:t,modal:o=!1,portal:r=!!o,preserveTabOrder:s=!0,autoFocusOnShow:a=!0,wrapperProps:n,...i}=e;const u=t.popoverRef;hooks.useSafeLayoutEffect((()=>{const e=u.current,o=t.contentElement;e&&o&&(e.style.zIndex=getComputedStyle(o).zIndex)}),[u,t.contentElement]);const[l,p]=react.useState(!1),{portalRef:c,domReady:d}=hooks.usePortalRef(r,i.portalRef);return hooks.useSafeLayoutEffect((()=>{if(!d)return;if(!t.mounted)return;if(!t.contentElement?.isConnected)return;const e=requestAnimationFrame((()=>{p(!0)}));return()=>{cancelAnimationFrame(e)}}),[d,t.mounted,t.contentElement]),i=hooks.useWrapElement(i,(e=>jsxRuntime.jsx("div",{role:"presentation",...n,style:{position:t.fixed?"fixed":"absolute",top:0,left:0,...n?.style},ref:u,children:e})),[t.fixed,u,n]),i=hooks.useWrapElement(i,(e=>jsxRuntime.jsx(__utils.PopoverContext.Provider,{value:t,children:e})),[t]),i={...i,style:{position:"relative",...i.style}},i=dialog_dialog.useDialog({state:t,modal:o,preserveTabOrder:s,portal:r,autoFocusOnShow:l&&a,...i,portalRef:c}),i})),Popover=system.createComponent((e=>{const t=usePopover(e);return system.createElement("div",t)}));"production"!=="production"&&(Popover.displayName="Popover"),exports.Popover=Popover,exports.usePopover=usePopover;

},{"../__utils-0b3ca09c.js":31,"../dialog/dialog.js":64,"ariakit-react-utils/hooks":20,"ariakit-react-utils/system":23,"react":146,"react/jsx-runtime":147}],291:[function(require,module,exports){
"use strict";const React=require("react"),{nanoid:nanoid}=require("nanoid"),{Redirect:Redirect}=require("wouter"),{urlSafe:urlSafe}=require("./util"),{Sidebar:Sidebar,ViewRouter:ViewRouter,MenuComponent:MenuComponent}=require("./components");function createNavigation(e,r){const n={url:e,links:[]},t=[],i=r.map((e=>e(n,t)));return{Sidebar:Sidebar(i,t),ViewRouter:ViewRouter(t,n.redirectUrl)}}function MenuEntry(e,r,n){return null==n&&(n=r,r={}),function(t,i){var l,u,o;const a=Array.isArray(n)?"category":"view";let c=[t.url];""!=r.url&&c.push(null!==(l=r.url)&&void 0!==l?l:urlSafe(e));const s=c.join("/");let d=s;r.wildcard&&(d+="/:wildcard*");const p={name:e,type:a,url:s,routingUrl:d,key:nanoid(),permissions:null!==(u=r.permissions)&&void 0!==u&&u,icon:r.icon,links:[d],level:(null!==(o=t.level)&&void 0!==o?o:-1)+1,redirectUrl:r.defaultUrl};if("category"==a){let e=n.map((e=>e(p,i))),l=[];e.forEach((e=>{e.url==p.url?l.unshift(e):l.push(e)})),l.reverse(),i.push(...l),r.redirectUrl!=p.url&&(i.push({key:p.key,url:p.url,permissions:p.permissions,routingUrl:p.redirectUrl+"/:fallback*",view:React.createElement(Redirect,{to:p.redirectUrl})}),p.url=p.redirectUrl),t.links.push(...p.links),p.MenuEntry=React.createElement(MenuComponent,p,e.map((e=>e.MenuEntry)))}else p.links.push(d),t.links.push(d),p.view=React.createElement(n,{baseUrl:s}),p.MenuEntry=React.createElement(MenuComponent,p);return null==t.redirectUrl&&(t.redirectUrl=p.url),p}}module.exports={createNavigation:createNavigation,Menu:MenuEntry,Item:MenuEntry};

},{"./components":290,"./util":292,"nanoid":98,"react":146,"wouter":234}],204:[function(require,module,exports){
"use strict";var __createBinding=this&&this.__createBinding||(Object.create?function(e,t,r,i){void 0===i&&(i=r);var o=Object.getOwnPropertyDescriptor(t,r);o&&!("get"in o?!t.__esModule:o.writable||o.configurable)||(o={enumerable:!0,get:function(){return t[r]}}),Object.defineProperty(e,i,o)}:function(e,t,r,i){void 0===i&&(i=r),e[i]=t[r]}),__setModuleDefault=this&&this.__setModuleDefault||(Object.create?function(e,t){Object.defineProperty(e,"default",{enumerable:!0,value:t})}:function(e,t){e.default=t}),__importStar=this&&this.__importStar||function(e){if(e&&e.__esModule)return e;var t={};if(null!=e)for(var r in e)"default"!==r&&Object.prototype.hasOwnProperty.call(e,r)&&__createBinding(t,e,r);return __setModuleDefault(t,e),t},__exportStar=this&&this.__exportStar||function(e,t){for(var r in e)"default"===r||Object.prototype.hasOwnProperty.call(t,r)||__createBinding(t,e,r)};Object.defineProperty(exports,"__esModule",{value:!0});var typia=__importStar(require("./module"));exports.default=typia,__exportStar(require("./module"),exports);

},{"./module":207}],14:[function(require,module,exports){
var __spreadArray=this&&this.__spreadArray||function(e,r){for(var t=0,o=r.length,i=e.length;t<o;t++,i++)e[i]=r[t];return e},__create=Object.create,__defProp=Object.defineProperty,__defProps=Object.defineProperties,__getOwnPropDesc=Object.getOwnPropertyDescriptor,__getOwnPropDescs=Object.getOwnPropertyDescriptors,__getOwnPropNames=Object.getOwnPropertyNames,__getOwnPropSymbols=Object.getOwnPropertySymbols,__getProtoOf=Object.getPrototypeOf,__hasOwnProp=Object.prototype.hasOwnProperty,__propIsEnum=Object.prototype.propertyIsEnumerable,__defNormalProp=function(e,r,t){return r in e?__defProp(e,r,{enumerable:!0,configurable:!0,writable:!0,value:t}):e[r]=t},__spreadValues=function(e,r){for(var t in r||(r={}))__hasOwnProp.call(r,t)&&__defNormalProp(e,t,r[t]);if(__getOwnPropSymbols)for(var o=0,i=__getOwnPropSymbols(r);o<i.length;o++){t=i[o];__propIsEnum.call(r,t)&&__defNormalProp(e,t,r[t])}return e},__spreadProps=function(e,r){return __defProps(e,__getOwnPropDescs(r))},__markAsModule=function(e){return __defProp(e,"__esModule",{value:!0})},__export=function(e,r){for(var t in r)__defProp(e,t,{get:r[t],enumerable:!0})},__reExport=function(e,r,t){if(r&&"object"==typeof r||"function"==typeof r)for(var o=function(o){__hasOwnProp.call(e,o)||"default"===o||__defProp(e,o,{get:function(){return r[o]},enumerable:!(t=__getOwnPropDesc(r,o))||t.enumerable})},i=0,n=__getOwnPropNames(r);i<n.length;i++){o(n[i])}return e},__toModule=function(e){return __reExport(__markAsModule(__defProp(null!=e?__create(__getProtoOf(e)):{},"default",e&&e.__esModule&&"default"in e?{get:function(){return e.default},enumerable:!0}:{value:e,enumerable:!0})),e)};__markAsModule(exports),__export(exports,{ApiProvider:function(){return ApiProvider},createApi:function(){return createApi},reactHooksModule:function(){return reactHooksModule},reactHooksModuleName:function(){return reactHooksModuleName}});var import_query3=__toModule(require("@reduxjs/toolkit/query")),import_toolkit2=__toModule(require("@reduxjs/toolkit")),import_react3=__toModule(require("react")),import_query=__toModule(require("@reduxjs/toolkit/query")),import_react_redux2=__toModule(require("react-redux")),import_react=__toModule(require("react"));function useStableQueryArgs(e,r,t,o){var i=(0,import_react.useMemo)((function(){return{queryArgs:e,serialized:"object"==typeof e?r({queryArgs:e,endpointDefinition:t,endpointName:o}):e}}),[e,r,t,o]),n=(0,import_react.useRef)(i);return(0,import_react.useEffect)((function(){n.current.serialized!==i.serialized&&(n.current=i)}),[i]),n.current.serialized===i.serialized?n.current.queryArgs:e}var UNINITIALIZED_VALUE=Symbol(),import_react2=__toModule(require("react")),import_react_redux=__toModule(require("react-redux"));function useShallowStableValue(e){var r=(0,import_react2.useRef)(e);return(0,import_react2.useEffect)((function(){(0,import_react_redux.shallowEqual)(r.current,e)||(r.current=e)}),[e]),(0,import_react_redux.shallowEqual)(r.current,e)?r.current:e}var DefinitionType,import_toolkit=__toModule(require("@reduxjs/toolkit")),cache=WeakMap?new WeakMap:void 0,defaultSerializeQueryArgs=function(e){var r=e.endpointName,t=e.queryArgs,o="",i=null==cache?void 0:cache.get(t);if("string"==typeof i)o=i;else{var n=JSON.stringify(t,(function(e,r){return(0,import_toolkit.isPlainObject)(r)?Object.keys(r).sort().reduce((function(e,t){return e[t]=r[t],e}),{}):r}));(0,import_toolkit.isPlainObject)(t)&&(null==cache||cache.set(t,n)),o=n}return r+"("+o+")"},useIsomorphicLayoutEffect="undefined"!=typeof window&&window.document&&window.document.createElement?import_react3.useLayoutEffect:import_react3.useEffect,defaultMutationStateSelector=function(e){return e},noPendingQueryStateSelector=function(e){return e.isUninitialized?__spreadProps(__spreadValues({},e),{isUninitialized:!1,isFetching:!0,isLoading:void 0===e.data,status:import_query.QueryStatus.pending}):e};function buildHooks(e){var r=e.api,t=e.moduleOptions,o=t.batch,i=t.useDispatch,n=t.useSelector,u=t.useStore,a=t.unstable__sideEffectsInRender,s=e.serializeQueryArgs,c=e.context,l=a?function(e){return e()}:import_react3.useEffect;return{buildQueryHooks:function(e){var t=function(t,o){var n=void 0===o?{}:o,u=n.refetchOnReconnect,a=n.refetchOnFocus,s=n.refetchOnMountOrArgChange,p=n.skip,_=void 0!==p&&p,d=n.pollingInterval,f=void 0===d?0:d,m=r.endpoints[e].initiate,y=i(),v=useStableQueryArgs(_?import_query.skipToken:t,defaultSerializeQueryArgs,c.endpointDefinitions[e],e),b=useShallowStableValue({refetchOnReconnect:u,refetchOnFocus:a,pollingInterval:f}),g=(0,import_react3.useRef)(!1),h=(0,import_react3.useRef)(),S=h.current||{},M=S.queryCacheKey,O=S.requestId,q=!1;if(M&&O){var P=y(r.internalActions.internal_probeSubscription({queryCacheKey:M,requestId:O}));if("boolean"!=typeof P)throw new Error('Warning: Middleware for RTK-Query API at reducerPath "'+r.reducerPath+'" has not been added to the store.\n    You must add the middleware for RTK-Query to function correctly!');q=!!P}var k=!q&&g.current;return l((function(){g.current=q})),l((function(){k&&(h.current=void 0)}),[k]),l((function(){var e,r=h.current;if(v===import_query.skipToken)return null==r||r.unsubscribe(),void(h.current=void 0);var t=null==(e=h.current)?void 0:e.subscriptionOptions;if(r&&r.arg===v)b!==t&&r.updateSubscriptionOptions(b);else{null==r||r.unsubscribe();var o=y(m(v,{subscriptionOptions:b,forceRefetch:s}));h.current=o}}),[y,m,s,v,b,k]),(0,import_react3.useEffect)((function(){return function(){var e;null==(e=h.current)||e.unsubscribe(),h.current=void 0}}),[]),(0,import_react3.useMemo)((function(){return{refetch:function(){var e;if(!h.current)throw new Error("Cannot refetch a query that has not been started yet.");return null==(e=h.current)?void 0:e.refetch()}}}),[])},a=function(t){var n=void 0===t?{}:t,u=n.refetchOnReconnect,a=n.refetchOnFocus,s=n.pollingInterval,c=void 0===s?0:s,p=r.endpoints[e].initiate,_=i(),d=(0,import_react3.useState)(UNINITIALIZED_VALUE),f=d[0],m=d[1],y=(0,import_react3.useRef)(),v=useShallowStableValue({refetchOnReconnect:u,refetchOnFocus:a,pollingInterval:c});l((function(){var e,r,t=null==(e=y.current)?void 0:e.subscriptionOptions;v!==t&&(null==(r=y.current)||r.updateSubscriptionOptions(v))}),[v]);var b=(0,import_react3.useRef)(v);l((function(){b.current=v}),[v]);var g=(0,import_react3.useCallback)((function(e,r){var t;return void 0===r&&(r=!1),o((function(){var o;null==(o=y.current)||o.unsubscribe(),y.current=t=_(p(e,{subscriptionOptions:b.current,forceRefetch:!r})),m(e)})),t}),[_,p]);return(0,import_react3.useEffect)((function(){return function(){var e;null==(e=null==y?void 0:y.current)||e.unsubscribe()}}),[]),(0,import_react3.useEffect)((function(){f===UNINITIALIZED_VALUE||y.current||g(f,!0)}),[f,g]),(0,import_react3.useMemo)((function(){return[g,f]}),[g,f])},_=function(t,o){var i=void 0===o?{}:o,a=i.skip,l=void 0!==a&&a,_=i.selectFromResult,d=r.endpoints[e].select,f=useStableQueryArgs(l?import_query.skipToken:t,s,c.endpointDefinitions[e],e),m=(0,import_react3.useRef)(),y=(0,import_react3.useMemo)((function(){return(0,import_toolkit2.createSelector)([d(f),function(e,r){return r},function(e){return f}],p)}),[d,f]),v=(0,import_react3.useMemo)((function(){return _?(0,import_toolkit2.createSelector)([y],_):y}),[y,_]),b=n((function(e){return v(e,m.current)}),import_react_redux2.shallowEqual),g=u(),h=y(g.getState(),m.current);return useIsomorphicLayoutEffect((function(){m.current=h}),[h]),b};return{useQueryState:_,useQuerySubscription:t,useLazyQuerySubscription:a,useLazyQuery:function(e){var r=a(e),t=r[0],o=r[1],i=_(o,__spreadProps(__spreadValues({},e),{skip:o===UNINITIALIZED_VALUE})),n=(0,import_react3.useMemo)((function(){return{lastArg:o}}),[o]);return(0,import_react3.useMemo)((function(){return[t,i,n]}),[t,i,n])},useQuery:function(e,r){var o=t(e,r),i=_(e,__spreadValues({selectFromResult:e===import_query.skipToken||(null==r?void 0:r.skip)?void 0:noPendingQueryStateSelector},r)),n=i.data,u=i.status,a=i.isLoading,s=i.isSuccess,c=i.isError,l=i.error;return(0,import_react3.useDebugValue)({data:n,status:u,isLoading:a,isSuccess:s,isError:c,error:l}),(0,import_react3.useMemo)((function(){return __spreadValues(__spreadValues({},i),o)}),[i,o])}}},buildMutationHook:function(e){return function(t){var u=void 0===t?{}:t,a=u.selectFromResult,s=void 0===a?defaultMutationStateSelector:a,c=u.fixedCacheKey,l=r.endpoints[e],p=l.select,_=l.initiate,d=i(),f=(0,import_react3.useState)(),m=f[0],y=f[1];(0,import_react3.useEffect)((function(){return function(){(null==m?void 0:m.arg.fixedCacheKey)||null==m||m.reset()}}),[m]);var v=(0,import_react3.useCallback)((function(e){var r=d(_(e,{fixedCacheKey:c}));return y(r),r}),[d,_,c]),b=(m||{}).requestId,g=(0,import_react3.useMemo)((function(){return(0,import_toolkit2.createSelector)([p({fixedCacheKey:c,requestId:null==m?void 0:m.requestId})],s)}),[p,m,s,c]),h=n(g,import_react_redux2.shallowEqual),S=null==c?null==m?void 0:m.arg.originalArgs:void 0,M=(0,import_react3.useCallback)((function(){o((function(){m&&y(void 0),c&&d(r.internalActions.removeMutationResult({requestId:b,fixedCacheKey:c}))}))}),[d,c,m,b]),O=h.endpointName,q=h.data,P=h.status,k=h.isLoading,A=h.isSuccess,E=h.isError,w=h.error;(0,import_react3.useDebugValue)({endpointName:O,data:q,status:P,isLoading:k,isSuccess:A,isError:E,error:w});var x=(0,import_react3.useMemo)((function(){return __spreadProps(__spreadValues({},h),{originalArgs:S,reset:M})}),[h,S,M]);return(0,import_react3.useMemo)((function(){return[v,x]}),[v,x])}},usePrefetch:function(e,t){var o=i(),n=useShallowStableValue(t);return(0,import_react3.useCallback)((function(t,i){return o(r.util.prefetch(e,t,__spreadValues(__spreadValues({},n),i)))}),[e,o,n])}};function p(e,r,t){if((null==r?void 0:r.endpointName)&&e.isUninitialized){var o=r.endpointName,i=c.endpointDefinitions[o];s({queryArgs:r.originalArgs,endpointDefinition:i,endpointName:o})===s({queryArgs:t,endpointDefinition:i,endpointName:o})&&(r=void 0)}var n=e.isSuccess?e.data:null==r?void 0:r.data;void 0===n&&(n=e.data);var u=void 0!==n,a=e.isLoading,l=!u&&a,p=e.isSuccess||a&&u;return __spreadProps(__spreadValues({},e),{data:n,currentData:e.data,isFetching:a,isLoading:l,isSuccess:p})}}function isQueryDefinition(e){return e.type===DefinitionType.query}function isMutationDefinition(e){return e.type===DefinitionType.mutation}function capitalize(e){return e.replace(e[0],e[0].toUpperCase())}function safeAssign(e){for(var r=[],t=1;t<arguments.length;t++)r[t-1]=arguments[t];Object.assign.apply(Object,__spreadArray([e],r))}!function(e){e.query="query",e.mutation="mutation"}(DefinitionType||(DefinitionType={}));var import_react_redux3=__toModule(require("react-redux")),reactHooksModuleName=Symbol(),reactHooksModule=function(e){var r=void 0===e?{}:e,t=r.batch,o=void 0===t?import_react_redux3.batch:t,i=r.useDispatch,n=void 0===i?import_react_redux3.useDispatch:i,u=r.useSelector,a=void 0===u?import_react_redux3.useSelector:u,s=r.useStore,c=void 0===s?import_react_redux3.useStore:s,l=r.unstable__sideEffectsInRender,p=void 0!==l&&l;return{name:reactHooksModuleName,init:function(e,r,t){var i=r.serializeQueryArgs,u=e,s=buildHooks({api:e,moduleOptions:{batch:o,useDispatch:n,useSelector:a,useStore:c,unstable__sideEffectsInRender:p},serializeQueryArgs:i,context:t}),l=s.buildQueryHooks,_=s.buildMutationHook,d=s.usePrefetch;return safeAssign(u,{usePrefetch:d}),safeAssign(t,{batch:o}),{injectEndpoint:function(r,t){if(isQueryDefinition(t)){var o=l(r),i=o.useQuery,n=o.useLazyQuery,a=o.useLazyQuerySubscription,s=o.useQueryState,c=o.useQuerySubscription;safeAssign(u.endpoints[r],{useQuery:i,useLazyQuery:n,useLazyQuerySubscription:a,useQueryState:s,useQuerySubscription:c}),e["use"+capitalize(r)+"Query"]=i,e["useLazy"+capitalize(r)+"Query"]=n}else if(isMutationDefinition(t)){var p=_(r);safeAssign(u.endpoints[r],{useMutation:p}),e["use"+capitalize(r)+"Mutation"]=p}}}}}};__reExport(exports,__toModule(require("@reduxjs/toolkit/query")));var import_toolkit3=__toModule(require("@reduxjs/toolkit")),import_react4=__toModule(require("react")),import_react5=__toModule(require("react")),import_react_redux4=__toModule(require("react-redux")),import_query2=__toModule(require("@reduxjs/toolkit/query"));function ApiProvider(e){var r=import_react5.default.useState((function(){var r;return(0,import_toolkit3.configureStore)({reducer:(r={},r[e.api.reducerPath]=e.api.reducer,r),middleware:function(r){return r().concat(e.api.middleware)}})}))[0];return(0,import_react4.useEffect)((function(){return!1===e.setupListeners?void 0:(0,import_query2.setupListeners)(r.dispatch,e.setupListeners)}),[e.setupListeners,r.dispatch]),import_react5.default.createElement(import_react_redux4.Provider,{store:r,context:e.context},e.children)}var createApi=(0,import_query3.buildCreateApi)((0,import_query3.coreModule)(),reactHooksModule());

},{"@reduxjs/toolkit":11,"@reduxjs/toolkit/query":12,"react":146,"react-redux":129}],15:[function(require,module,exports){
var e=this&&this.__spreadArray||function(e,r){for(var t=0,n=r.length,u=e.length;t<n;t++,u++)e[u]=r[t];return e},r=Object.create,t=Object.defineProperty,n=Object.defineProperties,u=Object.getOwnPropertyDescriptor,i=Object.getOwnPropertyDescriptors,o=Object.getOwnPropertyNames,s=Object.getOwnPropertySymbols,c=Object.getPrototypeOf,a=Object.prototype.hasOwnProperty,f=Object.prototype.propertyIsEnumerable,l=function(e,r,n){return r in e?t(e,r,{enumerable:!0,configurable:!0,writable:!0,value:n}):e[r]=n},d=function(e,r){for(var t in r||(r={}))a.call(r,t)&&l(e,t,r[t]);if(s)for(var n=0,u=s(r);n<u.length;n++)f.call(r,t=u[n])&&l(e,t,r[t]);return e},p=function(e,r){return n(e,i(r))},v=function(e){return t(e,"__esModule",{value:!0})},y=function(e,r,n){if(r&&"object"==typeof r||"function"==typeof r)for(var i=function(i){a.call(e,i)||"default"===i||t(e,i,{get:function(){return r[i]},enumerable:!(n=u(r,i))||n.enumerable})},s=0,c=o(r);s<c.length;s++)i(c[s]);return e},b=function(e){return y(v(t(null!=e?r(c(e)):{},"default",e&&e.__esModule&&"default"in e?{get:function(){return e.default},enumerable:!0}:{value:e,enumerable:!0})),e)};v(exports),function(e,r){for(var n in r)t(e,n,{get:r[n],enumerable:!0})}(exports,{ApiProvider:function(){return W},createApi:function(){return J},reactHooksModule:function(){return F},reactHooksModuleName:function(){return N}});var g=b(require("@reduxjs/toolkit/query")),h=b(require("@reduxjs/toolkit")),m=b(require("react")),q=b(require("@reduxjs/toolkit/query")),O=b(require("react-redux")),S=b(require("react"));function k(e,r,t,n){var u=(0,S.useMemo)((function(){return{queryArgs:e,serialized:"object"==typeof e?r({queryArgs:e,endpointDefinition:t,endpointName:n}):e}}),[e,r,t,n]),i=(0,S.useRef)(u);return(0,S.useEffect)((function(){i.current.serialized!==u.serialized&&(i.current=u)}),[u]),i.current.serialized===u.serialized?i.current.queryArgs:e}var E=Symbol(),j=b(require("react")),M=b(require("react-redux"));function x(e){var r=(0,j.useRef)(e);return(0,j.useEffect)((function(){(0,M.shallowEqual)(r.current,e)||(r.current=e)}),[e]),(0,M.shallowEqual)(r.current,e)?r.current:e}var Q,w,A=b(require("@reduxjs/toolkit")),R=WeakMap?new WeakMap:void 0,L=function(e){var r=e.endpointName,t=e.queryArgs,n="",u=null==R?void 0:R.get(t);if("string"==typeof u)n=u;else{var i=JSON.stringify(t,(function(e,r){return(0,A.isPlainObject)(r)?Object.keys(r).sort().reduce((function(e,t){return e[t]=r[t],e}),{}):r}));(0,A.isPlainObject)(t)&&(null==R||R.set(t,i)),n=i}return r+"("+n+")"},z="undefined"!=typeof window&&window.document&&window.document.createElement?m.useLayoutEffect:m.useEffect,P=function(e){return e},C=function(e){return e.isUninitialized?p(d({},e),{isUninitialized:!1,isFetching:!0,isLoading:void 0===e.data,status:q.QueryStatus.pending}):e};function D(e){return e.replace(e[0],e[0].toUpperCase())}function I(r){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];Object.assign.apply(Object,e([r],t))}(w=Q||(Q={})).query="query",w.mutation="mutation";var _=b(require("react-redux")),N=Symbol(),F=function(e){var r=void 0===e?{}:e,t=r.batch,n=void 0===t?_.batch:t,u=r.useDispatch,i=void 0===u?_.useDispatch:u,o=r.useSelector,s=void 0===o?_.useSelector:o,c=r.useStore,a=void 0===c?_.useStore:c,f=r.unstable__sideEffectsInRender,l=void 0!==f&&f;return{name:N,init:function(e,r,t){var u=e,o=function(e){var r=e.api,t=e.moduleOptions,n=t.batch,u=t.useDispatch,i=t.useSelector,o=t.useStore,s=e.serializeQueryArgs,c=e.context,a=t.unstable__sideEffectsInRender?function(e){return e()}:m.useEffect;return{buildQueryHooks:function(e){var t=function(t,n){var i=void 0===n?{}:n,o=i.refetchOnReconnect,s=i.refetchOnFocus,f=i.refetchOnMountOrArgChange,l=i.skip,d=void 0!==l&&l,p=i.pollingInterval,v=void 0===p?0:p,b=r.endpoints[e].initiate,y=u(),g=k(d?q.skipToken:t,L,c.endpointDefinitions[e],e),h=x({refetchOnReconnect:o,refetchOnFocus:s,pollingInterval:v}),S=(0,m.useRef)(!1),O=(0,m.useRef)(),E=O.current||{},j=E.queryCacheKey,Q=E.requestId,M=!1;if(j&&Q){var R=y(r.internalActions.internal_probeSubscription({queryCacheKey:j,requestId:Q}));M=!!R}var w=!M&&S.current;return a((function(){S.current=M})),a((function(){w&&(O.current=void 0)}),[w]),a((function(){var e,r=O.current;if(g===q.skipToken)return null==r||r.unsubscribe(),void(O.current=void 0);var t=null==(e=O.current)?void 0:e.subscriptionOptions;if(r&&r.arg===g)h!==t&&r.updateSubscriptionOptions(h);else{null==r||r.unsubscribe();var n=y(b(g,{subscriptionOptions:h,forceRefetch:f}));O.current=n}}),[y,b,f,g,h,w]),(0,m.useEffect)((function(){return function(){var e;null==(e=O.current)||e.unsubscribe(),O.current=void 0}}),[]),(0,m.useMemo)((function(){return{refetch:function(){var e;if(!O.current)throw new Error("Cannot refetch a query that has not been started yet.");return null==(e=O.current)?void 0:e.refetch()}}}),[])},l=function(t){var i=void 0===t?{}:t,o=i.refetchOnReconnect,s=i.refetchOnFocus,c=i.pollingInterval,f=void 0===c?0:c,l=r.endpoints[e].initiate,d=u(),p=(0,m.useState)(E),v=p[0],b=p[1],y=(0,m.useRef)(),g=x({refetchOnReconnect:o,refetchOnFocus:s,pollingInterval:f});a((function(){var e,r,t=null==(e=y.current)?void 0:e.subscriptionOptions;g!==t&&(null==(r=y.current)||r.updateSubscriptionOptions(g))}),[g]);var h=(0,m.useRef)(g);a((function(){h.current=g}),[g]);var q=(0,m.useCallback)((function(e,r){var t;return void 0===r&&(r=!1),n((function(){var n;null==(n=y.current)||n.unsubscribe(),y.current=t=d(l(e,{subscriptionOptions:h.current,forceRefetch:!r})),b(e)})),t}),[d,l]);return(0,m.useEffect)((function(){return function(){var e;null==(e=null==y?void 0:y.current)||e.unsubscribe()}}),[]),(0,m.useEffect)((function(){v===E||y.current||q(v,!0)}),[v,q]),(0,m.useMemo)((function(){return[q,v]}),[q,v])},v=function(t,n){var u=void 0===n?{}:n,a=u.skip,l=u.selectFromResult,d=r.endpoints[e].select,p=k(void 0!==a&&a?q.skipToken:t,s,c.endpointDefinitions[e],e),v=(0,m.useRef)(),b=(0,m.useMemo)((function(){return(0,h.createSelector)([d(p),function(e,r){return r},function(e){return p}],f)}),[d,p]),y=(0,m.useMemo)((function(){return l?(0,h.createSelector)([b],l):b}),[b,l]),g=i((function(e){return y(e,v.current)}),O.shallowEqual),S=o(),E=b(S.getState(),v.current);return z((function(){v.current=E}),[E]),g};return{useQueryState:v,useQuerySubscription:t,useLazyQuerySubscription:l,useLazyQuery:function(e){var r=l(e),t=r[0],n=r[1],u=v(n,p(d({},e),{skip:n===E})),i=(0,m.useMemo)((function(){return{lastArg:n}}),[n]);return(0,m.useMemo)((function(){return[t,u,i]}),[t,u,i])},useQuery:function(e,r){var n=t(e,r),u=v(e,d({selectFromResult:e===q.skipToken||(null==r?void 0:r.skip)?void 0:C},r));return(0,m.useDebugValue)({data:u.data,status:u.status,isLoading:u.isLoading,isSuccess:u.isSuccess,isError:u.isError,error:u.error}),(0,m.useMemo)((function(){return d(d({},u),n)}),[u,n])}}},buildMutationHook:function(e){return function(t){var o=void 0===t?{}:t,s=o.selectFromResult,c=void 0===s?P:s,a=o.fixedCacheKey,f=r.endpoints[e],l=f.select,v=f.initiate,b=u(),y=(0,m.useState)(),g=y[0],q=y[1];(0,m.useEffect)((function(){return function(){(null==g?void 0:g.arg.fixedCacheKey)||null==g||g.reset()}}),[g]);var S=(0,m.useCallback)((function(e){var r=b(v(e,{fixedCacheKey:a}));return q(r),r}),[b,v,a]),k=(g||{}).requestId,E=(0,m.useMemo)((function(){return(0,h.createSelector)([l({fixedCacheKey:a,requestId:null==g?void 0:g.requestId})],c)}),[l,g,c,a]),j=i(E,O.shallowEqual),Q=null==a?null==g?void 0:g.arg.originalArgs:void 0,x=(0,m.useCallback)((function(){n((function(){g&&q(void 0),a&&b(r.internalActions.removeMutationResult({requestId:k,fixedCacheKey:a}))}))}),[b,a,g,k]);(0,m.useDebugValue)({endpointName:j.endpointName,data:j.data,status:j.status,isLoading:j.isLoading,isSuccess:j.isSuccess,isError:j.isError,error:j.error});var M=(0,m.useMemo)((function(){return p(d({},j),{originalArgs:Q,reset:x})}),[j,Q,x]);return(0,m.useMemo)((function(){return[S,M]}),[S,M])}},usePrefetch:function(e,t){var n=u(),i=x(t);return(0,m.useCallback)((function(t,u){return n(r.util.prefetch(e,t,d(d({},i),u)))}),[e,n,i])}};function f(e,r,t){if((null==r?void 0:r.endpointName)&&e.isUninitialized){var n=r.endpointName,u=c.endpointDefinitions[n];s({queryArgs:r.originalArgs,endpointDefinition:u,endpointName:n})===s({queryArgs:t,endpointDefinition:u,endpointName:n})&&(r=void 0)}var i=e.isSuccess?e.data:null==r?void 0:r.data;void 0===i&&(i=e.data);var o=void 0!==i,a=e.isLoading,f=!o&&a,l=e.isSuccess||a&&o;return p(d({},e),{data:i,currentData:e.data,isFetching:a,isLoading:f,isSuccess:l})}}({api:e,moduleOptions:{batch:n,useDispatch:i,useSelector:s,useStore:a,unstable__sideEffectsInRender:l},serializeQueryArgs:r.serializeQueryArgs,context:t}),c=o.buildQueryHooks,f=o.buildMutationHook;return I(u,{usePrefetch:o.usePrefetch}),I(t,{batch:n}),{injectEndpoint:function(r,t){if(t.type===Q.query){var n=c(r),i=n.useQuery,o=n.useLazyQuery;I(u.endpoints[r],{useQuery:i,useLazyQuery:o,useLazyQuerySubscription:n.useLazyQuerySubscription,useQueryState:n.useQueryState,useQuerySubscription:n.useQuerySubscription}),e["use"+D(r)+"Query"]=i,e["useLazy"+D(r)+"Query"]=o}else if(t.type===Q.mutation){var s=f(r);I(u.endpoints[r],{useMutation:s}),e["use"+D(r)+"Mutation"]=s}}}}}};y(exports,b(require("@reduxjs/toolkit/query")));var K=b(require("@reduxjs/toolkit")),H=b(require("react")),T=b(require("react")),U=b(require("react-redux")),V=b(require("@reduxjs/toolkit/query"));function W(e){var r=T.default.useState((function(){var r;return(0,K.configureStore)({reducer:(r={},r[e.api.reducerPath]=e.api.reducer,r),middleware:function(r){return r().concat(e.api.middleware)}})}))[0];return(0,H.useEffect)((function(){return!1===e.setupListeners?void 0:(0,V.setupListeners)(r.dispatch,e.setupListeners)}),[e.setupListeners,r.dispatch]),T.default.createElement(U.Provider,{store:r,context:e.context},e.children)}var J=(0,g.buildCreateApi)((0,g.coreModule)(),F());

},{"@reduxjs/toolkit":11,"@reduxjs/toolkit/query":12,"react":146,"react-redux":129}],40:[function(require,module,exports){
"use strict";var hooks=require("ariakit-react-utils/hooks"),system=require("ariakit-react-utils/system"),dialog_dialogDisclosure=require("../dialog/dialog-disclosure.js"),jsxRuntime=require("react/jsx-runtime");const children=jsxRuntime.jsx("svg",{"aria-hidden":"true",display:"block",fill:"none",stroke:"currentColor",strokeLinecap:"round",strokeLinejoin:"round",strokeWidth:"1.5pt",viewBox:"0 0 16 16",height:"1em",width:"1em",pointerEvents:"none",children:jsxRuntime.jsx("polyline",{points:"4,6 8,10 12,6"})}),useComboboxDisclosure=system.createHook((e=>{let{state:o,...s}=e;const r=s.onMouseDown,i=hooks.useEvent((e=>{r?.(e),e.preventDefault(),o.move(null)})),t=s.onClick,n=hooks.useEvent((e=>{t?.(e),e.defaultPrevented||(o.disclosureRef.current=o.baseRef.current)})),u=o.open?"Hide popup":"Show popup";return s={children:children,tabIndex:-1,"aria-label":u,...s,onMouseDown:i,onClick:n},s=dialog_dialogDisclosure.useDialogDisclosure({state:o,...s}),s})),ComboboxDisclosure=system.createComponent((e=>{const o=useComboboxDisclosure(e);return system.createElement("button",o)}));"production"!=="production"&&(ComboboxDisclosure.displayName="ComboboxDisclosure"),exports.ComboboxDisclosure=ComboboxDisclosure,exports.useComboboxDisclosure=useComboboxDisclosure;

},{"../dialog/dialog-disclosure.js":62,"ariakit-react-utils/hooks":20,"ariakit-react-utils/system":23,"react/jsx-runtime":147}],46:[function(require,module,exports){
"use strict";var system=require("ariakit-react-utils/system"),dom=require("ariakit-utils/dom"),popover_popover=require("../popover/popover.js"),combobox_comboboxList=require("./combobox-list.js");function isController(o){if(!o)return!1;if("id"in o){for(var e=arguments.length,r=new Array(e>1?e-1:0),t=1;t<e;t++)r[t-1]=arguments[t];const s=r.filter(Boolean).map((o=>`[aria-controls="${o}"]`)).join(", ");return!!s&&dom.matches(o,s)}return!1}const useComboboxPopover=system.createHook((o=>{let{state:e,tabIndex:r,hideOnInteractOutside:t=!0,...s}=o;return s=combobox_comboboxList.useComboboxList({state:e,...s}),s=popover_popover.usePopover({state:e,autoFocusOnShow:!1,autoFocusOnHide:!1,finalFocusRef:e.baseRef,...s,modal:!1,hideOnInteractOutside:o=>{const r=e.contentElement?.id,s=e.baseRef.current?.id;if(isController(o.target,r,s))return!1;return"function"==typeof t?t(o):t}}),s})),ComboboxPopover=system.createComponent((o=>{const e=useComboboxPopover(o);return system.createElement("div",e)}));"production"!=="production"&&(ComboboxPopover.displayName="ComboboxPopover"),exports.ComboboxPopover=ComboboxPopover,exports.useComboboxPopover=useComboboxPopover;

},{"../popover/popover.js":76,"./combobox-list.js":45,"ariakit-react-utils/system":23,"ariakit-utils/dom":25}],307:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isDomainPermInternalKey = exports.validateDomainPerms = void 0;
const typia_1 = __importDefault(require("typia"));
const validateDomainPerms = input => {
    const errors = [];
    const __is = input => {
        const $io0 = input => (undefined === input.id || "string" === typeof input.id) && "string" === typeof input.domain && (undefined === input.obfuscate || "boolean" === typeof input.obfuscate) && (undefined === input.private_comment || "string" === typeof input.private_comment) && (undefined === input.public_comment || "string" === typeof input.public_comment) && (undefined === input.created_at || "string" === typeof input.created_at) && (undefined === input.key || "string" === typeof input.key) && (undefined === input.permType || "block" === input.permType || "allow" === input.permType) && (undefined === input.suggest || "string" === typeof input.suggest) && (undefined === input.valid || "boolean" === typeof input.valid) && (undefined === input.checked || "boolean" === typeof input.checked) && (undefined === input.commentType || "string" === typeof input.commentType) && (undefined === input.private_comment_behavior || "append" === input.private_comment_behavior || "replace" === input.private_comment_behavior) && (undefined === input.public_comment_behavior || "append" === input.public_comment_behavior || "replace" === input.public_comment_behavior);
        return Array.isArray(input) && input.every(elem => "object" === typeof elem && null !== elem && $io0(elem));
    };
    if (false === __is(input)) {
        const $report = typia_1.default.createValidate.report(errors);
        ((input, _path, _exceptionable = true) => {
            const $vo0 = (input, _path, _exceptionable = true) => [undefined === input.id || "string" === typeof input.id || $report(_exceptionable, {
                    path: _path + ".id",
                    expected: "(string | undefined)",
                    value: input.id
                }), "string" === typeof input.domain || $report(_exceptionable, {
                    path: _path + ".domain",
                    expected: "string",
                    value: input.domain
                }), undefined === input.obfuscate || "boolean" === typeof input.obfuscate || $report(_exceptionable, {
                    path: _path + ".obfuscate",
                    expected: "(boolean | undefined)",
                    value: input.obfuscate
                }), undefined === input.private_comment || "string" === typeof input.private_comment || $report(_exceptionable, {
                    path: _path + ".private_comment",
                    expected: "(string | undefined)",
                    value: input.private_comment
                }), undefined === input.public_comment || "string" === typeof input.public_comment || $report(_exceptionable, {
                    path: _path + ".public_comment",
                    expected: "(string | undefined)",
                    value: input.public_comment
                }), undefined === input.created_at || "string" === typeof input.created_at || $report(_exceptionable, {
                    path: _path + ".created_at",
                    expected: "(string | undefined)",
                    value: input.created_at
                }), undefined === input.key || "string" === typeof input.key || $report(_exceptionable, {
                    path: _path + ".key",
                    expected: "(string | undefined)",
                    value: input.key
                }), undefined === input.permType || "block" === input.permType || "allow" === input.permType || $report(_exceptionable, {
                    path: _path + ".permType",
                    expected: "(\"allow\" | \"block\" | undefined)",
                    value: input.permType
                }), undefined === input.suggest || "string" === typeof input.suggest || $report(_exceptionable, {
                    path: _path + ".suggest",
                    expected: "(string | undefined)",
                    value: input.suggest
                }), undefined === input.valid || "boolean" === typeof input.valid || $report(_exceptionable, {
                    path: _path + ".valid",
                    expected: "(boolean | undefined)",
                    value: input.valid
                }), undefined === input.checked || "boolean" === typeof input.checked || $report(_exceptionable, {
                    path: _path + ".checked",
                    expected: "(boolean | undefined)",
                    value: input.checked
                }), undefined === input.commentType || "string" === typeof input.commentType || $report(_exceptionable, {
                    path: _path + ".commentType",
                    expected: "(string | undefined)",
                    value: input.commentType
                }), undefined === input.private_comment_behavior || "append" === input.private_comment_behavior || "replace" === input.private_comment_behavior || $report(_exceptionable, {
                    path: _path + ".private_comment_behavior",
                    expected: "(\"append\" | \"replace\" | undefined)",
                    value: input.private_comment_behavior
                }), undefined === input.public_comment_behavior || "append" === input.public_comment_behavior || "replace" === input.public_comment_behavior || $report(_exceptionable, {
                    path: _path + ".public_comment_behavior",
                    expected: "(\"append\" | \"replace\" | undefined)",
                    value: input.public_comment_behavior
                })].every(flag => flag);
            return (Array.isArray(input) || $report(true, {
                path: _path + "",
                expected: "Array<DomainPerm>",
                value: input
            })) && input.map((elem, _index1) => ("object" === typeof elem && null !== elem || $report(true, {
                path: _path + "[" + _index1 + "]",
                expected: "DomainPerm",
                value: elem
            })) && $vo0(elem, _path + "[" + _index1 + "]", true) || $report(true, {
                path: _path + "[" + _index1 + "]",
                expected: "DomainPerm",
                value: elem
            })).every(flag => flag) || $report(true, {
                path: _path + "",
                expected: "Array<DomainPerm>",
                value: input
            });
        })(input, "$input", true);
    }
    const success = 0 === errors.length;
    return {
        success,
        errors,
        data: success ? input : undefined
    };
};
exports.validateDomainPerms = validateDomainPerms;
const domainPermInternalKeys = new Set([
    "key",
    "permType",
    "suggest",
    "valid",
    "checked",
    "commentType",
    "private_comment_behavior",
    "public_comment_behavior",
]);
/**
 * Returns true if provided DomainPerm Object key is
 * "internal"; ie., it's just for our use, and it shouldn't
 * be serialized to or deserialized from the GtS API.
 *
 * @param key
 * @returns
 */
function isDomainPermInternalKey(key) {
    return domainPermInternalKeys.has(key);
}
exports.isDomainPermInternalKey = isDomainPermInternalKey;

},{"typia":204}],13:[function(require,module,exports){
"use strict";"production"==="production"?module.exports=require("./rtk-query-react.cjs.production.min.js"):module.exports=require("./rtk-query-react.cjs.development.js");

},{"./rtk-query-react.cjs.development.js":14,"./rtk-query-react.cjs.production.min.js":15}],51:[function(require,module,exports){
"use strict";var combobox_comboboxCancel=require("./combobox-cancel.js"),combobox_comboboxDisclosure=require("./combobox-disclosure.js"),combobox_comboboxGroupLabel=require("./combobox-group-label.js"),combobox_comboboxGroup=require("./combobox-group.js"),combobox_comboboxItemValue=require("./combobox-item-value.js"),combobox_comboboxItem=require("./combobox-item.js"),combobox_comboboxList=require("./combobox-list.js"),combobox_comboboxPopover=require("./combobox-popover.js"),combobox_comboboxRow=require("./combobox-row.js"),combobox_comboboxSeparator=require("./combobox-separator.js"),combobox_comboboxState=require("./combobox-state.js"),combobox_combobox=require("./combobox.js");exports.ComboboxCancel=combobox_comboboxCancel.ComboboxCancel,exports.useComboboxCancel=combobox_comboboxCancel.useComboboxCancel,exports.ComboboxDisclosure=combobox_comboboxDisclosure.ComboboxDisclosure,exports.useComboboxDisclosure=combobox_comboboxDisclosure.useComboboxDisclosure,exports.ComboboxGroupLabel=combobox_comboboxGroupLabel.ComboboxGroupLabel,exports.useComboboxGroupLabel=combobox_comboboxGroupLabel.useComboboxGroupLabel,exports.ComboboxGroup=combobox_comboboxGroup.ComboboxGroup,exports.useComboboxGroup=combobox_comboboxGroup.useComboboxGroup,exports.ComboboxItemValue=combobox_comboboxItemValue.ComboboxItemValue,exports.useComboboxItemValue=combobox_comboboxItemValue.useComboboxItemValue,exports.ComboboxItem=combobox_comboboxItem.ComboboxItem,exports.useComboboxItem=combobox_comboboxItem.useComboboxItem,exports.ComboboxList=combobox_comboboxList.ComboboxList,exports.useComboboxList=combobox_comboboxList.useComboboxList,exports.ComboboxPopover=combobox_comboboxPopover.ComboboxPopover,exports.useComboboxPopover=combobox_comboboxPopover.useComboboxPopover,exports.ComboboxRow=combobox_comboboxRow.ComboboxRow,exports.useComboboxRow=combobox_comboboxRow.useComboboxRow,exports.ComboboxSeparator=combobox_comboboxSeparator.ComboboxSeparator,exports.useComboboxSeparator=combobox_comboboxSeparator.useComboboxSeparator,exports.useComboboxState=combobox_comboboxState.useComboboxState,exports.Combobox=combobox_combobox.Combobox,exports.useCombobox=combobox_combobox.useCombobox;

},{"./combobox-cancel.js":39,"./combobox-disclosure.js":40,"./combobox-group-label.js":41,"./combobox-group.js":42,"./combobox-item-value.js":43,"./combobox-item.js":44,"./combobox-list.js":45,"./combobox-popover.js":46,"./combobox-row.js":47,"./combobox-separator.js":48,"./combobox-state.js":49,"./combobox.js":50}],301:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useInstanceV1Query = exports.gtsApi = void 0;
const react_1 = require("@reduxjs/toolkit/query/react");
const object_to_formdata_1 = require("object-to-formdata");
/**
 * gtsBaseQuery wraps the redux toolkit fetchBaseQuery with some helper functionality.
 *
 * For an explainer of what's happening in this function, see:
 * - https://redux-toolkit.js.org/rtk-query/usage/customizing-queries#customizing-queries-with-basequery
 * - https://redux-toolkit.js.org/rtk-query/usage/customizing-queries#constructing-a-dynamic-base-url-using-redux-state
 *
 * @param args
 * @param api
 * @param extraOptions
 * @returns
 */
const gtsBaseQuery = (args, api, extraOptions) => __awaiter(void 0, void 0, void 0, function* () {
    // Retrieve state at the moment
    // this function was called.
    const state = api.getState();
    const { instanceUrl, token } = state.oauth;
    // Derive baseUrl dynamically.
    let baseUrl;
    // Check if simple string baseUrl provided
    // as args, or if more complex args provided.
    if (typeof args === "string") {
        baseUrl = args;
    }
    else {
        if (args.baseUrl != undefined) {
            baseUrl = args.baseUrl;
        }
        else {
            baseUrl = instanceUrl;
        }
        if (args.discardEmpty) {
            if (args.body == undefined || Object.keys(args.body).length == 0) {
                return { data: null };
            }
        }
        if (args.asForm) {
            args.body = (0, object_to_formdata_1.serialize)(args.body, {
                // Array indices, for profile fields.
                indices: true,
            });
        }
        // Delete any of our extended arguments
        // to avoid confusing fetchBaseQuery.
        delete args.baseUrl;
        delete args.discardEmpty;
        delete args.asForm;
    }
    if (!baseUrl) {
        return {
            error: {
                status: 400,
                statusText: 'Bad Request',
                data: { "error": "No baseUrl set for request" },
            },
        };
    }
    return (0, react_1.fetchBaseQuery)({
        baseUrl: baseUrl,
        prepareHeaders: (headers) => {
            if (token != undefined) {
                headers.set('Authorization', token);
            }
            headers.set("Accept", "application/json");
            return headers;
        },
    })(args, api, extraOptions);
});
exports.gtsApi = (0, react_1.createApi)({
    reducerPath: "api",
    baseQuery: gtsBaseQuery,
    tagTypes: [
        "Auth",
        "Emoji",
        "Reports",
        "Account",
        "InstanceRules",
    ],
    endpoints: (build) => ({
        instanceV1: build.query({
            query: () => ({
                url: `/api/v1/instance`
            })
        })
    })
});
/**
 * Query /api/v1/instance to retrieve basic instance information.
 * This endpoint does not require authentication/authorization.
 * TODO: move this to ./instance.
 */
const useInstanceV1Query = exports.gtsApi.useInstanceV1Query;
exports.useInstanceV1Query = useInstanceV1Query;

},{"@reduxjs/toolkit/query/react":13,"object-to-formdata":100}],269:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __rest = void 0 && (void 0).__rest || function (s, e) {
  var t = {};
  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};
const React = require("react");
const {
  Combobox,
  ComboboxItem,
  ComboboxPopover
} = require("ariakit/combobox");
module.exports = function ComboBox(_a) {
  var {
      field,
      items,
      label,
      children
    } = _a,
    inputProps = __rest(_a, ["field", "items", "label", "children"]);
  return React.createElement("div", {
    className: "form-field combobox-wrapper"
  }, React.createElement("label", null, label, React.createElement("div", {
    className: "row"
  }, React.createElement(Combobox, Object.assign({
    state: field.state,
    className: "combobox input"
  }, inputProps)), children)), React.createElement(ComboboxPopover, {
    state: field.state,
    className: "popover"
  }, items.map(_ref => {
    let [key, value] = _ref;
    return React.createElement(ComboboxItem, {
      className: "combobox-item",
      key: key,
      value: key
    }, value);
  })));
};

},{"ariakit/combobox":51,"react":146}],280:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const combobox_1 = require("ariakit/combobox");
const _default = "";
function useComboBoxInput({ name, Name }, { initialValue = _default }) {
    const [isNew, setIsNew] = (0, react_1.useState)(false);
    const state = (0, combobox_1.useComboboxState)({
        defaultValue: initialValue,
        gutter: 0,
        sameWidth: true
    });
    function reset() {
        state.setValue(initialValue);
    }
    return Object.assign([
        state,
        reset,
        {
            [name]: state.value,
            name,
            [`${name}IsNew`]: isNew,
            [`set${Name}IsNew`]: setIsNew
        }
    ], {
        reset,
        name,
        Name: "",
        state,
        value: state.value,
        setter: (val) => state.setValue(val),
        hasChanged: () => state.value != initialValue,
        isNew,
        setIsNew,
        _default
    });
}
exports.default = useComboBoxInput;

},{"ariakit/combobox":51,"react":146}],293:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePatchRemoteEmojisMutation = exports.useSearchItemForEmojiMutation = exports.useDeleteEmojiMutation = exports.useEditEmojiMutation = exports.useAddEmojiMutation = exports.useGetEmojiQuery = exports.useListEmojiQuery = void 0;
const gts_api_1 = require("../../gts-api");
/**
 * Parses the search response, prioritizing a status
 * result, and returns any referenced custom emoji.
 *
 * Due to current API constraints, the returned emojis
 * will not have their ID property set, so further
 * processing is required to retrieve the IDs.
 *
 * @param searchRes
 * @returns
 */
function emojisFromSearchResult(searchRes) {
    // We don't know in advance whether a searched URL
    // is the URL for a status, or the URL for an account,
    // but we can derive this by looking at which search
    // result field actually has entries in it (if any).
    let type;
    if (searchRes.statuses.length > 0) {
        // We had status results,
        // so this was a status URL.
        type = "statuses";
    }
    else if (searchRes.accounts.length > 0) {
        // We had account results,
        // so this was an account URL.
        type = "accounts";
    }
    else {
        // Nada, zilch, we can't do
        // anything with this.
        throw "NONE_FOUND";
    }
    // Narrow type to discard all the other
    // data on the result that we don't need.
    const data = searchRes[type][0];
    return {
        type,
        // Workaround to get host rather than account domain.
        // See https://github.com/superseriousbusiness/gotosocial/issues/1225.
        domain: (new URL(data.url)).host,
        list: data.emojis,
    };
}
const extended = gts_api_1.gtsApi.injectEndpoints({
    endpoints: (build) => ({
        listEmoji: build.query({
            query: (params = {}) => ({
                url: "/api/v1/admin/custom_emojis",
                params: Object.assign({ limit: 0 }, params)
            }),
            providesTags: (res, _error, _arg) => res
                ? [
                    ...res.map((emoji) => ({ type: "Emoji", id: emoji.id })),
                    { type: "Emoji", id: "LIST" }
                ]
                : [{ type: "Emoji", id: "LIST" }]
        }),
        getEmoji: build.query({
            query: (id) => ({
                url: `/api/v1/admin/custom_emojis/${id}`
            }),
            providesTags: (_res, _error, id) => [{ type: "Emoji", id }]
        }),
        addEmoji: build.mutation({
            query: (form) => {
                return {
                    method: "POST",
                    url: `/api/v1/admin/custom_emojis`,
                    asForm: true,
                    body: form,
                    discardEmpty: true
                };
            },
            invalidatesTags: (res) => res
                ? [{ type: "Emoji", id: "LIST" }, { type: "Emoji", id: res.id }]
                : [{ type: "Emoji", id: "LIST" }]
        }),
        editEmoji: build.mutation({
            query: (_a) => {
                var { id } = _a, patch = __rest(_a, ["id"]);
                return {
                    method: "PATCH",
                    url: `/api/v1/admin/custom_emojis/${id}`,
                    asForm: true,
                    body: Object.assign({ type: "modify" }, patch)
                };
            },
            invalidatesTags: (res) => res
                ? [{ type: "Emoji", id: "LIST" }, { type: "Emoji", id: res.id }]
                : [{ type: "Emoji", id: "LIST" }]
        }),
        deleteEmoji: build.mutation({
            query: (id) => ({
                method: "DELETE",
                url: `/api/v1/admin/custom_emojis/${id}`
            }),
            invalidatesTags: (_res, _error, id) => [{ type: "Emoji", id }]
        }),
        searchItemForEmoji: build.mutation({
            queryFn(url, api, _extraOpts, fetchWithBQ) {
                return __awaiter(this, void 0, void 0, function* () {
                    const state = api.getState();
                    const oauthState = state.oauth;
                    // First search for given url.
                    const searchRes = yield fetchWithBQ({
                        url: `/api/v2/search?q=${encodeURIComponent(url)}&resolve=true&limit=1`
                    });
                    if (searchRes.error) {
                        return { error: searchRes.error };
                    }
                    // Parse initial results of search.
                    // These emojis will not have IDs set.
                    const { type, domain, list: withoutIDs, } = emojisFromSearchResult(searchRes.data);
                    // Ensure emojis domain is not OUR domain. If it
                    // is, we already have the emojis by definition.
                    if (oauthState.instanceUrl !== undefined) {
                        if (domain == new URL(oauthState.instanceUrl).host) {
                            throw "LOCAL_INSTANCE";
                        }
                    }
                    // Search for each listed emoji with the admin
                    // api to get the version that includes an ID.
                    const errors = [];
                    const withIDs = (yield Promise.all(withoutIDs.map((emoji) => __awaiter(this, void 0, void 0, function* () {
                        // Request admin view of this emoji.
                        const emojiRes = yield fetchWithBQ({
                            url: `/api/v1/admin/custom_emojis`,
                            params: {
                                filter: `domain:${domain},shortcode:${emoji.shortcode}`,
                                limit: 1
                            }
                        });
                        if (emojiRes.error) {
                            // Put error in separate array so
                            // the null can be filtered nicely.
                            errors.push(emojiRes.error);
                            return null;
                        }
                        // Got it!
                        return emojiRes.data;
                    })))).flatMap((emoji) => {
                        // Remove any nulls.
                        return emoji || [];
                    });
                    if (errors.length !== 0) {
                        const errData = errors.map(e => JSON.stringify(e.data)).join(",");
                        return {
                            error: {
                                status: 400,
                                statusText: 'Bad Request',
                                data: {
                                    error: `One or more errors fetching custom emojis: [${errData}]`
                                },
                            },
                        };
                    }
                    // Return our ID'd
                    // emojis list.
                    return {
                        data: {
                            type,
                            domain,
                            list: withIDs,
                        }
                    };
                });
            }
        }),
        patchRemoteEmojis: build.mutation({
            queryFn(_a, _api, _extraOpts, fetchWithBQ) {
                var { action } = _a, formData = __rest(_a, ["action"]);
                return __awaiter(this, void 0, void 0, function* () {
                    const errors = [];
                    const selectedEmoji = formData.selectedEmoji;
                    // Map function to get a promise
                    // of an emoji (or null).
                    const copyEmoji = (emoji) => __awaiter(this, void 0, void 0, function* () {
                        let body = {
                            type: action,
                        };
                        if (action == "copy") {
                            body.shortcode = emoji.shortcode;
                            if (formData.category.trim().length != 0) {
                                body.category = formData.category;
                            }
                        }
                        const emojiRes = yield fetchWithBQ({
                            method: "PATCH",
                            url: `/api/v1/admin/custom_emojis/${emoji.id}`,
                            asForm: true,
                            body: body,
                        });
                        if (emojiRes.error) {
                            errors.push(emojiRes.error);
                            return null;
                        }
                        // Instead of mapping to the emoji we just got in emojiRes.data,
                        // we map here to the existing emoji. The reason for this is that
                        // if we return the new emoji, it has a new ID, and the checklist
                        // component calling this function gets its state mixed up.
                        //
                        // For example, say you copy an emoji with ID "some_emoji"; the
                        // result would return an emoji with ID "some_new_emoji_id". The
                        // checklist state would then contain one emoji with ID "some_emoji",
                        // and the new copy of the emoji with ID "some_new_emoji_id", leading
                        // to weird-looking bugs where it suddenly appears as if the searched
                        // status has another blank emoji attached to it.
                        return emoji;
                    });
                    // Wait for all the promises to
                    // resolve and remove any nulls.
                    const data = (yield Promise.all(selectedEmoji.map(copyEmoji))).flatMap((emoji) => emoji || []);
                    if (errors.length !== 0) {
                        const errData = errors.map(e => JSON.stringify(e.data)).join(",");
                        return {
                            error: {
                                status: 400,
                                statusText: 'Bad Request',
                                data: {
                                    error: `One or more errors patching custom emojis: [${errData}]`
                                },
                            },
                        };
                    }
                    return { data };
                });
            },
            invalidatesTags: () => [{ type: "Emoji", id: "LIST" }]
        })
    })
});
/**
 * List all custom emojis uploaded on our local instance.
 */
const useListEmojiQuery = extended.useListEmojiQuery;
exports.useListEmojiQuery = useListEmojiQuery;
/**
 * Get a single custom emoji uploaded on our local instance, by its ID.
 */
const useGetEmojiQuery = extended.useGetEmojiQuery;
exports.useGetEmojiQuery = useGetEmojiQuery;
/**
 * Add a new custom emoji by uploading it to our local instance.
 */
const useAddEmojiMutation = extended.useAddEmojiMutation;
exports.useAddEmojiMutation = useAddEmojiMutation;
/**
 * Edit an existing custom emoji that's already been uploaded to our local instance.
 */
const useEditEmojiMutation = extended.useEditEmojiMutation;
exports.useEditEmojiMutation = useEditEmojiMutation;
/**
 * Delete a single custom emoji from our local instance using its id.
 */
const useDeleteEmojiMutation = extended.useDeleteEmojiMutation;
exports.useDeleteEmojiMutation = useDeleteEmojiMutation;
/**
 * "Steal this look" function for selecting remote emoji from a status or account.
 */
const useSearchItemForEmojiMutation = extended.useSearchItemForEmojiMutation;
exports.useSearchItemForEmojiMutation = useSearchItemForEmojiMutation;
/**
 * Update/patch a bunch of remote emojis.
 */
const usePatchRemoteEmojisMutation = extended.usePatchRemoteEmojisMutation;
exports.usePatchRemoteEmojisMutation = usePatchRemoteEmojisMutation;

},{"../../gts-api":301}],294:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useExportDomainListMutation = void 0;
const js_file_download_1 = __importDefault(require("js-file-download"));
const papaparse_1 = require("papaparse");
const gts_api_1 = require("../../gts-api");
/**
 * Derive process functions and metadata
 * from provided export request form.
 *
 * @param formData
 * @returns
 */
function exportProcess(formData) {
    if (formData.exportType == "json") {
        return {
            transformEntry: (entry) => ({
                domain: entry.domain,
                public_comment: entry.public_comment,
                obfuscate: entry.obfuscate
            }),
            stringify: (list) => JSON.stringify(list),
            extension: ".json",
            mime: "application/json"
        };
    }
    if (formData.exportType == "csv") {
        return {
            transformEntry: (entry) => {
                var _a, _b;
                return [
                    entry.domain,
                    "suspend",
                    false,
                    false,
                    (_a = entry.public_comment) !== null && _a !== void 0 ? _a : "",
                    (_b = entry.obfuscate) !== null && _b !== void 0 ? _b : false // obfuscate
                ];
            },
            stringify: (list) => (0, papaparse_1.unparse)({
                fields: [
                    "#domain",
                    "#severity",
                    "#reject_media",
                    "#reject_reports",
                    "#public_comment",
                    "#obfuscate",
                ],
                data: list
            }),
            extension: ".csv",
            mime: "text/csv"
        };
    }
    // Fall back to plain text export.
    return {
        transformEntry: (entry) => entry.domain,
        stringify: (list) => list.join("\n"),
        extension: ".txt",
        mime: "text/plain"
    };
}
const extended = gts_api_1.gtsApi.injectEndpoints({
    endpoints: (build) => ({
        exportDomainList: build.mutation({
            queryFn(formData, api, _extraOpts, fetchWithBQ) {
                var _a;
                return __awaiter(this, void 0, void 0, function* () {
                    // Fetch domain perms from relevant endpoint.
                    // We could have used 'useDomainBlocksQuery'
                    // or 'useDomainAllowsQuery' for this, but
                    // we want the untransformed array version.
                    const permsRes = yield fetchWithBQ({ url: `/api/v1/admin/domain_${formData.permType}s` });
                    if (permsRes.error) {
                        return { error: permsRes.error };
                    }
                    // Process perms into desired export format.
                    const process = exportProcess(formData);
                    const transformed = permsRes.data.map(process.transformEntry);
                    const exportAsString = process.stringify(transformed);
                    if (formData.action == "export") {
                        // Data will just be exported
                        // to the domains text field.
                        return { data: exportAsString };
                    }
                    // File export has been requested.
                    // Parse filename to something like:
                    // `example.org-blocklist-2023-10-09.json`.
                    const state = api.getState();
                    const instanceUrl = (_a = state.oauth.instanceUrl) !== null && _a !== void 0 ? _a : "unknown";
                    const domain = new URL(instanceUrl).host;
                    const date = new Date();
                    const filename = [
                        domain,
                        "blocklist",
                        date.getFullYear(),
                        (date.getMonth() + 1).toString().padStart(2, "0"),
                        date.getDate().toString().padStart(2, "0"),
                    ].join("-");
                    (0, js_file_download_1.default)(exportAsString, filename + process.extension, process.mime);
                    // js-file-download handles the
                    // nitty gritty for us, so we can
                    // just return null data.
                    return { data: null };
                });
            }
        }),
    })
});
/**
 * Makes a GET to `/api/v1/admin/domain_{perm_type}s`
 * and exports the result in the requested format.
 *
 * Return type will be string if `action` is "export",
 * else it will be null, since the file downloader handles
 * the rest of the request then.
 */
const useExportDomainListMutation = extended.useExportDomainListMutation;
exports.useExportDomainListMutation = useExportDomainListMutation;

},{"../../gts-api":301,"js-file-download":94,"papaparse":101}],295:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.useDomainAllowsQuery = exports.useDomainBlocksQuery = void 0;
const gts_api_1 = require("../../gts-api");
const transforms_1 = require("../../transforms");
const extended = gts_api_1.gtsApi.injectEndpoints({
    endpoints: (build) => ({
        domainBlocks: build.query({
            query: () => ({
                url: `/api/v1/admin/domain_blocks`
            }),
            transformResponse: (0, transforms_1.listToKeyedObject)("domain"),
        }),
        domainAllows: build.query({
            query: () => ({
                url: `/api/v1/admin/domain_allows`
            }),
            transformResponse: (0, transforms_1.listToKeyedObject)("domain"),
        }),
    }),
});
/**
 * Get admin view of all explicitly blocked domains.
 */
const useDomainBlocksQuery = extended.useDomainBlocksQuery;
exports.useDomainBlocksQuery = useDomainBlocksQuery;
/**
 * Get admin view of all explicitly allowed domains.
 */
const useDomainAllowsQuery = extended.useDomainAllowsQuery;
exports.useDomainAllowsQuery = useDomainAllowsQuery;

},{"../../gts-api":301,"../../transforms":305}],297:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useProcessDomainPermissionsMutation = void 0;
const papaparse_1 = require("papaparse");
const nanoid_1 = require("nanoid");
const domain_permission_1 = require("../../../util/domain-permission");
const gts_api_1 = require("../../gts-api");
const domain_permission_2 = require("../../../types/domain-permission");
/**
 * Parse the given string of domain permissions and return it as an array.
 * Accepts input as a JSON array string, a CSV, or newline-separated domain names.
 * Will throw an error if input is invalid.
 * @param list
 * @returns
 * @throws
 */
function parseDomainList(list) {
    if (list.startsWith("[")) {
        // Assume JSON array.
        const data = JSON.parse(list);
        const validateRes = (0, domain_permission_2.validateDomainPerms)(data);
        if (!validateRes.success) {
            throw `parsed JSON was not array of DomainPermission: ${JSON.stringify(validateRes.errors)}`;
        }
        return data;
    }
    else if (list.startsWith("#domain") || list.startsWith("domain,severity")) {
        // Assume Mastodon-style CSV.
        const csvParseCfg = {
            // Key by header.
            header: true,
            // Remove leading '#' from headers if present.
            transformHeader: (header) => header.startsWith("#") ? header.slice(1) : header,
            // Massage weird boolean values.
            transform: (value, _field) => {
                if (value == "False" || value == "True") {
                    return value.toLowerCase();
                }
                else {
                    return value;
                }
            },
            skipEmptyLines: true,
            // Only dynamic type boolean values,
            // leave the rest as strings.
            dynamicTyping: {
                "domain": false,
                "severity": false,
                "reject_media": true,
                "reject_reports": true,
                "public_comment": false,
                "obfuscate": true,
            }
        };
        const { data, errors } = (0, papaparse_1.parse)(list, csvParseCfg);
        if (errors.length > 0) {
            let error = "";
            errors.forEach((err) => {
                error += `${err.message} (line ${err.row})`;
            });
            throw error;
        }
        const validateRes = (0, domain_permission_2.validateDomainPerms)(data);
        if (!validateRes.success) {
            throw `parsed CSV was not array of DomainPermission: ${JSON.stringify(validateRes.errors)}`;
        }
        return data;
    }
    else {
        // Fallback: assume newline-separated
        // list of simple domain strings.
        const data = [];
        list.split("\n").forEach((line) => {
            let domain = line.trim();
            let valid = true;
            if (domain.startsWith("http")) {
                try {
                    domain = new URL(domain).hostname;
                }
                catch (e) {
                    valid = false;
                }
            }
            if (domain.length > 0) {
                data.push({ domain, valid });
            }
        });
        return data;
    }
}
function deduplicateDomainList(list) {
    let domains = new Set();
    return list.filter((entry) => {
        if (domains.has(entry.domain)) {
            return false;
        }
        else {
            domains.add(entry.domain);
            return true;
        }
    });
}
function validateDomainList(list) {
    list.forEach((entry) => {
        if (entry.domain.startsWith("*.")) {
            // A domain permission always includes
            // all subdomains, wildcard is meaningless here
            entry.domain = entry.domain.slice(2);
        }
        entry.valid = (entry.valid !== false) && (0, domain_permission_1.isValidDomainPermission)(entry.domain);
        if (entry.valid) {
            entry.suggest = (0, domain_permission_1.hasBetterScope)(entry.domain);
        }
        entry.checked = entry.valid;
    });
    return list;
}
const extended = gts_api_1.gtsApi.injectEndpoints({
    endpoints: (build) => ({
        processDomainPermissions: build.mutation({
            queryFn(formData, _api, _extraOpts, _fetchWithBQ) {
                return __awaiter(this, void 0, void 0, function* () {
                    if (formData.domains == undefined || formData.domains.length == 0) {
                        throw "No domains entered";
                    }
                    // Parse + tidy up the form data.
                    const permissions = parseDomainList(formData.domains);
                    const deduped = deduplicateDomainList(permissions);
                    const validated = validateDomainList(deduped);
                    validated.forEach((entry) => {
                        // Set unique key that stays stable
                        // even if domain gets modified by user.
                        entry.key = (0, nanoid_1.nanoid)();
                    });
                    return { data: validated };
                });
            }
        })
    })
});
/**
 * useProcessDomainPermissionsMutation uses the RTK Query API without actually
 * hitting the GtS API, it's purely an internal function for our own convenience.
 *
 * It returns the validated and deduplicated domain permission list.
 */
const useProcessDomainPermissionsMutation = extended.useProcessDomainPermissionsMutation;
exports.useProcessDomainPermissionsMutation = useProcessDomainPermissionsMutation;

},{"../../../types/domain-permission":307,"../../../util/domain-permission":309,"../../gts-api":301,"nanoid":98,"papaparse":101}],300:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.useResolveReportMutation = exports.useGetReportQuery = exports.useListReportsQuery = void 0;
const gts_api_1 = require("../../gts-api");
const extended = gts_api_1.gtsApi.injectEndpoints({
    endpoints: (build) => ({
        listReports: build.query({
            query: (params) => ({
                url: "/api/v1/admin/reports",
                params: Object.assign({ 
                    // Override provided limit.
                    limit: 100 }, params)
            }),
            providesTags: ["Reports"]
        }),
        getReport: build.query({
            query: (id) => ({
                url: `/api/v1/admin/reports/${id}`
            }),
            providesTags: (_res, _error, id) => [{ type: "Reports", id }]
        }),
        resolveReport: build.mutation({
            query: (formData) => ({
                url: `/api/v1/admin/reports/${formData.id}/resolve`,
                method: "POST",
                asForm: true,
                body: formData
            }),
            invalidatesTags: (res) => res
                ? [{ type: "Reports", id: "LIST" }, { type: "Reports", id: res.id }]
                : [{ type: "Reports", id: "LIST" }]
        })
    })
});
/**
 * List reports received on this instance, filtered using given parameters.
 */
const useListReportsQuery = extended.useListReportsQuery;
exports.useListReportsQuery = useListReportsQuery;
/**
 * Get a single report by its ID.
 */
const useGetReportQuery = extended.useGetReportQuery;
exports.useGetReportQuery = useGetReportQuery;
/**
 * Mark an open report as resolved.
 */
const useResolveReportMutation = extended.useResolveReportMutation;
exports.useResolveReportMutation = useResolveReportMutation;

},{"../../gts-api":301}],303:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useLogoutMutation = exports.useAuthorizeFlowMutation = exports.useVerifyCredentialsQuery = void 0;
const gts_api_1 = require("../gts-api");
const oauth_1 = require("../../../redux/oauth");
function getSettingsURL() {
    /*
        needed in case the settings interface isn't hosted at /settings but
        some subpath like /gotosocial/settings. Other parts of the code don't
        take this into account yet so mostly future-proofing.

         Also drops anything past /settings/, because authorization urls that are too long
         get rejected by GTS.
    */
    let [pre, _past] = window.location.pathname.split("/settings");
    return `${window.location.origin}${pre}/settings`;
}
const SETTINGS_URL = (getSettingsURL());
// Couple auth functions here require multiple requests as
// part of an OAuth token 'flow'. To keep things simple for
// callers of these query functions, the multiple requests
// are chained within one query.
//
// https://redux-toolkit.js.org/rtk-query/usage/customizing-queries#performing-multiple-requests-with-a-single-query
const extended = gts_api_1.gtsApi.injectEndpoints({
    endpoints: (build) => ({
        verifyCredentials: build.query({
            providesTags: (_res, error) => error == undefined ? ["Auth"] : [],
            queryFn(_arg, api, _extraOpts, fetchWithBQ) {
                return __awaiter(this, void 0, void 0, function* () {
                    const state = api.getState();
                    const oauthState = state.oauth;
                    // If we're not in the middle of an auth/callback,
                    // we may already have an auth token, so just
                    // return a standard verify_credentials query.
                    if (oauthState.loginState != 'callback') {
                        return fetchWithBQ({
                            url: `/api/v1/accounts/verify_credentials`
                        });
                    }
                    // We're in the middle of an auth/callback flow.
                    // Try to retrieve callback code from URL query.
                    let urlParams = new URLSearchParams(window.location.search);
                    let code = urlParams.get("code");
                    if (code == undefined) {
                        return {
                            error: {
                                status: 400,
                                statusText: 'Bad Request',
                                data: { "error": "Waiting for callback, but no ?code= provided in url." },
                            },
                        };
                    }
                    // Retrieve app with which the
                    // callback code was generated.
                    let app = oauthState.app;
                    if (app == undefined || app.client_id == undefined) {
                        return {
                            error: {
                                status: 400,
                                statusText: 'Bad Request',
                                data: { "error": "No stored app registration data, can't finish login flow." },
                            },
                        };
                    }
                    // Use the provided code and app
                    // secret to request an auth token.
                    const tokenReqBody = {
                        client_id: app.client_id,
                        client_secret: app.client_secret,
                        redirect_uri: SETTINGS_URL,
                        grant_type: "authorization_code",
                        code: code
                    };
                    const tokenResult = yield fetchWithBQ({
                        method: "POST",
                        url: "/oauth/token",
                        body: tokenReqBody,
                    });
                    if (tokenResult.error) {
                        return { error: tokenResult.error };
                    }
                    // Remove ?code= query param from
                    // url, we don't want it anymore.
                    window.history.replaceState({}, document.title, window.location.pathname);
                    // Store returned token in redux.
                    api.dispatch((0, oauth_1.setToken)(tokenResult.data));
                    // We're now authed! So return
                    // standard verify_credentials query.
                    return fetchWithBQ({
                        url: `/api/v1/accounts/verify_credentials`
                    });
                });
            }
        }),
        authorizeFlow: build.mutation({
            queryFn(formData, api, _extraOpts, fetchWithBQ) {
                return __awaiter(this, void 0, void 0, function* () {
                    const state = api.getState();
                    const oauthState = state.oauth;
                    let instanceUrl;
                    if (!formData.instance.startsWith("http")) {
                        formData.instance = `https://${formData.instance}`;
                    }
                    instanceUrl = new URL(formData.instance).origin;
                    if ((oauthState === null || oauthState === void 0 ? void 0 : oauthState.instanceUrl) == instanceUrl && oauthState.app) {
                        return { data: oauthState.app };
                    }
                    const appResult = yield fetchWithBQ({
                        method: "POST",
                        baseUrl: instanceUrl,
                        url: "/api/v1/apps",
                        body: {
                            client_name: "GoToSocial Settings",
                            scopes: formData.scopes,
                            redirect_uris: SETTINGS_URL,
                            website: SETTINGS_URL
                        }
                    });
                    if (appResult.error) {
                        return { error: appResult.error };
                    }
                    let app = appResult.data;
                    app.scopes = formData.scopes;
                    api.dispatch((0, oauth_1.authorize)({
                        instanceUrl: instanceUrl,
                        app: app,
                        loginState: "callback",
                        expectingRedirect: true
                    }));
                    let url = new URL(instanceUrl);
                    url.pathname = "/oauth/authorize";
                    url.searchParams.set("client_id", app.client_id);
                    url.searchParams.set("redirect_uri", SETTINGS_URL);
                    url.searchParams.set("response_type", "code");
                    url.searchParams.set("scope", app.scopes);
                    let redirectURL = url.toString();
                    window.location.assign(redirectURL);
                    return { data: null };
                });
            },
        }),
        logout: build.mutation({
            queryFn: (_arg, api) => {
                api.dispatch((0, oauth_1.remove)());
                return { data: null };
            },
            invalidatesTags: ["Auth"]
        })
    })
});
exports.useVerifyCredentialsQuery = extended.useVerifyCredentialsQuery, exports.useAuthorizeFlowMutation = extended.useAuthorizeFlowMutation, exports.useLogoutMutation = extended.useLogoutMutation;

},{"../../../redux/oauth":311,"../gts-api":301}],304:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeFromCacheOnMutation = exports.updateCacheOnMutation = exports.spliceCacheOnMutation = exports.appendCacheOnMutation = exports.replaceCacheOnMutation = void 0;
const gts_api_1 = require("./gts-api");
const query_1 = require("../types/query");
/**
 * Cache mutation creator for pessimistic updates.
 *
 * Feed it a function that you want to perform on the
 * given draft and updated data, using the given parameters.
 *
 * https://redux-toolkit.js.org/rtk-query/api/createApi#onquerystarted
 * https://redux-toolkit.js.org/rtk-query/usage/manual-cache-updates#pessimistic-updates
 */
function makeCacheMutation(action) {
    return function cacheMutation(queryName, { key } = {}) {
        return {
            onQueryStarted: (mutationData, { dispatch, queryFulfilled }) => __awaiter(this, void 0, void 0, function* () {
                // queryName might be a function that returns
                // a query name; trigger it if so. The returned
                // queryName has to match one of the API endpoints
                // we've defined. So if we have endpoints called
                // (for example) `instanceV1` and `getPosts` then
                // the queryName provided here has to line up with
                // one of those in order to actually do anything.
                if (typeof queryName !== "string") {
                    queryName = queryName(mutationData);
                }
                if (queryName == "") {
                    throw ("provided queryName resolved to an empty string;" +
                        "double check your mutation definition!");
                }
                try {
                    // Wait for the mutation to finish (this
                    // is why it's a pessimistic update).
                    const { data: newData } = yield queryFulfilled;
                    // In order for `gtsApi.util.updateQueryData` to
                    // actually do something within a dispatch, the
                    // first two arguments passed into it have to line
                    // up with arguments that were used earlier to
                    // fetch the data whose cached version we're now
                    // trying to modify.
                    // 
                    // So, if we earlier fetched all reports with
                    // queryName `getReports`, and arg `undefined`,
                    // then we now need match those parameters in
                    // `updateQueryData` in order to modify the cache.
                    //
                    // If you pass something like `null` or `""` here
                    // instead, then the cache will not get modified!
                    // Redux will just quietly discard the thunk action.
                    dispatch(gts_api_1.gtsApi.util.updateQueryData(queryName, query_1.NoArg, (draft) => {
                        if (key != undefined && typeof key !== "string") {
                            key = key(draft, newData);
                        }
                        action(draft, newData, { key });
                    }));
                }
                catch (e) {
                    // eslint-disable-next-line no-console
                    console.error(`rolling back pessimistic update of ${queryName}: ${JSON.stringify(e)}`);
                }
            })
        };
    };
}
/**
 *
 */
const replaceCacheOnMutation = makeCacheMutation((draft, newData, _params) => {
    Object.assign(draft, newData);
});
exports.replaceCacheOnMutation = replaceCacheOnMutation;
const appendCacheOnMutation = makeCacheMutation((draft, newData, _params) => {
    draft.push(newData);
});
exports.appendCacheOnMutation = appendCacheOnMutation;
const spliceCacheOnMutation = makeCacheMutation((draft, _newData, { key }) => {
    if (key === undefined) {
        throw ("key undefined");
    }
    draft.splice(key, 1);
});
exports.spliceCacheOnMutation = spliceCacheOnMutation;
const updateCacheOnMutation = makeCacheMutation((draft, newData, { key }) => {
    if (key === undefined) {
        throw ("key undefined");
    }
    if (typeof key !== "string") {
        key = key(draft, newData);
    }
    draft[key] = newData;
});
exports.updateCacheOnMutation = updateCacheOnMutation;
const removeFromCacheOnMutation = makeCacheMutation((draft, newData, { key }) => {
    if (key === undefined) {
        throw ("key undefined");
    }
    if (typeof key !== "string") {
        key = key(draft, newData);
    }
    delete draft[key];
});
exports.removeFromCacheOnMutation = removeFromCacheOnMutation;

},{"../types/query":308,"./gts-api":301}],312:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.persistor = exports.store = void 0;
const redux_1 = require("redux");
const toolkit_1 = require("@reduxjs/toolkit");
const redux_persist_1 = require("redux-persist");
const oauth_1 = require("./oauth");
const gts_api_1 = require("../lib/query/gts-api");
const combinedReducers = (0, redux_1.combineReducers)({
    [gts_api_1.gtsApi.reducerPath]: gts_api_1.gtsApi.reducer,
    oauth: oauth_1.oauthSlice.reducer,
});
const persistedReducer = (0, redux_persist_1.persistReducer)({
    key: "gotosocial-settings",
    storage: require("redux-persist/lib/storage").default,
    stateReconciler: require("redux-persist/lib/stateReconciler/autoMergeLevel1").default,
    whitelist: ["oauth"],
    migrate: (state) => __awaiter(void 0, void 0, void 0, function* () {
        if (state == undefined) {
            return state;
        }
        // This is a cheeky workaround for
        // redux-persist being a stickler.
        let anyState = state;
        if ((anyState === null || anyState === void 0 ? void 0 : anyState.oauth) != undefined) {
            anyState.oauth.expectingRedirect = false;
        }
        return anyState;
    })
}, combinedReducers);
exports.store = (0, toolkit_1.configureStore)({
    reducer: persistedReducer,
    middleware: (getDefaultMiddleware) => {
        return getDefaultMiddleware({
            serializableCheck: {
                ignoredActions: [
                    redux_persist_1.FLUSH,
                    redux_persist_1.REHYDRATE,
                    redux_persist_1.PAUSE,
                    redux_persist_1.PERSIST,
                    redux_persist_1.PURGE,
                    redux_persist_1.REGISTER,
                ]
            }
        }).concat(gts_api_1.gtsApi.middleware);
    }
});
exports.persistor = (0, redux_persist_1.persistStore)(exports.store);

},{"../lib/query/gts-api":301,"./oauth":311,"@reduxjs/toolkit":11,"redux":165,"redux-persist":153,"redux-persist/lib/stateReconciler/autoMergeLevel1":159,"redux-persist/lib/storage":163}],286:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useValue = exports.useFieldArrayInput = exports.useCheckListInput = exports.useComboBoxInput = exports.useRadioInput = exports.useBoolInput = exports.useFileInput = exports.useTextInput = void 0;
const react_1 = require("react");
const get_by_dot_1 = __importDefault(require("get-by-dot"));
const text_1 = __importDefault(require("./text"));
const file_1 = __importDefault(require("./file"));
const bool_1 = __importDefault(require("./bool"));
const radio_1 = __importDefault(require("./radio"));
const combo_box_1 = __importDefault(require("./combo-box"));
const check_list_1 = __importDefault(require("./check-list"));
const field_array_1 = __importDefault(require("./field-array"));
function capitalizeFirst(str) {
    return str.slice(0, 1).toUpperCase + str.slice(1);
}
function selectorByKey(key) {
    if (key.includes("[")) {
        // get-by-dot does not support 'nested[deeper][key]' notation, convert to 'nested.deeper.key'
        key = key
            .replace(/\[/g, ".") // nested.deeper].key]
            .replace(/\]/g, ""); // nested.deeper.key
    }
    return function selector(obj) {
        if (obj == undefined) {
            return undefined;
        }
        else {
            return (0, get_by_dot_1.default)(obj, key);
        }
    };
}
/**
 * Memoized hook generator function. Take a createHook
 * function and use it to return a new FormInputHook function.
 *
 * @param createHook
 * @returns
 */
function inputHook(createHook) {
    return (name, opts) => {
        var _a;
        // for dynamically generating attributes like 'setName'
        const Name = (0, react_1.useMemo)(() => capitalizeFirst(name), [name]);
        const selector = (0, react_1.useMemo)(() => selectorByKey(name), [name]);
        const valueSelector = (_a = opts === null || opts === void 0 ? void 0 : opts.valueSelector) !== null && _a !== void 0 ? _a : selector;
        if (opts) {
            opts.initialValue = (0, react_1.useMemo)(() => {
                var _a;
                if (opts.source == undefined) {
                    return opts.defaultValue;
                }
                else {
                    return (_a = valueSelector(opts.source)) !== null && _a !== void 0 ? _a : opts.defaultValue;
                }
            }, [opts.source, opts.defaultValue, valueSelector]);
        }
        const hook = createHook({ name, Name }, opts !== null && opts !== void 0 ? opts : {});
        return Object.assign(hook, { name, Name });
    };
}
/**
 * Simplest form hook type in town.
 */
function value(name, initialValue) {
    return {
        _default: initialValue,
        name,
        Name: "",
        value: initialValue,
        hasChanged: () => true, // always included
    };
}
exports.useTextInput = inputHook(text_1.default);
exports.useFileInput = inputHook(file_1.default);
exports.useBoolInput = inputHook(bool_1.default);
exports.useRadioInput = inputHook(radio_1.default);
exports.useComboBoxInput = inputHook(combo_box_1.default);
exports.useCheckListInput = inputHook(check_list_1.default);
exports.useFieldArrayInput = inputHook(field_array_1.default);
exports.useValue = value;

},{"./bool":278,"./check-list":279,"./combo-box":280,"./field-array":282,"./file":283,"./radio":287,"./text":289,"get-by-dot":84,"react":146}],252:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
const splitFilterN = require("split-filter-n");
const syncpipe = require('syncpipe');
const {
  matchSorter
} = require("match-sorter");
const ComboBox = require("../../components/combo-box");
const {
  useListEmojiQuery
} = require("../../lib/query/admin/custom-emoji");
function useEmojiByCategory(emoji) {
  // split all emoji over an object keyed by the category names (or Unsorted)
  return React.useMemo(() => splitFilterN(emoji, [], entry => {
    var _a;
    return (_a = entry.category) !== null && _a !== void 0 ? _a : "Unsorted";
  }), [emoji]);
}
function CategorySelect(_ref) {
  let {
    field,
    children
  } = _ref;
  const {
    value,
    setIsNew
  } = field;
  const {
    data: emoji = [],
    isLoading,
    isSuccess,
    error
  } = useListEmojiQuery({
    filter: "domain:local"
  });
  const emojiByCategory = useEmojiByCategory(emoji);
  const categories = React.useMemo(() => new Set(Object.keys(emojiByCategory)), [emojiByCategory]);
  // data used by the ComboBox element to select an emoji category
  const categoryItems = React.useMemo(() => {
    return syncpipe(emojiByCategory, [_ => Object.keys(_), _ => matchSorter(_, value, {
      threshold: matchSorter.rankings.NO_MATCH
    }), _ => _.map(categoryName => [categoryName, React.createElement(React.Fragment, null, React.createElement("img", {
      src: emojiByCategory[categoryName][0].static_url,
      "aria-hidden": "true"
    }), categoryName)])]);
  }, [emojiByCategory, value]);
  React.useEffect(() => {
    if (value != undefined && isSuccess && value.trim().length > 0) {
      setIsNew(!categories.has(value.trim()));
    }
  }, [categories, value, isSuccess, setIsNew]);
  if (error) {
    // fall back to plain text input, but this would almost certainly have caused a bigger error message elsewhere
    return React.createElement(React.Fragment, null, React.createElement("input", {
      type: "text",
      placeholder: "e.g., reactions",
      onChange: e => {
        field.value = e.target.value;
      }
    }), ";");
  } else if (isLoading) {
    return React.createElement("input", {
      type: "text",
      value: "Loading categories...",
      disabled: true
    });
  }
  return React.createElement(ComboBox, {
    field: field,
    items: categoryItems,
    label: "Category",
    placeholder: "e.g., reactions",
    children: children
  });
}
module.exports = {
  useEmojiByCategory,
  CategorySelect
};

},{"../../components/combo-box":269,"../../lib/query/admin/custom-emoji":293,"match-sorter":97,"react":146,"split-filter-n":176,"syncpipe":177}],247:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_2 = require("react");
const export_1 = require("../../lib/query/admin/domain-permissions/export");
const submit_1 = __importDefault(require("../../lib/form/submit"));
const inputs_1 = require("../../components/form/inputs");
const mutation_button_1 = __importDefault(require("../../components/form/mutation-button"));
const error_1 = require("../../components/error");
const export_format_table_1 = __importDefault(require("./export-format-table"));
function ImportExportForm({ form, submitParse, parseResult }) {
    const [submitExport, exportResult] = (0, submit_1.default)(form, (0, export_1.useExportDomainListMutation)());
    function fileChanged(e) {
        const reader = new FileReader();
        reader.onload = function (read) {
            var _a;
            const res = (_a = read.target) === null || _a === void 0 ? void 0 : _a.result;
            if (typeof res === "string") {
                form.domains.value = res;
                submitParse();
            }
        };
        reader.readAsText(e.target.files[0]);
    }
    (0, react_2.useEffect)(() => {
        if (exportResult.isSuccess) {
            form.domains.setter(exportResult.data);
        }
        /* eslint-disable-next-line react-hooks/exhaustive-deps */
    }, [exportResult]);
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("h1", null, "Import / Export domain permissions"),
        react_1.default.createElement("p", null, "This page can be used to import and export lists of domain permissions."),
        react_1.default.createElement("p", null, "Exports can be done in various formats, with varying functionality and support in other software."),
        react_1.default.createElement("p", null, "Imports will automatically detect what format is being processed."),
        react_1.default.createElement(export_format_table_1.default, null),
        react_1.default.createElement("div", { className: "import-export" },
            react_1.default.createElement(inputs_1.TextArea, { field: form.domains, label: "Domains", placeholder: `google.com\nfacebook.com`, rows: 8 }),
            react_1.default.createElement(inputs_1.RadioGroup, { field: form.permType }),
            react_1.default.createElement("div", { className: "button-grid" },
                react_1.default.createElement(mutation_button_1.default, { label: "Import", type: "button", onClick: () => submitParse(), result: parseResult, showError: false, disabled: false }),
                react_1.default.createElement("label", { className: "button with-icon" },
                    react_1.default.createElement("i", { className: "fa fa-fw ", "aria-hidden": "true" }),
                    "Import file",
                    react_1.default.createElement("input", { type: "file", className: "hidden", onChange: fileChanged, accept: "application/json,text/plain,text/csv" })),
                react_1.default.createElement("b", null),
                " ",
                react_1.default.createElement(mutation_button_1.default, { label: "Export", type: "button", onClick: () => submitExport("export"), result: exportResult, showError: false, disabled: false }),
                react_1.default.createElement(mutation_button_1.default, { label: "Export to file", wrapperClassName: "export-file-button", type: "button", onClick: () => submitExport("export-file"), result: exportResult, showError: false, disabled: false }),
                react_1.default.createElement("div", { className: "export-file" },
                    react_1.default.createElement("span", null, "as"),
                    react_1.default.createElement(inputs_1.Select, { field: form.exportType, options: react_1.default.createElement(react_1.default.Fragment, null,
                            react_1.default.createElement("option", { value: "plain" }, "Text"),
                            react_1.default.createElement("option", { value: "json" }, "JSON"),
                            react_1.default.createElement("option", { value: "csv" }, "CSV")) }))),
            parseResult.error && react_1.default.createElement(error_1.Error, { error: parseResult.error }),
            exportResult.error && react_1.default.createElement(error_1.Error, { error: exportResult.error }))));
}
exports.default = ImportExportForm;

},{"../../components/error":270,"../../components/form/inputs":273,"../../components/form/mutation-button":274,"../../lib/form/submit":288,"../../lib/query/admin/domain-permissions/export":294,"./export-format-table":246,"react":146}],296:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.useImportDomainPermsMutation = void 0;
const query_modifiers_1 = require("../../query-modifiers");
const gts_api_1 = require("../../gts-api");
const domain_permission_1 = require("../../../types/domain-permission");
const transforms_1 = require("../../transforms");
/**
 * Builds up a map function that can be applied to a
 * list of DomainPermission entries in order to normalize
 * them before submission to the API.
 * @param formData
 * @returns
 */
function importEntriesProcessor(formData) {
    let processingFuncs = [];
    // Override each obfuscate entry if necessary.
    if (formData.obfuscate !== undefined) {
        const obfuscateEntry = (entry) => {
            entry.obfuscate = formData.obfuscate;
        };
        processingFuncs.push(obfuscateEntry);
    }
    // Check whether we need to append or replace
    // private_comment and public_comment.
    ["private_comment", "public_comment"].forEach((commentType) => {
        var _a;
        let text = (_a = formData.commentType) === null || _a === void 0 ? void 0 : _a.trim();
        if (!text) {
            return;
        }
        switch (formData[`${commentType}_behavior`]) {
            case "append":
                const appendComment = (entry) => {
                    if (entry.commentType == undefined) {
                        entry.commentType = text;
                    }
                    else {
                        entry.commentType = [entry.commentType, text].join("\n");
                    }
                };
                processingFuncs.push(appendComment);
                break;
            case "replace":
                const replaceComment = (entry) => {
                    entry.commentType = text;
                };
                processingFuncs.push(replaceComment);
                break;
        }
    });
    return function process(entry) {
        // Call all the assembled processing functions.
        processingFuncs.forEach((f) => f(entry));
        // Unset all internal processing keys
        // and any undefined keys on this entry.
        Object.entries(entry).forEach(([key, val]) => {
            if (val == undefined || (0, domain_permission_1.isDomainPermInternalKey)(key)) {
                delete entry[key];
            }
        });
        return entry;
    };
}
const extended = gts_api_1.gtsApi.injectEndpoints({
    endpoints: (build) => ({
        importDomainPerms: build.mutation(Object.assign({ query: (formData) => {
                // Add/replace comments, remove internal keys.
                const process = importEntriesProcessor(formData);
                const domains = formData.domains.map(process);
                return {
                    method: "POST",
                    url: `/api/v1/admin/domain_${formData.permType}s?import=true`,
                    asForm: true,
                    discardEmpty: true,
                    body: {
                        import: true,
                        domains: new Blob([JSON.stringify(domains)], { type: "application/json" }),
                    }
                };
            }, transformResponse: (0, transforms_1.listToKeyedObject)("domain") }, (0, query_modifiers_1.replaceCacheOnMutation)((formData) => {
            // Query names for blocks and allows are like
            // `domainBlocks` and `domainAllows`, so we need
            // to convert `block` -> `Block` or `allow` -> `Allow`
            // to do proper cache invalidation.
            const permType = formData.permType.charAt(0).toUpperCase() +
                formData.permType.slice(1);
            return `domain${permType}s`;
        })))
    })
});
/**
 * POST domain permissions to /api/v1/admin/domain_{permType}s.
 * Returns the newly created permissions.
 */
const useImportDomainPermsMutation = extended.useImportDomainPermsMutation;
exports.useImportDomainPermsMutation = useImportDomainPermsMutation;

},{"../../../types/domain-permission":307,"../../gts-api":301,"../../query-modifiers":304,"../../transforms":305}],298:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.useRemoveDomainAllowMutation = exports.useRemoveDomainBlockMutation = exports.useAddDomainAllowMutation = exports.useAddDomainBlockMutation = void 0;
const gts_api_1 = require("../../gts-api");
const query_modifiers_1 = require("../../query-modifiers");
const transforms_1 = require("../../transforms");
const extended = gts_api_1.gtsApi.injectEndpoints({
    endpoints: (build) => ({
        addDomainBlock: build.mutation(Object.assign({ query: (formData) => ({
                method: "POST",
                url: `/api/v1/admin/domain_blocks`,
                asForm: true,
                body: formData,
                discardEmpty: true
            }), transformResponse: (0, transforms_1.listToKeyedObject)("domain") }, (0, query_modifiers_1.replaceCacheOnMutation)("domainBlocks"))),
        addDomainAllow: build.mutation(Object.assign({ query: (formData) => ({
                method: "POST",
                url: `/api/v1/admin/domain_allows`,
                asForm: true,
                body: formData,
                discardEmpty: true
            }), transformResponse: (0, transforms_1.listToKeyedObject)("domain") }, (0, query_modifiers_1.replaceCacheOnMutation)("domainAllows"))),
        removeDomainBlock: build.mutation(Object.assign({ query: (id) => ({
                method: "DELETE",
                url: `/api/v1/admin/domain_blocks/${id}`,
            }) }, (0, query_modifiers_1.removeFromCacheOnMutation)("domainBlocks", {
            key: (_draft, newData) => {
                return newData.domain;
            }
        }))),
        removeDomainAllow: build.mutation(Object.assign({ query: (id) => ({
                method: "DELETE",
                url: `/api/v1/admin/domain_allows/${id}`,
            }) }, (0, query_modifiers_1.removeFromCacheOnMutation)("domainAllows", {
            key: (_draft, newData) => {
                return newData.domain;
            }
        }))),
    }),
});
/**
 * Add a single domain permission (block) by POSTing to `/api/v1/admin/domain_blocks`.
 */
const useAddDomainBlockMutation = extended.useAddDomainBlockMutation;
exports.useAddDomainBlockMutation = useAddDomainBlockMutation;
/**
 * Add a single domain permission (allow) by POSTing to `/api/v1/admin/domain_allows`.
 */
const useAddDomainAllowMutation = extended.useAddDomainAllowMutation;
exports.useAddDomainAllowMutation = useAddDomainAllowMutation;
/**
 * Remove a single domain permission (block) by DELETEing to `/api/v1/admin/domain_blocks/{id}`.
 */
const useRemoveDomainBlockMutation = extended.useRemoveDomainBlockMutation;
exports.useRemoveDomainBlockMutation = useRemoveDomainBlockMutation;
/**
 * Remove a single domain permission (allow) by DELETEing to `/api/v1/admin/domain_allows/{id}`.
 */
const useRemoveDomainAllowMutation = extended.useRemoveDomainAllowMutation;
exports.useRemoveDomainAllowMutation = useRemoveDomainAllowMutation;

},{"../../gts-api":301,"../../query-modifiers":304,"../../transforms":305}],299:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useDeleteInstanceRuleMutation = exports.useUpdateInstanceRuleMutation = exports.useAddInstanceRuleMutation = exports.useInstanceRulesQuery = exports.useSearchAccountMutation = exports.useActionAccountMutation = exports.useGetAccountQuery = exports.useInstanceKeysExpireMutation = exports.useMediaCleanupMutation = exports.useUpdateInstanceMutation = void 0;
const query_modifiers_1 = require("../query-modifiers");
const gts_api_1 = require("../gts-api");
const transforms_1 = require("../transforms");
const extended = gts_api_1.gtsApi.injectEndpoints({
    endpoints: (build) => ({
        updateInstance: build.mutation(Object.assign({ query: (formData) => ({
                method: "PATCH",
                url: `/api/v1/instance`,
                asForm: true,
                body: formData,
                discardEmpty: true
            }) }, (0, query_modifiers_1.replaceCacheOnMutation)("instanceV1"))),
        mediaCleanup: build.mutation({
            query: (days) => ({
                method: "POST",
                url: `/api/v1/admin/media_cleanup`,
                params: {
                    remote_cache_days: days
                }
            })
        }),
        instanceKeysExpire: build.mutation({
            query: (domain) => ({
                method: "POST",
                url: `/api/v1/admin/domain_keys_expire`,
                params: {
                    domain: domain
                }
            })
        }),
        getAccount: build.query({
            query: (id) => ({
                url: `/api/v1/accounts/${id}`
            }),
            providesTags: (_, __, id) => [{ type: "Account", id }]
        }),
        actionAccount: build.mutation({
            query: ({ id, action, reason }) => ({
                method: "POST",
                url: `/api/v1/admin/accounts/${id}/action`,
                asForm: true,
                body: {
                    type: action,
                    text: reason
                }
            }),
            invalidatesTags: (_, __, { id }) => [{ type: "Account", id }]
        }),
        searchAccount: build.mutation({
            query: (username) => ({
                url: `/api/v2/search?q=${encodeURIComponent(username)}&resolve=true`
            }),
            transformResponse: (res) => {
                var _a;
                return (_a = res.accounts) !== null && _a !== void 0 ? _a : [];
            }
        }),
        instanceRules: build.query({
            query: () => ({
                url: `/api/v1/admin/instance/rules`
            }),
            transformResponse: (0, transforms_1.listToKeyedObject)("id")
        }),
        addInstanceRule: build.mutation(Object.assign({ query: (formData) => ({
                method: "POST",
                url: `/api/v1/admin/instance/rules`,
                asForm: true,
                body: formData,
                discardEmpty: true
            }), transformResponse: (data) => {
                return {
                    [data.id]: data
                };
            } }, (0, query_modifiers_1.replaceCacheOnMutation)("instanceRules"))),
        updateInstanceRule: build.mutation(Object.assign({ query: (_a) => {
                var { id } = _a, edit = __rest(_a, ["id"]);
                return ({
                    method: "PATCH",
                    url: `/api/v1/admin/instance/rules/${id}`,
                    asForm: true,
                    body: edit,
                    discardEmpty: true
                });
            }, transformResponse: (data) => {
                return {
                    [data.id]: data
                };
            } }, (0, query_modifiers_1.replaceCacheOnMutation)("instanceRules"))),
        deleteInstanceRule: build.mutation(Object.assign({ query: (id) => ({
                method: "DELETE",
                url: `/api/v1/admin/instance/rules/${id}`
            }) }, (0, query_modifiers_1.removeFromCacheOnMutation)("instanceRules", {
            key: (_draft, rule) => rule.id,
        })))
    })
});
exports.useUpdateInstanceMutation = extended.useUpdateInstanceMutation, exports.useMediaCleanupMutation = extended.useMediaCleanupMutation, exports.useInstanceKeysExpireMutation = extended.useInstanceKeysExpireMutation, exports.useGetAccountQuery = extended.useGetAccountQuery, exports.useActionAccountMutation = extended.useActionAccountMutation, exports.useSearchAccountMutation = extended.useSearchAccountMutation, exports.useInstanceRulesQuery = extended.useInstanceRulesQuery, exports.useAddInstanceRuleMutation = extended.useAddInstanceRuleMutation, exports.useUpdateInstanceRuleMutation = extended.useUpdateInstanceRuleMutation, exports.useDeleteInstanceRuleMutation = extended.useDeleteInstanceRuleMutation;

},{"../gts-api":301,"../query-modifiers":304,"../transforms":305}],306:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePasswordChangeMutation = exports.useUpdateCredentialsMutation = void 0;
const query_modifiers_1 = require("../query-modifiers");
const gts_api_1 = require("../gts-api");
const extended = gts_api_1.gtsApi.injectEndpoints({
    endpoints: (build) => ({
        updateCredentials: build.mutation(Object.assign({ query: (formData) => ({
                method: "PATCH",
                url: `/api/v1/accounts/update_credentials`,
                asForm: true,
                body: formData,
                discardEmpty: true
            }) }, (0, query_modifiers_1.replaceCacheOnMutation)("verifyCredentials"))),
        passwordChange: build.mutation({
            query: (data) => ({
                method: "POST",
                url: `/api/v1/user/password_change`,
                body: data
            })
        })
    })
});
exports.useUpdateCredentialsMutation = extended.useUpdateCredentialsMutation, exports.usePasswordChangeMutation = extended.usePasswordChangeMutation;

},{"../gts-api":301,"../query-modifiers":304}],250:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_2 = require("react");
const wouter_1 = require("wouter");
const match_sorter_1 = require("match-sorter");
const form_1 = require("../../lib/form");
const inputs_1 = require("../../components/form/inputs");
const loading_1 = __importDefault(require("../../components/loading"));
const get_1 = require("../../lib/query/admin/domain-permissions/get");
const query_1 = require("../../lib/types/query");
function DomainPermissionsOverview({ permType, baseUrl }) {
    if (permType !== "block" && permType !== "allow") {
        throw "unrecognized perm type " + permType;
    }
    // Uppercase first letter of given permType.
    const permTypeUpper = (0, react_2.useMemo)(() => {
        return permType.charAt(0).toUpperCase() + permType.slice(1);
    }, [permType]);
    // Fetch / wait for desired perms to load.
    const { data: blocks, isLoading: isLoadingBlocks } = (0, get_1.useDomainBlocksQuery)(query_1.NoArg, { skip: permType !== "block" });
    const { data: allows, isLoading: isLoadingAllows } = (0, get_1.useDomainAllowsQuery)(query_1.NoArg, { skip: permType !== "allow" });
    let data;
    let isLoading;
    if (permType == "block") {
        data = blocks;
        isLoading = isLoadingBlocks;
    }
    else {
        data = allows;
        isLoading = isLoadingAllows;
    }
    if (isLoading || data === undefined) {
        return react_1.default.createElement(loading_1.default, null);
    }
    return (react_1.default.createElement("div", null,
        react_1.default.createElement("h1", null,
            "Domain ",
            permTypeUpper,
            "s"),
        permType == "block" ? react_1.default.createElement(BlockHelperText, null) : react_1.default.createElement(AllowHelperText, null),
        react_1.default.createElement(DomainPermsList, { data: data, baseUrl: baseUrl, permType: permType, permTypeUpper: permTypeUpper }),
        react_1.default.createElement(wouter_1.Link, { to: "/settings/admin/domain-permissions/import-export" },
            react_1.default.createElement("a", null, "Or use the bulk import/export interface"))));
}
exports.default = DomainPermissionsOverview;
function DomainPermsList({ data, baseUrl, permType, permTypeUpper }) {
    var _a;
    // Format perms into a list.
    const perms = (0, react_2.useMemo)(() => {
        return Object.values(data);
    }, [data]);
    const [_location, setLocation] = (0, wouter_1.useLocation)();
    const filterField = (0, form_1.useTextInput)("filter");
    function filterFormSubmit(e) {
        e.preventDefault();
        setLocation(`${baseUrl}/${filter}`);
    }
    const filter = (_a = filterField.value) !== null && _a !== void 0 ? _a : "";
    const filteredPerms = (0, react_2.useMemo)(() => {
        return (0, match_sorter_1.matchSorter)(perms, filter, { keys: ["domain"] });
    }, [perms, filter]);
    const filtered = perms.length - filteredPerms.length;
    const filterInfo = (react_1.default.createElement("span", null,
        perms.length,
        " ",
        permType,
        "ed domain",
        perms.length != 1 ? "s" : "",
        " ",
        filtered > 0 && `(${filtered} filtered by search)`));
    const entries = filteredPerms.map((entry) => {
        var _a;
        return (react_1.default.createElement(wouter_1.Link, { key: entry.domain, to: `${baseUrl}/${entry.domain}` },
            react_1.default.createElement("a", { className: "entry nounderline" },
                react_1.default.createElement("span", { id: "domain" }, entry.domain),
                react_1.default.createElement("span", { id: "date" }, new Date((_a = entry.created_at) !== null && _a !== void 0 ? _a : "").toLocaleString()))));
    });
    return (react_1.default.createElement("div", { className: "domain-permissions-list" },
        react_1.default.createElement("form", { className: "filter", role: "search", onSubmit: filterFormSubmit },
            react_1.default.createElement(inputs_1.TextInput, { field: filterField, placeholder: "example.org", label: `Search or add domain ${permType}` }),
            react_1.default.createElement(wouter_1.Link, { to: `${baseUrl}/${filter}` },
                react_1.default.createElement("a", { className: "button" },
                    permTypeUpper,
                    "\u00A0",
                    filter))),
        react_1.default.createElement("div", null,
            filterInfo,
            react_1.default.createElement("div", { className: "list" },
                react_1.default.createElement("div", { className: "entries scrolling" }, entries)))));
}
function BlockHelperText() {
    return (react_1.default.createElement("p", null,
        "Blocking a domain blocks interaction between your instance, and all current and future accounts on instance(s) running on the blocked domain. Stored content will be removed, and no more data is sent to the remote server. This extends to all subdomains as well, so blocking 'example.com' also blocks 'social.example.com'.",
        react_1.default.createElement("br", null),
        react_1.default.createElement("a", { href: "https://docs.gotosocial.org/en/latest/admin/domain_blocks/", target: "_blank", className: "docslink", rel: "noreferrer" }, "Learn more about domain blocks (opens in a new tab)"),
        react_1.default.createElement("br", null)));
}
function AllowHelperText() {
    return (react_1.default.createElement("p", null,
        "Allowing a domain explicitly allows instance(s) running on that domain to interact with your instance. If you're running in allowlist mode, this is how you \"allow\" instances through. If you're running in blocklist mode (the default federation mode), you can use explicit domain allows to override domain blocks. In blocklist mode, explicitly allowed instances will be able to interact with your instance regardless of any domain blocks in place.  This extends to all subdomains as well, so allowing 'example.com' also allows 'social.example.com'. This is useful when you're importing a block list but there are some domains on the list you don't want to block: just create an explicit allow for those domains before importing the list.",
        react_1.default.createElement("br", null),
        react_1.default.createElement("a", { href: "https://docs.gotosocial.org/en/latest/admin/federation_modes/", target: "_blank", className: "docslink", rel: "noreferrer" }, "Learn more about federation modes (opens in a new tab)")));
}

},{"../../components/form/inputs":273,"../../components/loading":276,"../../lib/form":286,"../../lib/query/admin/domain-permissions/get":295,"../../lib/types/query":308,"match-sorter":97,"react":146,"wouter":234}],257:[function(require,module,exports){
"use strict";const React=require("react"),{useTextInput:useTextInput}=require("../../../lib/form"),{useListEmojiQuery:useListEmojiQuery}=require("../../../lib/query/admin/custom-emoji"),shortcodeRegex=/^\w{2,30}$/;module.exports=function(){const{data:e=[]}=useListEmojiQuery({filter:"domain:local"}),t=React.useMemo((()=>new Set(e.map((e=>e.shortcode)))),[e]);return useTextInput("shortcode",{validator:function(e){return""==e?"":t.has(e)?"Shortcode already in use":e.length<2||e.length>30?"Shortcode must be between 2 and 30 characters":shortcodeRegex.test(e)?"":"Shortcode must only contain letters, numbers, and underscores"}})};

},{"../../../lib/form":286,"../../../lib/query/admin/custom-emoji":293,"react":146}],260:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
const {
  useRoute,
  Redirect
} = require("wouter");
const FormWithData = require("../../lib/form/form-with-data").default;
const BackButton = require("../../components/back-button");
const {
  useValue,
  useTextInput
} = require("../../lib/form");
const useFormSubmit = require("../../lib/form/submit").default;
const {
  TextArea
} = require("../../components/form/inputs");
const MutationButton = require("../../components/form/mutation-button");
const Username = require("./username");
const {
  useBaseUrl
} = require("../../lib/navigation/util");
const {
  useGetReportQuery,
  useResolveReportMutation
} = require("../../lib/query/admin/reports");
module.exports = function ReportDetail(_ref) {
  let {} = _ref;
  const baseUrl = useBaseUrl();
  let [_match, params] = useRoute(`${baseUrl}/:reportId`);
  if ((params === null || params === void 0 ? void 0 : params.reportId) == undefined) {
    return React.createElement(Redirect, {
      to: baseUrl
    });
  } else {
    return React.createElement("div", {
      className: "report-detail"
    }, React.createElement("h1", null, React.createElement(BackButton, {
      to: baseUrl
    }), " Report Details"), React.createElement(FormWithData, {
      dataQuery: useGetReportQuery,
      queryArg: params.reportId,
      DataForm: ReportDetailForm
    }));
  }
};
function ReportDetailForm(_ref2) {
  let {
    data: report
  } = _ref2;
  const from = report.account;
  const target = report.target_account;
  return React.createElement("div", {
    className: "report detail"
  }, React.createElement("div", {
    className: "usernames"
  }, React.createElement(Username, {
    user: from
  }), " reported ", React.createElement(Username, {
    user: target
  })), report.action_taken && React.createElement("div", {
    className: "info"
  }, React.createElement("h3", null, "Resolved by @", report.action_taken_by_account.account.acct), React.createElement("span", {
    className: "timestamp"
  }, "at ", new Date(report.action_taken_at).toLocaleString()), React.createElement("br", null), React.createElement("b", null, "Comment: "), React.createElement("span", null, report.action_taken_comment)), React.createElement("div", {
    className: "info-block"
  }, React.createElement("h3", null, "Report info:"), React.createElement("div", {
    className: "details"
  }, React.createElement("b", null, "Created: "), React.createElement("span", null, new Date(report.created_at).toLocaleString()), React.createElement("b", null, "Forwarded: "), " ", React.createElement("span", null, report.forwarded ? "Yes" : "No"), React.createElement("b", null, "Category: "), " ", React.createElement("span", null, report.category), React.createElement("b", null, "Reason: "), report.comment.length > 0 ? React.createElement("p", null, report.comment) : React.createElement("i", {
    className: "no-comment"
  }, "none provided"))), !report.action_taken && React.createElement(ReportActionForm, {
    report: report
  }), report.statuses.length > 0 && React.createElement("div", {
    className: "info-block"
  }, React.createElement("h3", null, "Reported toots (", report.statuses.length, "):"), React.createElement("div", {
    className: "reported-toots"
  }, report.statuses.map(status => React.createElement(ReportedToot, {
    key: status.id,
    toot: status
  })))));
}
function ReportActionForm(_ref3) {
  let {
    report
  } = _ref3;
  const form = {
    id: useValue("id", report.id),
    comment: useTextInput("action_taken_comment")
  };
  const [submit, result] = useFormSubmit(form, useResolveReportMutation(), {
    changedOnly: false
  });
  return React.createElement("form", {
    onSubmit: submit,
    className: "info-block"
  }, React.createElement("h3", null, "Resolving this report"), React.createElement("p", null, "An optional comment can be included while resolving this report. Useful for providing an explanation about what action was taken (if any) before the report was marked as resolved.", React.createElement("br", null), React.createElement("b", null, "This will be visible to the user that created the report!")), React.createElement(TextArea, {
    field: form.comment,
    label: "Comment"
  }), React.createElement(MutationButton, {
    label: "Resolve",
    result: result
  }));
}
function ReportedToot(_ref4) {
  let {
    toot
  } = _ref4;
  var _a, _b;
  const account = toot.account;
  return React.createElement("article", {
    className: "toot expanded"
  }, React.createElement("section", {
    className: "author"
  }, React.createElement("a", null, React.createElement("img", {
    className: "avatar",
    src: account.avatar,
    alt: ""
  }), React.createElement("span", {
    className: "displayname"
  }, account.display_name.trim().length > 0 ? account.display_name : account.username, React.createElement("span", {
    className: "sr-only"
  }, ".")), React.createElement("span", {
    className: "username"
  }, "@", account.username))), React.createElement("section", {
    className: "body"
  }, React.createElement("div", {
    className: "text"
  }, React.createElement("div", {
    className: "content"
  }, ((_a = toot.spoiler_text) === null || _a === void 0 ? void 0 : _a.length) > 0 ? React.createElement(TootCW, {
    content: toot.content,
    note: toot.spoiler_text
  }) : toot.content)), ((_b = toot.media_attachments) === null || _b === void 0 ? void 0 : _b.length) > 0 && React.createElement(TootMedia, {
    media: toot.media_attachments,
    sensitive: toot.sensitive
  })), React.createElement("aside", {
    className: "info"
  }, React.createElement("time", {
    dateTime: toot.created_at
  }, new Date(toot.created_at).toLocaleString())));
}
function TootCW(_ref5) {
  let {
    note,
    content
  } = _ref5;
  const [visible, setVisible] = React.useState(false);
  function toggleVisible() {
    setVisible(!visible);
  }
  return React.createElement(React.Fragment, null, React.createElement("div", {
    className: "spoiler"
  }, React.createElement("span", null, note), React.createElement("label", {
    className: "button spoiler-label",
    onClick: toggleVisible
  }, "Show ", visible ? "less" : "more")), visible && content);
}
function TootMedia(_ref6) {
  let {
    media,
    sensitive
  } = _ref6;
  let classes = media.length % 2 == 0 ? "even" : "odd";
  if (media.length == 1) {
    classes += " single";
  }
  return React.createElement("div", {
    className: `media photoswipe-gallery ${classes}`
  }, media.map(m => {
    var _a, _b, _c;
    return React.createElement("div", {
      key: m.id,
      className: "media-wrapper"
    }, sensitive && React.createElement(React.Fragment, null, React.createElement("input", {
      id: `sensitiveMedia-${m.id}`,
      type: "checkbox",
      className: "sensitive-checkbox hidden"
    }), React.createElement("div", {
      className: "sensitive"
    }, React.createElement("div", {
      className: "open"
    }, React.createElement("label", {
      htmlFor: `sensitiveMedia-${m.id}`,
      className: "button",
      role: "button",
      tabIndex: "0"
    }, React.createElement("i", {
      className: "fa fa-eye-slash",
      title: "Hide sensitive media"
    }))), React.createElement("div", {
      className: "closed",
      title: m.description
    }, React.createElement("label", {
      htmlFor: `sensitiveMedia-${m.id}`,
      className: "button",
      role: "button",
      tabIndex: "0"
    }, "Show sensitive media")))), React.createElement("a", {
      href: m.url,
      title: m.description,
      target: "_blank",
      rel: "noreferrer",
      "data-cropped": "true",
      "data-pswp-width": `${(_a = m.meta) === null || _a === void 0 ? void 0 : _a.original.width}px`,
      "data-pswp-height": `${(_b = m.meta) === null || _b === void 0 ? void 0 : _b.original.height}px`
    }, React.createElement("img", {
      alt: m.description,
      src: m.url,
      // thumb={m.preview_url}
      size: (_c = m.meta) === null || _c === void 0 ? void 0 : _c.original,
      type: m.type
    })));
  }));
}

},{"../../components/back-button":267,"../../components/form/inputs":273,"../../components/form/mutation-button":274,"../../lib/form":286,"../../lib/form/form-with-data":284,"../../lib/form/submit":288,"../../lib/navigation/util":292,"../../lib/query/admin/reports":300,"./username":262,"react":146,"wouter":234}],266:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const oauth_1 = require("../../lib/query/oauth");
const form_1 = require("../../lib/form");
const submit_1 = __importDefault(require("../../lib/form/submit"));
const mutation_button_1 = __importDefault(require("../form/mutation-button"));
const loading_1 = __importDefault(require("../loading"));
const inputs_1 = require("../form/inputs");
function Login({}) {
    const form = {
        instance: (0, form_1.useTextInput)("instance", {
            defaultValue: window.location.origin
        }),
        scopes: (0, form_1.useValue)("scopes", "user admin"),
    };
    const [formSubmit, result] = (0, submit_1.default)(form, (0, oauth_1.useAuthorizeFlowMutation)(), {
        changedOnly: false,
    });
    if (result.isLoading) {
        return (react_1.default.createElement("div", null,
            react_1.default.createElement(loading_1.default, null),
            " Checking instance."));
    }
    else if (result.isSuccess) {
        return (react_1.default.createElement("div", null,
            react_1.default.createElement(loading_1.default, null),
            " Redirecting to instance authorization page."));
    }
    return (react_1.default.createElement("form", { onSubmit: formSubmit },
        react_1.default.createElement(inputs_1.TextInput, { field: form.instance, label: "Instance", name: "instance" }),
        react_1.default.createElement(mutation_button_1.default, { label: "Login", result: result, disabled: false })));
}
exports.default = Login;

},{"../../lib/form":286,"../../lib/form/submit":288,"../../lib/query/oauth":303,"../form/inputs":273,"../form/mutation-button":274,"../loading":276,"react":146}],259:[function(require,module,exports){
"use strict";const React=require("react"),{useTextInput:useTextInput,useComboBoxInput:useComboBoxInput,useCheckListInput:useCheckListInput}=require("../../../lib/form"),useFormSubmit=require("../../../lib/form/submit").default,CheckList=require("../../../components/check-list").default,{CategorySelect:CategorySelect}=require("../category-select"),{TextInput:TextInput}=require("../../../components/form/inputs"),MutationButton=require("../../../components/form/mutation-button"),{Error:Error}=require("../../../components/error"),{useSearchItemForEmojiMutation:useSearchItemForEmojiMutation,usePatchRemoteEmojisMutation:usePatchRemoteEmojisMutation}=require("../../../lib/query/admin/custom-emoji");function SearchResult(e){let{result:t,localEmojiCodes:o}=e;const{error:r,data:a,isSuccess:c,isError:n}=t;return c||n?"NONE_FOUND"==r?"No results found":"LOCAL_INSTANCE"==r?React.createElement("b",null,"This is a local user/toot, all referenced emoji are already on your instance"):null!=r?React.createElement(Error,{error:t.error}):0==a.list.length?React.createElement("b",null,"This ","statuses"==a.type?"toot":"account"," doesn't use any custom emoji"):React.createElement(CopyEmojiForm,{localEmojiCodes:o,type:a.type,domain:a.domain,emojiList:a.list}):null}function CopyEmojiForm(e){let{localEmojiCodes:t,type:o,emojiList:r}=e;const a={selectedEmoji:useCheckListInput("selectedEmoji",{entries:r,uniqueKey:"id"}),category:useComboBoxInput("category")},[c,n]=useFormSubmit(a,usePatchRemoteEmojisMutation(),{changedOnly:!1,onFinish:e=>{let{data:t}=e;if(t){const e=t.map((e=>[e.id,{checked:!1}]));a.selectedEmoji.updateMultiple(e)}}}),l=a.selectedEmoji.someSelected?{}:{disabled:!0,title:"No emoji selected, cannot perform any actions"},s=React.useCallback((()=>({localEmojiCodes:t})),[t]);return React.createElement("div",{className:"parsed"},React.createElement("span",null,"This ","statuses"==o?"toot":"account"," uses the following custom emoji, select the ones you want to copy/disable:"),React.createElement("form",{onSubmit:c},React.createElement(CheckList,{field:a.selectedEmoji,EntryComponent:EmojiEntry,getExtraProps:s}),React.createElement(CategorySelect,{field:a.category}),React.createElement("div",{className:"action-buttons row"},React.createElement(MutationButton,Object.assign({name:"copy",label:"Copy to local emoji",result:n,showError:!1},l)),React.createElement(MutationButton,Object.assign({name:"disable",label:"Disable",result:n,className:"button danger",showError:!1},l))),n.error&&(Array.isArray(n.error)?React.createElement(ErrorList,{errors:n.error}):React.createElement(Error,{error:n.error}))))}function ErrorList(e){let{errors:t}=e;return React.createElement("div",{className:"error"},"One or multiple emoji failed to process:",t.map((e=>{let[t,o]=e;return React.createElement("div",{key:t},React.createElement("b",null,t,":")," ",o)})))}function EmojiEntry(e){let{entry:t,onChange:o,extraProps:{localEmojiCodes:r}}=e;const a=useTextInput("shortcode",{defaultValue:t.shortcode,validator:function(e){return t.checked&&r.has(e)?"Shortcode already in use":""}});return React.useEffect((()=>{t.valid!=a.valid&&o({valid:a.valid})}),[o,t.valid,a.valid]),React.useEffect((()=>{a.validate()}),[t.checked]),React.createElement(React.Fragment,null,React.createElement("img",{className:"emoji",src:t.url,title:t.shortcode}),React.createElement(TextInput,{field:a,onChange:e=>{a.onChange(e),o({shortcode:e.target.value,checked:!0})}}))}module.exports=function(e){let{emojiCodes:t}=e;const[o,r]=useSearchItemForEmojiMutation(),[a,c,{url:n}]=useTextInput("url");return React.createElement("div",{className:"parse-emoji"},React.createElement("h2",null,"Steal this look"),React.createElement("form",{onSubmit:function(e){e.preventDefault(),0!=n.trim().length&&o(n)}},React.createElement("div",{className:"form-field text"},React.createElement("label",{htmlFor:"url"},"Link to a toot:"),React.createElement("div",{className:"row"},React.createElement("input",{type:"text",id:"url",name:"url",onChange:a,value:n}),React.createElement("button",{disabled:r.isLoading},React.createElement("i",{className:["fa fa-fw",r.isLoading?"fa-refresh fa-spin":"fa-search"].join(" "),"aria-hidden":"true",title:"Search"}),React.createElement("span",{className:"sr-only"},"Search"))))),React.createElement(SearchResult,{result:r,localEmojiCodes:t}))};

},{"../../../components/check-list":268,"../../../components/error":270,"../../../components/form/inputs":273,"../../../components/form/mutation-button":274,"../../../lib/form":286,"../../../lib/form/submit":288,"../../../lib/query/admin/custom-emoji":293,"../category-select":252,"react":146}],251:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProcessImport = void 0;
const react_1 = __importDefault(require("react"));
const react_2 = require("react");
const domain_permission_1 = require("../../lib/util/domain-permission");
const form_1 = require("../../lib/form");
const inputs_1 = require("../../components/form/inputs");
const submit_1 = __importDefault(require("../../lib/form/submit"));
const check_list_1 = __importDefault(require("../../components/check-list"));
const mutation_button_1 = __importDefault(require("../../components/form/mutation-button"));
const form_with_data_1 = __importDefault(require("../../lib/form/form-with-data"));
const import_1 = require("../../lib/query/admin/domain-permissions/import");
const get_1 = require("../../lib/query/admin/domain-permissions/get");
exports.ProcessImport = (0, react_2.memo)(function ProcessImport({ list, permType }) {
    return (react_1.default.createElement("div", { className: "without-border" },
        react_1.default.createElement(form_with_data_1.default, { dataQuery: permType.value == "allow"
                ? get_1.useDomainAllowsQuery
                : get_1.useDomainBlocksQuery, DataForm: ImportList, list, permType })));
});
function ImportList({ list, data: domainPerms, permType }) {
    var _a;
    const hasComment = (0, react_2.useMemo)(() => {
        let hasPublic = false;
        let hasPrivate = false;
        list.some((entry) => {
            if (entry.public_comment) {
                hasPublic = true;
            }
            if (entry.private_comment) {
                hasPrivate = true;
            }
            return hasPublic && hasPrivate;
        });
        if (hasPublic && hasPrivate) {
            return { both: true };
        }
        else if (hasPublic) {
            return { type: "public_comment" };
        }
        else if (hasPrivate) {
            return { type: "private_comment" };
        }
        else {
            return {};
        }
    }, [list]);
    const showComment = (0, form_1.useTextInput)("showComment", { defaultValue: (_a = hasComment.type) !== null && _a !== void 0 ? _a : "public_comment" });
    const form = {
        domains: (0, form_1.useCheckListInput)("domains", { entries: list }),
        obfuscate: (0, form_1.useBoolInput)("obfuscate"),
        privateComment: (0, form_1.useTextInput)("private_comment", {
            defaultValue: `Imported on ${new Date().toLocaleString()}`
        }),
        privateCommentBehavior: (0, form_1.useRadioInput)("private_comment_behavior", {
            defaultValue: "append",
            options: {
                append: "Append to",
                replace: "Replace"
            }
        }),
        publicComment: (0, form_1.useTextInput)("public_comment"),
        publicCommentBehavior: (0, form_1.useRadioInput)("public_comment_behavior", {
            defaultValue: "append",
            options: {
                append: "Append to",
                replace: "Replace"
            }
        }),
        permType: permType,
    };
    const [importDomains, importResult] = (0, submit_1.default)(form, (0, import_1.useImportDomainPermsMutation)(), { changedOnly: false });
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("form", { onSubmit: importDomains, className: "domain-perm-import-list" },
            react_1.default.createElement("span", null,
                list.length,
                " domain",
                list.length != 1 ? "s" : "",
                " in this list"),
            hasComment.both &&
                react_1.default.createElement(inputs_1.Select, { field: showComment, options: react_1.default.createElement(react_1.default.Fragment, null,
                        react_1.default.createElement("option", { value: "public_comment" }, "Show public comments"),
                        react_1.default.createElement("option", { value: "private_comment" }, "Show private comments")) }),
            react_1.default.createElement("div", { className: "checkbox-list-wrapper" },
                react_1.default.createElement(DomainCheckList, { field: form.domains, domainPerms: domainPerms, commentType: showComment.value, permType: form.permType })),
            react_1.default.createElement(inputs_1.TextArea, { field: form.privateComment, label: "Private comment", rows: 3 }),
            react_1.default.createElement(inputs_1.RadioGroup, { field: form.privateCommentBehavior, label: "imported private comment" }),
            react_1.default.createElement(inputs_1.TextArea, { field: form.publicComment, label: "Public comment", rows: 3 }),
            react_1.default.createElement(inputs_1.RadioGroup, { field: form.publicCommentBehavior, label: "imported public comment" }),
            react_1.default.createElement(inputs_1.Checkbox, { field: form.obfuscate, label: "Obfuscate domains in public lists" }),
            react_1.default.createElement(mutation_button_1.default, { label: "Import", disabled: false, result: importResult }))));
}
function DomainCheckList({ field, domainPerms, commentType, permType }) {
    const getExtraProps = (0, react_2.useCallback)((entry) => {
        return {
            comment: entry[commentType],
            alreadyExists: entry.domain in domainPerms,
            permType: permType,
        };
    }, [domainPerms, commentType, permType]);
    const entriesWithSuggestions = (0, react_2.useMemo)(() => {
        var _a;
        const fieldValue = ((_a = field.value) !== null && _a !== void 0 ? _a : {});
        return Object.values(fieldValue).filter((entry) => entry.suggest);
    }, [field.value]);
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(check_list_1.default, { field: field, header: react_1.default.createElement(react_1.default.Fragment, null,
                react_1.default.createElement("b", null, "Domain"),
                react_1.default.createElement("b", null,
                    commentType == "public_comment" && "Public comment",
                    commentType == "private_comment" && "Private comment")), EntryComponent: DomainEntry, getExtraProps: getExtraProps }),
        react_1.default.createElement(UpdateHint, { entries: entriesWithSuggestions, updateEntry: field.onChange, updateMultiple: field.updateMultiple })));
}
const UpdateHint = (0, react_2.memo)(function UpdateHint({ entries, updateEntry, updateMultiple }) {
    if (entries.length == 0) {
        return null;
    }
    function changeAll() {
        updateMultiple(entries.map((entry) => [entry.key, { domain: entry.suggest, suggest: null }]));
    }
    return (react_1.default.createElement("div", { className: "update-hints" },
        react_1.default.createElement("p", null,
            entries.length,
            " ",
            entries.length == 1 ? "entry uses" : "entries use",
            " a specific subdomain, which you might want to change to the main domain, as that includes all it's (future) subdomains."),
        react_1.default.createElement("div", { className: "hints" }, entries.map((entry) => (react_1.default.createElement(UpdateableEntry, { key: entry.key, entry: entry, updateEntry: updateEntry })))),
        entries.length > 0 && react_1.default.createElement("a", { onClick: changeAll }, "change all")));
});
const UpdateableEntry = (0, react_2.memo)(function UpdateableEntry({ entry, updateEntry }) {
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("span", { className: "text-cutoff" }, entry.domain),
        react_1.default.createElement("i", { className: "fa fa-long-arrow-right", "aria-hidden": "true" }),
        react_1.default.createElement("span", null, entry.suggest),
        react_1.default.createElement("a", { role: "button", onClick: () => updateEntry(entry.key, { domain: entry.suggest, suggest: null }) }, "change")));
});
function domainValidationError(isValid) {
    return isValid ? "" : "Invalid domain";
}
function DomainEntry({ entry, onChange, extraProps: { alreadyExists, comment, permType } }) {
    var _a;
    const domainField = (0, form_1.useTextInput)("domain", {
        defaultValue: entry.domain,
        showValidation: entry.checked,
        initValidation: domainValidationError(entry.valid),
        validator: (value) => domainValidationError((0, domain_permission_1.isValidDomainPermission)(value))
    });
    (0, react_2.useEffect)(() => {
        if (entry.valid != domainField.valid) {
            onChange({ valid: domainField.valid });
        }
    }, [onChange, entry.valid, domainField.valid]);
    (0, react_2.useEffect)(() => {
        if (entry.domain != domainField.value) {
            domainField.setter(entry.domain);
        }
        // domainField.setter is enough, eslint wants domainField
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [entry.domain, domainField.setter]);
    (0, react_2.useEffect)(() => {
        var _a;
        onChange({ suggest: (0, domain_permission_1.hasBetterScope)((_a = domainField.value) !== null && _a !== void 0 ? _a : "") });
        // only need this update if it's the entry.checked that updated, not onChange
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [domainField.value]);
    function clickIcon(e) {
        if (entry.suggest) {
            e.stopPropagation();
            e.preventDefault();
            domainField.setter(entry.suggest);
            onChange({ domain: entry.suggest, checked: true });
        }
    }
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("div", { className: "domain-input" },
            react_1.default.createElement(inputs_1.TextInput, { field: domainField, onChange: (e) => {
                    domainField.onChange(e);
                    onChange({ domain: e.target.value, checked: true });
                } }),
            react_1.default.createElement("span", { id: "icon", onClick: clickIcon },
                react_1.default.createElement(DomainEntryIcon, { alreadyExists: alreadyExists, suggestion: entry.suggest, permTypeString: (_a = permType.value) !== null && _a !== void 0 ? _a : "" }))),
        react_1.default.createElement("p", null, comment)));
}
function DomainEntryIcon({ alreadyExists, suggestion, permTypeString }) {
    let icon;
    let text;
    if (suggestion) {
        icon = "fa-info-circle suggest-changes";
        text = `Entry targets a specific subdomain, consider changing it to '${suggestion}'.`;
    }
    else if (alreadyExists) {
        icon = "fa-history permission-already-exists";
        text = `Domain ${permTypeString} already exists.`;
    }
    if (!icon) {
        return null;
    }
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("i", { className: `fa fa-fw ${icon}`, "aria-hidden": "true", title: text }),
        react_1.default.createElement("span", { className: "sr-only" }, text)));
}

},{"../../components/check-list":268,"../../components/form/inputs":273,"../../components/form/mutation-button":274,"../../lib/form":286,"../../lib/form/form-with-data":284,"../../lib/form/submit":288,"../../lib/query/admin/domain-permissions/get":295,"../../lib/query/admin/domain-permissions/import":296,"../../lib/util/domain-permission":309,"react":146}],245:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_2 = require("react");
const wouter_1 = require("wouter");
const form_1 = require("../../lib/form");
const submit_1 = __importDefault(require("../../lib/form/submit"));
const inputs_1 = require("../../components/form/inputs");
const loading_1 = __importDefault(require("../../components/loading"));
const back_button_1 = __importDefault(require("../../components/back-button"));
const mutation_button_1 = __importDefault(require("../../components/form/mutation-button"));
const get_1 = require("../../lib/query/admin/domain-permissions/get");
const update_1 = require("../../lib/query/admin/domain-permissions/update");
const query_1 = require("../../lib/types/query");
const error_1 = require("../../components/error");
function DomainPermDetail({ baseUrl, permType, domain }) {
    var _a;
    const { data: domainBlocks = {}, isLoading: isLoadingDomainBlocks } = (0, get_1.useDomainBlocksQuery)(query_1.NoArg, { skip: permType !== "block" });
    const { data: domainAllows = {}, isLoading: isLoadingDomainAllows } = (0, get_1.useDomainAllowsQuery)(query_1.NoArg, { skip: permType !== "allow" });
    let isLoading;
    switch (permType) {
        case "block":
            isLoading = isLoadingDomainBlocks;
            break;
        case "allow":
            isLoading = isLoadingDomainAllows;
            break;
        default:
            throw "perm type unknown";
    }
    if (domain == "view") {
        // Retrieve domain from form field submission.
        domain = (_a = (new URL(document.location.toString())).searchParams.get("domain")) !== null && _a !== void 0 ? _a : "unknown";
    }
    if (domain == "unknown") {
        throw "unknown domain";
    }
    // Normalize / decode domain (it may be URL-encoded).
    domain = decodeURIComponent(domain);
    // Check if we already have a perm of the desired type for this domain.
    const existingPerm = (0, react_2.useMemo)(() => {
        if (permType == "block") {
            return domainBlocks[domain];
        }
        else {
            return domainAllows[domain];
        }
    }, [domainBlocks, domainAllows, domain, permType]);
    let infoContent;
    if (isLoading) {
        infoContent = react_1.default.createElement(loading_1.default, null);
    }
    else if (existingPerm == undefined) {
        infoContent = react_1.default.createElement("span", null,
            "No stored ",
            permType,
            " yet, you can add one below:");
    }
    else {
        infoContent = (react_1.default.createElement("div", { className: "info" },
            react_1.default.createElement("i", { className: "fa fa-fw fa-exclamation-triangle", "aria-hidden": "true" }),
            react_1.default.createElement("b", null,
                "Editing domain permissions isn't implemented yet, ",
                react_1.default.createElement("a", { href: "https://github.com/superseriousbusiness/gotosocial/issues/1198", target: "_blank", rel: "noopener noreferrer" }, "check here for progress"))));
    }
    return (react_1.default.createElement("div", null,
        react_1.default.createElement("h1", { className: "text-cutoff" },
            react_1.default.createElement(back_button_1.default, { to: baseUrl }),
            " Domain ",
            permType,
            " for: ",
            react_1.default.createElement("span", { title: domain }, domain)),
        infoContent,
        react_1.default.createElement(DomainPermForm, { defaultDomain: domain, perm: existingPerm, permType: permType, baseUrl: baseUrl })));
}
exports.default = DomainPermDetail;
function DomainPermForm({ defaultDomain, perm, permType, baseUrl }) {
    const isExistingPerm = perm !== undefined;
    const disabledForm = isExistingPerm
        ? {
            disabled: true,
            title: "Domain permissions currently cannot be edited."
        }
        : {
            disabled: false,
            title: "",
        };
    const form = {
        domain: (0, form_1.useTextInput)("domain", { source: perm, defaultValue: defaultDomain }),
        obfuscate: (0, form_1.useBoolInput)("obfuscate", { source: perm }),
        commentPrivate: (0, form_1.useTextInput)("private_comment", { source: perm }),
        commentPublic: (0, form_1.useTextInput)("public_comment", { source: perm })
    };
    // Check which perm type we're meant to be handling
    // here, and use appropriate mutations and results.
    // We can't call these hooks conditionally because
    // react is like "weh" (mood), but we can decide
    // which ones to use conditionally.
    const [addBlock, addBlockResult] = (0, update_1.useAddDomainBlockMutation)();
    const [removeBlock, removeBlockResult] = (0, update_1.useRemoveDomainBlockMutation)({ fixedCacheKey: perm === null || perm === void 0 ? void 0 : perm.id });
    const [addAllow, addAllowResult] = (0, update_1.useAddDomainAllowMutation)();
    const [removeAllow, removeAllowResult] = (0, update_1.useRemoveDomainAllowMutation)({ fixedCacheKey: perm === null || perm === void 0 ? void 0 : perm.id });
    const [addTrigger, addResult, removeTrigger, removeResult,] = (0, react_2.useMemo)(() => {
        return permType == "block"
            ? [
                addBlock,
                addBlockResult,
                removeBlock,
                removeBlockResult,
            ]
            : [
                addAllow,
                addAllowResult,
                removeAllow,
                removeAllowResult,
            ];
    }, [permType,
        addBlock, addBlockResult, removeBlock, removeBlockResult,
        addAllow, addAllowResult, removeAllow, removeAllowResult,
    ]);
    // Use appropriate submission params for this permType.
    const [submitForm, submitFormResult] = (0, submit_1.default)(form, [addTrigger, addResult], { changedOnly: false });
    // Uppercase first letter of given permType.
    const permTypeUpper = (0, react_2.useMemo)(() => {
        return permType.charAt(0).toUpperCase() + permType.slice(1);
    }, [permType]);
    const [location, setLocation] = (0, wouter_1.useLocation)();
    function verifyUrlThenSubmit(e) {
        // Adding a new domain permissions happens on a url like
        // "/settings/admin/domain-permissions/:permType/domain.com",
        // but if domain input changes, that doesn't match anymore
        // and causes issues later on so, before submitting the form,
        // silently change url, and THEN submit.
        let correctUrl = `${baseUrl}/${form.domain.value}`;
        if (location != correctUrl) {
            setLocation(correctUrl);
        }
        return submitForm(e);
    }
    return (react_1.default.createElement("form", { onSubmit: verifyUrlThenSubmit },
        react_1.default.createElement(inputs_1.TextInput, Object.assign({ field: form.domain, label: "Domain", placeholder: "example.com" }, disabledForm)),
        react_1.default.createElement(inputs_1.Checkbox, Object.assign({ field: form.obfuscate, label: "Obfuscate domain in public lists" }, disabledForm)),
        react_1.default.createElement(inputs_1.TextArea, Object.assign({ field: form.commentPrivate, label: "Private comment", rows: 3 }, disabledForm)),
        react_1.default.createElement(inputs_1.TextArea, Object.assign({ field: form.commentPublic, label: "Public comment", rows: 3 }, disabledForm)),
        react_1.default.createElement("div", { className: "action-buttons row" },
            react_1.default.createElement(mutation_button_1.default, Object.assign({ label: permTypeUpper, result: submitFormResult, showError: false }, disabledForm)),
            isExistingPerm &&
                react_1.default.createElement(mutation_button_1.default, { type: "button", onClick: () => { var _a; return removeTrigger((_a = perm.id) !== null && _a !== void 0 ? _a : ""); }, label: "Remove", result: removeResult, className: "button danger", showError: false, disabled: !isExistingPerm })),
        react_1.default.createElement(react_1.default.Fragment, null,
            addResult.error && react_1.default.createElement(error_1.Error, { error: addResult.error }),
            removeResult.error && react_1.default.createElement(error_1.Error, { error: removeResult.error }))));
}

},{"../../components/back-button":267,"../../components/error":270,"../../components/form/inputs":273,"../../components/form/mutation-button":274,"../../components/loading":276,"../../lib/form":286,"../../lib/form/submit":288,"../../lib/query/admin/domain-permissions/get":295,"../../lib/query/admin/domain-permissions/update":298,"../../lib/types/query":308,"react":146,"wouter":234}],302:[function(require,module,exports){
"use strict";module.exports=Object.assign(Object.assign(Object.assign(Object.assign({},require("./gts-api")),require("./oauth")),require("./user")),require("./admin"));

},{"./admin":299,"./gts-api":301,"./oauth":303,"./user":306}],261:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
const {
  Link,
  Switch,
  Route
} = require("wouter");
const FormWithData = require("../../lib/form/form-with-data").default;
const ReportDetail = require("./detail");
const Username = require("./username");
const {
  useBaseUrl
} = require("../../lib/navigation/util");
const {
  useListReportsQuery
} = require("../../lib/query/admin/reports");
module.exports = function Reports(_ref) {
  let {
    baseUrl
  } = _ref;
  return React.createElement("div", {
    className: "reports"
  }, React.createElement(Switch, null, React.createElement(Route, {
    path: `${baseUrl}/:reportId`
  }, React.createElement(ReportDetail, null)), React.createElement(ReportOverview, null)));
};
function ReportOverview(_ref2) {
  let {} = _ref2;
  return React.createElement(React.Fragment, null, React.createElement("h1", null, "Reports"), React.createElement("div", null, React.createElement("p", null, "Here you can view and resolve reports made to your instance, originating from local and remote users.")), React.createElement(FormWithData, {
    dataQuery: useListReportsQuery,
    DataForm: ReportsList
  }));
}
function ReportsList(_ref3) {
  let {
    data: reports
  } = _ref3;
  return React.createElement("div", {
    className: "list"
  }, reports.map(report => React.createElement(ReportEntry, {
    key: report.id,
    report: report
  })));
}
function ReportEntry(_ref4) {
  let {
    report
  } = _ref4;
  const baseUrl = useBaseUrl();
  const from = report.account;
  const target = report.target_account;
  let comment = report.comment.length > 200 ? report.comment.slice(0, 200) + "..." : report.comment;
  return React.createElement(Link, {
    to: `${baseUrl}/${report.id}`
  }, React.createElement("a", {
    className: `report entry${report.action_taken ? " resolved" : ""}`
  }, React.createElement("div", {
    className: "byline"
  }, React.createElement("div", {
    className: "usernames"
  }, React.createElement(Username, {
    user: from,
    link: false
  }), " reported ", React.createElement(Username, {
    user: target,
    link: false
  })), React.createElement("h3", {
    className: "status"
  }, report.action_taken ? "Resolved" : "Open")), React.createElement("div", {
    className: "details"
  }, React.createElement("b", null, "Created: "), React.createElement("span", null, new Date(report.created_at).toLocaleString()), React.createElement("b", null, "Reason: "), comment.length > 0 ? React.createElement("p", null, comment) : React.createElement("i", {
    className: "no-comment"
  }, "none provided"))));
}

},{"../../lib/form/form-with-data":284,"../../lib/navigation/util":292,"../../lib/query/admin/reports":300,"./detail":260,"./username":262,"react":146,"wouter":234}],265:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Authorization = void 0;
const oauth_1 = require("../../lib/query/oauth");
const store_1 = require("../../redux/store");
const react_1 = __importDefault(require("react"));
const login_1 = __importDefault(require("./login"));
const loading_1 = __importDefault(require("../loading"));
const error_1 = require("../error");
const query_1 = require("../../lib/types/query");
function Authorization({ App }) {
    const { loginState, expectingRedirect } = store_1.store.getState().oauth;
    const skip = (loginState == "none" || loginState == "logout" || expectingRedirect);
    const { isLoading, isSuccess, data: account, error, } = (0, oauth_1.useVerifyCredentialsQuery)(query_1.NoArg, { skip: skip });
    let showLogin = true;
    let content = null;
    if (isLoading) {
        showLogin = false;
        let loadingInfo = "";
        if (loginState == "callback") {
            loadingInfo = "Processing OAUTH callback.";
        }
        else if (loginState == "login") {
            loadingInfo = "Verifying stored login.";
        }
        content = (react_1.default.createElement("div", null,
            react_1.default.createElement(loading_1.default, null),
            " ",
            loadingInfo));
    }
    else if (error != undefined) {
        content = (react_1.default.createElement("div", null,
            react_1.default.createElement(error_1.Error, { error: error }),
            "You can attempt logging in again below:"));
    }
    if (loginState == "login" && isSuccess) {
        return react_1.default.createElement(App, { account: account });
    }
    else {
        return (react_1.default.createElement("section", { className: "oauth" },
            react_1.default.createElement("h1", null, "GoToSocial Settings"),
            content,
            showLogin && react_1.default.createElement(login_1.default, null)));
    }
}
exports.Authorization = Authorization;

},{"../../lib/query/oauth":303,"../../lib/types/query":308,"../../redux/store":312,"../error":270,"../loading":276,"./login":266,"react":146}],258:[function(require,module,exports){
"use strict";const React=require("react"),ParseFromToot=require("./parse-from-toot"),Loading=require("../../../components/loading"),{Error:Error}=require("../../../components/error"),{useListEmojiQuery:useListEmojiQuery}=require("../../../lib/query/admin/custom-emoji");module.exports=function(){const{data:e=[],isLoading:r,error:t}=useListEmojiQuery({filter:"domain:local"}),o=React.useMemo((()=>new Set(e.map((e=>e.shortcode)))),[e]);return React.createElement(React.Fragment,null,React.createElement("h1",null,"Custom Emoji (remote)"),t&&React.createElement(Error,{error:t}),r?React.createElement(Loading,null):React.createElement(React.Fragment,null,React.createElement(ParseFromToot,{emoji:e,emojiCodes:o})))};

},{"../../../components/error":270,"../../../components/loading":276,"../../../lib/query/admin/custom-emoji":293,"./parse-from-toot":259,"react":146}],248:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const wouter_1 = require("wouter");
const process_1 = require("../../lib/query/admin/domain-permissions/process");
const form_1 = require("../../lib/form");
const submit_1 = __importDefault(require("../../lib/form/submit"));
const process_2 = require("./process");
const form_2 = __importDefault(require("./form"));
function ImportExport({ baseUrl }) {
    const form = {
        domains: (0, form_1.useTextInput)("domains"),
        exportType: (0, form_1.useTextInput)("exportType", { defaultValue: "plain", dontReset: true }),
        permType: (0, form_1.useRadioInput)("permType", {
            options: {
                block: "Domain blocks",
                allow: "Domain allows",
            }
        })
    };
    const [submitParse, parseResult] = (0, submit_1.default)(form, (0, process_1.useProcessDomainPermissionsMutation)(), { changedOnly: false });
    const [_location, setLocation] = (0, wouter_1.useLocation)();
    return (react_1.default.createElement(wouter_1.Switch, null,
        react_1.default.createElement(wouter_1.Route, { path: `${baseUrl}/process` }, parseResult.isSuccess
            ? (react_1.default.createElement(react_1.default.Fragment, null,
                react_1.default.createElement("h1", null,
                    react_1.default.createElement("span", { className: "button", onClick: () => {
                            parseResult.reset();
                            setLocation(baseUrl);
                        } }, "< back"),
                    "\u00A0 Confirm import of domain ",
                    form.permType.value,
                    "s:"),
                react_1.default.createElement(process_2.ProcessImport, { list: parseResult.data, permType: form.permType })))
            : react_1.default.createElement(wouter_1.Redirect, { to: baseUrl })),
        react_1.default.createElement(wouter_1.Route, null, parseResult.isSuccess
            ? react_1.default.createElement(wouter_1.Redirect, { to: `${baseUrl}/process` })
            : react_1.default.createElement(form_2.default, { form: form, submitParse: submitParse, parseResult: parseResult }))));
}
exports.default = ImportExport;

},{"../../lib/form":286,"../../lib/form/submit":288,"../../lib/query/admin/domain-permissions/process":297,"./form":247,"./process":251,"react":146,"wouter":234}],249:[function(require,module,exports){
"use strict";
/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const wouter_1 = require("wouter");
const overview_1 = __importDefault(require("./overview"));
const detail_1 = __importDefault(require("./detail"));
function DomainPermissions({ baseUrl }) {
    return (react_1.default.createElement(wouter_1.Switch, null,
        react_1.default.createElement(wouter_1.Route, { path: "/settings/admin/domain-permissions/:permType/:domain" }, params => (react_1.default.createElement(detail_1.default, { permType: params.permType, baseUrl: baseUrl, domain: params.domain }))),
        react_1.default.createElement(wouter_1.Route, { path: "/settings/admin/domain-permissions/:permType" }, params => (react_1.default.createElement(overview_1.default, { permType: params.permType, baseUrl: baseUrl })))));
}
exports.default = DomainPermissions;

},{"./detail":245,"./overview":250,"react":146,"wouter":234}],239:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
const {
  useRoute,
  Redirect
} = require("wouter");
const query = require("../../lib/query");
const FormWithData = require("../../lib/form/form-with-data").default;
const {
  useBaseUrl
} = require("../../lib/navigation/util");
const FakeProfile = require("../../components/fake-profile");
const MutationButton = require("../../components/form/mutation-button");
const useFormSubmit = require("../../lib/form/submit").default;
const {
  useValue,
  useTextInput
} = require("../../lib/form");
const {
  TextInput
} = require("../../components/form/inputs");
module.exports = function AccountDetail(_ref) {
  let {} = _ref;
  const baseUrl = useBaseUrl();
  let [_match, params] = useRoute(`${baseUrl}/:accountId`);
  if ((params === null || params === void 0 ? void 0 : params.accountId) == undefined) {
    return React.createElement(Redirect, {
      to: baseUrl
    });
  } else {
    return React.createElement("div", {
      className: "account-detail"
    }, React.createElement("h1", null, "Account Details"), React.createElement(FormWithData, {
      dataQuery: query.useGetAccountQuery,
      queryArg: params.accountId,
      DataForm: AccountDetailForm
    }));
  }
};
function AccountDetailForm(_ref2) {
  let {
    data: account
  } = _ref2;
  let content;
  if (account.suspended) {
    content = React.createElement("h2", {
      className: "error"
    }, "Account is suspended.");
  } else {
    content = React.createElement(ModifyAccount, {
      account: account
    });
  }
  return React.createElement(React.Fragment, null, React.createElement(FakeProfile, Object.assign({}, account)), content);
}
function ModifyAccount(_ref3) {
  let {
    account
  } = _ref3;
  const form = {
    id: useValue("id", account.id),
    reason: useTextInput("text")
  };
  const [modifyAccount, result] = useFormSubmit(form, query.useActionAccountMutation());
  return React.createElement("form", {
    onSubmit: modifyAccount
  }, React.createElement("h2", null, "Actions"), React.createElement(TextInput, {
    field: form.reason,
    placeholder: "Reason for this action"
  }), React.createElement("div", {
    className: "action-buttons"
  }, React.createElement(MutationButton, {
    label: "Suspend",
    name: "suspend",
    result: result
  })));
}

},{"../../components/fake-profile":271,"../../components/form/inputs":273,"../../components/form/mutation-button":274,"../../lib/form":286,"../../lib/form/form-with-data":284,"../../lib/form/submit":288,"../../lib/navigation/util":292,"../../lib/query":302,"react":146,"wouter":234}],241:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
const query = require("../../../lib/query");
const {
  useTextInput
} = require("../../../lib/form");
const {
  TextInput
} = require("../../../components/form/inputs");
const MutationButton = require("../../../components/form/mutation-button");
module.exports = function ExpireRemote(_ref) {
  let {} = _ref;
  const domainField = useTextInput("domain");
  const [expire, expireResult] = query.useInstanceKeysExpireMutation();
  function submitExpire(e) {
    e.preventDefault();
    expire(domainField.value);
  }
  return React.createElement("form", {
    onSubmit: submitExpire
  }, React.createElement("h2", null, "Expire remote instance keys"), React.createElement("p", null, "Mark all public keys from the given remote instance as expired.", React.createElement("br", null), React.createElement("br", null), "This is useful in cases where the remote domain has had to rotate their keys for whatever reason (security issue, data leak, routine safety procedure, etc), and your instance can no longer communicate with theirs properly using cached keys. A key marked as expired in this way will be lazily refetched next time a request is made to your instance signed by the owner of that key."), React.createElement(TextInput, {
    field: domainField,
    label: "Domain",
    type: "string",
    placeholder: "example.org"
  }), React.createElement(MutationButton, {
    label: "Expire keys",
    result: expireResult
  }));
};

},{"../../../components/form/inputs":273,"../../../components/form/mutation-button":274,"../../../lib/form":286,"../../../lib/query":302,"react":146}],243:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
const query = require("../../../lib/query");
const {
  useTextInput
} = require("../../../lib/form");
const {
  TextInput
} = require("../../../components/form/inputs");
const MutationButton = require("../../../components/form/mutation-button");
module.exports = function Cleanup(_ref) {
  let {} = _ref;
  const daysField = useTextInput("days", {
    defaultValue: 30
  });
  const [mediaCleanup, mediaCleanupResult] = query.useMediaCleanupMutation();
  function submitCleanup(e) {
    e.preventDefault();
    mediaCleanup(daysField.value);
  }
  return React.createElement("form", {
    onSubmit: submitCleanup
  }, React.createElement("h2", null, "Cleanup"), React.createElement("p", null, "Clean up remote media older than the specified number of days. If the remote instance is still online they will be refetched when needed. Also cleans up unused headers and avatars from the media cache."), React.createElement(TextInput, {
    field: daysField,
    label: "Days",
    type: "number",
    min: "0",
    placeholder: "30"
  }), React.createElement(MutationButton, {
    label: "Remove old media",
    result: mediaCleanupResult
  }));
};

},{"../../../components/form/inputs":273,"../../../components/form/mutation-button":274,"../../../lib/form":286,"../../../lib/query":302,"react":146}],263:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
const {
  useTextInput,
  useFileInput
} = require("../../lib/form");
const useFormSubmit = require("../../lib/form/submit").default;
const {
  TextInput,
  TextArea,
  FileInput
} = require("../../components/form/inputs");
const FormWithData = require("../../lib/form/form-with-data").default;
const MutationButton = require("../../components/form/mutation-button");
const {
  useInstanceV1Query
} = require("../../lib/query");
const {
  useUpdateInstanceMutation
} = require("../../lib/query/admin");
module.exports = function AdminSettings() {
  return React.createElement(FormWithData, {
    dataQuery: useInstanceV1Query,
    DataForm: AdminSettingsForm
  });
};
function AdminSettingsForm(_ref) {
  let {
    data: instance
  } = _ref;
  var _a, _b;
  const form = {
    title: useTextInput("title", {
      source: instance,
      validator: val => val.length <= 40 ? "" : "Instance title must be 40 characters or less"
    }),
    thumbnail: useFileInput("thumbnail", {
      withPreview: true
    }),
    thumbnailDesc: useTextInput("thumbnail_description", {
      source: instance
    }),
    shortDesc: useTextInput("short_description", {
      source: instance
    }),
    description: useTextInput("description", {
      source: instance
    }),
    contactUser: useTextInput("contact_username", {
      source: instance,
      valueSelector: s => {
        var _a;
        return (_a = s.contact_account) === null || _a === void 0 ? void 0 : _a.username;
      }
    }),
    contactEmail: useTextInput("contact_email", {
      source: instance,
      valueSelector: s => s.email
    }),
    terms: useTextInput("terms", {
      source: instance
    })
  };
  const [submitForm, result] = useFormSubmit(form, useUpdateInstanceMutation());
  return React.createElement("form", {
    onSubmit: submitForm
  }, React.createElement("h1", null, "Instance Settings"), React.createElement(TextInput, {
    field: form.title,
    label: "Title",
    placeholder: "My GoToSocial instance"
  }), React.createElement("div", {
    className: "file-upload"
  }, React.createElement("h3", null, "Instance thumbnail"), React.createElement("div", null, React.createElement("img", {
    className: "preview avatar",
    src: (_a = form.thumbnail.previewValue) !== null && _a !== void 0 ? _a : instance.thumbnail,
    alt: (_b = form.thumbnailDesc.value) !== null && _b !== void 0 ? _b : instance.thumbnail ? `Thumbnail image for the instance` : "No instance thumbnail image set"
  }), React.createElement(FileInput, {
    field: form.thumbnail,
    accept: "image/*"
  }))), React.createElement(TextInput, {
    field: form.thumbnailDesc,
    label: "Instance thumbnail description",
    placeholder: "A cute drawing of a smiling sloth."
  }), React.createElement(TextArea, {
    field: form.shortDesc,
    label: "Short description",
    placeholder: "A small testing instance for the GoToSocial alpha software."
  }), React.createElement(TextArea, {
    field: form.description,
    label: "Full description",
    placeholder: "A small testing instance for the GoToSocial alpha software. Just trying it out, my main instance is https://example.com"
  }), React.createElement(TextInput, {
    field: form.contactUser,
    label: "Contact user (local account username)",
    placeholder: "admin"
  }), React.createElement(TextInput, {
    field: form.contactEmail,
    label: "Contact email",
    placeholder: "admin@example.com"
  }), React.createElement(TextArea, {
    field: form.terms,
    label: "Terms & Conditions",
    placeholder: ""
  }), React.createElement(MutationButton, {
    label: "Save",
    result: result
  }));
}

},{"../../components/form/inputs":273,"../../components/form/mutation-button":274,"../../lib/form":286,"../../lib/form/form-with-data":284,"../../lib/form/submit":288,"../../lib/query":302,"../../lib/query/admin":299,"react":146}],264:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
const {
  Switch,
  Route,
  Link,
  Redirect,
  useRoute
} = require("wouter");
const query = require("../../lib/query");
const FormWithData = require("../../lib/form/form-with-data").default;
const {
  useBaseUrl
} = require("../../lib/navigation/util");
const {
  useValue,
  useTextInput
} = require("../../lib/form");
const useFormSubmit = require("../../lib/form/submit").default;
const {
  TextArea
} = require("../../components/form/inputs");
const MutationButton = require("../../components/form/mutation-button");
module.exports = function InstanceRulesData(_ref) {
  let {
    baseUrl
  } = _ref;
  return React.createElement(FormWithData, {
    dataQuery: query.useInstanceRulesQuery,
    DataForm: InstanceRules,
    baseUrl: baseUrl
  });
};
function InstanceRules(_ref2) {
  let {
    baseUrl,
    data: rules
  } = _ref2;
  return React.createElement(Switch, null, React.createElement(Route, {
    path: `${baseUrl}/:ruleId`
  }, React.createElement(InstanceRuleDetail, {
    rules: rules
  })), React.createElement(Route, null, React.createElement("div", null, React.createElement("h1", null, "Instance Rules"), React.createElement("div", null, React.createElement("p", null, "The rules for your instance are listed on the about page, and can be selected when submitting reports.")), React.createElement(InstanceRuleList, {
    rules: rules
  }))));
}
function InstanceRuleList(_ref3) {
  let {
    rules
  } = _ref3;
  const newRule = useTextInput("text", {});
  const [submitForm, result] = useFormSubmit({
    newRule
  }, query.useAddInstanceRuleMutation(), {
    onFinish: () => newRule.reset()
  });
  return React.createElement(React.Fragment, null, React.createElement("form", {
    onSubmit: submitForm,
    className: "new-rule"
  }, React.createElement("ol", {
    className: "instance-rules"
  }, Object.values(rules).map(rule => React.createElement(InstanceRule, {
    key: rule.id,
    rule: rule
  }))), React.createElement(TextArea, {
    field: newRule,
    label: "New instance rule"
  }), React.createElement(MutationButton, {
    label: "Add rule",
    result: result
  })));
}
function InstanceRule(_ref4) {
  let {
    rule
  } = _ref4;
  const baseUrl = useBaseUrl();
  return React.createElement(Link, {
    to: `${baseUrl}/${rule.id}`
  }, React.createElement("a", {
    className: "rule"
  }, React.createElement("li", null, React.createElement("h2", null, rule.text, " ", React.createElement("i", {
    className: "fa fa-pencil edit-icon"
  }))), React.createElement("span", null, new Date(rule.created_at).toLocaleString())));
}
function InstanceRuleDetail(_ref5) {
  let {
    rules
  } = _ref5;
  const baseUrl = useBaseUrl();
  let [_match, params] = useRoute(`${baseUrl}/:ruleId`);
  if ((params === null || params === void 0 ? void 0 : params.ruleId) == undefined || rules[params.ruleId] == undefined) {
    return React.createElement(Redirect, {
      to: baseUrl
    });
  } else {
    return React.createElement(React.Fragment, null, React.createElement(Link, {
      to: baseUrl
    }, React.createElement("a", null, "< go back")), React.createElement(InstanceRuleForm, {
      rule: rules[params.ruleId]
    }));
  }
}
function InstanceRuleForm(_ref6) {
  let {
    rule
  } = _ref6;
  const baseUrl = useBaseUrl();
  const form = {
    id: useValue("id", rule.id),
    rule: useTextInput("text", {
      defaultValue: rule.text
    })
  };
  const [submitForm, result] = useFormSubmit(form, query.useUpdateInstanceRuleMutation());
  const [deleteRule, deleteResult] = query.useDeleteInstanceRuleMutation({
    fixedCacheKey: rule.id
  });
  if (result.isSuccess || deleteResult.isSuccess) {
    return React.createElement(Redirect, {
      to: baseUrl
    });
  }
  return React.createElement("div", {
    className: "rule-detail"
  }, React.createElement("form", {
    onSubmit: submitForm
  }, React.createElement(TextArea, {
    field: form.rule
  }), React.createElement("div", {
    className: "action-buttons row"
  }, React.createElement(MutationButton, {
    label: "Save",
    showError: false,
    result: result,
    disabled: !form.rule.hasChanged()
  }), React.createElement(MutationButton, {
    type: "button",
    onClick: () => deleteRule(rule.id),
    label: "Delete",
    className: "button danger",
    showError: false,
    result: deleteResult
  })), result.error && React.createElement(Error, {
    error: result.error
  }), deleteResult.error && React.createElement(Error, {
    error: deleteResult.error
  })));
}

},{"../../components/form/inputs":273,"../../components/form/mutation-button":274,"../../lib/form":286,"../../lib/form/form-with-data":284,"../../lib/form/submit":288,"../../lib/navigation/util":292,"../../lib/query":302,"react":146,"wouter":234}],272:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
const query = require("../lib/query");
module.exports = function FakeToot(_ref) {
  let {
    children
  } = _ref;
  const {
    data: account = {
      avatar: "/assets/default_avatars/GoToSocial_icon1.png",
      display_name: "",
      username: ""
    }
  } = query.useVerifyCredentialsQuery();
  return React.createElement("article", {
    className: "toot expanded"
  }, React.createElement("section", {
    className: "author"
  }, React.createElement("a", null, React.createElement("img", {
    className: "avatar",
    src: account.avatar,
    alt: ""
  }), React.createElement("span", {
    className: "displayname"
  }, account.display_name.trim().length > 0 ? account.display_name : account.username, React.createElement("span", {
    className: "sr-only"
  }, ".")), React.createElement("span", {
    className: "username"
  }, "@", account.username))), React.createElement("section", {
    className: "body"
  }, React.createElement("div", {
    className: "text"
  }, children)));
};

},{"../lib/query":302,"react":146}],277:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
const Loading = require("./loading");
const {
  useVerifyCredentialsQuery,
  useLogoutMutation
} = require("../lib/query/oauth");
const {
  useInstanceV1Query
} = require("../lib/query");
module.exports = function UserLogoutCard() {
  var _a;
  const {
    data: profile,
    isLoading
  } = useVerifyCredentialsQuery();
  const {
    data: instance
  } = useInstanceV1Query();
  const [logoutQuery] = useLogoutMutation();
  if (isLoading) {
    return React.createElement(Loading, null);
  } else {
    return React.createElement("div", {
      className: "account-card"
    }, React.createElement("img", {
      className: "avatar",
      src: profile.avatar,
      alt: ""
    }), React.createElement("h3", {
      className: "text-cutoff"
    }, ((_a = profile.display_name) === null || _a === void 0 ? void 0 : _a.length) > 0 ? profile.display_name : profile.acct), React.createElement("span", {
      className: "text-cutoff"
    }, "@", profile.username, "@", instance === null || instance === void 0 ? void 0 : instance.account_domain), React.createElement("a", {
      onClick: logoutQuery,
      href: "#",
      "aria-label": "Log out",
      title: "Log out",
      className: "logout"
    }, React.createElement("i", {
      className: "fa fa-fw fa-sign-out",
      "aria-hidden": "true"
    })));
  }
};

},{"../lib/query":302,"../lib/query/oauth":303,"./loading":276,"react":146}],314:[function(require,module,exports){
"use strict";const React=require("react"),{useTextInput:useTextInput,useFileInput:useFileInput,useBoolInput:useBoolInput,useFieldArrayInput:useFieldArrayInput}=require("../lib/form"),useFormSubmit=require("../lib/form/submit").default,{useWithFormContext:useWithFormContext,FormContext:FormContext}=require("../lib/form/context"),{TextInput:TextInput,TextArea:TextArea,FileInput:FileInput,Checkbox:Checkbox}=require("../components/form/inputs"),FormWithData=require("../lib/form/form-with-data").default,FakeProfile=require("../components/fake-profile"),MutationButton=require("../components/form/mutation-button"),{useInstanceV1Query:useInstanceV1Query}=require("../lib/query"),{useUpdateCredentialsMutation:useUpdateCredentialsMutation}=require("../lib/query/user"),{useVerifyCredentialsQuery:useVerifyCredentialsQuery}=require("../lib/query/oauth");function UserProfileForm(e){let{data:t}=e;var a,l,r,n;const{data:o}=useInstanceV1Query(),i=React.useMemo((()=>{var e,t,a,l,r;return{allowCustomCSS:!0===(null===(t=null===(e=null==o?void 0:o.configuration)||void 0===e?void 0:e.accounts)||void 0===t?void 0:t.allow_custom_css),maxPinnedFields:null!==(r=null===(l=null===(a=null==o?void 0:o.configuration)||void 0===a?void 0:a.accounts)||void 0===l?void 0:l.max_profile_fields)&&void 0!==r?r:6}}),[o]),s={avatar:useFileInput("avatar",{withPreview:!0}),header:useFileInput("header",{withPreview:!0}),displayName:useTextInput("display_name",{source:t}),note:useTextInput("note",{source:t,valueSelector:e=>{var t;return null===(t=e.source)||void 0===t?void 0:t.note}}),customCSS:useTextInput("custom_css",{source:t,nosubmit:!i.allowCustomCSS}),bot:useBoolInput("bot",{source:t}),locked:useBoolInput("locked",{source:t}),discoverable:useBoolInput("discoverable",{source:t}),enableRSS:useBoolInput("enable_rss",{source:t}),fields:useFieldArrayInput("fields_attributes",{defaultValue:null===(a=null==t?void 0:t.source)||void 0===a?void 0:a.fields,length:i.maxPinnedFields})},[u,c]=useFormSubmit(s,useUpdateCredentialsMutation(),{onFinish:()=>{s.avatar.reset(),s.header.reset()}});return React.createElement("form",{className:"user-profile",onSubmit:u},React.createElement("h1",null,"Profile"),React.createElement("div",{className:"overview"},React.createElement(FakeProfile,{avatar:null!==(l=s.avatar.previewValue)&&void 0!==l?l:t.avatar,header:null!==(r=s.header.previewValue)&&void 0!==r?r:t.header,display_name:null!==(n=s.displayName.value)&&void 0!==n?n:t.username,username:t.username,role:t.role}),React.createElement("div",{className:"files"},React.createElement("div",null,React.createElement(FileInput,{label:"Header",field:s.header,accept:"image/*"})),React.createElement("div",null,React.createElement(FileInput,{label:"Avatar",field:s.avatar,accept:"image/*"})))),React.createElement("div",{className:"form-section-docs"},React.createElement("h3",null,"Basic Information"),React.createElement("a",{href:"https://docs.gotosocial.org/en/latest/user_guide/settings/#basic-information",target:"_blank",className:"docslink",rel:"noreferrer"},"Learn more about these settings (opens in a new tab)")),React.createElement(TextInput,{field:s.displayName,label:"Display name",placeholder:"A GoToSocial user"}),React.createElement(TextArea,{field:s.note,label:"Bio",placeholder:"Just trying out GoToSocial, my pronouns are they/them and I like sloths.",rows:8}),React.createElement("b",null,"Profile fields"),React.createElement(ProfileFields,{field:s.fields}),React.createElement("div",{className:"form-section-docs"},React.createElement("h3",null,"Visibility and privacy"),React.createElement("a",{href:"https://docs.gotosocial.org/en/latest/user_guide/settings/#visibility-and-privacy",target:"_blank",className:"docslink",rel:"noreferrer"},"Learn more about these settings (opens in a new tab)")),React.createElement(Checkbox,{field:s.locked,label:"Manually approve follow requests"}),React.createElement(Checkbox,{field:s.discoverable,label:"Mark account as discoverable by search engines and directories"}),React.createElement(Checkbox,{field:s.enableRSS,label:"Enable RSS feed of Public posts"}),React.createElement("div",{className:"form-section-docs"},React.createElement("h3",null,"Advanced"),React.createElement("a",{href:"https://docs.gotosocial.org/en/latest/user_guide/settings/#advanced",target:"_blank",className:"docslink",rel:"noreferrer"},"Learn more about these settings (opens in a new tab)")),React.createElement(TextArea,{field:s.customCSS,label:"Custom CSS"+(i.allowCustomCSS?"":" (not enabled on this instance)"),className:"monospace",rows:8,disabled:!i.allowCustomCSS}),React.createElement(MutationButton,{label:"Save profile info",result:c}))}function ProfileFields(e){let{field:t}=e;return React.createElement("div",{className:"fields"},React.createElement(FormContext.Provider,{value:t.ctx},t.value.map(((e,t)=>React.createElement(Field,{key:t,index:t,data:e})))))}function Field(e){let{index:t,data:a}=e;const l=useWithFormContext(t,{name:useTextInput("name",{defaultValue:a.name}),value:useTextInput("value",{defaultValue:a.value})});return React.createElement("div",{className:"entry"},React.createElement(TextInput,{field:l.name,placeholder:"Name"}),React.createElement(TextInput,{field:l.value,placeholder:"Value"}))}module.exports=function(){return React.createElement(FormWithData,{dataQuery:useVerifyCredentialsQuery,DataForm:UserProfileForm})};

},{"../components/fake-profile":271,"../components/form/inputs":273,"../components/form/mutation-button":274,"../lib/form":286,"../lib/form/context":281,"../lib/form/form-with-data":284,"../lib/form/submit":288,"../lib/query":302,"../lib/query/oauth":303,"../lib/query/user":306,"react":146}],315:[function(require,module,exports){
"use strict";const React=require("react"),query=require("../lib/query"),{useTextInput:useTextInput,useBoolInput:useBoolInput}=require("../lib/form"),useFormSubmit=require("../lib/form/submit").default,{Select:Select,TextInput:TextInput,Checkbox:Checkbox}=require("../components/form/inputs"),FormWithData=require("../lib/form/form-with-data").default,Languages=require("../components/languages"),MutationButton=require("../components/form/mutation-button");function UserSettingsForm(e){let{data:t}=e;const a={defaultPrivacy:useTextInput("source[privacy]",{source:t,defaultValue:"unlisted"}),isSensitive:useBoolInput("source[sensitive]",{source:t}),language:useTextInput("source[language]",{source:t,valueSelector:e=>{var t,a;return null!==(a=null===(t=e.source.language)||void 0===t?void 0:t.toUpperCase())&&void 0!==a?a:"EN"}}),statusContentType:useTextInput("source[status_content_type]",{source:t,defaultValue:"text/plain"})},[s,n]=useFormSubmit(a,query.useUpdateCredentialsMutation());return React.createElement(React.Fragment,null,React.createElement("form",{className:"user-settings",onSubmit:s},React.createElement("h1",null,"Post settings"),React.createElement(Select,{field:a.language,label:"Default post language",options:React.createElement(Languages,null)}),React.createElement(Select,{field:a.defaultPrivacy,label:"Default post privacy",options:React.createElement(React.Fragment,null,React.createElement("option",{value:"private"},"Private / followers-only"),React.createElement("option",{value:"unlisted"},"Unlisted"),React.createElement("option",{value:"public"},"Public"))},React.createElement("a",{href:"https://docs.gotosocial.org/en/latest/user_guide/posts/#privacy-settings",target:"_blank",className:"docslink",rel:"noreferrer"},"Learn more about post privacy settings (opens in a new tab)")),React.createElement(Select,{field:a.statusContentType,label:"Default post (and bio) format",options:React.createElement(React.Fragment,null,React.createElement("option",{value:"text/plain"},"Plain (default)"),React.createElement("option",{value:"text/markdown"},"Markdown"))},React.createElement("a",{href:"https://docs.gotosocial.org/en/latest/user_guide/posts/#input-types",target:"_blank",className:"docslink",rel:"noreferrer"},"Learn more about post format settings (opens in a new tab)")),React.createElement(Checkbox,{field:a.isSensitive,label:"Mark my posts as sensitive by default"}),React.createElement(MutationButton,{label:"Save settings",result:n})),React.createElement("div",null,React.createElement(PasswordChange,null)))}function PasswordChange(){const e={oldPassword:useTextInput("old_password"),newPassword:useTextInput("new_password",{validator:t=>""!=t&&t==e.oldPassword.value?"New password same as old password":""})},t=useTextInput("verifyNewPassword",{validator:t=>""!=t&&t!=e.newPassword.value?"Passwords do not match":""}),[a,s]=useFormSubmit(e,query.usePasswordChangeMutation());return React.createElement("form",{className:"change-password",onSubmit:a},React.createElement("h1",null,"Change password"),React.createElement(TextInput,{type:"password",name:"password",field:e.oldPassword,label:"Current password"}),React.createElement(TextInput,{type:"password",name:"newPassword",field:e.newPassword,label:"New password"}),React.createElement(TextInput,{type:"password",name:"confirmNewPassword",field:t,label:"Confirm new password"}),React.createElement(MutationButton,{label:"Change password",result:s}))}module.exports=function(){return React.createElement(FormWithData,{dataQuery:query.useVerifyCredentialsQuery,DataForm:UserSettingsForm})};

},{"../components/form/inputs":273,"../components/form/mutation-button":274,"../components/languages":275,"../lib/form":286,"../lib/form/form-with-data":284,"../lib/form/submit":288,"../lib/query":302,"react":146}],240:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
const {
  Switch,
  Route,
  Link
} = require("wouter");
const query = require("../../lib/query");
const {
  useTextInput
} = require("../../lib/form");
const AccountDetail = require("./detail");
const {
  useBaseUrl
} = require("../../lib/navigation/util");
const {
  Error
} = require("../../components/error");
module.exports = function Accounts(_ref) {
  let {
    baseUrl
  } = _ref;
  return React.createElement("div", {
    className: "accounts"
  }, React.createElement(Switch, null, React.createElement(Route, {
    path: `${baseUrl}/:accountId`
  }, React.createElement(AccountDetail, null)), React.createElement(AccountOverview, null)));
};
function AccountOverview(_ref2) {
  let {} = _ref2;
  return React.createElement(React.Fragment, null, React.createElement("h1", null, "Accounts"), React.createElement("div", null, "Pending ", React.createElement("a", {
    href: "https://github.com/superseriousbusiness/gotosocial/issues/581"
  }, "#581"), ", there is currently no way to list accounts.", React.createElement("br", null), "You can perform actions on reported accounts by clicking their name in the report, or searching for a username below."), React.createElement(AccountSearchForm, null));
}
function AccountSearchForm() {
  const [searchAccount, result] = query.useSearchAccountMutation();
  const [onAccountChange, _resetAccount, {
    account
  }] = useTextInput("account");
  function submitSearch(e) {
    e.preventDefault();
    if (account.trim().length != 0) {
      searchAccount(account);
    }
  }
  return React.createElement("div", {
    className: "account-search"
  }, React.createElement("form", {
    onSubmit: submitSearch
  }, React.createElement("div", {
    className: "form-field text"
  }, React.createElement("label", {
    htmlFor: "url"
  }, "Account:"), React.createElement("div", {
    className: "row"
  }, React.createElement("input", {
    type: "text",
    id: "account",
    name: "account",
    onChange: onAccountChange,
    value: account
  }), React.createElement("button", {
    disabled: result.isLoading
  }, React.createElement("i", {
    className: ["fa fa-fw", result.isLoading ? "fa-refresh fa-spin" : "fa-search"].join(" "),
    "aria-hidden": "true",
    title: "Search"
  }), React.createElement("span", {
    className: "sr-only"
  }, "Search"))))), React.createElement(AccountList, {
    isSuccess: result.isSuccess,
    data: result.data,
    isError: result.isError,
    error: result.error
  }));
}
function AccountList(_ref3) {
  let {
    isSuccess,
    data,
    isError,
    error
  } = _ref3;
  const baseUrl = useBaseUrl();
  if (!(isSuccess || isError)) {
    return null;
  }
  if (error) {
    return React.createElement(Error, {
      error: error
    });
  }
  if (data.length == 0) {
    return React.createElement("b", null, "No accounts found that match your query");
  }
  return React.createElement(React.Fragment, null, React.createElement("h2", null, "Results:"), React.createElement("div", {
    className: "list"
  }, data.map(acc => {
    var _a;
    return React.createElement(Link, {
      key: acc.acct,
      className: "account entry",
      to: `${baseUrl}/${acc.id}`
    }, ((_a = acc.display_name) === null || _a === void 0 ? void 0 : _a.length) > 0 ? acc.display_name : acc.username, React.createElement("span", {
      id: "username"
    }, "(@", acc.acct, ")"));
  })));
}

},{"../../components/error":270,"../../lib/form":286,"../../lib/navigation/util":292,"../../lib/query":302,"./detail":239,"react":146,"wouter":234}],242:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
const ExpireRemote = require("./expireremote");
module.exports = function Keys() {
  return React.createElement(React.Fragment, null, React.createElement("h1", null, "Key Actions"), React.createElement(ExpireRemote, null));
};

},{"./expireremote":241,"react":146}],244:[function(require,module,exports){
"use strict";

/*
    GoToSocial
    Copyright (C) GoToSocial Authors admin@gotosocial.org
    SPDX-License-Identifier: AGPL-3.0-or-later

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
const React = require("react");
const Cleanup = require("./cleanup");
module.exports = function Media() {
  return React.createElement(React.Fragment, null, React.createElement("h1", null, "Media Actions"), React.createElement(Cleanup, null));
};

},{"./cleanup":243,"react":146}],253:[function(require,module,exports){
"use strict";const React=require("react"),{useRoute:useRoute,Link:Link,Redirect:Redirect}=require("wouter"),{useComboBoxInput:useComboBoxInput,useFileInput:useFileInput,useValue:useValue}=require("../../../lib/form"),{CategorySelect:CategorySelect}=require("../category-select"),useFormSubmit=require("../../../lib/form/submit").default,{useBaseUrl:useBaseUrl}=require("../../../lib/navigation/util"),FakeToot=require("../../../components/fake-toot"),FormWithData=require("../../../lib/form/form-with-data").default,Loading=require("../../../components/loading"),{FileInput:FileInput}=require("../../../components/form/inputs"),MutationButton=require("../../../components/form/mutation-button"),{Error:Error}=require("../../../components/error"),{useGetEmojiQuery:useGetEmojiQuery,useEditEmojiMutation:useEditEmojiMutation,useDeleteEmojiMutation:useDeleteEmojiMutation}=require("../../../lib/query/admin/custom-emoji");function EmojiDetailForm(e){let{data:t}=e;var r;const a=useBaseUrl(),o={id:useValue("id",t.id),category:useComboBoxInput("category",{source:t}),image:useFileInput("image",{withPreview:!0,maxSize:51200})},[i,l]=useFormSubmit(o,useEditEmojiMutation());React.useEffect((()=>{!o.category.hasChanged()||o.category.state.open||o.category.isNew||i()}),[o.category.hasChanged(),o.category.isNew,o.category.state.open]);const[u,c]=useDeleteEmojiMutation();return c.isSuccess?React.createElement(Redirect,{to:a}):React.createElement(React.Fragment,null,React.createElement("div",{className:"emoji-header"},React.createElement("img",{src:t.url,alt:t.shortcode,title:t.shortcode}),React.createElement("div",null,React.createElement("h2",null,t.shortcode),React.createElement(MutationButton,{label:"Delete",type:"button",onClick:()=>u(t.id),className:"danger",showError:!1,result:c}))),React.createElement("form",{onSubmit:i,className:"left-border"},React.createElement("h2",null,"Modify this emoji ",l.isLoading&&React.createElement(Loading,null)),React.createElement("div",{className:"update-category"},React.createElement(CategorySelect,{field:o.category},React.createElement(MutationButton,{name:"create-category",label:"Create",result:l,showError:!1,style:{visibility:o.category.isNew?"initial":"hidden"}}))),React.createElement("div",{className:"update-image"},React.createElement(FileInput,{field:o.image,label:"Image",accept:"image/png,image/gif"}),React.createElement(MutationButton,{name:"image",label:"Replace image",showError:!1,result:l}),React.createElement(FakeToot,null,"Look at this new custom emoji ",React.createElement("img",{className:"emoji",src:null!==(r=o.image.previewURL)&&void 0!==r?r:t.url,title:`:${t.shortcode}:`,alt:t.shortcode})," isn't it cool?"),l.error&&React.createElement(Error,{error:l.error}),c.error&&React.createElement(Error,{error:c.error}))))}module.exports=function(e){let{}=e;const t=useBaseUrl();let[r,a]=useRoute(`${t}/:emojiId`);return null==(null==a?void 0:a.emojiId)?React.createElement(Redirect,{to:t}):React.createElement("div",{className:"emoji-detail"},React.createElement(Link,{to:t},React.createElement("a",null,"< go back")),React.createElement(FormWithData,{dataQuery:useGetEmojiQuery,queryArg:a.emojiId,DataForm:EmojiDetailForm}))};

},{"../../../components/error":270,"../../../components/fake-toot":272,"../../../components/form/inputs":273,"../../../components/form/mutation-button":274,"../../../components/loading":276,"../../../lib/form":286,"../../../lib/form/form-with-data":284,"../../../lib/form/submit":288,"../../../lib/navigation/util":292,"../../../lib/query/admin/custom-emoji":293,"../category-select":252,"react":146,"wouter":234}],255:[function(require,module,exports){
"use strict";const React=require("react"),{useFileInput:useFileInput,useComboBoxInput:useComboBoxInput}=require("../../../lib/form"),useShortcode=require("./use-shortcode"),useFormSubmit=require("../../../lib/form/submit").default,{TextInput:TextInput,FileInput:FileInput}=require("../../../components/form/inputs"),{CategorySelect:CategorySelect}=require("../category-select"),FakeToot=require("../../../components/fake-toot"),MutationButton=require("../../../components/form/mutation-button"),{useAddEmojiMutation:useAddEmojiMutation}=require("../../../lib/query/admin/custom-emoji"),{useInstanceV1Query:useInstanceV1Query}=require("../../../lib/query");module.exports=function(){const e=useShortcode(),{data:t}=useInstanceV1Query(),u=React.useMemo((()=>{var e,u,o;return null!==(o=null===(u=null===(e=null==t?void 0:t.configuration)||void 0===e?void 0:e.emojis)||void 0===u?void 0:u.emoji_size_limit)&&void 0!==o?o:51200}),[t]),o=useFileInput("image",{withPreview:!0,maxSize:u}),i=useComboBoxInput("category"),[a,l]=useFormSubmit({shortcode:e,image:o,category:i},useAddEmojiMutation());React.useEffect((()=>{if(0==e.value.length&&null!=o.value){let[t,u]=o.value.name.split(".");e.setter(t)}}),[o.value]);let n=`:${e.value}:`;return null!=o.previewValue&&(n=React.createElement("img",{className:"emoji",src:o.previewValue,title:`:${e.value}:`,alt:e.value})),React.createElement("div",null,React.createElement("h2",null,"Add new custom emoji"),React.createElement(FakeToot,null,"Look at this new custom emoji ",n," isn't it cool?"),React.createElement("form",{onSubmit:a,className:"form-flex"},React.createElement(FileInput,{field:o,accept:"image/png,image/gif"}),React.createElement(TextInput,{field:e,label:"Shortcode, must be unique among the instance's local emoji"}),React.createElement(CategorySelect,{field:i}),React.createElement(MutationButton,{label:"Upload emoji",result:l})))};

},{"../../../components/fake-toot":272,"../../../components/form/inputs":273,"../../../components/form/mutation-button":274,"../../../lib/form":286,"../../../lib/form/submit":288,"../../../lib/query":302,"../../../lib/query/admin/custom-emoji":293,"../category-select":252,"./use-shortcode":257,"react":146}],256:[function(require,module,exports){
"use strict";const React=require("react"),{Link:Link}=require("wouter"),syncpipe=require("syncpipe"),{matchSorter:matchSorter}=require("match-sorter"),NewEmojiForm=require("./new-emoji"),{useTextInput:useTextInput}=require("../../../lib/form"),{useEmojiByCategory:useEmojiByCategory}=require("../category-select"),{useBaseUrl:useBaseUrl}=require("../../../lib/navigation/util"),Loading=require("../../../components/loading"),{Error:Error}=require("../../../components/error"),{TextInput:TextInput}=require("../../../components/form/inputs"),{useListEmojiQuery:useListEmojiQuery}=require("../../../lib/query/admin/custom-emoji");function EmojiList(e){let{emoji:t}=e;const r=useTextInput("filter"),a=r.value,o=useEmojiByCategory(t),{filteredEmoji:n,hidden:l}=React.useMemo((()=>{let e=t.length;return{filteredEmoji:syncpipe(o,[e=>Object.entries(o),t=>t.map((t=>{let[r,o]=t,n=matchSorter(o,a,{keys:["shortcode"]});return 0==n.length?null:(e-=n.length,[r,n])})),e=>e.filter((e=>null!==e))]),hidden:e}}),[a,o,t.length]);return React.createElement("div",null,React.createElement("h2",null,"Overview"),t.length>0?React.createElement("span",null,t.length," custom emoji ",l>0&&`(${l} filtered)`):React.createElement("span",null,"No custom emoji yet, you can add one below."),React.createElement("div",{className:"list emoji-list"},React.createElement("div",{className:"header"},React.createElement(TextInput,{field:r,name:"emoji-shortcode",placeholder:"Search"})),React.createElement("div",{className:"entries scrolling"},n.length>0?React.createElement("div",{className:"entries scrolling"},n.map((e=>{let[t,r]=e;return React.createElement(EmojiCategory,{key:t,category:t,entries:r})}))):React.createElement("div",{className:"entry"},"No local emoji matched your filter."))))}function EmojiCategory(e){let{category:t,entries:r}=e;const a=useBaseUrl();return React.createElement("div",{className:"entry"},React.createElement("b",null,t),React.createElement("div",{className:"emoji-group"},r.map((e=>React.createElement(Link,{key:e.id,to:`${a}/${e.id}`},React.createElement("a",null,React.createElement("img",{src:e.url,alt:e.shortcode,title:`:${e.shortcode}:`})))))))}module.exports=function(e){let{}=e;const{data:t=[],isLoading:r,isError:a,error:o}=useListEmojiQuery({filter:"domain:local"});let n=null;return n=r?React.createElement(Loading,null):a?React.createElement(Error,{error:o}):React.createElement(React.Fragment,null,React.createElement(EmojiList,{emoji:t}),React.createElement(NewEmojiForm,{emoji:t})),React.createElement(React.Fragment,null,React.createElement("h1",null,"Local Custom Emoji"),React.createElement("p",null,"To use custom emoji in your toots they have to be 'local' to the instance. You can either upload them here directly, or copy from those already present on other (known) instances through the ",React.createElement(Link,{to:"./remote"},"Remote Emoji")," page."),n)};

},{"../../../components/error":270,"../../../components/form/inputs":273,"../../../components/loading":276,"../../../lib/form":286,"../../../lib/navigation/util":292,"../../../lib/query/admin/custom-emoji":293,"../category-select":252,"./new-emoji":255,"match-sorter":97,"react":146,"syncpipe":177,"wouter":234}],254:[function(require,module,exports){
"use strict";const React=require("react"),{Switch:Switch,Route:Route}=require("wouter"),EmojiOverview=require("./overview"),EmojiDetail=require("./detail");module.exports=function(e){let{baseUrl:t}=e;return React.createElement(Switch,null,React.createElement(Route,{path:`${t}/:emojiId`},React.createElement(EmojiDetail,null)),React.createElement(EmojiOverview,null))};

},{"./detail":253,"./overview":256,"react":146,"wouter":234}],316:[function(require,module,exports){
"use strict";const React=require("react"),ReactDom=require("react-dom/client"),{Provider:Provider}=require("react-redux"),{PersistGate:PersistGate}=require("redux-persist/integration/react"),{store:store,persistor:persistor}=require("./redux/store"),{createNavigation:createNavigation,Menu:Menu,Item:Item}=require("./lib/navigation"),{Authorization:Authorization}=require("./components/authorization"),Loading=require("./components/loading"),UserLogoutCard=require("./components/user-logout-card"),{RoleContext:RoleContext}=require("./lib/navigation/util"),DomainPerms=require("./admin/domain-permissions").default,DomainPermsImportExport=require("./admin/domain-permissions/import-export").default;require("./style.css");const{Sidebar:Sidebar,ViewRouter:ViewRouter}=createNavigation("/settings",[Menu("User",[Item("Profile",{icon:"fa-user"},require("./user/profile")),Item("Settings",{icon:"fa-cogs"},require("./user/settings"))]),Menu("Moderation",{url:"admin",permissions:["admin"]},[Item("Reports",{icon:"fa-flag",wildcard:!0},require("./admin/reports")),Item("Accounts",{icon:"fa-users",wildcard:!0},require("./admin/accounts")),Menu("Domain Permissions",{icon:"fa-hubzilla"},[Item("Blocks",{icon:"fa-close",url:"block",wildcard:!0},DomainPerms),Item("Allows",{icon:"fa-check",url:"allow",wildcard:!0},DomainPerms),Item("Import/Export",{icon:"fa-floppy-o",url:"import-export",wildcard:!0},DomainPermsImportExport)])]),Menu("Administration",{url:"admin",defaultUrl:"/settings/admin/settings",permissions:["admin"]},[Menu("Actions",{icon:"fa-bolt"},[Item("Media",{icon:"fa-photo"},require("./admin/actions/media")),Item("Keys",{icon:"fa-key-modern"},require("./admin/actions/keys"))]),Menu("Custom Emoji",{icon:"fa-smile-o"},[Item("Local",{icon:"fa-home",wildcard:!0},require("./admin/emoji/local")),Item("Remote",{icon:"fa-cloud"},require("./admin/emoji/remote"))]),Menu("Settings",{icon:"fa-sliders"},[Item("Settings",{icon:"fa-sliders",url:""},require("./admin/settings")),Item("Rules",{icon:"fa-dot-circle-o",wildcard:!0},require("./admin/settings/rules"))])])]);function App(e){let{account:t}=e;const r=[t.role.name];return React.createElement(RoleContext.Provider,{value:r},React.createElement("div",{className:"sidebar"},React.createElement(UserLogoutCard,null),React.createElement(Sidebar,null)),React.createElement("section",{className:"with-sidebar"},React.createElement(ViewRouter,null)))}function Main(){return React.createElement(Provider,{store:store},React.createElement(PersistGate,{loading:React.createElement("section",null,React.createElement(Loading,null)),persistor:persistor},React.createElement(Authorization,{App:App})))}const root=ReactDom.createRoot(document.getElementById("root"));root.render(React.createElement(React.StrictMode,null,React.createElement(Main,null)));

},{"./admin/accounts":240,"./admin/actions/keys":242,"./admin/actions/media":244,"./admin/domain-permissions":249,"./admin/domain-permissions/import-export":248,"./admin/emoji/local":254,"./admin/emoji/remote":258,"./admin/reports":261,"./admin/settings":263,"./admin/settings/rules":264,"./components/authorization":265,"./components/loading":276,"./components/user-logout-card":277,"./lib/navigation":291,"./lib/navigation/util":292,"./redux/store":312,"./style.css":313,"./user/profile":314,"./user/settings":315,"react":146,"react-dom/client":109,"react-redux":129,"redux-persist/integration/react":154}],86:[function(require,module,exports){
"use strict";null;

},{"insert-css":90}]},{},[316]);
